@@ -44,14 +44,15 @@
 
 #include <glib.h>
 
+#include "abinit.h"
+
 #include <config.h>
-#include <ab6_invars.h>
 #include <visu_tools.h>
 #include <visu_basic.h>
 #include <gtk_interactive.h>
 #include <openGLFunctions/interactive.h>
 #include <coreTools/toolMatrix.h>
-#include <coreTools/toolElements.h>
+#include <coreTools/toolPhysic.h>
 #include <renderingMethods/renderingAtomic.h>
 #include <renderingMethods/renderingSpin.h>
 
@@ -68,6 +69,8 @@
 #define ab6_error_string_from_id(A) #A
 #endif
 
+#define ABINIT_DT          "ABINIT_datasets"
+
 #define ABINIT_DESCRIPTION _("<span size=\"smaller\">"			\
 			     "This plug-in introduces support for\n"	\
 			     "crystallographic structures in\n"		\
@@ -75,31 +78,30 @@
 #define ABINIT_AUTHORS     "Caliste Damien"
 
 /* Local methods */
-static RenderingFormatLoad* abStructuralInit();
-static RenderingFormatLoad* abSpinInit();
+static void abStructuralInit(VisuRendering *method);
+static void abSpinInit(VisuRendering *method);
 static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
-			     FileFormat *format, int nSet, GError **error);
+			     ToolFileFormat *format, int nSet, GError **error);
 static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
-			       FileFormat *format, int nSet, GError **error);
+			       ToolFileFormat *format, int nSet, GError **error);
 static gpointer parseAbinitThread(gpointer data);
 static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet);
+static gboolean waitDt(gpointer data);
+static void freeDt(gpointer dt);
+
 /* Local variables */
 static gchar *iconPath;
 
 /* Required methods for a loadable module. */
 gboolean abinitInit()
 {
-  RenderingFormatLoad* meth, *spin;
-
   DBG_fprintf(stderr, "Abinit: loading plug-in 'abinit'...\n");
 
   DBG_fprintf(stderr, "Abinit: declare a new rendering load method.\n");
-  meth = abStructuralInit();
-  renderingAtomicAdd_loadMethod(meth);
+  abStructuralInit(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME));
 
   DBG_fprintf(stderr, "Abinit: declare a new spin load method.\n");
-  spin = abSpinInit();
-  rspin_addLoadMethod(spin);
+  abSpinInit(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME));
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "abinit.png", NULL);
 
@@ -131,58 +133,300 @@ const char* abinitGet_icon()
   return iconPath;
 }
 
-static RenderingFormatLoad* abStructuralInit()
+static void abStructuralInit(VisuRendering *method)
 {
   char *type[] = {"*.in", (char*)0};
-  char *descr = _("ABINIT input file format");
-  RenderingFormatLoad *meth;
   
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = "ABINIT input file format";
-  meth->fmt = fileFormatNew(descr, type);
-  if (!meth->fmt)
-    {
-      g_error("Can't initialize the ABINIT loading method, aborting...\n");
-    }
-  meth->priority = 90;
-  meth->load = loadAbinitIn;
-
-  return meth;
+  visu_rendering_addFileFormat(method, 0,
+                               tool_file_format_new(_("ABINIT input file format"),
+                                                    type),
+                               95, loadAbinitIn, (GDestroyNotify)0);
 }
 
-static Ab6Invars *dt;
+static GMutex *dt_mutex = (GMutex*)0;
+void abinit_mutexInit()
+{
+  if (!dt_mutex)
+    dt_mutex = g_mutex_new();
+}
+void abinit_mutexRelease()
+{
+  if (dt_mutex)
+    {
+      g_mutex_free(dt_mutex);
+      dt_mutex = (GMutex*)0;
+    }
+}
+void abinit_mutexUnlock()
+{
+  if (dt_mutex)
+    g_mutex_unlock(dt_mutex);
+}
+static AbinitData ABINIT_DATA;
+AbinitData* abinit_getDt()
+{
+  if (!g_mutex_trylock(dt_mutex))
+    return (AbinitData*)0;
+  else
+    return &ABINIT_DATA;
+}
+AbinitData* abinit_getDirectDt()
+{
+  return &ABINIT_DATA;
+}
 
 static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
-			     FileFormat *format _U_, int nSet, GError **error)
+			     ToolFileFormat *format _U_, int nSet, GError **error)
 {
 #ifdef G_THREADS_ENABLED
   GThread *ld_thread;
 #endif
+  AbinitData *dt;
+  Ab6Invars *dataset;
 
   g_return_val_if_fail(error && !*error, FALSE);
 
+  /* Try to see if data has already read this dataset. */
+  dataset = (Ab6Invars*)g_object_get_data(G_OBJECT(data), ABINIT_DT);
+  if (dataset)
+    {
+      *error = loadAbinit(data, dataset, nSet);
+      return TRUE;
+    }
+  
+  /* Read the file, since it's the first time. */
+  dt = abinit_getDirectDt();
+  dt->dt          = (Ab6Invars*)0;
+  dt->filename    = filename;
+  dt->error       = (GError*)0;
+  dt->isABFormat  = FALSE;
+  dt->data        = data;
+  dt->nSet        = nSet;
+  dt->getMessages = TRUE;
+  dt->messages    = g_async_queue_new();
+  dt->useSignals  = TRUE;
+  dt->signals     = g_async_queue_new();
 #ifdef G_THREADS_ENABLED
-  DBG_fprintf(stderr, "AB structure: run ABINIT parsing into a thread.\n");
-  ld_thread = g_thread_create(parseAbinitThread, (gpointer)filename,
-			      TRUE, error);
+  abinit_mutexInit();
+  ld_thread = g_thread_create(parseAbinitThread, (gpointer)0, FALSE, error);
+  DBG_fprintf(stderr, "AB structure: run ABINIT parsing into a thread (%p) from me (%p).\n",
+              (gpointer)ld_thread, (gpointer)g_thread_self());
   if (ld_thread)
-    *error = (GError*)g_thread_join(ld_thread);
+    {
+      g_async_queue_pop(dt->signals);
+      DBG_fprintf(stderr, "AB structure: start waiting.\n");
+      g_idle_add_full(G_PRIORITY_LOW, waitDt, (gpointer)0, (GDestroyNotify)0);
+    }
   else
     g_warning("Can't run thread for ABINIT parsing.");
 #else
   DBG_fprintf(stderr, "AB structure: run ABINIT parsing directly.\n");
-  *error = (GError*)parseAbinitThread((gpointer)filename);
+  *error = (GError*)parseAbinitThread((gpointer)(&dt));
 #endif
 
-  if (*error && (*error)->code == RENDERING_ERROR_FILE)
-    return FALSE;
-  else if (*error)
-    return TRUE;
-  else
-    *error = loadAbinit(data, dt, nSet);
-  ab6_invars_free(dt);
+  while(g_main_context_pending(NULL))
+    g_main_context_dispatch(g_main_context_default());
+  
+  if (dt->error)
+    *error = dt->error;
 
-  return TRUE;
+  g_async_queue_unref(dt->signals);
+  g_async_queue_unref(dt->messages);
+  abinit_mutexRelease();
+
+  DBG_fprintf(stderr, "AB structure: file parsed, returns %d.\n", dt->isABFormat);
+  return dt->isABFormat;
+}
+
+static gpointer parseAbinitThread(gpointer data _U_)
+{
+  AbinitData *dt;
+  Ab6Invars *dt_;
+
+  DBG_fprintf(stderr, "AB(%p) main: get the dt structure.\n",
+              (gpointer)g_thread_self());
+  dt = abinit_getDt();
+  g_return_val_if_fail(dt, (gpointer)0);
+
+  /* Send a signal to V_Sim to say that parsing will start. */
+  g_async_queue_push(dt->signals, GINT_TO_POINTER(TRUE));
+
+  /* Read the file and store its contain as a string. */
+  DBG_fprintf(stderr, "AB(%p) main: read and store input file.\n",
+              (gpointer)g_thread_self());
+  dt_ = ab6_invars_new_from_file(dt->filename);
+
+  /* If we reach here, it means that no error happened. */
+  dt->dt = dt_;
+
+  abinit_mutexUnlock();
+
+  return (gpointer)0;
+}
+
+static gboolean waitDt(gpointer data _U_)
+{
+  AbinitData *dt;
+  gpointer mess;
+
+  dt = abinit_getDirectDt();
+
+  /* We stop on cancel, without error. */
+  if (visu_basic_getLoadCancel())
+    {
+      visu_basic_setLoadCancel(FALSE);
+      /* We push a message in the queue to be tested by ABINIT. */
+      g_async_queue_push(dt->signals, GINT_TO_POINTER(TRUE));
+      return TRUE;
+    }
+
+  mess = g_async_queue_try_pop(dt->messages);
+  if (mess)
+    {
+      visu_basic_setLoadMessage((const gchar*)mess);
+      g_free(mess);
+    }
+
+  /* DBG_fprintf(stderr, "AB structure: waiting...\n"); */
+  dt = abinit_getDt();
+  if (!dt)
+    return TRUE;
+
+  /* We empty the message queue, in case. */
+  DBG_fprintf(stderr, "AB structure: empty the queue.\n");
+  while (g_async_queue_length(dt->messages) > 0)
+    {
+      DBG_fprintf(stderr, " | emptying.\n");
+      g_free(g_async_queue_pop(dt->messages));
+    }
+
+  DBG_fprintf(stderr, "AB structure: stop waiting, analyse.\n");
+  dt->isABFormat = TRUE;
+  if (dt->error && dt->error->code == RENDERING_ERROR_FILE)
+    {
+      dt->isABFormat = FALSE;
+      g_error_free(dt->error);
+      dt->error = (GError*)0;
+      abinit_mutexUnlock();
+      return FALSE;
+    }
+  else if (dt->error)
+    {
+      abinit_mutexUnlock();
+      return FALSE;
+    }
+  else
+    {
+      dt->error = loadAbinit(dt->data, dt->dt, dt->nSet);
+      /* We attach this Abinit dataset to this VisuData. */
+      DBG_fprintf(stderr, "AB structure: add '%s' to VisuData %p.\n",
+                  ABINIT_DT, (gpointer)dt->data);
+      g_object_set_data_full(G_OBJECT(dt->data), ABINIT_DT, (gpointer)dt->dt, freeDt);
+    }
+
+  abinit_mutexUnlock();
+
+  return FALSE;
+}
+
+static void freeDt(gpointer dt)
+{
+  DBG_fprintf(stderr, "AB structure: release ABINIT resources.\n");
+  ab6_invars_free((Ab6Invars*)dt);
+}
+
+void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
+{
+  gchar *buf, *ptError, *ptInvars0, *ptInstrng, *ptSize, *ptLen, *ptMinus;
+  AbinitData *dt;
+
+  dt = abinit_getDirectDt();
+  g_return_if_fail(dt);
+
+#ifdef G_THREADS_ENABLED
+  if (dt->useSignals && g_async_queue_try_pop(dt->signals))
+    {
+      dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_CANCEL,
+                              "Loading process cancelled.");
+      abinit_mutexUnlock();
+      g_thread_exit((gpointer)0);
+    }
+#endif
+
+  buf = g_strndup(message, 500);
+  g_strstrip(buf);
+  DBG_fprintf(stderr, "AB(%p) main: wrtout(%d %c%c%c%c) %s\n", (gpointer)g_thread_self(),
+	      *unit, mode_paral[0], mode_paral[1], mode_paral[2], mode_paral[3], buf);
+  /* We analyse buf. If, it contains an error, we test if it is
+     about natom in inarvs0. If so, the file is not a valid ABINIT
+     file. On the contrary, we get the message and raise an error. */
+  ptError = strstr(buf, "ERROR");
+  if (!ptError)
+    ptError = strstr(buf, "BUG");
+  ptInvars0 = strstr(buf, "Input natom must be defined");
+  ptInstrng = strstr(buf, "The occurence of a tab");
+  ptSize    = strstr(buf, "The size of your input file");
+  ptLen     = strstr(buf, "The number of lines already read from input file=");
+  ptMinus   = strstr(buf, "the occurence of a minus sign followed");
+  if (ptError && ptInvars0)
+    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                            "Not an ABINIT file (no 'natom' keyword found).");
+  else if (ptError && ptInstrng)
+    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                            "Not an ABINIT file (tab characters found in the file).");
+  else if (ptError && ptSize)
+    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                            "Not an ABINIT file (input file too long).");
+  else if (ptError && ptLen)
+    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                            "Not an ABINIT file (too many lines).");
+  else if (ptError && ptMinus)
+    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                            "Not an ABINIT file (minus space error).");
+  else if (ptError)
+    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT, "%s", buf);
+  else
+    dt->error = (GError*)0;
+
+  if (dt->getMessages && strstr(buf, "getkgrid"))
+    g_async_queue_push(dt->messages, buf);
+  else
+    g_free(buf);
+
+  if (dt->error)
+    {
+      DBG_fprintf(stderr, "AB(%p) main: an error occured in ABINIT.\n",
+                  (gpointer)g_thread_self());
+#ifdef G_THREADS_ENABLED
+      abinit_mutexUnlock();
+      g_thread_exit((gpointer)0);
+#else
+      g_error("ABINIT plug-in requires threads.");
+#endif
+    }
+}
+void FC_FUNC(leave_new, LEAVE_NEW)(char mode_paral[4])
+{
+  AbinitData *dt;
+
+  dt = abinit_getDirectDt();
+  g_return_if_fail(dt);
+
+  DBG_fprintf(stderr, "AB(%p) main: leave_new(%c%c%c%c)\n", (gpointer)g_thread_self(),
+	      mode_paral[0], mode_paral[1], mode_paral[2], mode_paral[3]);
+  dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                          "Not an ABINIT file");
+  DBG_fprintf(stderr, "AB(%p) main: return error (%p).\n",
+              (gpointer)g_thread_self(), (gpointer)dt->error);
+#ifdef G_THREADS_ENABLED
+  abinit_mutexUnlock();
+  g_thread_exit((gpointer)0);
+#else
+  g_error("ABINIT plug-in requires threads.");
+#endif
+}
+void FC_FUNC(timab, TIMAB)()
+{
 }
 
 static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
@@ -192,12 +436,15 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   int *typat;
   double *znucl, rprimd[3][3], *coord, *spinat;
   VisuElement **types, **ntypes;
-  float rcov, cart[3], red[3];
-  double  box[6];
+  float rcov, red[3];
   char *ptChar, *name;
   unsigned int *nattyp;
   Ab6Error error;
+  gboolean newEle;
 
+  g_return_val_if_fail(dt, (GError*)0);
+
+  DBG_fprintf(stderr, "AB structure: transfer data.\n");
   /* Ok, try to find the required keywords. */
   error = ab6_invars_get_ndtset(dt, &ndtset);
   if (error != AB6_NO_ERROR)
@@ -206,7 +453,7 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 		       (int)error);
   DBG_fprintf(stderr, "AB structure: found %d dtsets.\n", ndtset);
   /* Store the number of datasets. */
-  visuDataSet_nSet(data, ndtset);
+  visu_data_setNSubset(data, ndtset);
 
   g_return_val_if_fail(nSet >= 0 && nSet < ndtset,
 		       g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
@@ -256,18 +503,12 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   for (i = 0; i < ntypat; i++)
     {
       /* Try to find a name instead of a z number. */
-      toolElementsGet_element(&ptChar, &rcov, znucl[i]);
+      tool_physic_getElementFromZ(&ptChar, &rcov, znucl[i]);
       name = g_strdup(ptChar);
       /* adding name to the hashtable */
-      types[i] = visuElementGet_fromName(name);
-      if (!types[i])
-	{
-	  types[i] = visuElementNew_withName(name);
-	  g_return_val_if_fail(types[i], (gpointer)0);
-	  res = visuElementAdd(types[i]);
-	  g_return_val_if_fail(!res, (gpointer)0);
-	  renderingAtomicSet_radius(types[i], rcov);
-	}
+      types[i] = visu_element_retrieveFromName(name, &newEle);
+      if (newEle)
+        visu_renderingAtomic_setRadius(types[i], rcov);
       g_free(name);
     }
   g_free(znucl);
@@ -311,7 +552,7 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   if (DEBUG)
     for (i = 0; i < natom; i++)
       fprintf(stderr, " | atom %d of type %p.\n", i, (gpointer)ntypes[i]);
-  res = visuDataSet_population(data, ntypat, nattyp, types);
+  res = visu_data_setPopulation(data, ntypat, nattyp, types);
   if (!res)
     {
       g_error("Can't store the nodes in the VisuData object.");
@@ -335,8 +576,7 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 	      rprimd[1][0], rprimd[1][1], rprimd[1][2]);
   DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
 	      rprimd[2][0], rprimd[2][1], rprimd[2][2]);
-  g_return_val_if_fail(matrix_reducePrimitiveVectors(box, rprimd), (gpointer)0);
-  visuDataSet_boxGeometry(data, box, BOX_PERIODIC);
+  visu_data_setBoxGeometryFull(data, rprimd, VISU_DATA_BOX_PERIODIC);
   
   coord = g_malloc(sizeof(double) * 3 * natom);
   error = ab6_invars_get_real_array(dt, coord, 3 * natom,
@@ -357,20 +597,16 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
       red[2] = (float)*(coord + 3 * i + 2);
       DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
 		  red[0], red[1], red[2]);
-      /* Transform the reduced coordinates into cartesians. */
-      visuDataConvert_boxCoordinatestoXYZ(data, cart, red);
-      DBG_fprintf(stderr, " |               -> ( %f %f %f )\n",
-		  cart[0], cart[1], cart[2]);
-      visuDataAdd_nodeFromElement(data, ntypes[i], cart, FALSE);
+      visu_data_addNodeFromElement(data, ntypes[i], red, TRUE, FALSE);
     }
   /* We reset the box size after we set all the coordinates to get the
      OpenGL box right. */
-  visuDataApply_boxGeometry(data, 0.f);
+  visu_data_applyBoxGeometry(data);
   g_free(ntypes);
   g_free(coord);
 
   /* We set the units. */
-  visuDataSet_unit(data, unit_bohr);
+  visu_data_setUnit(data, unit_bohr);
 
   /* We store the spinat array as a property to be used later by the spin
      loading method. */
@@ -390,107 +626,14 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   return (GError*)0;
 }
 
-static gpointer parseAbinitThread(gpointer data)
-{
-  /* Read the file and store its contain as a string. */
-  DBG_fprintf(stderr, "AB(1) structure: read and store input file.\n");
-  dt = (Ab6Invars*)0;
-  dt = ab6_invars_new_from_file((gchar*)data);
-
-  return (gpointer)0;
-}
-
-void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
-{
-  gchar *buf, *ptError, *ptInvars0, *ptInstrng, *ptSize, *ptLen, *ptMinus;
-  GError *error;
-
-  buf = g_strndup(message, 500);
-  g_strstrip(buf);
-  DBG_fprintf(stderr, "AB(1) structure: (%d %c%c%c%c) %s\n",
-	      *unit, mode_paral[0], mode_paral[1], mode_paral[2], mode_paral[3], buf);
-  /* We analyse buf. If, it contains an error, we test if it is
-     about natom in inarvs0. If so, the file is not a valid ABINIT
-     file. On the contrary, we get the message and raise an error. */
-  ptError = strstr(buf, "ERROR");
-  ptInvars0 = strstr(buf, "Input natom must be defined");
-  ptInstrng = strstr(buf, "The occurence of a tab");
-  ptSize    = strstr(buf, "The size of your input file");
-  ptLen     = strstr(buf, "The number of lines already read from input file=");
-  ptMinus   = strstr(buf, "the occurence of a minus sign followed");
-  if (ptError && ptInvars0)
-    error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			"Not an ABINIT file (no 'natom' keyword found).");
-  else if (ptError && ptInstrng)
-    error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			"Not an ABINIT file (tab characters found in the file).");
-  else if (ptError && ptSize)
-    error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			"Not an ABINIT file (input file too long).");
-  else if (ptError && ptLen)
-    error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			"Not an ABINIT file (too many lines).");
-  else if (ptError && ptMinus)
-    error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			"Not an ABINIT file (minus space error).");
-  else if (ptError)
-    error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT, buf);
-  else
-    error = (GError*)0;
-
-  g_free(buf);
-
-  if (error)
-    {
-      DBG_fprintf(stderr, "AB(1) structure: an error occured while parsing.\n");
-      if (dt)
-	ab6_invars_free(dt);
-      dt = (Ab6Invars*)0;
-#ifdef G_THREADS_ENABLED
-      g_thread_exit((gpointer)error);
-#else
-      g_error("ABINIT plug-in requires threads.");
-#endif
-    }
-}
-void FC_FUNC(leave_new, LEAVE_NEW)(char mode_paral[4])
-{
-  GError *error;
-
-  DBG_fprintf(stderr, "AB(1) structure: leave_new(%c%c%c%c)\n",
-	      mode_paral[0], mode_paral[1], mode_paral[2], mode_paral[3]);
-  if (dt)
-    ab6_invars_free(dt);
-  dt = (Ab6Invars*)0;
-  error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-		      "Not an ABINIT file");
-#ifdef G_THREADS_ENABLED
-  g_thread_exit((gpointer)error);
-#else
-  g_error("ABINIT plug-in requires threads.");
-#endif
-}
-void FC_FUNC(timab, TIMAB)()
-{
-}
-
-static RenderingFormatLoad* abSpinInit()
+static void abSpinInit(VisuRendering *method)
 {
   char *type[] = {"*.in", (char*)0};
-  char *descr = _("ABINIT input file format");
-  RenderingFormatLoad *meth;
   
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = "ABINIT input file format";
-  meth->fmt = fileFormatNew(descr, type);
-  if (!meth->fmt)
-    {
-      g_error("Can't initialize the XSF loading method, aborting...\n");
-    }
-  meth->priority = 90;
-  meth->load = loadAbinitSpin;
-
-  return meth;
+  visu_rendering_addFileFormat(method, FILE_KIND_SPIN,
+                               tool_file_format_new(_("ABINIT input file format"),
+                                                    type),
+                               95, loadAbinitSpin, (GDestroyNotify)0);
 }
 
 static void freeSpin(gpointer obj, gpointer data _U_)
@@ -519,7 +662,7 @@ static gpointer newOrCopySpin(gconstpointer obj, gpointer data _U_)
 }
 
 static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
-			       FileFormat *format _U_, int nSet _U_, GError **error)
+			       ToolFileFormat *format _U_, int nSet _U_, GError **error)
 {
   double *spinat;
   float spins[3];
@@ -544,25 +687,25 @@ static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
   memset(svgMaxSpinModulus, 0, sizeof(float) * data->ntype);
   g_object_set_data_full(G_OBJECT(data), SPINMAXMODULUS_ID,
 			 (gpointer)svgMaxSpinModulus, g_free);
-  spin = visuNodeNew_pointerProperty(visuDataGet_nodeArray(data), SPINVALUES_ID,
+  spin = visu_node_property_newPointer(visu_data_getNodeArray(data), SPINVALUES_ID,
 				     freeSpin, newOrCopySpin, (gpointer)0);
 
   g_value_init(&spinValue, G_TYPE_POINTER);
-  visuDataIter_new(data, &iter);
-  for(visuDataIter_startNumber(data, &iter); iter.node;
-      visuDataIter_nextNodeNumber(data, &iter))
+  visu_data_iterNew(data, &iter);
+  for(visu_data_iterStartNumber(data, &iter); iter.node;
+      visu_data_iterNextNodeNumber(data, &iter))
     {
       spins[0] = (float)(spinat + iter.node->number * 3)[0];
       spins[1] = (float)(spinat + iter.node->number * 3)[1];
       spins[2] = (float)(spinat + iter.node->number * 3)[2];
-      matrix_cartesianToSpherical(sph, spins);
-      vals[SPIN_MODULUS] = sph[0];
-      vals[SPIN_THETA]   = sph[1];
-      vals[SPIN_PHI]     = sph[2];
+      tool_matrix_cartesianToSpherical(sph, spins);
+      vals[TOOL_MATRIX_SPHERICAL_MODULUS] = sph[0];
+      vals[TOOL_MATRIX_SPHERICAL_THETA]   = sph[1];
+      vals[TOOL_MATRIX_SPHERICAL_PHI]     = sph[2];
       svgSpinValues = newOrCopySpin(vals, (gpointer)0);
       g_value_set_pointer(&spinValue, svgSpinValues);
-      visuNodePropertySet_value(spin, iter.node, &spinValue);
-      svgMaxSpinModulus[iter.iElement] = MAX(vals[SPIN_MODULUS],
+      visu_node_property_setValue(spin, iter.node, &spinValue);
+      svgMaxSpinModulus[iter.iElement] = MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
 					     svgMaxSpinModulus[iter.iElement]);
     }
 
