@@ -44,7 +44,7 @@
 #include <visu_data.h>
 #include <renderingMethods/renderingAtomic_ascii.h>
 #include <coreTools/toolMatrix.h>
-#include <coreTools/toolElements.h>
+#include <coreTools/toolPhysic.h>
 #include <extraFunctions/scalarFields.h>
 
 #define CUBE_DESCRIPTION _("<span size=\"smaller\">"			\
@@ -63,9 +63,8 @@ struct cube_reader
   const gchar  *filename;
   GString      *line;
   gchar        *comment;
-  double        box[6];
+  double        box[3][3];
   float         shift[3];
-  float         rot[3][3];
   int           ntype, natom;
   GHashTable   *elements;
   VisuElement **nodeTypes;
@@ -77,11 +76,11 @@ struct cube_reader
 };
 
 static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
-			       FileFormat *format, int nSet, GError **error);
+			       ToolFileFormat *format, int nSet, GError **error);
 static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
-				GError **error, OptionTable *table _U_);
+				GError **error, GHashTable *table);
 /* static gboolean xvAtomicLoad(VisuData *data, const gchar* filename, */
-/* 			     FileFormat *format, int nSet, GError **error); */
+/* 			     ToolFileFormat *format, int nSet, GError **error); */
 
 /* Local variables */
 static gchar *iconPath;
@@ -90,33 +89,27 @@ gboolean cubeInit()
 {
   char *typeCube[] = {"*.cube", "*.cub", (char*)0};
   char *nameCube   = "Cube format (from Gaussian)";
-  char *descrCube  = _("Gaussian structural/volumetric format");
-  RenderingFormatLoad *meth;
 /*   char *typeXV[] = {"*.XV", "*.STRUCT_OUT", (char*)0}; */
 /*   char *nameXV   = "Siesta output format"; */
 /*   char *descrXV  = _("Siesta geometric output format"); */
-  FileFormat *fmt;
+  ToolFileFormat *fmt;
 
-  fmt = fileFormatNew(descrCube, typeCube);
-
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = nameCube;
-  meth->fmt = fmt;
-  meth->priority = 60;
-  meth->load = cubeAtomicLoad;
-  renderingAtomicAdd_loadMethod(meth);
+  fmt = tool_file_format_new(_("Gaussian structural/volumetric format"),
+                             typeCube);
+  visu_rendering_addFileFormat(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME), 0,
+                               fmt, 60, cubeAtomicLoad, (GDestroyNotify)0);
 
   scalarFieldAdd_loadMethod(nameCube, cubeDensityLoad,
 			    fmt, G_PRIORITY_HIGH - 5);
 
-/*   fmt = fileFormatNew(descrXV, typeXV); */
+/*   fmt = tool_file_format_new(descrXV, typeXV); */
 
-/*   meth = g_malloc(sizeof(RenderingFormatLoad)); */
+/*   meth = g_malloc(sizeof(VisuRenderingFormatLoad)); */
 /*   meth->name = nameXV; */
 /*   meth->fmt = fmt; */
 /*   meth->priority = 61; */
 /*   meth->load = xvAtomicLoad; */
-/*   renderingAtomicAdd_loadMethod(meth); */
+/*   visu_renderingAtomic_addLoadMethod(meth); */
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "cube.png", NULL);
 
@@ -161,10 +154,7 @@ static void reader_free(struct cube_reader *rd)
 static gboolean read_line(struct cube_reader *rd, GError **error)
 {
   rd->status = g_io_channel_read_line_string(rd->flux, rd->line, NULL, error);
-  if (rd->status != G_IO_STATUS_NORMAL)
-    return FALSE;
-  g_strstrip(rd->line->str);
-  return TRUE;
+  return (rd->status == G_IO_STATUS_NORMAL);
 }
 
 static gboolean read_comment(struct cube_reader *rd, GError **error)
@@ -176,6 +166,7 @@ static gboolean read_comment(struct cube_reader *rd, GError **error)
 			   _("Wrong Cube format, missing comment lines.\n"));
       return FALSE;
     }
+  g_strstrip(rd->line->str);
   rd->comment = g_strdup(rd->line->str);
   if (!read_line(rd, error))
     {
@@ -183,6 +174,7 @@ static gboolean read_comment(struct cube_reader *rd, GError **error)
 			   _("Wrong Cube format, missing comment lines.\n"));
       return FALSE;
     }
+  g_strstrip(rd->line->str);
   g_string_prepend(rd->line, " ");
   g_string_prepend(rd->line, rd->comment);
   g_free(rd->comment);
@@ -209,13 +201,13 @@ static gboolean read_natom(struct cube_reader *rd, GError **error)
       return FALSE;
     }
   rd->natom = ABS(rd->natom);
+  DBG_fprintf(stderr, "Cube: number of atoms %d.\n", rd->natom);
   return TRUE;
 }
 
 static gboolean read_box(struct cube_reader *rd, GError **error)
 {
   int i;
-  double cart[3][3];
   gchar dir[3] = "XYZ";
 
   /* Read the box definition. */
@@ -229,7 +221,7 @@ static gboolean read_box(struct cube_reader *rd, GError **error)
 	  return FALSE;
 	}
       if (sscanf(rd->line->str, "%d %lf %lf %lf\n",
-		 rd->mesh + i, cart[i], cart[i] + 1, cart[i] + 2) != 4)
+		 rd->mesh + i, rd->box[i], rd->box[i] + 1, rd->box[i] + 2) != 4)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong Cube format, missing float values"
@@ -243,38 +235,26 @@ static gboolean read_box(struct cube_reader *rd, GError **error)
 				 " size in %c direction.\n"), dir[i]);
 	  return FALSE;
 	}
-      cart[i][0] *= rd->mesh[i];
-      cart[i][1] *= rd->mesh[i];
-      cart[i][2] *= rd->mesh[i];
+      rd->box[i][0] *= rd->mesh[i];
+      rd->box[i][1] *= rd->mesh[i];
+      rd->box[i][2] *= rd->mesh[i];
     }
   DBG_fprintf(stderr, "Cube: read box %8g %8g %8g\n"
-	      "              %8g %8g %8g\n"
-	      "              %8g %8g %8g\n",
-	      cart[0][0], cart[0][1], cart[0][2],
-	      cart[1][0], cart[1][1], cart[1][2],
-	      cart[2][0], cart[2][1], cart[2][2]);
-  if (!matrix_reducePrimitiveVectors(rd->box, cart))
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Wrong Cube format, primitive vectors are not 3D.\n"));
-      return FALSE;
-    }
-  if (!matrix_fromFullToBoxCartesian(rd->rot, cart, rd->box))
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Wrong Cube format, cannot invert primitive vectors.\n"));
-      return FALSE;
-    }
+	      "               %8g %8g %8g\n"
+	      "               %8g %8g %8g\n",
+	      rd->box[0][0], rd->box[0][1], rd->box[0][2],
+	      rd->box[1][0], rd->box[1][1], rd->box[1][2],
+	      rd->box[2][0], rd->box[2][1], rd->box[2][2]);
   return TRUE;
 }
 
 static gboolean read_coords(struct cube_reader *rd, GError **error)
 {
   int i, zele, nb;
-  float rcov, trash, coord[3];
+  float rcov, trash;
   gchar *name, *ptChar;
   VisuElement *type;
-  struct dataAscii *infos;
+  struct VisuMethAscii *infos;
   gboolean new;
 
   rd->ntype     = 0;
@@ -293,32 +273,37 @@ static gboolean read_coords(struct cube_reader *rd, GError **error)
 	  return FALSE;
 	}
       nb = sscanf(rd->line->str, "%d %f %f %f %f\n", &zele, &trash,
-		  coord, coord + 1, coord + 2);
+		  rd->coords + 3 * i, rd->coords + 3 * i + 1, rd->coords + 3 * i + 2);
       if (nb != 5)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong Cube format, can't read coordinates.\n"));
 	  return FALSE;
 	}
-      coord[0] -= rd->shift[0];
-      coord[1] -= rd->shift[1];
-      coord[2] -= rd->shift[2];
-      matrix_productVector(rd->coords + 3 * i, rd->rot, coord);
+      rd->coords[3 * i + 0] -= rd->shift[0];
+      rd->coords[3 * i + 1] -= rd->shift[1];
+      rd->coords[3 * i + 2] -= rd->shift[2];
       /* Try to find a z number instead of a name. */
       rcov = -1.f;
-      toolElementsGet_element(&ptChar, &rcov, zele);
+      if (!tool_physic_getElementFromZ(&ptChar, &rcov, zele))
+        {
+	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+			       _("Wrong Cube format, one atomic number is 0 or lower,"
+                                 " or greater than 103, check your input file.\n"));
+	  return FALSE;
+        }
       name = g_strdup(ptChar);
       /* adding nomloc to the hashtable */
-      type = visuElementRetrieve_fromName(name, &new);
+      type = visu_element_retrieveFromName(name, &new);
       if (new && rcov > 0.f)
-	renderingAtomicSet_radius(type, rcov * 0.52917720859);
+	visu_renderingAtomic_setRadius(type, rcov * 0.52917720859);
       g_return_val_if_fail(type, FALSE);
       rd->nodeTypes[i] = type;
-      infos = (struct dataAscii*)g_hash_table_lookup(rd->elements,
+      infos = (struct VisuMethAscii*)g_hash_table_lookup(rd->elements,
 						     (gconstpointer)type);
       if (!infos)
 	{
-	  infos = g_malloc(sizeof(struct dataAscii));
+	  infos = g_malloc(sizeof(struct VisuMethAscii));
 	  infos->ele = type;
 	  infos->pos = rd->ntype;
 	  infos->nbNodes = 1;
@@ -334,45 +319,55 @@ static gboolean read_coords(struct cube_reader *rd, GError **error)
 
 static gboolean read_density(struct cube_reader *rd, GError **error)
 {
-  int i, j;
+  int i, j, n;
   gchar **tokens;
+#if DEBUG == 1
+  GTimer *timer;
+  gulong fractionTimer;
+#endif
 
-  rd->density = g_malloc(sizeof(double) * rd->mesh[0] * rd->mesh[1] * rd->mesh[2]);
+#if DEBUG == 1
+  timer = g_timer_new();
+  g_timer_start(timer);
+#endif
 
+  n = rd->mesh[0] * rd->mesh[1] * rd->mesh[2];
+  rd->density = g_malloc(sizeof(double) * n);
+
+  DBG_fprintf(stderr, "Cube: read density (%gMo).\n",
+              sizeof(double) * n / 1024. / 1024.);
   i = 0;
   do
     {
       if (!read_line(rd, error))
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			       _("Wrong Cube format, missing density lines.\n"));
+	        	       _("Wrong Cube format, missing density lines.\n"));
 	  return FALSE;
 	}
-      if (i > 0 || strchr(rd->line->str, '.'))
-	{
-	  tokens = g_strsplit(rd->line->str, " ", 0);
-	  for (j = 0; tokens[j] && i < rd->mesh[0] * rd->mesh[1] * rd->mesh[2]; j++)
-	    {
-	      g_strstrip(tokens[j]);
-	      if (tokens[j][0])
-		{
-		  if (sscanf(tokens[j], "%lf", rd->density + i) != 1)
-		    {
-		      *error = g_error_new(VISU_ERROR_RENDERING,
-					   RENDERING_ERROR_FORMAT,
-					   _("Wrong Cube format, missing float value"
-					     " %d for density.\n"), i);
-		      g_strfreev(tokens);
-		      return FALSE;
-		    }
-		  i += 1;
-		}
-	    }
-	  g_strfreev(tokens);
-	}
+      tokens = g_strsplit(rd->line->str, " ", 0);
+      for (j = 0; tokens[j] && i < n; j++)
+        if (tokens[j][0])
+          {
+            if (sscanf(tokens[j], "%lf", rd->density + i) != 1)
+              {
+                *error = g_error_new(VISU_ERROR_RENDERING,
+                                     RENDERING_ERROR_FORMAT,
+                                     _("Wrong Cube format, unreadable float value"
+                                       " %d for density.\n"), i);
+                g_strfreev(tokens);
+                return FALSE;
+              }
+            i += 1;
+          }
+      g_strfreev(tokens);
     }
-  while(i < rd->mesh[0] * rd->mesh[1] * rd->mesh[2] &&
-	rd->status == G_IO_STATUS_NORMAL);
+  while(i < n && rd->status == G_IO_STATUS_NORMAL);
+#if DEBUG == 1
+  g_timer_stop(timer);
+  fprintf(stderr, "Cube: density parsed in %g milli-s.\n", g_timer_elapsed(timer, &fractionTimer)/1e-3);
+  g_timer_destroy(timer);
+#endif
   if (rd->status != G_IO_STATUS_NORMAL)
     {
       *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
@@ -424,7 +419,7 @@ static int read_cube_file(struct cube_reader *rd, GError **error,
 }
 
 static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
-			       FileFormat *format _U_, int nSet _U_, GError **error)
+			       ToolFileFormat *format _U_, int nSet _U_, GError **error)
 {
   int res, iNodes, i;
   struct cube_reader rd;
@@ -447,14 +442,14 @@ static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
       /* Allocate the space for the nodes. */
       types  = g_malloc(sizeof(VisuElement*) * rd.ntype);
       nattyp = g_malloc(sizeof(int) * rd.ntype);
-      g_hash_table_foreach(rd.elements, (GHFunc)putValTypeInAsciiType, (gpointer)&types);
-      g_hash_table_foreach(rd.elements, (GHFunc)putValNbInAsciiType, (gpointer)&nattyp);
+      g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
+      g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
 
       DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
       /* Begin the storage into VisuData. */
-      visuDataSet_nSet(data, 1);
+      visu_data_setNSubset(data, 1);
 
-      res = visuDataSet_population(data, rd.ntype, nattyp, types);
+      res = visu_data_setPopulation(data, rd.ntype, nattyp, types);
       if (!res)
 	{
 	  g_error("Can't store the nodes in the VisuData object.");
@@ -467,12 +462,12 @@ static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
       g_free(types);
          
       /* Store the coordinates */
+      visu_data_setBoxGeometryFull(data, rd.box, VISU_DATA_BOX_PERIODIC);
       for(iNodes = 0; iNodes < rd.natom; iNodes++)
-	visuDataAdd_nodeFromElement(data, rd.nodeTypes[iNodes],
-				    rd.coords + 3 * iNodes, FALSE);
-      visuDataSet_boxGeometry(data, rd.box, BOX_PERIODIC);
-      visuDataApply_boxGeometry(data, 0.f);
-      visuDataSet_fileCommentary(data, rd.comment, 0);
+	visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
+                                     rd.coords + 3 * iNodes, FALSE, FALSE);
+      visu_data_applyBoxGeometry(data);
+      visu_data_setFileCommentary(data, rd.comment, 0);
 
       flag = g_malloc(sizeof(gboolean));
       *flag = TRUE;
@@ -495,7 +490,7 @@ static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
 }
 
 static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
-				GError **error, OptionTable *table _U_)
+				GError **error, GHashTable *table _U_)
 {
   int res;
   struct cube_reader rd;
@@ -521,7 +516,7 @@ static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
 	{
 	  scalarFieldSet_periodic(field, TRUE);
 	  scalarFieldSet_commentary(field, rd.comment);
-	  scalarFieldSet_box(field, rd.box);
+	  scalarFieldSet_boxFull(field, rd.box);
 	  scalarFieldSet_gridSize(field, rd.mesh);
 	  DBG_fprintf(stderr, "Cube: transfer density into field object.\n");
 	  scalarFieldSet_data(field, rd.density, FALSE);
@@ -544,7 +539,7 @@ static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
 }
 
 /* static gboolean xvAtomicLoad(VisuData *data, const gchar* filename, */
-/* 			     FileFormat *format, int nSet, GError **error) */
+/* 			     ToolFileFormat *format, int nSet, GError **error) */
 /* { */
 /*   GIOChannel *flux; */
 /*   GIOStatus status; */
@@ -605,7 +600,7 @@ static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
 /*     } */
 
 
-/*   if (!matrix_reducePrimitiveVectors(box, cart)) */
+/*   if (!tool_matrix_reducePrimitiveVectors(box, cart)) */
 /*     { */
 /*       *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT, */
 /* 			   _("Wrong Siesta format, primitive vectors are not 3D.\n")); */
