@@ -43,48 +43,48 @@
 */
 
 #include "xsf.h"
+#include "xsf_density.h"
 #include <visu_tools.h>
 #include <visu_basic.h>
 #include <renderingMethods/renderingAtomic.h>
 #include <renderingMethods/renderingAtomic_ascii.h>
 #include <renderingMethods/renderingSpin.h>
 #include <coreTools/toolMatrix.h>
-#include <coreTools/toolElements.h>
+#include <coreTools/toolPhysic.h>
 
 
 #define XSF_DESCRIPTION _("<span size=\"smaller\">" \
 			  "This plug-in reads <b>XSF</b>"	\
-			  "input files.</span>")
+			  " input files\n (position, forces and densities).</span>")
 #define XSF_AUTHORS     "Caliste Damien"
 
 /* Local methods */
 static gboolean loadXsfIn(VisuData *data, const gchar* filename,
-			  FileFormat *format _U_, int nSet, GError **error);
+			  ToolFileFormat *format _U_, int nSet, GError **error);
 static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
-			    FileFormat *format _U_, int nSet _U_, GError **error);
+			    ToolFileFormat *format _U_, int nSet _U_, GError **error);
 static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **error);
-static RenderingFormatLoad* xsfStructuralInit();
-static RenderingFormatLoad* xsfSpinInit();
+static void xsfStructuralInit(VisuRendering *method);
+static void xsfSpinInit(VisuRendering *method);
 /* Local variables */
 static gchar *iconPath;
 
 /* Required methods for a loadable module. */
 gboolean xsfInit()
 {
-  RenderingFormatLoad* meth, *spin;
-
   DBG_fprintf(stderr, "XSF: loading plug-in 'xsf'...\n");
 
   DBG_fprintf(stderr, "XSF: declare a new rendering load method.\n");
-  meth = xsfStructuralInit();
-  renderingAtomicAdd_loadMethod(meth);
+  xsfStructuralInit(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME));
 
   DBG_fprintf(stderr, "XSF: declare a new spin load method.\n");
-  spin = xsfSpinInit();
-  rspin_addLoadMethod(spin);
+  xsfSpinInit(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME));
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "xsf.png", NULL);
 
+  DBG_fprintf(stderr, "XSF: declare a new density load method.\n");
+  xsfDensityInit();
+
   return TRUE;
 }
 
@@ -103,27 +103,18 @@ const char* xsfGet_icon()
   return iconPath;
 }
 
-static RenderingFormatLoad* xsfStructuralInit()
+static void xsfStructuralInit(VisuRendering *method)
 {
   char *type[] = {"*.xsf", "*.axsf", (char*)0};
-  char *descr = _("XCrysDen Structure File format");
-  RenderingFormatLoad *meth;
   
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = "XCrysDen Structure File (XSF) format";
-  meth->fmt = fileFormatNew(descr, type);
-  if (!meth->fmt)
-    {
-      g_error("Can't initialize the XSF loading method, aborting...\n");
-    }
-  meth->priority = 90;
-  meth->load = loadXsfIn;
-
-  return meth;
+  visu_rendering_addFileFormat(method, 0,
+                               tool_file_format_new(_("XCrysDen Structure File format"),
+                                                    type),
+                               90, loadXsfIn, (GDestroyNotify)0);
 }
 
 static gboolean loadXsfIn(VisuData *data, const gchar* filename,
-			  FileFormat *format _U_, int nSet, GError **error)
+			  ToolFileFormat *format _U_, int nSet, GError **error)
 {
   int res;
   GIOChannel *readFrom;
@@ -148,26 +139,26 @@ static gboolean loadXsfIn(VisuData *data, const gchar* filename,
   return TRUE;
 }
 
-struct xsf_reader
+void xsf_reader_new(struct xsf_reader *rd)
 {
-  GString *line;
-  GList   *lst;
-  int ntype;
-  GHashTable *elements;
-  VisuElement **nodeTypes;
-  int nNodes;
-  float rot[3][3];
-  float *coords;
-  float *forces;
-  GIOStatus status;
-  GIOChannel *flux;
-};
+  /* The storage for read line. */
+  rd->line      = g_string_new("");
 
-static void reader_free(struct xsf_reader *rd)
+  /* Storage of number of elements per types. */
+  rd->ntype     = 0;
+  rd->elements  = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
+  rd->nodeTypes = (VisuElement**)0;
+  rd->bc        = VISU_DATA_BOX_FREE;
+
+  rd->coords    = (float*)0;
+  rd->forces    = (float*)0;
+  /* rd->lst       = (GList*)0; */
+}
+
+void xsf_reader_free(struct xsf_reader *rd)
 {
-  GList *tmpLst;
+  /* GList *tmpLst; */
 
-  g_string_free(rd->line, TRUE);
   g_hash_table_destroy(rd->elements);
   if (rd->nodeTypes)
     g_free(rd->nodeTypes);
@@ -176,23 +167,24 @@ static void reader_free(struct xsf_reader *rd)
   if (rd->forces)
     g_free(rd->forces);
   
-  if (rd->lst)
-    {
-      tmpLst = rd->lst;
-      while (tmpLst)
-	{
-	  g_free(tmpLst->data);
-	  tmpLst = g_list_next(tmpLst);
-	}
-      g_list_free(rd->lst);
-    }  
+  /* if (rd->lst) */
+  /*   { */
+  /*     tmpLst = rd->lst; */
+  /*     while (tmpLst) */
+  /*       { */
+  /*         g_free(tmpLst->data); */
+  /*         tmpLst = g_list_next(tmpLst); */
+  /*       } */
+  /*     g_list_free(rd->lst); */
+  /*   }   */
 
+  g_string_free(rd->line, TRUE);
   if (g_io_channel_shutdown(rd->flux, FALSE, (GError**)0) != G_IO_STATUS_NORMAL)
     g_warning("XSF: can't close file.");
   g_io_channel_unref(rd->flux);
 }
 
-static gboolean skip_commentary(struct xsf_reader *rd, GError **error)
+gboolean xsf_reader_skip_comment(struct xsf_reader *rd, GError **error)
 {
   gsize term;
 
@@ -211,8 +203,8 @@ static gboolean skip_commentary(struct xsf_reader *rd, GError **error)
   return TRUE;
 }
 
-static gboolean read_flag(struct xsf_reader *rd, gboolean *found, const gchar *flag,
-			  int *value, gboolean  mandatory, GError **error)
+gboolean xsf_reader_get_flag(struct xsf_reader *rd, gboolean *found, const gchar *flag,
+                             int *value, gboolean  mandatory, GError **error)
 {
   size_t len;
 
@@ -241,15 +233,36 @@ static gboolean read_flag(struct xsf_reader *rd, gboolean *found, const gchar *f
       *found = TRUE;
     }
   if (*found)
-    return skip_commentary(rd, error);
+    return xsf_reader_skip_comment(rd, error);
   else
     return TRUE;
 }
 
-static gboolean read_box(struct xsf_reader *rd, double box[6], GError **error)
+static gboolean read_periodicity(struct xsf_reader *rd, GError **error)
+{
+  gboolean found;
+
+  if (!xsf_reader_get_flag(rd, &found, "MOLECULE", (int*)0, FALSE, error))
+    return FALSE;
+  if (found)
+    rd->bc = VISU_DATA_BOX_FREE;
+
+  if (!xsf_reader_get_flag(rd, &found, "SLAB", (int*)0, FALSE, error))
+    return FALSE;
+  if (found)
+    rd->bc = VISU_DATA_BOX_SURFACE_XY;
+
+  if (!xsf_reader_get_flag(rd, &found, "CRYSTAL", (int*)0, FALSE, error))
+    return FALSE;
+  if (found)
+    rd->bc = VISU_DATA_BOX_PERIODIC;
+
+  return TRUE;
+}
+
+gboolean xsf_reader_get_box(struct xsf_reader *rd, double cart[3][3], GError **error)
 {
   int i;
-  double cart[3][3];
   
   for (i = 0; i < 3; i++)
     {
@@ -261,7 +274,7 @@ static gboolean read_box(struct xsf_reader *rd, double box[6], GError **error)
 				 " after tag '%s'.\n"), "PRIMVEC");
 	  return FALSE;
 	}
-      if (!skip_commentary(rd, error))
+      if (!xsf_reader_skip_comment(rd, error))
 	return FALSE;
     }
   DBG_fprintf(stderr, "XSF: read box %8g %8g %8g\n"
@@ -270,37 +283,25 @@ static gboolean read_box(struct xsf_reader *rd, double box[6], GError **error)
 	      cart[0][0], cart[0][1], cart[0][2],
 	      cart[1][0], cart[1][1], cart[1][2],
 	      cart[2][0], cart[2][1], cart[2][2]);
-  if (!matrix_reducePrimitiveVectors(box, cart))
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Wrong XSF format, primitive vectors are not 3D.\n"));
-      return FALSE;
-    }
-  if (!matrix_fromFullToBoxCartesian(rd->rot, cart, box))
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Wrong XSF format, cannot invert primitive vectors.\n"));
-      return FALSE;
-    }
   return TRUE;
 }
 
 static gboolean read_coords(struct xsf_reader *rd, GError **error)
 {
-  int i, res, zele, nb;
-  float rcov, f[3], coord[3];
+  int i, zele, nb;
+  float rcov, f[3];
   gchar *name, *ptChar;
   VisuElement *type;
-  struct dataAscii *infos;
+  struct VisuMethAscii *infos;
 
-  if (sscanf(rd->line->str, "%d\n", &rd->nNodes) != 1 && rd->nNodes <= 0)
+  if (sscanf(rd->line->str, "%d", &rd->nNodes) != 1 && rd->nNodes <= 0)
     {
       *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			   _("Wrong XSF format, missing or wrong integer values"
 			     " after tag '%s'.\n"), "PRIMCOORD");
       return FALSE;
     }
-  if (!skip_commentary(rd, error))
+  if (!xsf_reader_skip_comment(rd, error))
     return FALSE;
   rd->ntype     = 0;
   rd->nodeTypes = g_malloc(sizeof(VisuElement*) * rd->nNodes);
@@ -320,55 +321,39 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       *ptChar = '\0';
       /* The first three values are coordinates.
 	 Possible three others are forces. */
-      nb = sscanf(ptChar + 1, "%f %f %f %f %f %f\n", coord + 0,
-		  coord + 1, coord + 2, f + 0, f + 1, f + 2);
+      nb = sscanf(ptChar + 1, "%f %f %f %f %f %f\n", rd->coords + 3 * i,
+		  rd->coords + 3 * i + 1, rd->coords + 3 * i + 2, f + 0, f + 1, f + 2);
       if (nb != 3 && nb != 6)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong XSF format, can't read coordinates.\n"));
 	  return FALSE;
 	}
-      matrix_productVector(rd->coords + 3 * i, rd->rot, coord);
       if (nb == 6)
 	{
 	  /* If forces where not used, we allocate then now. */
 	  if (!rd->forces)
 	    rd->forces = g_malloc(sizeof(float) * 3 * rd->nNodes);
-	  matrix_productVector(rd->forces + 3 * i, rd->rot, f);
+          rd->forces[3 * i + 0] = f[0];
+          rd->forces[3 * i + 1] = f[1];
+          rd->forces[3 * i + 2] = f[2];
 	}
       /* Try to find a z number instead of a name. */
       rcov = -1.f;
       if (sscanf(name, "%d", &zele) == 1 &&
-	  toolElementsGet_element(&ptChar, &rcov, zele))
+	  tool_physic_getElementFromZ(&ptChar, &rcov, zele))
 	{
 	  g_free(name);
 	  name = g_strdup(ptChar);
 	}
       /* adding nomloc to the hashtable */
-      type = visuElementGet_fromName(name);
-      if (!type)
-	{
-	  type = visuElementNew_withName(name);
-	  if (!type)
-	    {
-	      g_warning("Cannot create a new type for '%s'.", name);
-	      return FALSE;
-	    }
-	  res = visuElementAdd(type);
-	  if (res)
-	    {
-	      g_warning("Cannot add new element, maximum has been reached.");
-	      return FALSE;
-	    }
-	  if (rcov > 0.f)
-	    renderingAtomicSet_radius(type, rcov * 0.52917720859);
-	}
+      type = visu_element_retrieveFromName(name, (gboolean*)0);
       rd->nodeTypes[i] = type;
-      infos = (struct dataAscii*)g_hash_table_lookup(rd->elements,
+      infos = (struct VisuMethAscii*)g_hash_table_lookup(rd->elements,
 						     (gconstpointer)type);
       if (!infos)
 	{
-	  infos = g_malloc(sizeof(struct dataAscii));
+	  infos = g_malloc(sizeof(struct VisuMethAscii));
 	  infos->ele = type;
 	  infos->pos = rd->ntype;
 	  infos->nbNodes = 1;
@@ -377,7 +362,7 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
 	}
       else
 	infos->nbNodes += 1;
-      if (!skip_commentary(rd, error))
+      if (!xsf_reader_skip_comment(rd, error))
 	return FALSE;
     }
   DBG_fprintf(stderr, " | read OK.\n");
@@ -390,7 +375,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
   struct xsf_reader rd;
   gboolean found;
   int valInt;
-  double box[6];
+  double box[3][3];
   int i;
   int res, nSets, iNodes;
   VisuElement **types;
@@ -401,32 +386,29 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 
   rd.flux = flux;
 
-  /* The storage for read line. */
-  rd.line = g_string_new("");
-
-  /* Storage of number of elements per types. */
-  rd.ntype     = 0;
-  rd.elements  = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
-  rd.nodeTypes = (VisuElement**)0;
-
-  rd.coords    = (float*)0;
-  rd.forces    = (float*)0;
-  rd.lst       = (GList*)0;
+  xsf_reader_new(&rd);
 
   /* We read the file completely to find the number of sets of points
      and we store only the one corresponding to @nSet. */
   nSets     = -1;
-  if (!skip_commentary(&rd, error))
+  if (!xsf_reader_skip_comment(&rd, error))
     {
-      reader_free(&rd);
+      xsf_reader_free(&rd);
       return -1;
     }
   do
     {
-      /* If ANIMSTEPS is found, we are in animated mode. */
-      if (!read_flag(&rd, &found, "ANIMSTEPS", &valInt, TRUE, error))
+      /* Test the periodicity mode. */
+      if (!read_periodicity(&rd, error))
 	{
-	  reader_free(&rd);
+	  xsf_reader_free(&rd);
+	  return 1;
+	}
+
+      /* If ANIMSTEPS is found, we are in animated mode. */
+      if (!xsf_reader_get_flag(&rd, &found, "ANIMSTEPS", &valInt, TRUE, error))
+	{
+	  xsf_reader_free(&rd);
 	  return 1;
 	}
       if (found)
@@ -437,7 +419,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 				   _("Wrong XSF format, '%s' tag already"
 				     " defined.\n"), "ANIMSTEPS");
-	      reader_free(&rd);
+	      xsf_reader_free(&rd);
 	      return 1;
 	    }
 	  else
@@ -447,18 +429,26 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 
       /* If PRIMVEC is found, we store the box. */
       valInt = -1;
-      if (!read_flag(&rd, &found, "PRIMVEC", &valInt, FALSE, error))
+      if (!xsf_reader_get_flag(&rd, &found, "PRIMVEC", &valInt, FALSE, error))
 	{
-	  reader_free(&rd);
+	  xsf_reader_free(&rd);
 	  return 1;
 	}
       if (found && (valInt < 0 || (valInt - 1) == nSet))
 	{
+	  if (rd.bc == VISU_DATA_BOX_FREE)
+	    {
+	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+				   _("Wrong XSF format, primitive vectors found"
+				     " with free boundary conditions.\n"));
+	      xsf_reader_free(&rd);
+	      return 1;
+	    }
 	  DBG_fprintf(stderr, "XSF: found the 'PRIMVEC' flag (%d).\n", valInt);
 	  /* We read the box. */
-	  if (!read_box(&rd, box, error))
+	  if (!xsf_reader_get_box(&rd, box, error))
 	    {
-	      reader_free(&rd);
+	      xsf_reader_free(&rd);
 	      return 1;
 	    }
 	  /* We set nSets to 1 if not already set. */
@@ -469,27 +459,66 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 
       /* If PRIMCOORD is found, we store the coordinates. */
       valInt = -1;
-      if (!read_flag(&rd, &found, "PRIMCOORD", &valInt, FALSE, error))
+      if (!xsf_reader_get_flag(&rd, &found, "PRIMCOORD", &valInt, FALSE, error))
 	{
-	  reader_free(&rd);
+	  xsf_reader_free(&rd);
 	  return 1;
 	}
       if (found && (valInt < 0 || (valInt - 1) == nSet))
 	{
+	  if (rd.bc == VISU_DATA_BOX_FREE)
+	    {
+	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+				   _("Wrong XSF format, primitive coordinates found"
+				     " with free boundary conditions.\n"));
+	      xsf_reader_free(&rd);
+	      return 1;
+	    }
 	  DBG_fprintf(stderr, "XSF: found the 'PRIMCOORD' flag (%d).\n", valInt);
 	  /* We read the coords. */
 	  if (!read_coords(&rd, error))
 	    {
-	      reader_free(&rd);
+	      xsf_reader_free(&rd);
 	      return 1;
 	    }
 	  /* We set nSets to 1 if not already set. */
 	  if (nSets < 0)
 	    nSets = 1;
 	}
-      if (!skip_commentary(&rd, error))
+
+      /* If ATOMS is found, we store the coordinates. */
+      valInt = -1;
+      if (!xsf_reader_get_flag(&rd, &found, "ATOMS", &valInt, FALSE, error))
 	{
-	  reader_free(&rd);
+	  xsf_reader_free(&rd);
+	  return 1;
+	}
+      if (found && (valInt < 0 || (valInt - 1) == nSet))
+	{
+	  if (rd.bc != VISU_DATA_BOX_FREE)
+	    {
+	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+				   _("Wrong XSF format, atom coordinates found"
+				     " with free boundary conditions.\n"));
+	      xsf_reader_free(&rd);
+	      return 1;
+	    }
+	  DBG_fprintf(stderr, "XSF: found the 'ATOMS' flag (%d).\n", valInt);
+	  /* We read the coords. */
+	  if (!read_coords(&rd, error))
+	    {
+	      xsf_reader_free(&rd);
+	      return 1;
+	    }
+	  /* We set nSets to 1 if not already set. */
+	  if (nSets < 0)
+	    nSets = 1;
+	}
+
+      /* We go on. */
+      if (!xsf_reader_skip_comment(&rd, error))
+	{
+	  xsf_reader_free(&rd);
 	  return 1;
 	}
 /*       fprintf(stderr, "'%s'\n", rd.line->str); */
@@ -499,21 +528,21 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
   DBG_fprintf(stderr, " | found %d types.\n", rd.ntype);
   if (rd.ntype == 0)
     {
-      reader_free(&rd);
+      xsf_reader_free(&rd);
       return -1;
     }
 
   /* Allocate the space for the nodes. */
   types  = g_malloc(sizeof(VisuElement*) * rd.ntype);
   nattyp = g_malloc(sizeof(int) * rd.ntype);
-  g_hash_table_foreach(rd.elements, (GHFunc)putValTypeInAsciiType, (gpointer)&types);
-  g_hash_table_foreach(rd.elements, (GHFunc)putValNbInAsciiType, (gpointer)&nattyp);
+  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
+  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
 
   DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
   /* Begin the storage into VisuData. */
-  visuDataSet_nSet(data, nSets);
+  visu_data_setNSubset(data, nSets);
 
-  res = visuDataSet_population(data, rd.ntype, nattyp, types);
+  res = visu_data_setPopulation(data, rd.ntype, nattyp, types);
   if (!res)
     {
       g_error("Can't store the nodes in the VisuData object.");
@@ -526,12 +555,12 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
   g_free(types);
          
   /* Store the coordinates */
+  visu_data_setBoxGeometryFull(data, box, rd.bc);
   for(iNodes = 0; iNodes < rd.nNodes; iNodes++)
-    visuDataAdd_nodeFromElement(data, rd.nodeTypes[iNodes],
-				rd.coords + 3 * iNodes, FALSE);
-  visuDataSet_boxGeometry(data, box, BOX_PERIODIC);
-  visuDataApply_boxGeometry(data, 0.f);
-  visuDataSet_unit(data, unit_angstroem);
+    visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
+                                 rd.coords + 3 * iNodes, FALSE, FALSE);
+  visu_data_applyBoxGeometry(data);
+  visu_data_setUnit(data, unit_angstroem);
 
   /* We store the forces as a property to be used later by the spin
      loading method. */
@@ -544,7 +573,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
     }
 
   /* Free the local data. */
-  reader_free(&rd);
+  xsf_reader_free(&rd);
   
   return 0;
 }
@@ -574,27 +603,18 @@ static gpointer newOrCopySpin(gconstpointer obj, gpointer data _U_)
   return (gpointer)spinData;
 }
 
-static RenderingFormatLoad* xsfSpinInit()
+static void xsfSpinInit(VisuRendering *method)
 {
   char *type[] = {"*.xsf", "*.axsf", (char*)0};
-  char *descr = _("XCrysDen Structure File format");
-  RenderingFormatLoad *meth;
-  
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = "XCrysDen Structure File (XSF) format";
-  meth->fmt = fileFormatNew(descr, type);
-  if (!meth->fmt)
-    {
-      g_error("Can't initialize the XSF loading method, aborting...\n");
-    }
-  meth->priority = 40;
-  meth->load = loadXsfSpin;
 
-  return meth;
+  visu_rendering_addFileFormat(method, FILE_KIND_SPIN,
+                               tool_file_format_new(_("XCrysDen Structure File format"),
+                                                    type),
+                               40, loadXsfSpin, (GDestroyNotify)0);
 }
 
 static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
-			    FileFormat *format _U_, int nSet _U_, GError **error)
+			    ToolFileFormat *format _U_, int nSet _U_, GError **error)
 {
   float *forces, *svgMaxSpinModulus, *svgSpinValues;
   float sph[3], vals[3];
@@ -617,22 +637,22 @@ static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
   memset(svgMaxSpinModulus, 0, sizeof(float) * data->ntype);
   g_object_set_data_full(G_OBJECT(data), SPINMAXMODULUS_ID,
 			 (gpointer)svgMaxSpinModulus, g_free);
-  spin = visuNodeNew_pointerProperty(visuDataGet_nodeArray(data), SPINVALUES_ID,
+  spin = visu_node_property_newPointer(visu_data_getNodeArray(data), SPINVALUES_ID,
 				     freeSpin, newOrCopySpin, (gpointer)0);
 
   g_value_init(&spinValue, G_TYPE_POINTER);
-  visuDataIter_new(data, &iter);
-  for(visuDataIter_startNumber(data, &iter); iter.node;
-      visuDataIter_nextNodeNumber(data, &iter))
+  visu_data_iterNew(data, &iter);
+  for(visu_data_iterStartNumber(data, &iter); iter.node;
+      visu_data_iterNextNodeNumber(data, &iter))
     {
-      matrix_cartesianToSpherical(sph, forces + iter.node->number * 3);
-      vals[SPIN_MODULUS] = sph[0];
-      vals[SPIN_THETA]   = sph[1];
-      vals[SPIN_PHI]     = sph[2];
+      visu_data_convertFullCartesianToSpherical(data, sph, forces + iter.node->number * 3);
+      vals[TOOL_MATRIX_SPHERICAL_MODULUS] = sph[0];
+      vals[TOOL_MATRIX_SPHERICAL_THETA]   = sph[1];
+      vals[TOOL_MATRIX_SPHERICAL_PHI]     = sph[2];
       svgSpinValues = newOrCopySpin(vals, (gpointer)0);
       g_value_set_pointer(&spinValue, svgSpinValues);
-      visuNodePropertySet_value(spin, iter.node, &spinValue);
-      svgMaxSpinModulus[iter.iElement] = MAX(vals[SPIN_MODULUS],
+      visu_node_property_setValue(spin, iter.node, &spinValue);
+      svgMaxSpinModulus[iter.iElement] = MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
 					     svgMaxSpinModulus[iter.iElement]);
     }
 
