@@ -45,7 +45,7 @@
 #include "visu_openGL.h"
 #include <visu_tools.h>
 
-struct DumpImage_struct
+struct VisuPixmapContext_struct
 {
   GdkGLConfig *glConfig;
   GdkGLContext *glContext;
@@ -103,15 +103,15 @@ GLuint visuOpenGLinit_fontList(guint size)
   return BASE; 
 }
 
-DumpImage* visuOpenGLNew_pixmapContext(guint width, guint height)
+VisuPixmapContext* visu_pixmap_context_new(guint width, guint height)
 {
   GdkScreen *screen;
   gboolean res;
-  DumpImage *image;
+  VisuPixmapContext *image;
 
   DBG_fprintf(stderr, "Visu GtkGlExt: creating a off-screen buffer (%dx%d).\n",
 	      width, height);
-  image            = g_malloc(sizeof(DumpImage));
+  image            = g_malloc(sizeof(VisuPixmapContext));
   image->glConfig  = (GdkGLConfig*)0;
   image->glContext = (GdkGLContext*)0;
   image->pixmap    = (GdkPixmap*)0;
@@ -127,16 +127,16 @@ DumpImage* visuOpenGLNew_pixmapContext(guint width, guint height)
   if (!image->pixmap)
     {
       g_warning("Cannot allocate a GdkPixmap for the indirect rendering.");
-      visuOpenGLFree_pixmapContext(image);
-      return (DumpImage*)0;
+      visu_pixmap_context_free(image);
+      return (VisuPixmapContext*)0;
     }
 
   image->glPixmap = gdk_gl_pixmap_new(image->glConfig, image->pixmap, NULL);
   if (!image->glPixmap)
     {
       g_warning("Cannot allocate a GdkGLPixmap for the indirect rendering.");
-      visuOpenGLFree_pixmapContext(image);
-      return (DumpImage*)0;
+      visu_pixmap_context_free(image);
+      return (VisuPixmapContext*)0;
     }
 
   image->glContext = gdk_gl_context_new(GDK_GL_DRAWABLE(image->glPixmap),
@@ -144,22 +144,22 @@ DumpImage* visuOpenGLNew_pixmapContext(guint width, guint height)
   if (!image->glContext)
     {
       g_warning("Cannot create indirect context.");
-      visuOpenGLFree_pixmapContext(image);
-      return (DumpImage*)0;
+      visu_pixmap_context_free(image);
+      return (VisuPixmapContext*)0;
     }
 
   res = gdk_gl_drawable_make_current((GdkGLDrawable*)image->glPixmap, image->glContext);
   if (!res)
     {
       g_warning("Cannot make current the pixmap context.");
-      visuOpenGLFree_pixmapContext(image);
-      return (DumpImage*)0;
+      visu_pixmap_context_free(image);
+      return (VisuPixmapContext*)0;
     }
 
   return image;
 }
 
-void visuOpenGLFree_pixmapContext(DumpImage *dumpData)
+void visu_pixmap_context_free(VisuPixmapContext *dumpData)
 {
   if (!dumpData)
     return;
