@@ -52,69 +52,55 @@
 #include <GL/gl.h>
 
 #ifdef HAVE_GTKGLEXT
+/**
+ * GDKGLEXT_MULTIHEAD_SUPPORT: (skip)
+ *
+ * GtkGlExt support.
+ */
   #define GDKGLEXT_MULTIHEAD_SUPPORT
   #include <gtk/gtkgl.h>
+/**
+ * IMPL_GTKGLEXT: (skip)
+ *
+ * GtkGlExt support.
+ */
   #define IMPL_GTKGLEXT
 #else
   #if SYSTEM_X11 == 1
   #include <X11/Xlib.h>
   #include <GL/glx.h>
+/**
+ * IMPL_BUILTIN_X11: (skip)
+ *
+ * X11 support.
+ */
   #define IMPL_BUILTIN_X11
   #endif
   #if SYSTEM_WIN32 == 1
   #include <windows.h>
+/**
+ * IMPL_BUILTIN_WIN32: (skip)
+ *
+ * Win32 support.
+ */
   #define IMPL_BUILTIN_WIN32
   #endif
 #endif
 
 /**
- * DumpImage_struct:
+ * VisuPixmapContext:
  *
- * Opaque structure used when an dump is done from an OpenGL area.
- * See visuOpenGLNew_pixmapContext().
+ * Short way to address #VisuPixmapContext_struct objects.
  */
-struct DumpImage_struct;
-/**
- * DumpImage:
- *
- * Short way to address #DumpImage_struct objects.
- */
-typedef struct DumpImage_struct DumpImage;
+typedef struct _VisuPixmapContext VisuPixmapContext;
 
-/**
- * visuOpenGLGet_pixmapData:
- * @width: an integer ;
- * @height: an integer ;
- * @hasAlpha: if TRUE, read also the alpha channel.
- *
- * Dump the pixels of the current GL area, assuming that its size
- * is given by @widthx@height. This method should not be used directly, see
- * openGLWidgetGet_pixmapData() to dump a given OpenGL area.
- *
- * Returns: newly allocated dump data (use g_free() after use).
- */
-guchar* visuOpenGLGet_pixmapData(guint width, guint height, gboolean hasAlpha);
-/**
- * visuOpenGLNew_pixmapContext:
- * @width: an integer ;
- * @height: an integer.
- *
- * Create a pixmap storage and a context associated to it. This pixmap
- * can then be used to dump pixel data from an OpenGL area.
- *
- * Returns: a newly allocated #DumpImage object.
- */
-DumpImage* visuOpenGLNew_pixmapContext(guint width, guint height);
-/**
- * visuOpenGLFree_pixmapContext:
- * @dumpData: an allocated #DumpImage object.
- *
- * Free an allocated #DumpImage.
- */
-void visuOpenGLFree_pixmapContext(DumpImage *dumpData);
+GArray* visuOpenGLGet_pixmapData(guint width, guint height, gboolean hasAlpha);
+VisuPixmapContext* visu_pixmap_context_new(guint width, guint height);
+void visu_pixmap_context_free(VisuPixmapContext *dumpData);
 
 /**
  * visuOpenGLinit_fontList:
+ * @size: the size of the text.
  *
  * This method create a list with a default font.
  *
