@@ -55,30 +55,31 @@
  *
  * <para>This file defines a basic structure to store colours (not
  * using the GDK one beca use V_Sim core should not rely on GDK and
- * GTK): #Color. Several transformations are possible on a colour,
- * going from and to RGB encoding. Use color_HSVtoRGB() and
- * color_HSLtoRGB() to do that.</para>
+ * GTK): #ToolColor. Several transformations are possible on a colour,
+ * going from and to RGB encoding. Use tool_color_convertHSVtoRGB() and
+ * tool_color_convertHSLtoRGB() to do that.</para>
  *
  * <para>This file gives also the capability to store known colours in
- * a list. Use methods such as colorAdd_color() or
- * colorAdd_floatRGBA(). Them, one can access to stored colours, using
- * colorGet_byValues() or colorGet_byColor().</para>
+ * a list. Use methods such as tool_color_addColor() or
+ * tool_color_addFloatRGBA(). Them, one can access to stored colours, using
+ * tool_color_getByValues() or tool_color_getByColor().</para>
  */
 
 /******************/
 /* Storing colors */
 /******************/
 #define COLOR_NB_MAX 10
-GList *color_storageArray;
+GList *color_storageArray = (GList*)0;
 
 /******************/
 /* Storing colors */
 /******************/
-void toolColorInit_storage()
-{
-  color_storageArray = (GList*)0;
-}
-void toolColorFree_storage()
+/**
+ * tool_color_freeAll:
+ *
+ * Remove all previously stored colours.
+ */
+void tool_color_freeAll(void)
 {
   GList *lst;
   
@@ -87,12 +88,21 @@ void toolColorFree_storage()
   if (lst)
     g_list_free(lst);
 }
-Color* colorNew_floatRGBA(float rgba[4])
+
+/**
+ * tool_color_new:
+ * @rgba: four values between 0. and 1. that represent [Red, Green, Blue, Alpha].
+ * 
+ * Create a new color with initial values given as arguments.
+ *
+ * Returns: (transfer none): a new allocated #ToolColor (use g_free() to free it).
+ */
+ToolColor* tool_color_new(float rgba[4])
 {
-  Color *color;
+  ToolColor *color;
   int i;
 
-  color = g_malloc(sizeof(Color));
+  color = g_malloc(sizeof(ToolColor));
   for (i = 0; i< 4; i++)
     {
       if (rgba[i] < 0.)
@@ -105,34 +115,74 @@ Color* colorNew_floatRGBA(float rgba[4])
   color->userData = (gpointer)0;
   return color;
 }
-gboolean colorEqual_color(Color *color1, Color *color2)
+
+/**
+ * tool_color_equal:
+ * @color1: a #ToolColor ;
+ * @color2: an other #ToolColor.
+ *
+ * Test if the two colours are the same.
+ *
+ * Returns: TRUE if the @rgba attributes are the same.
+ */
+gboolean tool_color_equal(ToolColor *color1, ToolColor *color2)
 {
   return (color1->rgba[0] == color2->rgba[0] &&
 	  color1->rgba[1] == color2->rgba[1] &&
 	  color1->rgba[2] == color2->rgba[2]);
 }
-Color* colorGet_byId(int num)
+/**
+ * tool_color_getById:
+ * @num: an integer (>0).
+ *
+ * This function retrieves the nth stored color. Number 0, is the last
+ * added color.
+ *
+ * Returns: (transfer none): the corresponding color, or NULL if none has been found.
+ */
+ToolColor* tool_color_getById(int num)
 {
   GList *tmpLst;
 
   tmpLst = g_list_nth(color_storageArray, num);
   if (tmpLst)
-    return (Color*)tmpLst->data;
+    return (ToolColor*)tmpLst->data;
   else
-    return (Color*)0;
+    return (ToolColor*)0;
 }
-int colorGet_byColor(Color *color)
+/**
+ * tool_color_getByColor:
+ * @color: a pointer to a stored color.
+ *
+ * This function retrieves the number (begining at 0) of the specified color.
+ *
+ * Returns: the position of the specified color or -1 if not found.
+ */
+int tool_color_getByColor(ToolColor *color)
 {
   int pos;
 
   if (color)
-    colorGet_byValues(&pos, color->rgba[0], color->rgba[1], color->rgba[2], color->rgba[3]);
+    tool_color_getByValues(&pos, color->rgba[0], color->rgba[1], color->rgba[2], color->rgba[3]);
   else
     pos = -1;
   return pos;
 
 }
-Color* colorGet_byValues(int *pos, float red, float green, float blue, float alpha)
+/**
+ * tool_color_getByValues:
+ * @pos: (out caller-allocates): an allocated int to store the position of the found color ;
+ * @red: a value between 0. and 1. ;
+ * @green: a value between 0. and 1. ;
+ * @blue: a value between 0. and 1. ;
+ * @alpha: a value between 0. and 1..
+ *
+ * This method is used to look for a specific color in the stored list. The argument @pos
+ * is -1 if nothing is found or stores the position (beginning at 0) of the found color.
+ *
+ * Returns: (transfer none): the found color, or NULL if none exists.
+ */
+ToolColor* tool_color_getByValues(int *pos, float red, float green, float blue, float alpha)
 {
   GList *tmpLst;
   int found;
@@ -143,42 +193,65 @@ Color* colorGet_byValues(int *pos, float red, float green, float blue, float alp
     *pos = -1;
   while (tmpLst && !found)
     {
-      found = (red == ((Color*)tmpLst->data)->rgba[0]) &&
-	(green == ((Color*)tmpLst->data)->rgba[1]) &&
-	(blue == ((Color*)tmpLst->data)->rgba[2]) &&
-	(alpha == ((Color*)tmpLst->data)->rgba[3]);
+      found = (red == ((ToolColor*)tmpLst->data)->rgba[0]) &&
+	(green == ((ToolColor*)tmpLst->data)->rgba[1]) &&
+	(blue == ((ToolColor*)tmpLst->data)->rgba[2]) &&
+	(alpha == ((ToolColor*)tmpLst->data)->rgba[3]);
       if (pos)
 	*pos += 1;
       if (!found)
 	tmpLst = g_list_next(tmpLst);
     }
   if (found)
-    return (Color*)tmpLst->data;
+    return (ToolColor*)tmpLst->data;
   else
     {
       if (pos)
 	*pos = -1;
-      return (Color*)0;
+      return (ToolColor*)0;
     }
 }
-GList* colorGet_storedColors()
+/**
+ * tool_color_getStoredColors:
+ *
+ * Use this method to get a pointeur to the list of stored colors.
+ *
+ * Returns: (transfer none) (element-type ToolColor):
+ * a GList pointer to the stored colors.
+ */
+GList* tool_color_getStoredColors(void)
 {
   return color_storageArray;
 }
-void colorCopy_color(Color *color, Color *color_old)
+/**
+ * tool_color_copy:
+ * @color: an allocated #ToolColor object to receive values ;
+ * @color_old: a #ToolColor to read the values from.
+ * 
+ * This method copies all values from @color_old to @color.
+ */
+void tool_color_copy(ToolColor *color, ToolColor *color_old)
 {
   g_return_if_fail(color && color_old);
 
   memcpy(color->rgba, color_old->rgba, sizeof(float) * 4);
   color->userData = color_old->userData;
 }
-Color* colorAdd_color(Color* color)
+/**
+ * tool_color_addColor:
+ * @color: a #ToolColor.
+ *
+ * This method copies color informations from @color to the list of stored colors.
+ *
+ * Returns: (transfer none): the newly created #ToolColor.
+ */
+ToolColor* tool_color_addColor(ToolColor* color)
 {
   int pos;
 
-  g_return_val_if_fail(color, (Color*)0);
+  g_return_val_if_fail(color, (ToolColor*)0);
 
-  if (!colorGet_byValues(&pos, color->rgba[0], color->rgba[1], color->rgba[2], color->rgba[3]))
+  if (!tool_color_getByValues(&pos, color->rgba[0], color->rgba[1], color->rgba[2], color->rgba[3]))
     {
       color_storageArray = g_list_append(color_storageArray, (gpointer)color);
       DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
@@ -188,22 +261,33 @@ Color* colorAdd_color(Color* color)
     }
   return color;
 }
-Color* colorAdd_floatRGBA(float rgba[4], int *position)
+/**
+ * tool_color_addFloatRGBA:
+ * @rgba: four values between 0. and 1. that represent [Red, Green, Blue, Alpha] ;
+ * @position: (out caller-allocates): an int pointer to store the position
+ *  of the returned colour.
+ *
+ * This method adds a new color in the list of stored colors with the given values.
+ * If it already exits it returns the pointer of that color.
+ *
+ * Returns: (transfer none): a newly created #ToolColor or the already existing one.
+ */
+ToolColor* tool_color_addFloatRGBA(float rgba[4], int *position)
 {
-  Color *color;
+  ToolColor *color;
   int i;
 
   for (i = 0; i < 4; i++)
-    g_return_val_if_fail(rgba[i] >= 0. && rgba[i] <= 1., (Color*)0);
+    g_return_val_if_fail(rgba[i] >= 0. && rgba[i] <= 1., (ToolColor*)0);
 
-  color = colorGet_byValues(position, rgba[0], rgba[1], rgba[2], rgba[3]);
+  color = tool_color_getByValues(position, rgba[0], rgba[1], rgba[2], rgba[3]);
   if (color)
     {
       DBG_fprintf(stderr, "Visu Tools : color already exist, no color added.\n");
       return color;
     }
 
-  color = colorNew_floatRGBA(rgba);
+  color = tool_color_new(rgba);
   color_storageArray = g_list_append(color_storageArray, (gpointer)color);
   if (position)
     *position = g_list_length(color_storageArray);
@@ -213,25 +297,33 @@ Color* colorAdd_floatRGBA(float rgba[4], int *position)
 		0 , (gpointer)color, NULL);
   return color;
 }
-Color* colorAdd_intRGBA(int rgba[4])
+/**
+ * tool_color_addIntRGBA:
+ * @rgba: four values between 0 and 255 that represent [Red, Green, Blue, Alpha].
+ *
+ * This method adds a new color in the list of stored colors with the given values.
+ *
+ * Returns: (transfer none): a newly created #ToolColor or the already existing one.
+ */
+ToolColor* tool_color_addIntRGBA(int rgba[4])
 {
-  Color *color;
+  ToolColor *color;
   float rgbaf[4];
   int pos, i;
 
   for (i = 0; i < 4; i++)
-    g_return_val_if_fail(rgba[i] >= 0 && rgba[i] < 256, (Color*)0);
+    g_return_val_if_fail(rgba[i] >= 0 && rgba[i] < 256, (ToolColor*)0);
 
   for (i = 0; i < 4; i++)
     rgbaf[i] = (float)rgba[i] / 255.;
-  color = colorGet_byValues(&pos, rgbaf[0], rgbaf[1], rgbaf[2], rgbaf[3]);
+  color = tool_color_getByValues(&pos, rgbaf[0], rgbaf[1], rgbaf[2], rgbaf[3]);
   if (color)
     {
       DBG_fprintf(stderr, "Visu Tools : color already exist, no color added.\n");
       return color;
     }
 
-  color = colorNew_floatRGBA(rgbaf);
+  color = tool_color_new(rgbaf);
   color_storageArray = g_list_append(color_storageArray, (gpointer)color);
   DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 	      (gpointer)color_storageArray, g_list_length(color_storageArray));
@@ -239,12 +331,27 @@ Color* colorAdd_intRGBA(int rgba[4])
 		0 , (gpointer)color, NULL);
   return color;
 }
-Color* colorGet_lastStored()
+/**
+ * tool_color_getLastStored:
+ *
+ * This method is typiccally called after a client has catched
+ * the colorNewAvailable signal.
+ *
+ * Returns: (transfer none): the last added color, NULL if no color exists.
+ */
+ToolColor* tool_color_getLastStored(void)
 {
-  return (Color*)g_list_last(color_storageArray)->data;
+  return (ToolColor*)g_list_last(color_storageArray)->data;
 }
 
-void color_HSVtoRGB(float* rgb, float* hsv)
+/**
+ * tool_color_convertHSVtoRGB:
+ * @rgb: an allocated 3 elements array to receive the RGB values ;
+ * @hsv: a 3 elements array to retrieve the HSV values from.
+ *
+ * This methods convert a HSV color to a RGB one.
+ */
+void tool_color_convertHSVtoRGB(float* rgb, float* hsv)
 {
   float var_h, var_0, var_1, var_2, var_3;
   int var_i;
@@ -315,10 +422,14 @@ float Hue_2_RGB(float v1, float v2, float vH)
   return v1;
 }
 
-/* hsl[0] = hue
-   hsl[1] = saturation
-   hsl[2] = lightness */
-void color_HSLtoRGB(float *rgb, float *hsl)
+/**
+ * tool_color_convertHSLtoRGB:
+ * @rgb: an allocated 3 elements array to receive the RGB values ;
+ * @hsl: a 3 elements array to retrieve the HSL values from.
+ *
+ * This methods convert a HSL color to a RGB one.
+ */
+void tool_color_convertHSLtoRGB(float *rgb, float *hsl)
 {
   /* from www.easyrgb.com */
   if (hsl[1] == 0)                       /*HSL values = 0  1*/
@@ -343,8 +454,14 @@ void color_HSLtoRGB(float *rgb, float *hsl)
       rgb[2] = Hue_2_RGB( var_1, var_2, hsl[0] - ( 1. / 3. ) );
     }  
 }
-
-void color_RGBtoHSL(float *hsl, float *rgb)
+/**
+ * tool_color_convertRGBtoHSL:
+ * @hsl: three float to store the HSL value ;
+ * @rgb: three floats giving the RGB values.
+ *
+ * Convert a RGB colour into a HSL one.
+ */
+void tool_color_convertRGBtoHSL(float *hsl, float *rgb)
 {
   float var_Min, var_Max, del_Max, del_R, del_G, del_B;
 
