@@ -58,7 +58,17 @@
  * cartesian and spherical.</para>
  */
 
-gboolean matrix_reducePrimitiveVectors(double reduced[6], double full[3][3])
+/**
+ * tool_matrix_reducePrimitiveVectors:
+ * @reduced: (out caller-allocates) (array fixed-size=6): a storage for 6 floating point values ;
+ * @full: (in) (array fixed-size=9): a full 3x3 matrix to be transformed.
+ *
+ * This routine transforms the given matrix @full into a reduced array
+ * used by V_Sim to store box definition.
+ *
+ * Returns: FALSE if the given matrix is planar.
+ */
+gboolean tool_matrix_reducePrimitiveVectors(double reduced[6], double full[3][3])
 {
   double X[3];
   double Y[3];
@@ -70,7 +80,13 @@ gboolean matrix_reducePrimitiveVectors(double reduced[6], double full[3][3])
 
   g_return_val_if_fail(reduced && full, FALSE);
 
-  DBG_fprintf(stderr, "Matrix : transform full to reduced matrix.\n");
+  DBG_fprintf(stderr, "Matrix: transform full to reduced matrix.\n");
+  DBG_fprintf(stderr, "Matrix: full is  %8g %8g %8g\n"
+              "                 %8g %8g %8g\n"
+	      "                 %8g %8g %8g\n",
+	      full[0][0], full[0][1], full[0][2],
+	      full[1][0], full[1][1], full[1][2],
+	      full[2][0], full[2][1], full[2][2]);
   /* Compute the X vector of the new basis, colinear with old x. */
   for (i = 0; i < 3; i++)
     {
@@ -165,6 +181,7 @@ gboolean matrix_reducePrimitiveVectors(double reduced[6], double full[3][3])
 /*   DBG_fprintf(stderr, "Z : %f %f %f\n", Z[0], Z[1], Z[2]); */
 
   /* Compute the reduce value for the basis. */
+  DBG_fprintf(stderr, " Write to reduced (%p).\n", (gpointer)reduced);
   reduced[0] = 0.;
   for (i = 0; i < 3; i++)
     reduced[0] += X[i] * full[0][i];
@@ -188,11 +205,23 @@ gboolean matrix_reducePrimitiveVectors(double reduced[6], double full[3][3])
   reduced[5] = 0.;
   for (i = 0; i < 3; i++)
     reduced[5] += Z[i] * full[2][i];
+  DBG_fprintf(stderr, " Write OK.\n");
 
   return TRUE;
 }
 
-void matrix_productMatrix(float matRes[3][3], float matA[3][3], float matB[3][3])
+/**
+ * tool_matrix_productMatrix:
+ * @matRes: an array of floating point values of size 3x3 ;
+ * @matA: an array of floating point values of size 3x3 ;
+ * @matB: an array of floating point values of size 3x3.
+ *
+ * Compute the mathematical product between @matA and @matB and
+ * put the result matrix in @matRes.
+ *
+ * Since: 3.2
+ */
+void tool_matrix_productMatrix(float matRes[3][3], float matA[3][3], float matB[3][3])
 {
   int i, j, k;
 
@@ -204,7 +233,18 @@ void matrix_productMatrix(float matRes[3][3], float matA[3][3], float matB[3][3]
 	  matRes[i][j] += matA[i][k] * matB[k][j];
       }
 }
-void matrix_productVector(float vectRes[3], float mat[3][3], float vect[3])
+/**
+ * tool_matrix_productVector:
+ * @vectRes: an array of floating point values of size 3 ;
+ * @mat: an array of floating point values of size 3x3 ;
+ * @vect: an array of floating point values of size 3.
+ *
+ * Compute the mathematical product between @matA and @vect and
+ * put the result vector in @vectRes.
+ *
+ * Since: 3.2
+ */
+void tool_matrix_productVector(float vectRes[3], float mat[3][3], float vect[3])
 {
   int i, j;
 
@@ -215,13 +255,48 @@ void matrix_productVector(float vectRes[3], float mat[3][3], float vect[3])
 	vectRes[i] += mat[i][j] * vect[j];
     }
 }
-gboolean matrix_invert(float inv[3][3], float mat[3][3])
+/**
+ * tool_matrix_determinant:
+ * @mat: a matrix.
+ *
+ * Calculate the determinant of matrix @mat.
+ *
+ * Since: 3.6
+ *
+ * Returns: the determinant value.
+ */
+float tool_matrix_determinant(float mat[3][3])
+{
+  DBG_fprintf(stderr, "Tool Matrix: %g is det( %8g %8g %8g\n"
+	              "                        %8g %8g %8g\n"
+	              "                        %8g %8g %8g )\n",
+	      mat[0][0] * (mat[1][1] * mat[2][2] - mat[1][2] * mat[2][1]) -
+              mat[0][1] * (mat[1][0] * mat[2][2] - mat[1][2] * mat[2][0]) +
+              mat[0][2] * (mat[1][0] * mat[2][1] - mat[1][1] * mat[2][0]),
+              mat[0][0], mat[0][1], mat[0][2],
+	      mat[1][0], mat[1][1], mat[1][2],
+	      mat[2][0], mat[2][1], mat[2][2]);
+
+  return mat[0][0] * (mat[1][1] * mat[2][2] - mat[1][2] * mat[2][1]) -
+    mat[0][1] * (mat[1][0] * mat[2][2] - mat[1][2] * mat[2][0]) +
+    mat[0][2] * (mat[1][0] * mat[2][1] - mat[1][1] * mat[2][0]);
+}
+/**
+ * tool_matrix_invert:
+ * @inv: a matrix (out values).
+ * @mat: a matrix.
+ *
+ * Calculate the inverse matrix of matrix @mat and store it in @inv.
+ *
+ * Since: 3.6
+ *
+ * Returns: FALSE if @mat is singular.
+ */
+gboolean tool_matrix_invert(float inv[3][3], float mat[3][3])
 {
   float det;
 
-  det = mat[0][0] * (mat[1][1] * mat[2][2] - mat[1][2] * mat[2][1]) -
-    mat[0][1] * (mat[1][0] * mat[2][2] - mat[1][2] * mat[2][0]) +
-    mat[0][2] * (mat[1][0] * mat[2][1] - mat[1][1] * mat[2][0]);
+  det = tool_matrix_determinant(mat);
   if (det == 0.f)
     return FALSE;
 
@@ -241,7 +316,20 @@ gboolean matrix_invert(float inv[3][3], float mat[3][3])
 
   return TRUE;
 }
-gboolean matrix_fromFullToBoxCartesian(float rot[3][3],
+/**
+ * tool_matrix_getRotationFromFull:
+ * @rot: a rotation matrix (out values).
+ * @full: the description of basis set in full development.
+ * @box: the description of basis set in align X axis.
+ *
+ * There is a rotation matrix to transform from full cartesian
+ * coordinates into reduced box cartesian coordinates.
+ *
+ * Since: 3.6
+ *
+ * Returns: TRUE if @full does not describe properly a 3D box.
+ */
+gboolean tool_matrix_getRotationFromFull(float rot[3][3],
 				       double full[3][3], double box[6])
 {
   float boxMat[3][3], fileMat[3][3], fileMatInv[3][3];
@@ -266,10 +354,10 @@ gboolean matrix_fromFullToBoxCartesian(float rot[3][3],
   fileMat[2][0] = (float)full[0][2];
   fileMat[2][1] = (float)full[1][2];
   fileMat[2][2] = (float)full[2][2];
-  if (!matrix_invert(fileMatInv, fileMat))
+  if (!tool_matrix_invert(fileMatInv, fileMat))
     return FALSE;
 
-  matrix_productMatrix(rot, boxMat, fileMatInv);
+  tool_matrix_productMatrix(rot, boxMat, fileMatInv);
   DBG_fprintf(stderr, "Tool Matrix: rotation matrix %8g %8g %8g\n"
 	              "                             %8g %8g %8g\n"
 	              "                             %8g %8g %8g\n",
@@ -278,6 +366,81 @@ gboolean matrix_fromFullToBoxCartesian(float rot[3][3],
 	      rot[2][0], rot[2][1], rot[2][2]);
   return TRUE;
 }
+/**
+ * tool_matrix_constrainInBox:
+ * @translat: a translation in cartesian coordinates (out values).
+ * @xyz: a set of cartesian coordinates.
+ * @extension: the box expansion in the three directions.
+ * @XYZToBox: the transformation matrix to go from cartesian to
+ * reduced coordinates.
+ * @boxToXYZ: the reverse transformation matrix.
+ *
+ * Given the box difintion as the transformation matrices @XYZToBox
+ * and @boxToXYZ and the initial @xyz cartesian coordinates, it
+ * returns the translation @translat to be applied to @xyz to move the
+ * node into the box.
+ *
+ * Since: 3.6
+ *
+ * Returns: TRUE if @translat is not (0;0;0).
+ */
+gboolean tool_matrix_constrainInBox(float translat[3], float xyz[3], float extension[3],
+                                    double XYZToBox[3][3], double boxToXYZ[3][3])
+{
+  float boxCoord[3], bounds[3], size[3];
+  gboolean moved;
+  int i, k;
+
+  bounds[0] = ceil(extension[0]);
+  bounds[1] = ceil(extension[1]);
+  bounds[2] = ceil(extension[2]);
+  size[0]   = 1. + 2. * bounds[0];
+  size[1]   = 1. + 2. * bounds[1];
+  size[2]   = 1. + 2. * bounds[2];
+
+  for (i = 0; i < 3; i++)
+    {
+      boxCoord[i]  = (float)XYZToBox[i][0] * xyz[0];
+      boxCoord[i] += (float)XYZToBox[i][1] * xyz[1];
+      boxCoord[i] += (float)XYZToBox[i][2] * xyz[2];
+    }
+  moved = FALSE;
+  for (k = 0; k < 3; k++)
+    {
+      while (boxCoord[k] < - bounds[k])
+	{
+	  moved = TRUE;
+	  boxCoord[k] += size[k];
+	}
+      while (boxCoord[k] >= 1. + bounds[k])
+	{
+	  moved = TRUE;
+	  boxCoord[k] -= size[k];
+	}
+    }
+  if (moved)
+    {
+      for (i = 0; i < 3; i++)
+	{
+	  translat[i]  = (float)boxToXYZ[i][0] * boxCoord[0];
+	  translat[i] += (float)boxToXYZ[i][1] * boxCoord[1];
+	  translat[i] += (float)boxToXYZ[i][2] * boxCoord[2];
+	}
+      translat[0] -= xyz[0];
+      translat[1] -= xyz[1];
+      translat[2] -= xyz[2];
+      DBG_fprintf(stderr, "Tool Matrix: move coord. from %gx%gx%g to %gx%gx%g.\n",
+		  xyz[0], xyz[1], xyz[2],
+		  boxCoord[0], boxCoord[1], boxCoord[2]);
+    }
+  else
+    {
+      translat[0] = 0.f;
+      translat[1] = 0.f;
+      translat[2] = 0.f;
+    }
+  return moved;
+}
 
 #ifndef RAD2DEG
 #define RAD2DEG(x) (57.29577951308232311 * x)
@@ -287,10 +450,20 @@ gboolean matrix_fromFullToBoxCartesian(float rot[3][3],
 #define DEG2RAD(x) (0.01745329251994329509 * x)
 #endif
 
-/* s[0] = pho, s[1] = theta, s[2] = phi
-   c[0] = x, c[1] = y, c[2] = z */
-void matrix_cartesianToSpherical(float *spherical, float *cartesian)
+/**
+ * tool_matrix_cartesianToSpherical:
+ * @spherical: an allocated array of 3 floating point values to store the result ;
+ * @cartesian: an allocated array of 3 floating point values to read the input.
+ *
+ * A method to transform cartesian coordinates in spherical
+ * coordinates (radius, phi and theta).
+ *
+ * Since: 3.3
+ */
+void tool_matrix_cartesianToSpherical(float *spherical, float *cartesian)
 {
+/* s[0] = rho, s[1] = theta, s[2] = phi
+   c[0] = x, c[1] = y, c[2] = z */
   const float *c = cartesian;
   float *s = spherical;
 
@@ -332,15 +505,35 @@ void matrix_cartesianToSpherical(float *spherical, float *cartesian)
   s[2] = fModulo(RAD2DEG(phi), 360);
 }
 
-void matrix_sphericalToCartesian(float *cartesian, float *spherical)
+/**
+ * tool_matrix_sphericalToCartesian:
+ * @cartesian: an allocated array of 3 floating point values to store the result ;
+ * @spherical: an allocated array of 3 floating point values to read the input.
+ *
+ * A method to transform spherical coordinates (radius, phi and theta)
+ * to cartesian coordinates.
+ *
+ * Since: 3.3
+ */
+void tool_matrix_sphericalToCartesian(float *cartesian, float *spherical)
 {
   cartesian[0] = spherical[0] * sin(DEG2RAD(spherical[1]))*cos(DEG2RAD(spherical[2]));
   cartesian[1] = spherical[0] * sin(DEG2RAD(spherical[1]))*sin(DEG2RAD(spherical[2]));
   cartesian[2] = spherical[0] * cos(DEG2RAD(spherical[1]));
-
-  return;
 }
 
+/**
+ * matrixGet_inter2D:
+ * @lambda: a location to store a float.
+ * @a: a point.
+ * @b: another point.
+ * @A: a point.
+ * @B: another point.
+ *
+ * Get the intersection coeeficient of lines [ab] and [AB].
+ *
+ * Returns: TRUE if [ab] and [AB] have an intersection.
+ */
 gboolean matrixGet_inter2D(float *lambda,
 			   float a[2], float b[2], float A[2], float B[2])
 {
@@ -354,6 +547,18 @@ gboolean matrixGet_inter2D(float *lambda,
 /*   fprintf(stderr, "%g\n", *lambda); */
   return TRUE;
 }
+/**
+ * matrixGet_inter2DFromList:
+ * @i: a location to store a point.
+ * @lambda: a location to store a float.
+ * @a: a point.
+ * @b: another point.
+ * @set: a list of points.
+ *
+ * Same as matrixGet_inter2D(), but from a list of points.
+ *
+ * Returns: TRUE if an intersection exists.
+ */
 gboolean matrixGet_inter2DFromList(float i[2], float *lambda,
 				   float a[2], float b[2], GList *set)
 {
@@ -388,19 +593,55 @@ static void exportParameters(GString *data, VisuData *dataObj);
 static gboolean readThreshold(gchar **lines, int nbLines,
 			      int position, VisuData *dataObj, GError **error);
 
-double matrixGet_linear(double x, double minmax[2], double param _U_)
+/**
+ * tool_matrix_getScaledLinear:
+ * @x: the initial value ;
+ * @minmax: the boundaries for the @x argument ;
+ *
+ * Transform @x into [0;1] with a linear scale.
+ *
+ * Returns: a value into [0;1].
+ *
+ * Since: 3.5
+ */
+double tool_matrix_getScaledLinear(double x, double minmax[2])
 {
   return ((CLAMP(x, minmax[0], minmax[1]) - minmax[0]) /
 	  (minmax[1] - minmax[0]));
 }
-double matrixGet_logarithm(double x, double minmax[2], double param)
+/**
+ * tool_matrix_getScaledLog:
+ * @x: the initial value ;
+ * @minmax: the boundaries for the @x argument.
+ *
+ * Transform @x into [0;1] with a log scale.
+ *
+ * Returns: a value into [0;1].
+ *
+ * Since: 3.5
+ */
+double tool_matrix_getScaledLog(double x, double minmax[2])
 {
-  double v;
+  /* double v; */
+  double lMinMax[2];
 
-  v = matrixGet_linear(x, minmax, param);
-  return (v == 0.)?0.: - (log10(v) - param) / param;
+  lMinMax[0] = log10(MAX(1e-12, minmax[0]));
+  lMinMax[1] = log10(MAX(1e-12, minmax[1]));
+  return tool_matrix_getScaledLinear(log10(MAX(1e-12, x)), lMinMax);
+  /* return (v == 0.)?0.: - (log10(v) - param) / param; */
 }
-double matrixGet_zeroCenteredLog(double x, double minmax[2], double param _U_)
+/**
+ * tool_matrix_getScaledZeroCentredLog:
+ * @x: the initial value ;
+ * @minmax: the boundaries for the @x argument.
+ *
+ * Transform @x into [0;1] with a log scale with zero centred values.
+ *
+ * Returns: a value into [0;1].
+ *
+ * Since: 3.5
+ */
+double tool_matrix_getScaledZeroCentredLog(double x, double minmax[2])
 {
   double v, m;
 
@@ -410,15 +651,49 @@ double matrixGet_zeroCenteredLog(double x, double minmax[2], double param _U_)
 				  log(MAX(ABS(v), m * threshold))) / 
     (2. * log(threshold));
 }
-double matrixGet_invLinear(double x, double minmax[2], double param _U_)
+/**
+ * tool_matrix_getScaledLinearInv:
+ * @x: the initial value ;
+ * @minmax: the boundaries for the @x argument.
+ *
+ * Reverse function for tool_matrix_getScaledLinear().
+ *
+ * Returns: a value into [0;1].
+ *
+ * Since: 3.5
+ */
+double tool_matrix_getScaledLinearInv(double x, double minmax[2])
 {
   return (minmax[0] + CLAMP(x, 0., 1.) * (minmax[1] - minmax[0]));
 }
-double matrixGet_invLogarithm(double x, double minmax[2], double param)
+/**
+ * tool_matrix_getScaledLogInv:
+ * @x: the initial value ;
+ * @minmax: the boundaries for the @x argument.
+ *
+ * Reverse function for tool_matrix_getScaledLog().
+ *
+ * Returns: a value into [0;1].
+ *
+ * Since: 3.5
+ */
+double tool_matrix_getScaledLogInv(double x, double minmax[2])
 {
-  return (minmax[0] + (minmax[1] - minmax[0]) * exp((1. - CLAMP(x, 0., 1.)) * param));
+  return MAX(1e-12, minmax[0]) * pow(MAX(1e-12, minmax[1]) / MAX(1e-12, minmax[0]), CLAMP(x, 0., 1.));
+  /* return (minmax[0] + (minmax[1] - minmax[0]) * exp((1. - CLAMP(x, 0., 1.)) * param)); */
 }
-double matrixGet_invZeroCenteredLog(double x, double minmax[2], double param _U_)
+/**
+ * tool_matrix_getScaledZeroCentredLogInv:
+ * @x: the initial value ;
+ * @minmax: the boundaries for the @x argument.
+ *
+ * Reverse function for tool_matrix_getScaledZeroCentredLog().
+ *
+ * Returns: a value into [0;1].
+ *
+ * Since: 3.5
+ */
+double tool_matrix_getScaledZeroCentredLogInv(double x, double minmax[2])
 {
   double s, m, out;
 
@@ -426,7 +701,7 @@ double matrixGet_invZeroCenteredLog(double x, double minmax[2], double param _U_
   s = (x < 0.5)?-1.:1.;
   m = MAX(minmax[1], -minmax[0]);
   out = s * m * threshold * exp(s * (1. - 2. * CLAMP(x, 0., 1.)) * log(threshold));
-  DBG_fprintf(stderr, " | %g (%g)\n", out, matrixGet_zeroCenteredLog(out, minmax, 0.));
+  DBG_fprintf(stderr, " | %g (%g)\n", out, tool_matrix_getScaledZeroCentredLog(out, minmax));
   return out;
 }
 
@@ -445,7 +720,7 @@ static gboolean readThreshold(gchar **lines, int nbLines,
 
   if (sscanf(lines[0],"%f", &val) != 1 || val <= 0.f)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_MISSING,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
 			   _("Parse error at line %d,"
 			     " 1 positive float value must appear"
 			     " after the %s markup.\n"),
@@ -457,16 +732,23 @@ static gboolean readThreshold(gchar **lines, int nbLines,
 
   return TRUE;
 }
-void matrixInit()
+/**
+ * initToolMatrix: (skip)
+ *
+ * This method is used by V_Sim internally and should not be called.
+ *
+ * Since: 3.5
+ */
+void initToolMatrix(void)
 {
   VisuConfigFileEntry *entry;
 
   /* Set private variables. */
-  entry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  entry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 				  FLAG_PARAMETER_THRESHOLD,
 				  DESC_PARAMETER_THRESHOLD,
 				  1, readThreshold);
-  visuConfigFileSet_version(entry, 3.5f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(entry, 3.5f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParameters);
 }
