@@ -275,7 +275,7 @@ gboolean shadeSet_linearCoeff(Shade *shade, float coeff, int channel, int order)
   *pt = coeff;
   return TRUE;
 }
-void shadeGet_RGBFromValues(Shade *shade, float rgba[4], float values[3])
+void shadeGet_RGBFromValues(const Shade *shade, float rgba[4], float values[3])
 {
   int i;
   float f;
@@ -310,9 +310,9 @@ void shadeGet_RGBFromValues(Shade *shade, float rgba[4], float values[3])
   rgba[3] = 1.;
   /* Transform if required. */
   if (shade->colorMode == shade_colorModeHSV)
-    color_HSVtoRGB(rgba, rgba);
+    tool_color_convertHSVtoRGB(rgba, rgba);
 }
-void shadeGet_valueTransformedInRGB(Shade *shade, float rgba[4], float value)
+void shadeGet_valueTransformedInRGB(const Shade *shade, float rgba[4], float value)
 {
   float vals[3];
 
@@ -327,15 +327,15 @@ void shadeGet_valueTransformedInRGB(Shade *shade, float rgba[4], float value)
 /****************/
 void shadeDraw_legend(Shade *shade, float widthVal, float heightVal,
 		      float minMax[2], float *marks, int nbMarks,
-		      matrix_scaleflag scale, float *smin)
+		      ToolMatrixScalingFlag scale)
 {
   int viewport[4];
   guint width, height, wTotal, hTotal;
   int i;
-  float yStep, logval;
+  float yStep, xbuf, ybuf;
   float rgba[4];
   char value[16];
-  matrixGet_scaleVal get_val, get_inv;
+  tool_matrix_getScaledValue get_inv;
   double minmax[2];
 
   g_return_if_fail(shade);
@@ -404,52 +404,55 @@ void shadeDraw_legend(Shade *shade, float widthVal, float heightVal,
   switch (scale)
     {
     case linear:
-      logval = 0.;
-      get_val = matrixGet_linear;
-      get_inv = matrixGet_invLinear;
+      get_inv = tool_matrix_getScaledLinearInv;
       break;
     case logarithm:
-      logval = log10((*smin - minMax[0]) /
-		     (minMax[1] - minMax[0]));
-      get_val = matrixGet_logarithm;
-      get_inv = matrixGet_invLogarithm;
+      get_inv = tool_matrix_getScaledLogInv;
       break;
     case zeroCentredLog:
-      logval = 0;
-      get_val = matrixGet_zeroCenteredLog;
-      get_inv = matrixGet_invZeroCenteredLog;
+      get_inv = tool_matrix_getScaledZeroCentredLogInv;
       break;
     default:
-      logval = 0.;
-      get_val = (matrixGet_scaleVal)0;
-      get_inv = (matrixGet_scaleVal)0;
+      get_inv = (tool_matrix_getScaledValue)0;
       break;
     }
-  g_return_if_fail(get_val);
+  g_return_if_fail(get_inv);
+
+  glDisable(GL_LINE_SMOOTH);
 
   /* We draw some marks. */
   if (marks)
     {
+      xbuf = 3.;
+      ybuf = 1.;
       glLineWidth(2);
       glBegin(GL_LINES);
       for (i = 0; i < nbMarks; i++)
 	{
-	  yStep = (float)get_val((double)marks[i], minmax, logval);
+          if (i > 1)
+            {
+              glEnd();
+              glLineWidth(1);
+              glBegin(GL_LINES);
+              xbuf = 8.;
+              ybuf = 0.;
+            }
+	  yStep = CLAMP(marks[i], 0., 1.);
 	  shadeGet_valueTransformedInRGB(shade, rgba, yStep);
 	  rgba[0] = 1. - rgba[0];
 	  rgba[1] = 1. - rgba[1];
 	  rgba[2] = 1. - rgba[2];
 	  glColor4fv(rgba);
 	  yStep *= (float)height;
-	  glVertex2f(5. + 3., 5. + yStep);
-	  glVertex2f(5. + (float)width - 3., 5. + yStep);
+	  glVertex2f(5. + xbuf, 5. + ybuf + yStep);
+	  glVertex2f(5. + (float)width - xbuf, 5. + ybuf + yStep);
 	}
       glEnd();
     }
 
   /* We draw the frame around. */
   glColor3f(0., 0., 0.);
-  glLineWidth(1);
+  glLineWidth(1.f);
   glBegin(GL_LINE_STRIP);
   glVertex2i(5, 5);
   glVertex2i(5 + width, 5);
@@ -460,7 +463,7 @@ void shadeDraw_legend(Shade *shade, float widthVal, float heightVal,
 
   /* We draw the tics. */
   glColor3f(0., 0., 0.);
-  glLineWidth(1);
+  glLineWidth(1.f);
   glBegin(GL_LINES);
   glVertex2i(5 + width    , 5);
   glVertex2i(5 + width + 3, 5);
@@ -473,16 +476,16 @@ void shadeDraw_legend(Shade *shade, float widthVal, float heightVal,
   glEnd();
   
   /* We print the labels. */
-  sprintf(value, "%.3g", get_inv(0., minmax, logval));
+  sprintf(value, "%.3g", get_inv(0., minmax));
   glRasterPos2i(5 + width + 5, 5);
   openGLText_drawChars(value, TEXT_NORMAL); 
-  sprintf(value, "%.3g", get_inv(0.33333, minmax, logval));
+  sprintf(value, "%.3g", get_inv(0.33333, minmax));
   glRasterPos2i(5 + width + 5, 5 + height / 3 - 6);
   openGLText_drawChars(value, TEXT_NORMAL); 
-  sprintf(value, "%.3g", get_inv(0.66667, minmax, logval));
+  sprintf(value, "%.3g", get_inv(0.66667, minmax));
   glRasterPos2i(5 + width + 5, 5 + 2 * height / 3 - 6);
   openGLText_drawChars(value, TEXT_NORMAL);
-  sprintf(value, "%.3g", get_inv(1., minmax, logval));
+  sprintf(value, "%.3g", get_inv(1., minmax));
   glRasterPos2i(5 + width + 5, 5 + height - 12);
   openGLText_drawChars(value, TEXT_NORMAL);
 
@@ -500,7 +503,7 @@ void shadeDraw_legend(Shade *shade, float widthVal, float heightVal,
 /*********************************************/
 /* Methods to deal with internal shade list. */
 /*********************************************/
-GList* toolShadeListGet()
+GList* toolShadeListGet(void)
 {
   return toolShadeList;
 }
@@ -511,12 +514,12 @@ GList* toolShadeListAppend(Shade *shade)
   toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
   return toolShadeList;
 }
-GList* toolShadeBuild_presetList()
+GList* toolShadeBuild_presetList(void)
 {
   Shade *shade;
   float vectA[3], vectB[3];
 
-  /* Zero Centred Coloured. */
+  /* Zero Centred Colored. */
   #define zccLn 3
   float zccH[zccLn] = {0.f, 0.333f, 0.667f};
   float zccS[zccLn] = {1.0f, 0.0f, 1.0f};
