@@ -56,26 +56,26 @@
  */
 
 static gpointer waitData;
-static voidDataFunc waitFunc;
+static ToolVoidDataFunc waitFunc;
 
-static gboolean writeViewInPngFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInPngFormat(ToolFileFormat *format, const char* filename,
 				     int width, int height, VisuData *dataObj,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait, gpointer data);
-static gboolean writeViewInJpegFormat(FileFormat *format, const char* filename,
+				     ToolVoidDataFunc functionWait, gpointer data);
+static gboolean writeViewInJpegFormat(ToolFileFormat *format, const char* filename,
 				      int width, int height, VisuData *dataObj,
 				      guchar* imageData, GError **error,
-				      voidDataFunc functionWait, gpointer data);
+				      ToolVoidDataFunc functionWait, gpointer data);
 
 
-DumpType* dumpToPNG_init()
+VisuDump* dumpToPNG_init()
 {
-  DumpType *png;
+  VisuDump *png;
   char *typePng[] = {"*.png", (char*)0};
-  FileFormat* fmt;
+  ToolFileFormat* fmt;
 
-  png = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(_("Png file"), typePng);
+  png = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(_("Png file"), typePng);
   if (!fmt)
     {
       g_error("Can't initialize the Png dump module, aborting.\n");
@@ -83,23 +83,24 @@ DumpType* dumpToPNG_init()
 
   png->bitmap = TRUE;
   png->hasAlpha = TRUE;
+  png->glRequired = TRUE;
   png->fileType = fmt;
   png->writeFunc = writeViewInPngFormat;
   
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
 
   return png;
 }
 
-DumpType* dumpToJPEG_init()
+VisuDump* dumpToJPEG_init()
 {
-  DumpType *jpeg;
+  VisuDump *jpeg;
   char *typeJpeg[] = {"*.jpg", "*.jpeg", (char*)0};
-  FileFormat* fmt;
+  ToolFileFormat* fmt;
 
-  jpeg = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(_("Jpeg file"), typeJpeg);
+  jpeg = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(_("Jpeg file"), typeJpeg);
   if (!fmt)
     {
       g_error("Can't initialize the Jpeg dump module, aborting.\n");
@@ -107,18 +108,20 @@ DumpType* dumpToJPEG_init()
 
   jpeg->bitmap = TRUE;
   jpeg->hasAlpha = FALSE;
+  jpeg->glRequired = TRUE;
   jpeg->fileType = fmt;
   jpeg->writeFunc = writeViewInJpegFormat;
 
-  fileFormatAdd_propertyInteger(fmt, "quality", _("Compression ratio (given in percent)"), 85);
+  tool_file_format_addPropertyInt(fmt, "quality",
+                                  _("Compression ratio (given in percent)"), 85);
   
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
 
   return jpeg;
 }
 
-static gboolean writeViewWithGdkPixbuf(FileFormat *format, const char* filename,
+static gboolean writeViewWithGdkPixbuf(ToolFileFormat *format, const char* filename,
 				       int width, int height, char *type,
 				       VisuData *dataObj _U_, guchar* imageData,
 				       GError **error)
@@ -126,9 +129,10 @@ static gboolean writeViewWithGdkPixbuf(FileFormat *format, const char* filename,
   unsigned char *image;
   GdkPixbuf *pixbuf;
   gboolean success, hasAlpha;
-  GList *prop;
+  const GList *prop;
   char **propName, **propValues;
   int nb, length;
+  ToolFileFormatIter iter;
 
   g_return_val_if_fail(error && !*error, FALSE);
   g_return_val_if_fail(imageData, FALSE);
@@ -165,26 +169,18 @@ static gboolean writeViewWithGdkPixbuf(FileFormat *format, const char* filename,
       return FALSE;
     }
   
-  prop = fileFormatGet_propertiesList(format);
-  nb = g_list_length(prop) + 1;
-  propName = g_malloc(sizeof(char*) * nb);
-  propValues = g_malloc(sizeof(char*) * nb);
+  prop = tool_file_format_getPropertyList(format);
+  nb = g_list_length((GList*)prop) + 1;
+  propName = g_malloc(sizeof(gchar*) * nb);
+  propValues = g_malloc(sizeof(gchar*) * nb);
   nb = 0;
-  while (prop)
+  iter.lst = (GList*)0;
+  for (tool_file_format_iterNextProperty(format, &iter); iter.lst;
+       tool_file_format_iterNextProperty(format, &iter))
     {
-      propName[nb] = g_strdup(fileFormatGet_propertyName((FileFormatProperty*)(prop->data)));
-      switch (fileFormatGet_propertyType((FileFormatProperty*)(prop->data)))
-	{
-	case fileFormat_type_integer:
-	  propValues[nb] =
-	    g_strdup_printf("%d",
-			    fileFormatGet_propertyInteger((FileFormatProperty*)(prop->data)));
-	  break;
-	default:
-	  propValues[nb] = g_malloc(sizeof(char));
-	};
+      propName[nb] = g_strdup(iter.name);
+      propValues[nb] = g_strdup_value_contents(iter.val);
       nb += 1;
-      prop = g_list_next(prop);
     }
   propName[nb] = (char*)0;
   propValues[nb] = (char*)0;
@@ -195,10 +191,10 @@ static gboolean writeViewWithGdkPixbuf(FileFormat *format, const char* filename,
   return success;
 }
 
-static gboolean writeViewInJpegFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInJpegFormat(ToolFileFormat *format, const char* filename,
 				     int width, int height, VisuData *dataObj,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait, gpointer data)
+				     ToolVoidDataFunc functionWait, gpointer data)
 {
   int i, res;
 
@@ -213,10 +209,10 @@ static gboolean writeViewInJpegFormat(FileFormat *format, const char* filename,
   return res;
 }
 
-static gboolean writeViewInPngFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInPngFormat(ToolFileFormat *format, const char* filename,
 				     int width, int height, VisuData *dataObj,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait, gpointer data)
+				     ToolVoidDataFunc functionWait, gpointer data)
 {
   int i, res;
 
