@@ -50,17 +50,17 @@
  * This routine should not be used since it inialised the module
  * and is already called when V_Sim is launched.
  *
- * Returns: a newly created dump object to create PNG files.
+ * Returns: (transfer none): a newly created dump object to create PNG files.
  */
-DumpType* dumpToPNG_init();
+VisuDump* dumpToPNG_init();
 /**
  * dumpToJPEG_init:
  *
  * This routine should not be used since it inialised the module
  * and is already called when V_Sim is launched.
  *
- * Returns: a newly created dump object to create JPEG files.
+ * Returns: (transfer none): a newly created dump object to create JPEG files.
  */
-DumpType* dumpToJPEG_init();
+VisuDump* dumpToJPEG_init();
 
 #endif
