@@ -50,6 +50,7 @@
 
 #include <visu_tools.h>
 #include <extraFunctions/extraNode.h>
+#include <extraFunctions/geometry.h>
 
 /**
  * SECTION:dumpToAscii
@@ -60,65 +61,65 @@
  * or replicated nodes.
  */
 
-static gboolean writeDataInAscii(FileFormat *format, const char* filename,
+static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 				 int width, int height, VisuData *dataObj,
 				 guchar* imageData, GError **error,
-				 voidDataFunc functionWait, gpointer data);
+				 ToolVoidDataFunc functionWait, gpointer data);
 static gpointer waitData;
-static voidDataFunc waitFunc;
+static ToolVoidDataFunc waitFunc;
 
-DumpType* dumpToAscii_init()
+VisuDump* dumpToAscii_init()
 {
-  DumpType *ascii;
+  VisuDump *ascii;
   char *typeASCII[] = {"*.ascii", (char*)0};
-#define descrASCII _("Ascii file (current positions)")
-  FileFormat* fmt;
+#define descrASCII _("ASCII file (current positions)")
+  ToolFileFormat* fmt;
 
-  ascii = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(descrASCII, typeASCII);
+  ascii = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(descrASCII, typeASCII);
   if (!fmt)
     {
       g_error("Can't initialize the ASCII dump module, aborting.\n");
     }
 
   ascii->bitmap = FALSE;
+  ascii->glRequired = FALSE;
   ascii->fileType = fmt;
   ascii->writeFunc = writeDataInAscii;
   
-  fileFormatAdd_propertyBoolean(fmt, "delete_hidden_nodes",
+  tool_file_format_addPropertyBoolean(fmt, "delete_hidden_nodes",
 				_("Don't output hidden nodes"), FALSE);
-  fileFormatAdd_propertyBoolean(fmt, "comment_hidden_nodes",
+  tool_file_format_addPropertyBoolean(fmt, "comment_hidden_nodes",
 				_("Comment hidden nodes (if output)"), TRUE);
-  fileFormatAdd_propertyBoolean(fmt, "expand_box",
+  tool_file_format_addPropertyBoolean(fmt, "expand_box",
 				_("Keep primitive box (in case of node expansion)"), FALSE);
-  fileFormatAdd_propertyBoolean(fmt, "reduced_coordinates",
+  tool_file_format_addPropertyBoolean(fmt, "reduced_coordinates",
 				_("Export positions in reduced coordinates"), FALSE);
-  fileFormatAdd_propertyBoolean(fmt, "angdeg_box",
+  tool_file_format_addPropertyBoolean(fmt, "angdeg_box",
 				_("Export box as lengths and angles"), FALSE);
-  fileFormatAdd_propertyBoolean(fmt, "type_alignment",
+  tool_file_format_addPropertyBoolean(fmt, "type_alignment",
 				_("Export nodes sorted by elements"), FALSE);
 
   waitData = (gpointer)0;
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
 
   return ascii;
 }
 
-static gboolean writeDataInAscii(FileFormat *format, const char* filename,
+static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 				 int width _U_, int height _U_, VisuData *dataObj,
 				 guchar* imageData _U_, GError **error,
-				 voidDataFunc functionWait, gpointer data)
+				 ToolVoidDataFunc functionWait, gpointer data)
 {
   gchar *nom, *prevFile;
-  OpenGLView *view;
   char tmpChr;
-  GList *prop;
-  gchar* name;
+  gchar *diff;
   gboolean suppr, comment, expand, reduced, angdeg, eleSort;
   float xyz[3], ext[3], uvw[3], vertices[8][3], box[6];
   VisuDataIter iter;
   GString *output;
   const gchar *nodeComment;
+  ToolFileFormatIter it;
 
   g_return_val_if_fail(error && !*error, FALSE);
 
@@ -128,33 +129,39 @@ static gboolean writeDataInAscii(FileFormat *format, const char* filename,
   reduced = FALSE;
   angdeg  = FALSE;
   eleSort = FALSE;
-  prop = fileFormatGet_propertiesList(format);
-  while (prop)
+  it.lst = (GList*)0;
+  for (tool_file_format_iterNextProperty(format, &it); it.lst;
+       tool_file_format_iterNextProperty(format, &it))
     {
-      name = fileFormatGet_propertyName((FileFormatProperty*)(prop->data));
-      if (strcmp(name, "comment_hidden_nodes") == 0)
-	comment = fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data));
-      else if (strcmp(name, "expand_box") == 0)
-	expand  = !fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data));
-      else if (strcmp(name, "delete_hidden_nodes") == 0)
-	suppr   = fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data));
-      else if (strcmp(name, "reduced_coordinates") == 0)
-	reduced = fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data));
-      else if (strcmp(name, "angdeg_box") == 0)
-	angdeg  = fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data));
-      else if (strcmp(name, "type_alignment") == 0)
-	eleSort  = fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data));
-      prop = g_list_next(prop);
+      DBG_fprintf(stderr, "Dump ASCII: test property '%s'.\n", it.name);
+      if (strcmp(it.name, "comment_hidden_nodes") == 0)
+	comment = g_value_get_boolean(it.val);
+      else if (strcmp(it.name, "expand_box") == 0)
+	expand  = !g_value_get_boolean(it.val);
+      else if (strcmp(it.name, "delete_hidden_nodes") == 0)
+	suppr   = g_value_get_boolean(it.val);
+      else if (strcmp(it.name, "reduced_coordinates") == 0)
+	reduced = g_value_get_boolean(it.val);
+      else if (strcmp(it.name, "angdeg_box") == 0)
+	angdeg  = g_value_get_boolean(it.val);
+      else if (strcmp(it.name, "type_alignment") == 0)
+	eleSort = g_value_get_boolean(it.val);
     }
 
   waitData = data;
   waitFunc = functionWait;
 
   DBG_fprintf(stderr, "Dump ASCII: begin export of current positions...\n");
+  DBG_fprintf(stderr, " | comment %d ;\n", comment);
+  DBG_fprintf(stderr, " | expand  %d ;\n", expand);
+  DBG_fprintf(stderr, " | suppr   %d ;\n", suppr);
+  DBG_fprintf(stderr, " | reduced %d ;\n", reduced);
+  DBG_fprintf(stderr, " | angdeg  %d ;\n", angdeg);
+  DBG_fprintf(stderr, " | eleSort %d ;\n", eleSort);
 
   output = g_string_new("");
 
-  nom = visuDataGet_file(dataObj, 0, (FileFormat**)0);
+  nom = visu_data_getFile(dataObj, 0, (ToolFileFormat**)0);
   if (nom)
     {
       prevFile = g_path_get_basename(nom);
@@ -167,18 +174,9 @@ static gboolean writeDataInAscii(FileFormat *format, const char* filename,
       g_string_append(output, "# V_Sim export to ascii\n");
     }
 
-  view = visuDataGet_openGLView(dataObj);
-  if (expand)
-    visuDataGet_extension(dataObj, ext);
-  else
-    {
-      ext[0] = 0.;
-      ext[1] = 0.;
-      ext[2] = 0.;
-    }
+  visu_data_getBoxVertices(dataObj, vertices, expand);
   if (angdeg)
     {
-      visuDataGet_boxVertices(dataObj, vertices, expand);
       box[0] = sqrt((vertices[1][0] - vertices[0][0]) *
 		    (vertices[1][0] - vertices[0][0]) +
 		    (vertices[1][1] - vertices[0][1]) *
@@ -222,20 +220,20 @@ static gboolean writeDataInAscii(FileFormat *format, const char* filename,
     }
   else
     {
-      box[0] = view->box->p2[0] * (1. + 2. * ext[0]);
-      box[1] = view->box->p4[0] * (1. + 2. * ext[1]);
-      box[2] = view->box->p4[1] * (1. + 2. * ext[1]);
-      box[3] = view->box->p5[0] * (1. + 2. * ext[2]);
-      box[4] = view->box->p5[1] * (1. + 2. * ext[2]);
-      box[5] = view->box->p5[2] * (1. + 2. * ext[2]);
+      box[0] = vertices[1][0] - vertices[0][0];
+      box[1] = vertices[3][0] - vertices[0][0];
+      box[2] = vertices[3][1] - vertices[0][1];
+      box[3] = vertices[4][0] - vertices[0][0];
+      box[4] = vertices[4][1] - vertices[0][1];
+      box[5] = vertices[4][2] - vertices[0][2];
     }
-  g_string_append_printf(output, "%15g %15g %15g\n", box[0], box[1], box[2]);
-  g_string_append_printf(output, "%15g %15g %15g\n", box[3], box[4], box[5]);
+  g_string_append_printf(output, "%17.8g %17.8g %17.8g\n", box[0], box[1], box[2]);
+  g_string_append_printf(output, "%17.8g %17.8g %17.8g\n", box[3], box[4], box[5]);
   if (angdeg)
     g_string_append(output, "#keyword: angdeg\n");
   if (reduced)
     g_string_append(output, "#keyword: reduced\n");
-  switch (visuDataGet_unit(dataObj))
+  switch (visu_data_getUnit(dataObj))
     {
     case unit_angstroem:
       g_string_append(output, "#keyword: angstroem\n");
@@ -246,27 +244,44 @@ static gboolean writeDataInAscii(FileFormat *format, const char* filename,
     default:
       break;
     }
-  switch (visuDataGet_boundaryConditions(dataObj))
+  switch (visu_data_getBoundaryConditions(dataObj))
     {
-    case BOX_SURFACE_XY:
-    case BOX_SURFACE_YZ:
-    case BOX_SURFACE_ZX:
+    case VISU_DATA_BOX_SURFACE_XY:
+      g_string_append(output, "#keyword: surfaceXY\n");
+      break;
+    case VISU_DATA_BOX_SURFACE_YZ:
+      g_string_append(output, "#keyword: surfaceYZ\n");
+      break;
+    case VISU_DATA_BOX_SURFACE_ZX:
       g_string_append(output, "#keyword: surface\n");
       break;
-    case BOX_FREE:
+    case VISU_DATA_BOX_FREE:
+      if (reduced)
+	g_warning("Using reduced coordinates in free boundary conditions"
+		  " is possible but not not adviced. The given box will be"
+		  " used to obtain the real coordinates.");
       g_string_append(output, "#keyword: freeBC\n");
       break;
     default:
       break;
     }
 
+  visu_data_getBoxVertices(dataObj, vertices, FALSE);
+  if (expand)
+    visu_data_getExtension(dataObj, ext);
+  else
+    {
+      ext[0] = 0.;
+      ext[1] = 0.;
+      ext[2] = 0.;
+    }
   if (ext[0] != 0. || ext[1] != 0. || ext[2] != 0.)
     {
       g_string_append(output, "# Box is expanded, previous box size:\n");
-      g_string_append_printf(output, "# %15g %15g %15g\n", view->box->p2[0], view->box->p4[0],
-	      view->box->p4[1]);
-      g_string_append_printf(output, "# %15g %15g %15g\n", view->box->p5[0], view->box->p5[1],
-	      view->box->p5[2]);
+      g_string_append_printf(output, "# %15g %15g %15g\n", vertices[1][0],
+			     vertices[3][0], vertices[3][1]);
+      g_string_append_printf(output, "# %15g %15g %15g\n", vertices[4][0],
+			     vertices[4][1], vertices[4][2]);
       g_string_append(output, "# and box extension:\n");
       g_string_append_printf(output, "# %15g %15g %15g\n", ext[0], ext[1], ext[2]);
     }
@@ -275,35 +290,47 @@ static gboolean writeDataInAscii(FileFormat *format, const char* filename,
       g_string_append(output, "# Statistics are valid for all nodes (hidden or not).\n");
       g_string_append(output, "# Hidden nodes are printed, but commented.\n");
     }
-  visuDataIter_new(dataObj, &iter);
+  visu_data_iterNew(dataObj, &iter);
   g_string_append_printf(output, "# Box contains %d element(s).\n", iter.nElements);
   g_string_append_printf(output, "# Box contains %d nodes.\n", iter.nAllStoredNodes);
-  for (visuDataIter_start(dataObj, &iter); iter.element;
-       visuDataIter_nextElement(dataObj, &iter))
+  for (visu_data_iterStart(dataObj, &iter); iter.element;
+       visu_data_iterNextElement(dataObj, &iter))
     g_string_append_printf(output, "#  | %d nodes for element '%s'.\n",
 	    iter.nStoredNodes[iter.iElement], iter.element->name);
   if (suppr)
     g_string_append(output, "# Hidden nodes have been suppressed.\n");
+  if (visu_geodiff_hasData(dataObj))
+    {
+      diff = visu_geodiff_export(dataObj);
+      g_string_append(output, diff);
+      g_free(diff);
+    }
 
-  for (visuDataIter_startNumber(dataObj, &iter); iter.node && iter.element;
-       (eleSort)?visuDataIter_next(dataObj, &iter):
-       visuDataIter_nextNodeNumber(dataObj, &iter))
+  for ((eleSort)?visu_data_iterStart(dataObj, &iter):
+	 visu_data_iterStartNumber(dataObj, &iter);
+       iter.node && iter.element;
+       (eleSort)?visu_data_iterNext(dataObj, &iter):
+	 visu_data_iterNextNodeNumber(dataObj, &iter))
     {
       if ((iter.element->rendered && iter.node->rendered) || !comment)
 	tmpChr = ' ';
       else
 	tmpChr = '#';
-      visuDataGet_nodePosition(dataObj, iter.node, xyz);
+
+      visu_data_getNodePosition(dataObj, iter.node, xyz);
+
       if ((iter.element->rendered && iter.node->rendered) || !suppr)
 	{
-	  xyz[0] += ext[0] * view->box->p2[0] + ext[1] * view->box->p4[0] +
-	    ext[2] * view->box->p5[0];
-	  xyz[1] += ext[1] * view->box->p4[1] + ext[2] * view->box->p5[1];
-	  xyz[2] += ext[2] * view->box->p5[2];
+/*g_message("ext : %f,  vertices : %f, ext : %f, vertices : %f, ext : %f, vertice : %f\n",ext[0],vertices[1][0],ext[1],vertices[3][0],
+	    ext[2],vertices[4][0]);*/
+	  xyz[0] += ext[0] * vertices[1][0] + ext[1] * vertices[3][0] +
+	    ext[2] * vertices[4][0];
+	  xyz[1] += ext[1] * vertices[3][1] + ext[2] * vertices[4][1];
+	  xyz[2] += ext[2] * vertices[4][2];
 	  
 	  if (reduced)
 	    {
-	      visuDataConvert_XYZtoBoxCoordinates(dataObj, uvw, xyz);
+	      visu_data_convertXYZtoBoxCoordinates(dataObj, uvw, xyz);
 	      uvw[0] /= (1.f + 2.f * ext[0]);
 	      uvw[1] /= (1.f + 2.f * ext[1]);
 	      uvw[2] /= (1.f + 2.f * ext[2]);
@@ -314,7 +341,7 @@ static gboolean writeDataInAscii(FileFormat *format, const char* filename,
 	      uvw[1] = xyz[1];
 	      uvw[2] = xyz[2];
 	    }
-	  g_string_append_printf(output, "%c%15g %15g %15g %s", tmpChr,
+	  g_string_append_printf(output, "%c%17.8g %17.8g %17.8g %s", tmpChr,
 		  uvw[0], uvw[1], uvw[2], iter.element->name);
 	  nodeComment = extraNodeGet_label(dataObj, iter.node);
 	  if (nodeComment)
