@@ -52,8 +52,8 @@
  * This routine should not be used since it inialised the module
  * and is already called when V_Sim is launched.
  *
- * Returns: a newly created dump object to create ASCII files.
+ * Returns: (transfer none): a newly created dump object to create ASCII files.
  */
-DumpType* dumpToAscii_init();
+VisuDump* dumpToAscii_init();
 
 #endif
