@@ -114,7 +114,7 @@ static FILE *file;
 #define NodesInAList  2048
 
 static gpointer waitData;
-static voidDataFunc waitFunc;
+static ToolVoidDataFunc waitFunc;
 
 
 typedef struct _Node {
@@ -161,10 +161,10 @@ static void Reduction(unsigned int number_colors);
 static unsigned int LZWEncodeImage(unsigned int data_size);
 static void LSBFirstWriteShort(unsigned int value);
 
-static gboolean writeViewInGifFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInGifFormat(ToolFileFormat *format, const char* filename,
 				     int width, int height, VisuData *dataObj,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait, gpointer data);
+				     ToolVoidDataFunc functionWait, gpointer data);
 
 
 /******************************************************************************/
@@ -581,7 +581,7 @@ void Reduction(unsigned int number_colors)
 /******************************************************************************/
 
 unsigned int dumpToGif_quantizeImage(unsigned int number_colors, GError **error,
-				     voidDataFunc functionWait, gpointer data)
+				     ToolVoidDataFunc functionWait, gpointer data)
 {
   Nodes *nodes;
 
@@ -805,15 +805,15 @@ static void write_comment_comm(unsigned char comm[]) {
 
 /******************************************************************************/
 
-DumpType* dumpToGif_init()
+VisuDump* dumpToGif_init()
 {
-  DumpType *gif;
+  VisuDump *gif;
   char *typeGIF[] = {"*.gif", (char*)0};
   #define descrGIF _("Gif (256 colors) file")
-  FileFormat* fmt;
+  ToolFileFormat* fmt;
 
-  gif = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(descrGIF, typeGIF);
+  gif = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(descrGIF, typeGIF);
   if (!fmt)
     {
       g_error("Can't initialize the GIF dump module, aborting.\n");
@@ -821,20 +821,21 @@ DumpType* dumpToGif_init()
 
   gif->bitmap = TRUE;
   gif->hasAlpha = FALSE;
+  gif->glRequired = TRUE;
   gif->fileType = fmt;
   gif->writeFunc = writeViewInGifFormat;
 
   waitData = (gpointer)0;
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
 
   return gif;
 }
 
 
-static gboolean writeViewInGifFormat(FileFormat *format _U_, const char* filename,
+static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* filename,
 				     int width, int height, VisuData *dataObj _U_,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait, gpointer data)
+				     ToolVoidDataFunc functionWait, gpointer data)
 {
   register unsigned int i;
   register ColorPacket *q;
