@@ -64,7 +64,7 @@
  *
  * This provides a write routine to export V_Sim views into bitmaps
  * encapsulated into PS or PDF files. The PostScript file can be
- * either in 256 colours or in full True Colour. For a vectorial
+ * either in 256 colours or in full True Color. For a vectorial
  * export, see #dumpToSVG.
  */
 
@@ -80,35 +80,35 @@ static Image *img;
 static int PSwidth, PSheight;
 
 static gpointer waitData;
-static voidDataFunc waitFunc;
+static ToolVoidDataFunc waitFunc;
 
 
-static gboolean writeViewInPsFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInPsFormat(ToolFileFormat *format, const char* filename,
 				    int width, int height, VisuData *dataObj,
 				    guchar* imageData, GError **error,
-				    voidDataFunc functionWait, gpointer data);
+				    ToolVoidDataFunc functionWait, gpointer data);
 static gboolean writeViewInPs256Format(const char* filename,
 				       int width, int height, VisuData *dataObj,
 				       guchar* imageData, GError **error,
-				       voidDataFunc functionWait, gpointer data);
+				       ToolVoidDataFunc functionWait, gpointer data);
 static gboolean writePsTrueColor(const char* filename,
 				 int width, int height, VisuData *dataObj,
 				 guchar* imageData, GError **error,
-				 voidDataFunc functionWait, gpointer data);
-static gboolean writeViewInPdfFormat(FileFormat *format, const char* filename,
+				 ToolVoidDataFunc functionWait, gpointer data);
+static gboolean writeViewInPdfFormat(ToolFileFormat *format, const char* filename,
 				     int width, int height, VisuData *dataObj,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait, gpointer data);
+				     ToolVoidDataFunc functionWait, gpointer data);
 
-DumpType* dumpToPS_init()
+VisuDump* dumpToPS_init()
 {
-  DumpType *ps;
+  VisuDump *ps;
   char *typePS[] = {"*.ps", (char*)0};
-  #define descrPS _("Postscript (v3.0) file")
-  FileFormat* fmt;
+  #define descrPS _("Bitmap in a postscript (v3.0) file")
+  ToolFileFormat* fmt;
 
-  ps = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(descrPS, typePS);
+  ps = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(descrPS, typePS);
   if (!fmt)
     {
       g_error("Can't initialize the PS dump module, aborting.\n");
@@ -116,26 +116,27 @@ DumpType* dumpToPS_init()
 
   ps->bitmap = TRUE;
   ps->hasAlpha = FALSE;
+  ps->glRequired = TRUE;
   ps->fileType = fmt;
   ps->writeFunc = writeViewInPsFormat;
 
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
 
-  fileFormatAdd_propertyBoolean(fmt, "reduced_colormap",
-				_("Use a reduced colormap (256 colors)"), FALSE);
+  tool_file_format_addPropertyBoolean(fmt, "reduced_colormap",
+                                      _("Use a reduced colormap (256 colors)"), FALSE);
   
   return ps;
 }
-DumpType* dumpToPDF_init()
+VisuDump* dumpToPDF_init()
 {
-  DumpType *pdf;
+  VisuDump *pdf;
   char *typePDF[] = {"*.pdf", (char*)0};
-#define descrPDF _("PDF file (v. 1.2)")
-  FileFormat* fmt;
+#define descrPDF _("Bitmap in a PDF (v. 1.2)")
+  ToolFileFormat* fmt;
 
-  pdf = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(descrPDF, typePDF);
+  pdf = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(descrPDF, typePDF);
   if (!fmt)
     {
       g_error("Can't initialize the PS dump module, aborting.\n");
@@ -143,10 +144,11 @@ DumpType* dumpToPDF_init()
 
   pdf->bitmap = TRUE;
   pdf->hasAlpha = FALSE;
+  pdf->glRequired = TRUE;
   pdf->fileType = fmt;
   pdf->writeFunc = writeViewInPdfFormat;
   
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
 
   return pdf;
@@ -347,31 +349,24 @@ static void OutputDataPS256() {
 
 /******************************************************************************/
 
-static gboolean writeViewInPsFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInPsFormat(ToolFileFormat *format, const char* filename,
 				    int width, int height, VisuData *dataObj,
 				    guchar* imageData, GError **error,
-				    voidDataFunc functionWait, gpointer data)
+				    ToolVoidDataFunc functionWait, gpointer data)
 {
-  GList *prop;
-  gchar* name;
+  ToolOption *prop;
+  GValue *val;
 
-  prop = fileFormatGet_propertiesList(format);
-  while (prop)
-    {
-      name = fileFormatGet_propertyName((FileFormatProperty*)(prop->data));
-      if (strcmp(name, "reduced_colormap") == 0)
-	{
-	  if (fileFormatGet_propertyBoolean((FileFormatProperty*)(prop->data)))
-	    return writeViewInPs256Format(filename, width, height, dataObj,
-					  imageData, error, functionWait, data);
-	  else
-	    return writePsTrueColor(filename, width, height, dataObj,
-				    imageData, error, functionWait, data);
-	}
-      prop = g_list_next(prop);
-    }
-  return writePsTrueColor(filename, width, height, dataObj,
-			  imageData, error, functionWait, data);
+  prop = tool_file_format_getPropertyByName(format, "reduced_colormap");
+  g_return_val_if_fail(prop, FALSE);
+
+  val = tool_option_getValue(prop);
+  if (g_value_get_boolean(val))
+    return writeViewInPs256Format(filename, width, height, dataObj,
+                                  imageData, error, functionWait, data);
+  else
+    return writePsTrueColor(filename, width, height, dataObj,
+                            imageData, error, functionWait, data);
 }
 
 /******************************************************************************/
@@ -379,7 +374,7 @@ static gboolean writeViewInPsFormat(FileFormat *format, const char* filename,
 static gboolean writePsTrueColor(const char* filename,
 				 int width, int height, VisuData *dataObj _U_,
 				 guchar* imageData, GError **error,
-				 voidDataFunc functionWait _U_, gpointer data _U_)
+				 ToolVoidDataFunc functionWait _U_, gpointer data _U_)
 {
   static int x = 10, y = 10;
   time_t timer;
@@ -393,7 +388,7 @@ static gboolean writePsTrueColor(const char* filename,
   PSwidth  = width;
   PSheight = height;
 
-  DBG_fprintf(stderr, "Dump PS & PDF : begin PS True Color export in %dx%d : %s.\n",
+  DBG_fprintf(stderr, "Dump PS & PDF : begin PS True ToolColor export in %dx%d : %s.\n",
 	      width, height, filename);
 
   out = fopen(filename, "w");
@@ -475,10 +470,10 @@ static gboolean writePsTrueColor(const char* filename,
 
 /******************************************************************************/
 
-static gboolean writeViewInPdfFormat(FileFormat *format _U_, const char* filename,
+static gboolean writeViewInPdfFormat(ToolFileFormat *format _U_, const char* filename,
 				     int width, int height, VisuData *dataObj _U_,
 				     guchar* imageData, GError **error,
-				     voidDataFunc functionWait _U_, gpointer data _U_)
+				     ToolVoidDataFunc functionWait _U_, gpointer data _U_)
 {
   time_t timer;
    
@@ -563,7 +558,7 @@ static gboolean writeViewInPdfFormat(FileFormat *format _U_, const char* filenam
   (void)fprintf(out, "7 0 obj\n");
   (void)fprintf(out, "<<\n");
   (void)fprintf(out, "/Type/XObject/Subtype/Image/Name/IMG/Length"
-                " 8 0 R/ColorSpace /DeviceRGB\n");
+                " 8 0 R/ToolColorSpace /DeviceRGB\n");
   (void)fprintf(out, "/Width %d/Height %d/BitsPerComponent"
                 " 8/Filter[/ASCIIHexDecode/LZWDecode]\n",
 		PSwidth, PSheight);
@@ -605,7 +600,7 @@ static gboolean writeViewInPdfFormat(FileFormat *format _U_, const char* filenam
 static gboolean writeViewInPs256Format(const char* filename,
 				       int width, int height, VisuData *dataObj _U_,
 				       guchar* imageData, GError **error,
-				       voidDataFunc functionWait, gpointer data)
+				       ToolVoidDataFunc functionWait, gpointer data)
 {
   static int x = 10, y = 10;
   time_t timer;
