@@ -62,22 +62,22 @@ static FILE *output;
 static unsigned char *image;
 static int TIFFwidth, TIFFheight;
 
-static gboolean writeViewInTiffFormat(FileFormat *format, const char* filename,
+static gboolean writeViewInTiffFormat(ToolFileFormat *format, const char* filename,
 				      int width, int height, VisuData *dataObj,
 				      guchar* imageData, GError **error,
-				      voidDataFunc functionWait, gpointer data);
+				      ToolVoidDataFunc functionWait, gpointer data);
 static gpointer waitData;
-static voidDataFunc waitFunc;
+static ToolVoidDataFunc waitFunc;
 
-DumpType* dumpToTIFF_init()
+VisuDump* dumpToTIFF_init()
 {
-  DumpType *tiff;
+  VisuDump *tiff;
   char *typeTIF[] = {"*.tif", "*.tiff", (char*)0};
 #define descrTIF _("Tiff file")
-  FileFormat* fmt;
+  ToolFileFormat* fmt;
 
-  tiff = g_malloc(sizeof(DumpType));
-  fmt = fileFormatNew(descrTIF, typeTIF);
+  tiff = g_malloc(sizeof(VisuDump));
+  fmt = tool_file_format_new(descrTIF, typeTIF);
   if (!fmt)
     {
       g_error("Can't initialize the TIF dump module, aborting.\n");
@@ -85,11 +85,12 @@ DumpType* dumpToTIFF_init()
 
   tiff->bitmap = TRUE;
   tiff->hasAlpha = FALSE;
+  tiff->glRequired = TRUE;
   tiff->fileType = fmt;
   tiff->writeFunc = writeViewInTiffFormat;
   
   waitData = (gpointer)0;
-  waitFunc = (voidDataFunc)0;
+  waitFunc = (ToolVoidDataFunc)0;
 
   return tiff;
 }
@@ -673,10 +674,10 @@ static void encode() {
  
 /******************************************************************************/
 
-static gboolean writeViewInTiffFormat(FileFormat *format _U_, const char* filename,
+static gboolean writeViewInTiffFormat(ToolFileFormat *format _U_, const char* filename,
 				      int width, int height, VisuData *dataObj _U_,
 				      guchar* imageData, GError **error,
-				      voidDataFunc functionWait, gpointer data)
+				      ToolVoidDataFunc functionWait, gpointer data)
 {
   g_return_val_if_fail(error && !*error, FALSE);
   g_return_val_if_fail(imageData, FALSE);
