@@ -54,6 +54,6 @@
  *
  * Returns: a newly created dump object to create TIFF files.
  */
-DumpType* dumpToTIFF_init();
+VisuDump* dumpToTIFF_init();
 
 #endif
