@@ -48,18 +48,17 @@
 #include <GL/gl.h>
 #include <GL/glu.h> 
 
+#include <math.h>
+
 #include <opengl.h>
 #include <openGLFunctions/text.h>
 #include <visu_object.h>
 #include <visu_tools.h>
 #include <visu_configFile.h>
-#include <renderingBackend/visu_windowInterface.h>
 #include <openGLFunctions/objectList.h>
 #include <coreTools/toolColor.h>
 #include <coreTools/toolConfigFile.h>
 
-#include <math.h>
-
 /**
  * SECTION:axes
  * @short_description: Defines methods to draw axes.
@@ -71,8 +70,8 @@
  * currently used. For instance, when the spin is used, a projection
  * of the colour scheme is added to the simple lines of the basis
  * set. Besides that, axes are defined by their width (see
- * axesSet_lineWidth()) and their colour (see
- * axesSet_RGBValues()).</para>
+ * visu_glExt_axes_setLineWidth()) and their colour (see
+ * visu_glExt_axes_setRGBValues()).</para>
  */
 
 /* Parameters & resources*/
@@ -109,7 +108,7 @@ static gboolean readAxesLineStipple(gchar **lines, int nbLines,
 static void exportResourcesAxes(GString *data, VisuData *dataObj);
 
 
-static OpenGLExtension* extensionAxes;
+static VisuExtension* extensionAxes;
 
 
 static void rebuildAxes(VisuData *dataObj);
@@ -118,50 +117,50 @@ static void rebuildAxes(VisuData *dataObj);
 static gboolean axesHaveBeenBuilt;
 
 /* Local callbacks */
-static void onAxesParametersChange(VisuData *dataObj, OpenGLView *view, gpointer data);
-static void onAxesConfigChange(GObject *visu, VisuData *dataObj, gpointer data);
+static void onAxesParametersChange(VisuData *dataObj, VisuOpenGLView *view, gpointer data);
+static void onAxesConfigChange(VisuRenderingSpin *render, gpointer data);
 static void rebuildAxesOnResourcesLoaded(GObject *visu, VisuData *dataObj,
 					 gpointer data);
 static void onDataNewSignal(GObject *visu, VisuData *dataObj, gpointer data);
 static void onDataReady(GObject *obj, VisuData *dataObj, gpointer data);
 
-OpenGLExtension* initExtensionAxes()
+VisuExtension* initExtensionAxes()
 {
-  char *name = EXT_AXES_ID;
+  char *name = VISU_GLEXT_AXES_ID;
   char *description = _("Draw the axes at the bottom right of the rendering area.");
   int listAxes;
   VisuConfigFileEntry *resourceEntry;
 
   DBG_fprintf(stderr,"Initialising the axes OpenGL extension...\n");
-  listAxes = openGLObjectList_new(1);
-  extensionAxes = OpenGLExtension_new(name, _(name), description,
+  listAxes = visu_openGL_objectList_new(1);
+  extensionAxes = visu_extension_new(name, _(name), description,
 				      listAxes, rebuildAxes);
 
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_AXES_USED,
 					  DESC_RESOURCE_AXES_USED,
 					  1, readAxesAreOn);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_AXES_COLOR,
 					  DESC_RESOURCE_AXES_COLOR,
 					  1, readAxesColor);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_AXES_LINE,
 					  DESC_RESOURCE_AXES_LINE,
 					  1, readAxesLineWidth);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_AXES_STIPPLE,
 					  DESC_RESOURCE_AXES_STIPPLE,
 					  1, readAxesLineStipple);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesAxes);
 
   /* Initialisation des valeurs par dfaut. */
-  axesSet_RGBValues(axesRGBDefault, MASK_RGB_ALL);
+  visu_glExt_axes_setRGBValues(axesRGBDefault, TOOL_COLOR_MASK_RGBA);
   extensionAxes->used = RESOURCE_AXES_USED_DEFAULT;
-  OpenGLExtensionSet_priority(extensionAxes, OPENGL_EXTENSION_PRIORITY_LAST);
-  OpenGLExtensionSet_saveOpenGLState(extensionAxes, TRUE);
+  visu_extension_setPriority(extensionAxes, VISU_EXTENSION_PRIORITY_LAST);
+  visu_extension_setSaveOpenGLState(extensionAxes, TRUE);
   axesLineWidth   = RESOURCE_AXES_LINE_DEFAULT;
   axesLineStipple = RESOURCE_AXES_STIPPLE_DEFAULT;
 
@@ -170,8 +169,6 @@ OpenGLExtension* initExtensionAxes()
   g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReady), (gpointer)0);
 
-  g_signal_connect(VISU_INSTANCE, "SpinAxes",
- 		   G_CALLBACK(onAxesConfigChange), (gpointer)0);
   g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
  		   G_CALLBACK(rebuildAxesOnResourcesLoaded), (gpointer)0);
 
@@ -182,21 +179,21 @@ OpenGLExtension* initExtensionAxes()
 }
 
 /* Method used to change the value of the parameter axes_color. */
-gboolean axesSet_RGBValues(float rgb[3], int mask)
+gboolean visu_glExt_axes_setRGBValues(float rgb[3], int mask)
 {
   int diff = 0;
   
-  if (mask & MASK_RGB_R && axesRGB[0] != rgb[0])
+  if (mask & TOOL_COLOR_MASK_R && axesRGB[0] != rgb[0])
     {
       axesRGB[0] = rgb[0];
       diff = 1;
     }
-  if (mask & MASK_RGB_G && axesRGB[1] != rgb[1])
+  if (mask & TOOL_COLOR_MASK_G && axesRGB[1] != rgb[1])
     {
       axesRGB[1] = rgb[1];
       diff = 1;
     }
-  if (mask & MASK_RGB_B && axesRGB[2] != rgb[2])
+  if (mask & TOOL_COLOR_MASK_B && axesRGB[2] != rgb[2])
     {
       axesRGB[2] = rgb[2];
       diff = 1;
@@ -209,7 +206,7 @@ gboolean axesSet_RGBValues(float rgb[3], int mask)
 }
 
 /* Method used to change the value of the parameter axes_line_width. */
-gboolean axesSet_lineWidth(float width)
+gboolean visu_glExt_axes_setLineWidth(float width)
 {
   if (width < 1. || width > 10. || width == axesLineWidth)
     return FALSE;
@@ -218,7 +215,7 @@ gboolean axesSet_lineWidth(float width)
   axesHaveBeenBuilt = FALSE;
   return (gboolean)extensionAxes->used;
 }
-gboolean axesSet_lineStipple(guint16 stipple)
+gboolean visu_glExt_axes_setLineStipple(guint16 stipple)
 {
   if (stipple == axesLineStipple)
     return FALSE;
@@ -229,7 +226,7 @@ gboolean axesSet_lineStipple(guint16 stipple)
 }
 
 /* Method used to change the value of the parameter axes_is_on. */
-gboolean axesSet_areOn(gboolean value)
+gboolean visu_glExt_axes_setOn(gboolean value)
 {
   if (value == extensionAxes->used)
     return FALSE;
@@ -239,21 +236,21 @@ gboolean axesSet_areOn(gboolean value)
 }
 
 /* Get methods. */
-float* axesGet_RGBvalues()
+float* visu_glExt_axes_getRGBValues()
 {
   return axesRGB;
 }
 
-int axesGet_areOn()
+int visu_glExt_axes_getOn()
 {
   return extensionAxes->used;
 }
 
-float axesGet_lineWidth()
+float visu_glExt_axes_getLineWidth()
 {
   return axesLineWidth;
 }
-guint16 axesGet_lineStipple()
+guint16 visu_glExt_axes_getLineStipple()
 {
   return axesLineStipple;
 }
@@ -268,14 +265,12 @@ static void rebuildAxes(VisuData *dataObj)
   openGLText_rebuildFontList();
   /* Set flag to false to force recreation of axes. */
   axesHaveBeenBuilt = FALSE;
-  axesDraw(dataObj);
+  visu_glExt_axes_draw(dataObj);
 }
-static void rebuildAxesOnResourcesLoaded(GObject *visu _U_, VisuData *dataObj,
+static void rebuildAxesOnResourcesLoaded(GObject *visu _U_, VisuData *dataObj _U_,
 					 gpointer data _U_)
 {
-  if (!dataObj)
-    return;
-  axesDraw(dataObj);
+  axesHaveBeenBuilt = FALSE;
 }
 static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj,
 			    gpointer data _U_)
@@ -284,37 +279,29 @@ static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj,
 		   G_CALLBACK(onAxesParametersChange), (gpointer)0);
   g_signal_connect(G_OBJECT(dataObj), "OpenGLWidthHeight",
 		   G_CALLBACK(onAxesParametersChange), (gpointer)0);
+  g_signal_connect(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
+                   "colorisationChange", G_CALLBACK(onAxesConfigChange), (gpointer)dataObj);
 }
 static void onDataReady(GObject *obj _U_, VisuData *dataObj, gpointer data)
 {
   if (dataObj)
-    onAxesParametersChange(dataObj, (OpenGLView*)0, data);
+    onAxesParametersChange(dataObj, (VisuOpenGLView*)0, data);
 }
-static void onAxesConfigChange(GObject *visu _U_, VisuData *dataObj, gpointer data)
+static void onAxesConfigChange(VisuRenderingSpin *render _U_, gpointer data)
 {
-  g_return_if_fail(dataObj);
-
-  onAxesParametersChange(dataObj, (OpenGLView*)0, data);
+  axesHaveBeenBuilt = FALSE;
+  visu_glExt_axes_draw(VISU_DATA(data));
 }
 
-static void onAxesParametersChange(VisuData *dataObj, OpenGLView *view _U_,
+static void onAxesParametersChange(VisuData *dataObj, VisuOpenGLView *view _U_,
 				   gpointer data _U_)
 {
   axesHaveBeenBuilt = FALSE;
-  axesDraw(dataObj);
+  visu_glExt_axes_draw(dataObj);
 }
 
-/**
- * drawAxes
- * @length: the length of the axes
- * @width: the width of the line used to draw the axes
- * @long_axes:
- *
- * Draw three axes following the current x,y,z directions. Their @length and
- * @width can be specified.
- */
-void drawAxes(float length, GLsizei w, GLsizei h, float width,
-	      char *legend, gboolean long_axes) 
+static void drawAxes(float length, GLsizei w, GLsizei h, float width,
+		     char *legend, gboolean long_axes) 
 {
   glLineWidth(width);
   glColor3fv(axesRGB);
@@ -405,7 +392,7 @@ void draw_coloured_cone(double r, double h, int n, float phi_prime_zero)
 	  p_y = /*r * e_y*/h*(hsv[1] - hsv[2]);
 	  p_z = r * e_z;
 	  
-	  color_HSVtoRGB(rgb, hsv);
+	  tool_color_convertHSVtoRGB(rgb, hsv);
 	  glColor3f(rgb[0], rgb[1], rgb[2]); 
 	  glNormal3f(e_x,e_y,e_z);
 	  glVertex3f(p_x,p_y,p_z);
@@ -425,7 +412,7 @@ void draw_coloured_cone(double r, double h, int n, float phi_prime_zero)
 	  p_y = /*r * e_y*/h*(hsv[1] - hsv[2]);
 	  p_z = r * e_z;
 	
-	  color_HSVtoRGB(rgb, hsv);
+	  tool_color_convertHSVtoRGB(rgb, hsv);
 	  glColor3f(rgb[0], rgb[1], rgb[2]); 
 	  glNormal3f(e_x,e_y,e_z);
 	  glVertex3f(p_x,p_y,p_z);
@@ -476,36 +463,42 @@ void draw_coloured_cone(double r, double h, int n, float phi_prime_zero)
 
 /* } */
 
-void axesDraw(VisuData *dataObj)
+void visu_glExt_axes_draw(VisuData *dataObj)
 {
   float length;
   GLsizei w, h;
   GLint xx, yy;
   double mini, maxi, near, far;
-  OpenGLView *view;
+  VisuOpenGLView *view;
+  float centre[3], length0;
+  VisuRendering *spin;
 
   /* Nothing to draw; */
-  if(!axesGet_areOn() || axesHaveBeenBuilt) return;
+  if(!visu_glExt_axes_getOn() || axesHaveBeenBuilt) return;
 
   /* Nothing to draw if no data is associated to
      the current rendering window. */
   if (!dataObj)
     return;
 
-  DBG_fprintf(stderr, "Extension axes: creating axes.\n");
+  view = visu_data_getOpenGLView(dataObj);
 
-  view = visuDataGet_openGLView(dataObj);
-  length = 0.26178f * view->camera->length0;
-  w = 0.2f * MIN(view->window->width, view->window->height);
+  DBG_fprintf(stderr, "Extension axes: creating axes in (%dx%d).\n",
+	      view->window->width, view->window->height);
+
+  visu_data_getBoxCentre(dataObj, centre);
+  length0 = openGLCameraGet_refLength(view->camera, (ToolUnits*)0);
+  length = 0.33 * length0;
+  w = 0.16f * MIN(view->window->width, view->window->height);
   h = w;
   xx = view->window->width - w;
   yy = 0;
-  mini = -0.5f * view->camera->length0 *
+  mini = -0.5f * length0 *
     (view->camera->d_red - 1.f) / view->camera->d_red;
   maxi = -mini;
-  near = far = view->camera->d_red * view->camera->length0;
-  near -= view->camera->length0;
-  far  += view->camera->length0;
+  near = far = view->camera->d_red * length0;
+  near -= length0;
+  far  += length0;
 
   axesHaveBeenBuilt = TRUE;
 
@@ -515,15 +508,11 @@ void axesDraw(VisuData *dataObj)
 
   glNewList(extensionAxes->objectListId, GL_COMPILE);
 
-  glEnable(GL_CULL_FACE);
-
   /* Dsactivation de la lumire et du brouillard et activation du culling. */
+  glEnable(GL_CULL_FACE);
   glDisable(GL_LIGHTING);
   glDisable(GL_FOG);
 
-  /* Resetting the depth buffer. */
-  glDisable(GL_DEPTH_TEST);
-
   if (axesLineStipple != 65535)
     {
       glEnable(GL_LINE_STIPPLE);
@@ -533,31 +522,42 @@ void axesDraw(VisuData *dataObj)
   glMatrixMode(GL_PROJECTION);
   glPushMatrix();
   glLoadIdentity();
+  DBG_fprintf(stderr, "Extension axes: frustum is %fx%f %fx%f %fx%f.\n",
+	      mini, maxi, mini, maxi, near, far);
   glFrustum(mini, maxi, mini, maxi, near, far);
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
-  glTranslated(+view->box->dxxs2+view->camera->centre[0],
-	       +view->box->dyys2+view->camera->centre[1],
-	       +view->box->dzzs2+view->camera->centre[2]);
-  if(visuRenderingClassIs_currentByName(VISU_RENDERING_SPIN))
+  DBG_fprintf(stderr, "Extension axes: translat is %fx%fx%f.\n",
+	      +centre[0]+view->camera->centre[0],
+	      +centre[1]+view->camera->centre[1],
+	      +centre[2]+view->camera->centre[2]);
+  glTranslated(+centre[0]+view->camera->centre[0],
+	       +centre[1]+view->camera->centre[1],
+	       +centre[2]+view->camera->centre[2]);
+
+  spin = visu_rendering_getByName(VISU_RENDERING_SPIN_NAME);
+  if(visu_object_getRendering(VISU_INSTANCE) == spin)
     {
       float phi_prime_zero, phi_a, theta_a;
 
-      phi_prime_zero = rspin_getGlobalResource_float(spin_globalColorWheel);
-      phi_a          = rspin_getGlobalResource_float(spin_globalConePhi);
-      theta_a        = rspin_getGlobalResource_float(spin_globalConeTheta);
+      g_object_get(G_OBJECT(spin), "cone-omega", &phi_prime_zero,
+                   "cone-phi", &phi_a, "cone-theta", &theta_a, NULL);
 
       glViewport(xx, yy, w, h);
 
-      /* Draw the first color cone */
-      drawAxes(1.5*length, w, h, axesLineWidth, _("front"), TRUE);
+      /* Resetting the depth buffer. */
+      glClear(GL_DEPTH_BUFFER_BIT);
+      glEnable(GL_DEPTH_TEST);
 
+      /* Draw the first color cone */
       glPushMatrix();
       glRotatef(phi_a, 0, 0, 1);
       glRotatef(theta_a, 0, 1, 0);
       draw_coloured_cone(length, 1.2*length, 16, phi_prime_zero);
       glPopMatrix();
 
+      drawAxes(1.5*length, w, h, axesLineWidth, _("front"), TRUE);
+
       glViewport(xx, yy+h, w, h);
 
       /* Enabling front culling and drawing the second color cone */
@@ -571,11 +571,16 @@ void axesDraw(VisuData *dataObj)
 
       drawAxes(1.5*length, w, h, axesLineWidth, _("back"), TRUE);
     }
-  else if(visuRenderingClassIs_currentByName(VISU_RENDERING_ATOMIC))
+  else if(visu_object_getRendering(VISU_INSTANCE) ==
+          visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME))
     {
+      DBG_fprintf(stderr, "Extension Axes: new view port at %dx%d, size %dx%d.\n",
+		  xx, yy, w, h);
       glViewport(xx, yy, w, h);
 
+      glDisable(GL_DEPTH_TEST);
       drawAxes(length, w, h, axesLineWidth, NULL, FALSE);
+      glEnable(GL_DEPTH_TEST);
     }
   glPopMatrix();
   glMatrixMode(GL_PROJECTION);
@@ -597,9 +602,9 @@ static gboolean readAxesAreOn(gchar **lines, int nbLines,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  axesSet_areOn(val);
+  visu_glExt_axes_setOn(val);
   return TRUE;
 }
 /* A resource to control the color used to render the lines of the axes. */
@@ -610,21 +615,21 @@ static gboolean readAxesColor(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, rgb, 3, error))
+  if (!tool_configFile_readFloat(lines[0], position, rgb, 3, error))
     return FALSE;
 
-  if (configFileClamp_float(&rgb[0], rgb[0], 0., 1.) ||
-      configFileClamp_float(&rgb[1], rgb[1], 0., 1.) ||
-      configFileClamp_float(&rgb[2], rgb[2], 0., 1.))
+  if (tool_configFile_clampFloat(&rgb[0], rgb[0], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[1], rgb[1], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[2], rgb[2], 0., 1.))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 3 floating points"
 			     "(0 <= v <= 1) must appear after the %s markup.\n"),
 			   position, FLAG_RESOURCE_AXES_COLOR);
-      axesSet_RGBValues(axesRGBDefault, MASK_RGB_ALL);
+      visu_glExt_axes_setRGBValues(axesRGBDefault, TOOL_COLOR_MASK_RGBA);
       return FALSE;
     }
-  axesSet_RGBValues(rgb, MASK_RGB_ALL);
+  visu_glExt_axes_setRGBValues(rgb, TOOL_COLOR_MASK_RGBA);
 
   return TRUE;
 }
@@ -636,18 +641,18 @@ static gboolean readAxesLineWidth(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, &width, 1, error))
+  if (!tool_configFile_readFloat(lines[0], position, &width, 1, error))
     return FALSE;
-  if (configFileClamp_float(&width, width, 1., 10.))
+  if (tool_configFile_clampFloat(&width, width, 1., 10.))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 floating point"
 			     "(1 <= v <= 10) must appear after the %s markup.\n"),
 			   position, FLAG_RESOURCE_AXES_LINE);
-      axesSet_lineWidth(RESOURCE_AXES_LINE_DEFAULT);
+      visu_glExt_axes_setLineWidth(RESOURCE_AXES_LINE_DEFAULT);
       return FALSE;
     }
-  axesSet_lineWidth(width);
+  visu_glExt_axes_setLineWidth(width);
 
   return TRUE;
 }
@@ -659,9 +664,9 @@ static gboolean readAxesLineStipple(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_integer(lines[0], position, &stipple, 1, error))
+  if (!tool_configFile_readInteger(lines[0], position, &stipple, 1, error))
     return FALSE;
-  axesSet_lineStipple((guint16)stipple);
+  visu_glExt_axes_setLineStipple((guint16)stipple);
 
   return TRUE;
 }
@@ -676,7 +681,7 @@ static void exportResourcesAxes(GString *data, VisuData *dataObj _U_)
   g_string_append_printf(data, "# %s\n", DESC_RESOURCE_AXES_COLOR);
   g_string_append_printf(data, "%s:\n", FLAG_RESOURCE_AXES_COLOR);
   g_string_append_printf(data, "    %4.3f %4.3f %4.3f\n",
-	  axesRGB[0], axesRGB[1], axesRGB[2]);
+			 axesRGB[0], axesRGB[1], axesRGB[2]);
   g_string_append_printf(data, "# %s\n", DESC_RESOURCE_AXES_LINE);
   g_string_append_printf(data, "%s:\n", FLAG_RESOURCE_AXES_LINE);
   g_string_append_printf(data, "    %4.0f\n", axesLineWidth);
