@@ -55,106 +55,106 @@
  * It creates all resources and parameters introduced by
  * this extension.
  * This method should be added in the #listInitExtensionFunc to
- * be called automatically by the initOpenGLExtensions() at V_Sim
+ * be called automatically by the initVisuExtensions() at V_Sim
  * startup.
  *
- * Returns: a pointer to the OpenGLExtension it created or
+ * Returns: a pointer to the VisuExtension it created or
  * NULL otherwise.
  */
-OpenGLExtension* initExtensionAxes();
+VisuExtension* initExtensionAxes();
 
 /**
- * EXT_AXES_ID:
+ * VISU_GLEXT_AXES_ID:
  *
  * The id used to identify this extension, see
- * OpenGLExtensionRebuild_list() for instance.
+ * visuExtensions_rebuildList() for instance.
  */
-#define EXT_AXES_ID "Axes"
+#define VISU_GLEXT_AXES_ID "Axes"
 
 /**
- * axesSet_RGBValues:
+ * visu_glExt_axes_setRGBValues:
  * @rgb: a three floats array with values (0 <= values <= 1) for the
  * red, the green and the blue color. Only values specified by the mask
  * are really relevant.
- * @mask: use #MASK_RGB_R, #MASK_RGB_G, #MASK_RGB_B, #MASK_RGB_ALL or a
+ * @mask: use #TOOL_COLOR_MASK_R, #TOOL_COLOR_MASK_G, #TOOL_COLOR_MASK_B, #TOOL_COLOR_MASK_RGBA or a
  * combinaison to indicate what values in the rgb array must be taken
  * into account.
  *
  * Method used to change the value of the parameter axes_color.
  *
- * Returns: TRUE if axesDraw() should be called and then 'OpenGLAskForReDraw'
+ * Returns: TRUE if visu_glExt_axes_draw() should be called and then 'OpenGLAskForReDraw'
  *          signal be emitted.
  */
-gboolean axesSet_RGBValues(float rgb[3], int mask);
+gboolean visu_glExt_axes_setRGBValues(float rgb[3], int mask);
 /**
- * axesSet_lineWidth:
+ * visu_glExt_axes_setLineWidth:
  * @width: value of the desired axe width.
  *
  * Method used to change the value of the parameter axes_line_width.
  *
- * Returns: TRUE if axesDraw() should be called and then 'OpenGLAskForReDraw'
+ * Returns: TRUE if visu_glExt_axes_draw() should be called and then 'OpenGLAskForReDraw'
  *          signal be emitted.
  */
-gboolean axesSet_lineWidth(float width);
+gboolean visu_glExt_axes_setLineWidth(float width);
 /**
- * axesSet_lineStipple:
+ * visu_glExt_axes_setLineStipple:
  * @stipple: value of the desired pattern.
  *
  * Method used to change the value of the parameter axes_line_stipple.
  *
- * Returns: TRUE if axesDraw() should be called and then 'OpenGLAskForReDraw'
+ * Returns: TRUE if visu_glExt_axes_draw() should be called and then 'OpenGLAskForReDraw'
  *          signal be emitted.
  */
-gboolean axesSet_lineStipple(guint16 stipple);
+gboolean visu_glExt_axes_setLineStipple(guint16 stipple);
 /**
- * axesSet_areOn:
+ * visu_glExt_axes_setOn:
  * @value: TRUE if axes must be drawn, FALSE otherwise.
  *
  * Method used to change the value of the parameter axes_are_on.
  *
- * Returns: TRUE if axesDraw() should be called. In all cases, 'OpenGLAskForReDraw'
+ * Returns: TRUE if visu_glExt_axes_draw() should be called. In all cases, 'OpenGLAskForReDraw'
  *          signal should then be emitted.
  */
-gboolean axesSet_areOn(gboolean value);
+gboolean visu_glExt_axes_setOn(gboolean value);
 
 /**
- * axesGet_RGBvalues:
+ * visu_glExt_axes_getRGBValues:
  *
  * Read all the colour components of axes (in [0;1]). 
  *
  * Returns: three RGB values, private from V_Sim, read only.
  */
-float* axesGet_RGBvalues();
+float* visu_glExt_axes_getRGBValues();
 /**
- * axesGet_areOn:
+ * visu_glExt_axes_getOn:
  *
  * Read if axes are drawn or not.
  *
  * Returns: 1 if axes are drawn, 0 otherwise.
  */
-int axesGet_areOn();
+int visu_glExt_axes_getOn();
 /**
- * axesGet_lineWidth:
+ * visu_glExt_axes_getLineWidth:
  *
  * Read the line width used to draw axes.
  *
  * Returns: the value of current axes width.
  */
-float axesGet_lineWidth();
+float visu_glExt_axes_getLineWidth();
 /**
- * axesGet_lineStipple:
+ * visu_glExt_axes_getLineStipple:
  *
  * Read the line pattern used to draw axes.
  *
  * Returns: the value of current axes pattern.
  */
-guint16 axesGet_lineStipple();
+guint16 visu_glExt_axes_getLineStipple();
 /**
- * axesDraw:
+ * visu_glExt_axes_draw:
  * @dataObj: the #VisuData object to build axes for.
  *
  * This method create a compile list that draw a box for the given @data.
  */
-void axesDraw(VisuData *dataObj);
+void visu_glExt_axes_draw(VisuData *dataObj);
 
 #endif
