@@ -46,11 +46,14 @@
 #include <GL/gl.h>
 #include <GL/glu.h> 
 
+#include <math.h>
+
+#include <opengl.h>
 #include <visu_object.h>
 #include <visu_tools.h>
 #include <visu_configFile.h>
-#include <renderingBackend/visu_windowInterface.h>
 #include <openGLFunctions/objectList.h>
+#include <openGLFunctions/text.h>
 #include <coreTools/toolColor.h>
 #include <coreTools/toolConfigFile.h>
 
@@ -60,7 +63,7 @@
  *
  * <para>This extension allows V_Sim to draw a box around the
  * nodes. The box is defined in the #VisuData structure and can be
- * retrieved with visuDataGet_boxGeometry(). This box is not necessary
+ * retrieved with visu_data_getBoxGeometry(). This box is not necessary
  * orthogonal.</para>
  * <para>It has several properties, namely, its colour, its line width
  * and its line pattern. It is represented in OpenGL with simple lines
@@ -90,9 +93,9 @@
 
 
 
-static OpenGLExtension* extensionBox;
+static VisuExtension* extensionBox, *extBoxLegend;
 static float boxRGBDefault[3] = {1.0, 0.5, 0.1};
-static gboolean boxHasBeenBuilt;
+static gboolean boxHasBeenBuilt, legendHasBeenBuilt;
 
 /* Parameters & resources*/
 /* This is a boolean to control is the box is render or not. */
@@ -123,6 +126,17 @@ static guint16 boxLineStipple[2];
 static gboolean readBoxLineStipple(gchar **lines, int nbLines,
 				   int position, VisuData *dataObj, GError **error);
 
+/* A resource to control if the box lengths are printed. */
+#define FLAG_RESOURCE_BOX_LENGTHS   "box_show_lengths"
+#define DESC_RESOURCE_BOX_LENGTHS   "Print the box lengths ; boolean (0 or 1)"
+#define RESOURCE_WITH_LENGTHS_DEFAULT FALSE
+static gboolean readBoxLengths(gchar **lines, int nbLines,
+			       int position, VisuData *dataObj, GError **error);
+
+#define RESOURCE_WITH_BASIS_DEFAULT FALSE
+static gboolean withBasis;
+static float basisLength = 2.5f;
+
 /* Export function that is called by visu_module to write the
    values of resources to a file. */
 static void exportResourcesBox(GString *data, VisuData *dataObj);
@@ -130,74 +144,92 @@ static void exportResourcesBox(GString *data, VisuData *dataObj);
 static void rebuildBox(VisuData *dataObj);
 
 /* Callbacks. */
+static void onDataNewSignal(GObject *visu, VisuData *dataObj, gpointer data);
 static void rebuildBoxOnDataReady(GObject *obj, VisuData *dataObj, gpointer data);
 static void rebuildBoxOnResources(GObject *obj, VisuData *dataObj, gpointer data);
 static void onBoxSizeChanged(VisuData *data, gpointer user_data);
 
-OpenGLExtension* initExtensionBox()
+VisuExtension* initExtensionBox()
 {
   char *description = _("Draw a box representing the limit of the area.");
   int listBox;
   VisuConfigFileEntry *resourceEntry;
 
   DBG_fprintf(stderr,"Initialising the box OpenGL extension...\n");
-  listBox = openGLObjectList_new(1);
-  extensionBox = OpenGLExtension_new(EXT_BOX_ID, _("Box"),
+  listBox = visu_openGL_objectList_new(1);
+  extensionBox = visu_extension_new(VISU_GLEXT_BOX_ID, _("Box"),
 				     description, listBox, rebuildBox);
-  OpenGLExtensionSet_priority(extensionBox, OPENGL_EXTENSION_PRIORITY_LOW);
+  visu_extension_setPriority(extensionBox, VISU_EXTENSION_PRIORITY_LOW);
 
+  extBoxLegend = visu_extension_new("boxLegend", _("Box legend"),
+				     _("Draw informations related to the box."),
+				     visu_openGL_objectList_new(1), rebuildBox);
+  visu_extension_setPriority(extBoxLegend, VISU_EXTENSION_PRIORITY_LAST);
+  visu_extension_setSaveOpenGLState(extBoxLegend, TRUE);
+  extBoxLegend->used = RESOURCE_WITH_LENGTHS_DEFAULT;
+  visuExtensions_add(extBoxLegend);
+
+  g_signal_connect(VISU_INSTANCE, "dataNew",
+		   G_CALLBACK(onDataNewSignal), (gpointer)0);
   g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(rebuildBoxOnDataReady), (gpointer)0);
   g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
  		   G_CALLBACK(rebuildBoxOnResources), (gpointer)0);
 
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_BOX_USED,
 					  DESC_RESOURCE_BOX_USED,
 					  1, readBoxIsOn);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_BOX_COLOR,
 					  DESC_RESOURCE_BOX_COLOR,
 					  1, readBoxColor);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_BOX_LINE,
 					  DESC_RESOURCE_BOX_LINE,
 					  1, readBoxLineWidth);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_BOX_STIPPLE,
 					  DESC_RESOURCE_BOX_STIPPLE,
 					  1, readBoxLineStipple);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
+					  FLAG_RESOURCE_BOX_LENGTHS,
+					  DESC_RESOURCE_BOX_LENGTHS,
+					  1, readBoxLengths);
+  visu_configFile_entry_setVersion(resourceEntry, 3.6f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesBox);
 
   /* Initialisation des valeurs par dfaut. */
-  boxSet_RGBValues(boxRGBDefault, MASK_RGB_ALL);
+  visu_glExt_box_setRGBValues(boxRGBDefault, TOOL_COLOR_MASK_RGBA);
   extensionBox->used = RESOURCE_BOX_USED_DEFAULT;
   boxLineWidth       = RESOURCE_BOX_LINE_DEFAULT;
   boxHasBeenBuilt    = FALSE;
+  legendHasBeenBuilt = FALSE;
   boxLineStipple[0]  = RESOURCE_BOX_STIPPLE_DEFAULT;
   boxLineStipple[1]  = RESOURCE_EXPAND_STIPPLE_DEFAULT;
+  withBasis          = RESOURCE_WITH_BASIS_DEFAULT;
 
   return extensionBox;
 }
 
 /* Method used to change the value of the parameter box_color. */
-gboolean boxSet_RGBValues(float rgb[3], int mask)
+gboolean visu_glExt_box_setRGBValues(float rgb[3], int mask)
 {
   int diff = 0;
   
-  if (mask & MASK_RGB_R && boxRGB[0] != rgb[0])
+  if (mask & TOOL_COLOR_MASK_R && boxRGB[0] != rgb[0])
     {
       boxRGB[0] = rgb[0];
       diff = 1;
     }
-  if (mask & MASK_RGB_G && boxRGB[1] != rgb[1])
+  if (mask & TOOL_COLOR_MASK_G && boxRGB[1] != rgb[1])
     {
       boxRGB[1] = rgb[1];
       diff = 1;
     }
-  if (mask & MASK_RGB_B && boxRGB[2] != rgb[2])
+  if (mask & TOOL_COLOR_MASK_B && boxRGB[2] != rgb[2])
     {
       boxRGB[2] = rgb[2];
       diff = 1;
@@ -207,11 +239,11 @@ gboolean boxSet_RGBValues(float rgb[3], int mask)
 
   /* Il faut recrer la bote puisque des param ont changs. */
   boxHasBeenBuilt = FALSE;
-/*   boxDraw(); */
+/*   visu_glExt_box_draw(); */
   return (gboolean)extensionBox->used;
 }
 /* Method used to change the value of the parameter box_line_width. */
-gboolean boxSet_lineWidth(float width)
+gboolean visu_glExt_box_setLineWidth(float width)
 {
   if (width < 1. || width > 10. || width == boxLineWidth)
     return FALSE;
@@ -219,19 +251,19 @@ gboolean boxSet_lineWidth(float width)
   boxLineWidth = width;
   /* Il faut recrer la bote puisque des param ont changs. */
   boxHasBeenBuilt = FALSE;
-/*   boxDraw(); */
+/*   visu_glExt_box_draw(); */
   return (gboolean)extensionBox->used;
 }
 /* Method used to change the value of the parameter box_is_on. */
-gboolean boxSet_isOn(int value)
+gboolean visu_glExt_box_setOn(int value)
 {
   if (value == extensionBox->used)
     return FALSE;
 
   extensionBox->used = value;
-  return (value && !boxHasBeenBuilt);
+  return (value && (!boxHasBeenBuilt || !legendHasBeenBuilt));
 }
-gboolean boxSet_lineStipple(guint16 stipple)
+gboolean visu_glExt_box_setLineStipple(guint16 stipple)
 {
   if (stipple == boxLineStipple[0])
     return FALSE;
@@ -240,7 +272,7 @@ gboolean boxSet_lineStipple(guint16 stipple)
   boxHasBeenBuilt = FALSE;
   return (gboolean)extensionBox->used;
 }
-gboolean boxSet_expandStipple(guint16 stipple)
+gboolean visu_glExt_box_setExpandStipple(guint16 stipple)
 {
   if (stipple == boxLineStipple[1])
     return FALSE;
@@ -249,75 +281,107 @@ gboolean boxSet_expandStipple(guint16 stipple)
   boxHasBeenBuilt = FALSE;
   return (gboolean)extensionBox->used;
 }
+gboolean visu_glExt_box_setShowLegend(gboolean value)
+{
+  if (value == extBoxLegend->used)
+    return FALSE;
+
+  extBoxLegend->used = value;
+  return (value && (!boxHasBeenBuilt || !legendHasBeenBuilt));
+}
 /* Get methods. */
-float* boxGet_RGBValues()
+float* visu_glExt_box_getRGBValues()
 {
   return boxRGB;
 }
-int boxGet_isOn()
+int visu_glExt_box_getOn()
 {
   if (extensionBox)
     return extensionBox->used;
   else
     return 0;
 }
-float boxGet_lineWidth()
+float visu_glExt_box_getLineWidth()
 {
   return boxLineWidth;
 }
-guint16 boxGet_lineStipple()
+guint16 visu_glExt_box_getLineStipple()
 {
   return boxLineStipple[0];
 }
-guint16 boxGet_expandStipple()
+guint16 visu_glExt_box_getExpandStipple()
 {
   return boxLineStipple[1];
 }
+/**
+ * visu_glExt_box_getShowLegend:
+ *
+ * The box extension can draw a frame showing the lengths of the box.
+ *
+ * Since: 3.6
+ *
+ * Returns: TRUE if the frame is displayed.
+ */
+gboolean visu_glExt_box_getShowLegend()
+{
+  return extBoxLegend->used;
+}
 
 
 /****************/
 /* Private part */
 /****************/
 
+static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj, gpointer data _U_)
+{
+  if (dataObj)
+    g_signal_connect(G_OBJECT(dataObj), "BoxSizeChanged",
+		     G_CALLBACK(onBoxSizeChanged), (gpointer)0);
+}
 static void rebuildBox(VisuData *dataObj)
 {
   /* Force redraw. */
   boxHasBeenBuilt = FALSE;
-  boxDraw(dataObj);
+  visu_glExt_box_draw(dataObj);
+  legendHasBeenBuilt = FALSE;
+  visu_glExt_box_draw_legend(dataObj);
 }
 static void rebuildBoxOnDataReady(GObject *obj _U_, VisuData *dataObj,
 				  gpointer data _U_)
 {
   if (dataObj)
     {
-      DBG_fprintf(stderr, "Extension box : caught the 'dataReadyForRendering' signal.\n");
+      DBG_fprintf(stderr, "Extension box: caught the 'dataReadyForRendering' signal.\n");
       boxHasBeenBuilt = FALSE;
-      boxDraw(dataObj);
-
-      g_signal_connect(G_OBJECT(dataObj), "BoxSizeChanged",
-		       G_CALLBACK(onBoxSizeChanged), (gpointer)0);
+      visu_glExt_box_draw(dataObj);
+      legendHasBeenBuilt = FALSE;
+      visu_glExt_box_draw_legend(dataObj);
     }
 }
-static void rebuildBoxOnResources(GObject *obj _U_, VisuData *dataObj,
+static void rebuildBoxOnResources(GObject *obj _U_, VisuData *dataObj _U_,
 				  gpointer data _U_)
 {
-  if (!dataObj)
-    return;
-  boxDraw(dataObj);
+  boxHasBeenBuilt = FALSE;
+  legendHasBeenBuilt = FALSE;
 }
 static void onBoxSizeChanged(VisuData *data, gpointer user_data _U_)
 {
   DBG_fprintf(stderr, "Extension Box: caught the 'BoxSizeChanged' signal.\n");
 
   boxHasBeenBuilt = FALSE;
-  boxDraw(data);
+  visu_glExt_box_draw(data);
+  legendHasBeenBuilt = FALSE;
+  visu_glExt_box_draw_legend(data);
 }
 
-void boxDraw(VisuData *data)
+void visu_glExt_box_draw(VisuData *data)
 {
   int i, j, k;
-  OpenGLBox *box;
-  float ext[3];
+  float v[8][3];
+  float ext[3], centre[3];
+  float material[5] = {.5f, .5f, .2f, .5f, .0f};
+  GLUquadricObj *obj;
+  gchar strLg[64];
 
   if (boxHasBeenBuilt)
     return;
@@ -325,7 +389,7 @@ void boxDraw(VisuData *data)
   DBG_fprintf(stderr, "Extension box: creating box for"
 	      " VisuData %p.\n", (gpointer)data);
   boxHasBeenBuilt = TRUE;
-  box = (visuDataGet_openGLView(data))->box;
+  visu_data_getBoxVertices(data, v, FALSE);
   glDeleteLists(extensionBox->objectListId, 1);
   glNewList(extensionBox->objectListId, GL_COMPILE);
   glLineWidth(boxLineWidth);
@@ -339,35 +403,35 @@ void boxDraw(VisuData *data)
       glLineStipple(1, boxLineStipple[0]);
     }
   glBegin(GL_LINES);
-  glVertex3fv(box->p1);
-  glVertex3fv(box->p2);
-  glVertex3fv(box->p2);
-  glVertex3fv(box->p3);
-  glVertex3fv(box->p3);
-  glVertex3fv(box->p4);
-  glVertex3fv(box->p4);
-  glVertex3fv(box->p1);
-  glVertex3fv(box->p5);
-  glVertex3fv(box->p6);
-  glVertex3fv(box->p6);
-  glVertex3fv(box->p7);
-  glVertex3fv(box->p7);
-  glVertex3fv(box->p8);
-  glVertex3fv(box->p8);
-  glVertex3fv(box->p5);
-  glVertex3fv(box->p1);
-  glVertex3fv(box->p5);
-  glVertex3fv(box->p2);
-  glVertex3fv(box->p6);
-  glVertex3fv(box->p3);
-  glVertex3fv(box->p7);
-  glVertex3fv(box->p4);
-  glVertex3fv(box->p8);
+  glVertex3fv(v[0]);
+  glVertex3fv(v[1]);
+  glVertex3fv(v[1]);
+  glVertex3fv(v[2]);
+  glVertex3fv(v[2]);
+  glVertex3fv(v[3]);
+  glVertex3fv(v[3]);
+  glVertex3fv(v[0]);
+  glVertex3fv(v[4]);
+  glVertex3fv(v[5]);
+  glVertex3fv(v[5]);
+  glVertex3fv(v[6]);
+  glVertex3fv(v[6]);
+  glVertex3fv(v[7]);
+  glVertex3fv(v[7]);
+  glVertex3fv(v[4]);
+  glVertex3fv(v[0]);
+  glVertex3fv(v[4]);
+  glVertex3fv(v[1]);
+  glVertex3fv(v[5]);
+  glVertex3fv(v[2]);
+  glVertex3fv(v[6]);
+  glVertex3fv(v[3]);
+  glVertex3fv(v[7]);
   glEnd();
   if (boxLineStipple[0] != 65535)
     glDisable(GL_LINE_STIPPLE);
   /* Draw the extension lines. */
-  visuDataGet_extension(data, ext);
+  visu_data_getExtension(data, ext);
   if (ext[0] > 0. || ext[1] > 0. || ext[2] > 0.)
     {
       if (boxLineStipple[1] != 65535)
@@ -380,61 +444,61 @@ void boxDraw(VisuData *data)
       for (j = -(int)ext[1]; j < 2 + (int)ext[1]; j++)
 	for (k = -(int)ext[2]; k < 2 + (int)ext[2]; k++)
 	  {
-	    glVertex3f(-ext[0] * box->p2[0] +  box->p4[0] * j + box->p5[0] * k,
-		       -ext[0] * box->p2[1] +  box->p4[1] * j + box->p5[1] * k,
-		       -ext[0] * box->p2[2] +  box->p4[2] * j + box->p5[2] * k);
+	    glVertex3f(-ext[0] * v[1][0] +  v[3][0] * j + v[4][0] * k,
+		       -ext[0] * v[1][1] +  v[3][1] * j + v[4][1] * k,
+		       -ext[0] * v[1][2] +  v[3][2] * j + v[4][2] * k);
 	    if ((j == 0 || j == 1) && (k == 0 || k == 1))
 	      {
-		glVertex3f(box->p4[0] * j + box->p5[0] * k,
-			   box->p4[1] * j + box->p5[1] * k,
-			   box->p4[2] * j + box->p5[2] * k);
-		glVertex3f(box->p2[0] +  box->p4[0] * j + box->p5[0] * k,
-			   box->p2[1] +  box->p4[1] * j + box->p5[1] * k,
-			   box->p2[2] +  box->p4[2] * j + box->p5[2] * k);
+		glVertex3f(v[3][0] * j + v[4][0] * k,
+			   v[3][1] * j + v[4][1] * k,
+			   v[3][2] * j + v[4][2] * k);
+		glVertex3f(v[1][0] +  v[3][0] * j + v[4][0] * k,
+			   v[1][1] +  v[3][1] * j + v[4][1] * k,
+			   v[1][2] +  v[3][2] * j + v[4][2] * k);
 	      }
-	    glVertex3f((1. + ext[0]) * box->p2[0] +  box->p4[0] * j + box->p5[0] * k,
-		       (1. + ext[0]) * box->p2[1] +  box->p4[1] * j + box->p5[1] * k,
-		       (1. + ext[0]) * box->p2[2] +  box->p4[2] * j + box->p5[2] * k);
+	    glVertex3f((1. + ext[0]) * v[1][0] +  v[3][0] * j + v[4][0] * k,
+		       (1. + ext[0]) * v[1][1] +  v[3][1] * j + v[4][1] * k,
+		       (1. + ext[0]) * v[1][2] +  v[3][2] * j + v[4][2] * k);
 	  }
       /* Y coordinate. */
       for (i = -(int)ext[0]; i < 2 + (int)ext[0]; i++)
 	for (k = -(int)ext[2]; k < 2 + (int)ext[2]; k++)
 	  {
-	    glVertex3f(-ext[1] * box->p4[0] +  box->p2[0] * i + box->p5[0] * k,
-		       -ext[1] * box->p4[1] +  box->p2[1] * i + box->p5[1] * k,
-		       -ext[1] * box->p4[2] +  box->p2[2] * i + box->p5[2] * k);
+	    glVertex3f(-ext[1] * v[3][0] +  v[1][0] * i + v[4][0] * k,
+		       -ext[1] * v[3][1] +  v[1][1] * i + v[4][1] * k,
+		       -ext[1] * v[3][2] +  v[1][2] * i + v[4][2] * k);
 	    if ((i == 0 || i == 1) && (k == 0 || k == 1))
 	      {
-		glVertex3f(box->p2[0] * i + box->p5[0] * k,
-			   box->p2[1] * i + box->p5[1] * k,
-			   box->p2[2] * i + box->p5[2] * k);
-		glVertex3f(box->p4[0] +  box->p2[0] * i + box->p5[0] * k,
-			   box->p4[1] +  box->p2[1] * i + box->p5[1] * k,
-			   box->p4[2] +  box->p2[2] * i + box->p5[2] * k);
+		glVertex3f(v[1][0] * i + v[4][0] * k,
+			   v[1][1] * i + v[4][1] * k,
+			   v[1][2] * i + v[4][2] * k);
+		glVertex3f(v[3][0] +  v[1][0] * i + v[4][0] * k,
+			   v[3][1] +  v[1][1] * i + v[4][1] * k,
+			   v[3][2] +  v[1][2] * i + v[4][2] * k);
 	      }
-	    glVertex3f((1. + ext[1]) * box->p4[0] +  box->p2[0] * i + box->p5[0] * k,
-		       (1. + ext[1]) * box->p4[1] +  box->p2[1] * i + box->p5[1] * k,
-		       (1. + ext[1]) * box->p4[2] +  box->p2[2] * i + box->p5[2] * k);
+	    glVertex3f((1. + ext[1]) * v[3][0] +  v[1][0] * i + v[4][0] * k,
+		       (1. + ext[1]) * v[3][1] +  v[1][1] * i + v[4][1] * k,
+		       (1. + ext[1]) * v[3][2] +  v[1][2] * i + v[4][2] * k);
 	  }
       /* Z coordinate. */
       for (i = -(int)ext[0]; i < 2 + (int)ext[0]; i++)
 	for (j = -(int)ext[1]; j < 2 + (int)ext[1]; j++)
 	  {
-	    glVertex3f(-ext[2] * box->p5[0] +  box->p2[0] * i + box->p4[0] * j,
-		       -ext[2] * box->p5[1] +  box->p2[1] * i + box->p4[1] * j,
-		       -ext[2] * box->p5[2] +  box->p2[2] * i + box->p4[2] * j);
+	    glVertex3f(-ext[2] * v[4][0] +  v[1][0] * i + v[3][0] * j,
+		       -ext[2] * v[4][1] +  v[1][1] * i + v[3][1] * j,
+		       -ext[2] * v[4][2] +  v[1][2] * i + v[3][2] * j);
 	    if ((j == 0 || j == 1) && (i == 0 || i == 1))
 	      {
-		glVertex3f(box->p2[0] * i + box->p4[0] * j,
-			   box->p2[1] * i + box->p4[1] * j,
-			   box->p2[2] * i + box->p4[2] * j);
-		glVertex3f(box->p5[0] +  box->p2[0] * i + box->p4[0] * j,
-			   box->p5[1] +  box->p2[1] * i + box->p4[1] * j,
-			   box->p5[2] +  box->p2[2] * i + box->p4[2] * j);
+		glVertex3f(v[1][0] * i + v[3][0] * j,
+			   v[1][1] * i + v[3][1] * j,
+			   v[1][2] * i + v[3][2] * j);
+		glVertex3f(v[4][0] +  v[1][0] * i + v[3][0] * j,
+			   v[4][1] +  v[1][1] * i + v[3][1] * j,
+			   v[4][2] +  v[1][2] * i + v[3][2] * j);
 	      }
-	    glVertex3f((1. + ext[2]) * box->p5[0] +  box->p2[0] * i + box->p4[0] * j,
-		       (1. + ext[2]) * box->p5[1] +  box->p2[1] * i + box->p4[1] * j,
-		       (1. + ext[2]) * box->p5[2] +  box->p2[2] * i + box->p4[2] * j);
+	    glVertex3f((1. + ext[2]) * v[4][0] +  v[1][0] * i + v[3][0] * j,
+		       (1. + ext[2]) * v[4][1] +  v[1][1] * i + v[3][1] * j,
+		       (1. + ext[2]) * v[4][2] +  v[1][2] * i + v[3][2] * j);
 	  }
       glEnd();
       if (boxLineStipple[1] != 65535)
@@ -442,9 +506,142 @@ void boxDraw(VisuData *data)
     }
   glEnable(GL_LIGHTING);
   glEnable(GL_DITHER); /* WARNING: it is the default! */
+  /* Draw the basis set if needed. */
+  if (withBasis)
+    {
+      visu_data_getBoxCentre(data, centre);
+
+      obj = gluNewQuadric();
+      openGLSet_highlightColor(material, boxRGB, 1.f);
+
+      /* Draw the basis set. */
+      glPushMatrix();
+      glTranslated(0., 0., 0.);
+      glRotated(90., 0, 1, 0);  
+      visu_openGL_drawSmoothArrow(obj, -1, VISU_OPENGL_ARROW_BOTTOM_CENTERED,
+				       basisLength - 0.3f, 0.1f, 10, FALSE,
+				       0.3f, 0.2f, 10, FALSE);
+      glRasterPos3f(0.0f, 0.0f, basisLength);
+      sprintf(strLg, _("x: %7.3f"), centre[0]);
+      openGLText_drawChars(strLg, TEXT_SMALL); 
+      glPopMatrix();
+      glPushMatrix();
+      glTranslated(0., 0., 0.);
+      glRotated(-90., 1, 0, 0);  
+      visu_openGL_drawSmoothArrow(obj, -1, VISU_OPENGL_ARROW_BOTTOM_CENTERED,
+				       basisLength - 0.3f, 0.1f, 10, FALSE,
+				       0.3f, 0.2f, 10, FALSE);
+      glRasterPos3f(0.0f, 0.0f, basisLength);
+      sprintf(strLg, _("y: %7.3f"), centre[1]);
+      openGLText_drawChars(strLg, TEXT_SMALL); 
+      glPopMatrix();
+      glPushMatrix();
+      glTranslated(0., 0., 0.);
+      visu_openGL_drawSmoothArrow(obj, -1, VISU_OPENGL_ARROW_BOTTOM_CENTERED,
+				       basisLength - 0.3f, 0.1f, 10, FALSE,
+				       0.3f, 0.2f, 10, FALSE);
+      glRasterPos3f(0.0f, 0.0f, basisLength);
+      sprintf(strLg, _("z: %7.3f"), centre[2]);
+      openGLText_drawChars(strLg, TEXT_SMALL); 
+      glPopMatrix();
+
+      gluDeleteQuadric(obj);
+    }
   glLineWidth(1.);
   glEndList();
 }
+void visu_glExt_box_draw_legend(VisuData *dataObj)
+{
+  VisuOpenGLView *view;
+  float buf, wLg, w;
+  gchar strLg[64];
+#define BOX_PADDING 10
+  float vertices[8][3], box[3];
+
+  if (legendHasBeenBuilt)
+    return;
+  legendHasBeenBuilt = TRUE;
+
+  view = visu_data_getOpenGLView(dataObj);
+  w = 0.16f * MIN(view->window->width, view->window->height);
+
+  buf = 70.f + BOX_PADDING;
+  wLg = MAX(w, 90);
+
+  openGLText_initFontList();
+
+  glDeleteLists(extBoxLegend->objectListId, 1);
+  glNewList(extBoxLegend->objectListId, GL_COMPILE);
+
+  glViewport((float)view->window->width / 2. - wLg / 2.,
+	     BOX_PADDING, wLg, 70.f);
+
+  /* Dsactivation de la lumire et du brouillard et activation du culling. */
+  glDisable(GL_LIGHTING);
+  glDisable(GL_FOG);
+
+  /* Resetting the depth buffer. */
+  glDisable(GL_DEPTH_TEST);
+
+  glEnable(GL_BLEND);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+  glMatrixMode(GL_PROJECTION);
+  glPushMatrix();
+  glLoadIdentity();
+  glOrtho(0.0, wLg, 0., 70.f, -50., +50.);
+  glMatrixMode(GL_MODELVIEW);
+  glPushMatrix();
+  glLoadIdentity();
+
+  /* We draw a big transparent square to do the back. */
+  glColor4f(1., 1., 1., 0.4);
+  glRecti(0, 0, wLg, 75.f);
+
+  glColor4f(0.f, 0.f, 0.f, 1.f);
+
+  visu_data_getBoxVertices(dataObj, vertices, FALSE);
+  box[0] = sqrt((vertices[1][0] - vertices[0][0]) *
+		(vertices[1][0] - vertices[0][0]) +
+		(vertices[1][1] - vertices[0][1]) *
+		(vertices[1][1] - vertices[0][1]) +
+		(vertices[1][2] - vertices[0][2]) *
+		(vertices[1][2] - vertices[0][2]));
+  box[1] = sqrt((vertices[3][0] - vertices[0][0]) *
+		(vertices[3][0] - vertices[0][0]) +
+		(vertices[3][1] - vertices[0][1]) *
+		(vertices[3][1] - vertices[0][1]) +
+		(vertices[3][2] - vertices[0][2]) *
+		(vertices[3][2] - vertices[0][2]));
+  box[2] = sqrt((vertices[4][0] - vertices[0][0]) *
+		(vertices[4][0] - vertices[0][0]) +
+		(vertices[4][1] - vertices[0][1]) *
+		(vertices[4][1] - vertices[0][1]) +
+		(vertices[4][2] - vertices[0][2]) *
+		(vertices[4][2] - vertices[0][2]));
+
+  glRasterPos2f(BOX_PADDING / 2.f, 52.5f);
+  openGLText_drawChars(_("Box lengths"), TEXT_SMALL); 
+
+  glRasterPos2f(BOX_PADDING / 2.f, 35.0f);
+  sprintf(strLg, _("  x: %7.3f"), box[0]);
+  openGLText_drawChars(strLg, TEXT_SMALL); 
+
+  glRasterPos2f(BOX_PADDING / 2.f, 20.0f);
+  sprintf(strLg, _("  y: %7.3f"), box[1]);
+  openGLText_drawChars(strLg, TEXT_SMALL); 
+
+  glRasterPos2f(BOX_PADDING / 2.f, 5.0f);
+  sprintf(strLg, _("  z: %7.3f"), box[2]);
+  openGLText_drawChars(strLg, TEXT_SMALL); 
+
+  glPopMatrix();
+  glMatrixMode(GL_PROJECTION);
+  glPopMatrix();
+  glMatrixMode(GL_MODELVIEW);
+
+  glEndList();
+}
 
 /* Parameters & resources*/
 
@@ -456,9 +653,9 @@ static gboolean readBoxIsOn(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  boxSet_isOn(val);
+  visu_glExt_box_setOn(val);
   return TRUE;
 }
 /* A resource to control the color used to render the lines of the box. */
@@ -469,21 +666,21 @@ static gboolean readBoxColor(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, rgb, 3, error))
+  if (!tool_configFile_readFloat(lines[0], position, rgb, 3, error))
     return FALSE;
 
-  if (configFileClamp_float(&rgb[0], rgb[0], 0., 1.) ||
-      configFileClamp_float(&rgb[1], rgb[1], 0., 1.) ||
-      configFileClamp_float(&rgb[2], rgb[2], 0., 1.))
+  if (tool_configFile_clampFloat(&rgb[0], rgb[0], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[1], rgb[1], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[2], rgb[2], 0., 1.))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 3 floating points"
 			     "(0 <= v <= 1) must appear after the %s markup.\n"),
 			   position, FLAG_RESOURCE_BOX_COLOR);
-      boxSet_RGBValues(boxRGBDefault, MASK_RGB_ALL);
+      visu_glExt_box_setRGBValues(boxRGBDefault, TOOL_COLOR_MASK_RGBA);
       return FALSE;
     }
-  boxSet_RGBValues(rgb, MASK_RGB_ALL);
+  visu_glExt_box_setRGBValues(rgb, TOOL_COLOR_MASK_RGBA);
 
   return TRUE;
 }
@@ -495,18 +692,18 @@ static gboolean readBoxLineWidth(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, &width, 1, error))
+  if (!tool_configFile_readFloat(lines[0], position, &width, 1, error))
     return FALSE;
-  if (configFileClamp_float(&width, width, 1., 10.))
+  if (tool_configFile_clampFloat(&width, width, 1., 10.))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 floating point"
 			     "(1 <= v <= 10) must appear after the %s markup.\n"),
 			   position, FLAG_RESOURCE_BOX_LINE);
-      boxSet_lineWidth(RESOURCE_BOX_LINE_DEFAULT);
+      visu_glExt_box_setLineWidth(RESOURCE_BOX_LINE_DEFAULT);
       return FALSE;
     }
-  boxSet_lineWidth(width);
+  visu_glExt_box_setLineWidth(width);
 
   return TRUE;
 }
@@ -517,13 +714,25 @@ static gboolean readBoxLineStipple(gchar **lines, int nbLines, int position,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
   
-  if (!configFileRead_integer(lines[0], position, stipple, 2, error))
+  if (!tool_configFile_readInteger(lines[0], position, stipple, 2, error))
     return FALSE;
-  boxSet_lineStipple((guint16)stipple[0]);
-  boxSet_expandStipple((guint16)stipple[1]);
+  visu_glExt_box_setLineStipple((guint16)stipple[0]);
+  visu_glExt_box_setExpandStipple((guint16)stipple[1]);
 
   return TRUE;
 }
+static gboolean readBoxLengths(gchar **lines, int nbLines,
+			       int position, VisuData *dataObj _U_, GError **error)
+{
+  gboolean val;
+
+  g_return_val_if_fail(nbLines == 1, FALSE);
+
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
+    return FALSE;
+  extBoxLegend->used = val;
+  return TRUE;
+}
 
 /* Export function that is called by visu_module to write the
    values of resources to a file. */
@@ -542,5 +751,8 @@ static void exportResourcesBox(GString *data, VisuData *dataObj _U_)
   g_string_append_printf(data, "# %s\n", DESC_RESOURCE_BOX_STIPPLE);
   g_string_append_printf(data, "%s:\n", FLAG_RESOURCE_BOX_STIPPLE);
   g_string_append_printf(data, "    %d %d\n", boxLineStipple[0], boxLineStipple[1]);
+  g_string_append_printf(data, "# %s\n", DESC_RESOURCE_BOX_LENGTHS);
+  g_string_append_printf(data, "%s:\n", FLAG_RESOURCE_BOX_LENGTHS);
+  g_string_append_printf(data, "    %d\n", extBoxLegend->used);
   g_string_append_printf(data, "\n");
 }
