@@ -54,121 +54,138 @@
  * It creates all resources and parameters introduced by
  * this extension.
  * This method should be added in the %listInitExtensionFunc to
- * be called automatically by the initOpenGLExtensions() at V_Sim
+ * be called automatically by the initVisuExtensions() at V_Sim
  * startup.
  *
- * Returns: a pointer to the OpenGLExtension it created or
+ * Returns: a pointer to the VisuExtension it created or
  * NULL otherwise.
  */
-OpenGLExtension* initExtensionBox();
+VisuExtension* initExtensionBox();
 
 /**
- * EXT_BOX_ID:
+ * VISU_GLEXT_BOX_ID:
  *
  * The id used to identify this extension, see
- * OpenGLExtensionRebuild_list() for instance.
+ * visuExtensions_rebuildList() for instance.
  */
-#define EXT_BOX_ID "Box"
+#define VISU_GLEXT_BOX_ID "Box"
 
 /**
- * boxSet_RGBValues:
+ * visu_glExt_box_setRGBValues:
  * @rgb: a three floats array with values (0 <= values <= 1) for the
  * red, the green and the blue color. Only values specified by the mask
  * are really relevant.
- * @mask: use #MASK_RGB_R, #MASK_RGB_G, #MASK_RGB_B, #MASK_RGB_ALL or a
+ * @mask: use #TOOL_COLOR_MASK_R, #TOOL_COLOR_MASK_G, #TOOL_COLOR_MASK_B, #TOOL_COLOR_MASK_RGBA or a
  * combinaison to indicate what values in the rgb array must be taken
  * into account.
  *
  * Method used to change the value of the parameter box_color.
  *
- * Returns: TRUE if boxDraw() should be called.
+ * Returns: TRUE if visu_glExt_box_draw() should be called.
  */
-gboolean boxSet_RGBValues(float rgb[3], int mask);
+gboolean visu_glExt_box_setRGBValues(float rgb[3], int mask);
 /**
- * boxSet_lineWidth:
+ * visu_glExt_box_setLineWidth:
  * @width: value of the desired box line width.
  *
  * Method used to change the value of the parameter box_line_width.
  *
- * Returns: TRUE if boxDraw() should be called.
+ * Returns: TRUE if visu_glExt_box_draw() should be called.
  */
-gboolean boxSet_lineWidth(float width);
+gboolean visu_glExt_box_setLineWidth(float width);
 /**
- * boxSet_isOn:
+ * visu_glExt_box_setOn:
  * @value: 1 if box must be drawn, 0 otherwise.
  *
  * Method used to change the value of the parameter box_is_on.
  *
- * Returns: TRUE if boxDraw() should be called.
+ * Returns: TRUE if visu_glExt_box_draw() should be called.
  */
-gboolean boxSet_isOn(int value);
+gboolean visu_glExt_box_setOn(int value);
 /**
- * boxSet_lineStipple:
+ * visu_glExt_box_setLineStipple:
  * @stipple: a pattern for line stipple in OpenGL.
  *
  * Method used to change the value of the parameter box_line_stipple
  * (main part).
  *
- * Returns: TRUE if boxDraw() should be called.
+ * Returns: TRUE if visu_glExt_box_draw() should be called.
  */
-gboolean boxSet_lineStipple(guint16 stipple);
+gboolean visu_glExt_box_setLineStipple(guint16 stipple);
 /**
- * boxSet_expandStipple:
+ * visu_glExt_box_setExpandStipple:
  * @stipple: a pattern for line stipple in OpenGL.
  *
  * Method used to change the value of the parameter box_line_stipple
  * (expanded part).
  *
- * Returns: TRUE if boxDraw() should be called.
+ * Returns: TRUE if visu_glExt_box_draw() should be called.
  */
-gboolean boxSet_expandStipple(guint16 stipple);
+gboolean visu_glExt_box_setExpandStipple(guint16 stipple);
 
 /**
- * boxGet_RGBValues:
+ * visu_glExt_box_getRGBValues:
  *
  * Read the colour components of box (in [0;1]). 
  *
  * Returns: all the colour values of the current box line.
  */
-float* boxGet_RGBValues();
+float* visu_glExt_box_getRGBValues();
 /**
- * boxGet_isOn:
+ * visu_glExt_box_getOn:
  *
  * Read if the box is drawn or not.
  *
  * Returns: 1 if a box is drawn, 0 otherwise.
  */
-int boxGet_isOn();
+int visu_glExt_box_getOn();
 /**
- * boxGet_lineWidth:
+ * visu_glExt_box_getLineWidth:
  *
  * Read the line width used for box.
  *
  * Returns: the value of current box line width.
  */
-float boxGet_lineWidth();
+float visu_glExt_box_getLineWidth();
 /**
- * boxGet_lineStipple:
+ * visu_glExt_box_getLineStipple:
  *
  * Read the line stipple pattern used for box (main part).
  *
  * Returns: the value of current box line pattern.
  */
-guint16 boxGet_lineStipple();
+guint16 visu_glExt_box_getLineStipple();
 /**
- * boxGet_expandStipple:
+ * visu_glExt_box_getExpandStipple:
  *
  * Read the line stipple pattern used for box (expanded part).
  *
  * Returns: the value of current box line pattern.
  */
-guint16 boxGet_expandStipple();
+guint16 visu_glExt_box_getExpandStipple();
 /**
- * boxDraw:
+ * visu_glExt_box_draw:
  * @data: a #VisuData object.
  *
  * This method create a compile list that draw a box for the given @data.
  */
-void boxDraw(VisuData *data);
+void visu_glExt_box_draw(VisuData *data);
+/**
+ * visu_glExt_box_draw_legend:
+ * @dataObj: the #VisuData defining the box.
+ *
+ * Draw a legend giving the different box lengths.
+ */
+void visu_glExt_box_draw_legend(VisuData *dataObj);
+gboolean visu_glExt_box_getShowLegend();
+/**
+ * visu_glExt_box_setShowLegend:
+ * @value: a boolean.
+ *
+ * Draw or not the lengths near the axis.
+ *
+ * Returns: TRUE if status changed.
+ */
+gboolean visu_glExt_box_setShowLegend(gboolean value);
 
 #endif
