@@ -45,6 +45,7 @@
 
 #include <GL/gl.h>
 
+#include <visu_object.h>
 #include <visu_rendering.h>
 #include <openGLFunctions/objectList.h>
 #include <openGLFunctions/text.h>
@@ -63,10 +64,10 @@
 
 /* Interface for a routine to draw the informations into a label. */
 typedef void (*DrawInfosFunc)(VisuData *data, VisuElement *element,
-			      VisuNode *node, DataNode *dataNode);
+			      VisuNode *node, VisuDataNode *dataNode);
 
 /* Local variables. */
-static OpenGLExtension *extInfos;
+static VisuExtension *extInfos;
 static gboolean extIsBuilt;
 
 /* These values are stored to be able to redraw the list when needed.
@@ -76,7 +77,7 @@ typedef struct ExtInfos_struct
 {
   int *nodes;
   DrawInfosFunc draw;
-  DataNode *dataNode;
+  VisuDataNode *dataNode;
 } ExtInfos;
 
 
@@ -84,35 +85,33 @@ typedef struct ExtInfos_struct
 static void freeExtInfos(gpointer extInfos);
 static ExtInfos* getExtInfos(VisuData *data);
 static void drawNumber(VisuData *data, VisuElement *element,
-		       VisuNode *node, DataNode *dataNode);
+		       VisuNode *node, VisuDataNode *dataNode);
 static void drawElement(VisuData *data, VisuElement *element,
-			VisuNode *node, DataNode *dataNode);
+			VisuNode *node, VisuDataNode *dataNode);
 static void drawInfos(VisuData *data, VisuElement *element,
-		      VisuNode *node, DataNode *dataNode);
+		      VisuNode *node, VisuDataNode *dataNode);
 
 /* Callbacks. */
 static void onPopulationIncrease(VisuData *data, int *newNodes, gpointer user_data);
 static void onPopulationDecrease(VisuData *data, int *oldNodes, gpointer user_data);
-static void onPositionUpdate(VisuData *data, gpointer user_data);
-static void onNodeRender(VisuData *data, gpointer user_data);
-static void onElementRender(VisuData *data, VisuElement *element, gpointer user_data);
-static void onCameraMoved(VisuData *data, OpenGLView *view, gpointer user_data);
+static void onNodeChanged(VisuData *data, gpointer user_data);
+static void onCameraMoved(VisuData *data, VisuOpenGLView *view, gpointer user_data);
 
 
 /********************/
 /* Public routines. */
 /********************/
-OpenGLExtension* extInfosInit()
+VisuExtension* initExtInfos()
 {
   char *name = "Information";
   char *description = _("Draw informations on nodes.");
   int listInfos;
 
   DBG_fprintf(stderr,"Initialising the informations OpenGL extension...\n");
-  listInfos = openGLObjectList_new(1);
-  extInfos = OpenGLExtension_new(name, _(name), description,
-				 listInfos, extInfosBuild);
-  OpenGLExtensionSet_priority(extInfos, OPENGL_EXTENSION_PRIORITY_HIGH);
+  listInfos = visu_openGL_objectList_new(1);
+  extInfos = visu_extension_new(name, _(name), description,
+				 listInfos, visu_glExt_infos_build);
+  visu_extension_setPriority(extInfos, VISU_EXTENSION_PRIORITY_HIGH);
 
   /* Initialisation des valeurs par dfaut. */
   extInfos->used = 0;
@@ -120,7 +119,7 @@ OpenGLExtension* extInfosInit()
 
   return extInfos;
 }
-void extInfosSet_number(VisuData *data, int *nodes)
+void visu_glExt_infos_drawIds(VisuData *data, int *nodes)
 {
   ExtInfos *infos;
 
@@ -129,14 +128,14 @@ void extInfosSet_number(VisuData *data, int *nodes)
     g_free(infos->nodes);
   infos->nodes    = nodes;
   infos->draw     = drawNumber;
-  infos->dataNode = (DataNode*)0;
+  infos->dataNode = (VisuDataNode*)0;
 
   if (extInfos->used)
-    extInfosBuild(data);
+    visu_glExt_infos_build(data);
   else
     extIsBuilt = FALSE;
 }
-void extInfosSet_element(VisuData *data, int *nodes)
+void visu_glExt_infos_drawElements(VisuData *data, int *nodes)
 {
   ExtInfos *infos;
 
@@ -145,14 +144,14 @@ void extInfosSet_element(VisuData *data, int *nodes)
     g_free(infos->nodes);
   infos->nodes    = nodes;
   infos->draw     = drawElement;
-  infos->dataNode = (DataNode*)0;
+  infos->dataNode = (VisuDataNode*)0;
 
   if (extInfos->used)
-    extInfosBuild(data);
+    visu_glExt_infos_build(data);
   else
     extIsBuilt = FALSE;
 }
-void extInfosSet_data(VisuData *data, DataNode *dataNode, int *nodes)
+void visu_glExt_infos_drawData(VisuData *data, VisuDataNode *dataNode, int *nodes)
 {
   ExtInfos *infos;
 
@@ -164,11 +163,11 @@ void extInfosSet_data(VisuData *data, DataNode *dataNode, int *nodes)
   infos->dataNode = dataNode;
 
   if (extInfos->used)
-    extInfosBuild(data);
+    visu_glExt_infos_build(data);
   else
     extIsBuilt = FALSE;
 }
-void extInfosBuild(VisuData *dataObj)
+void visu_glExt_infos_build(VisuData *dataObj)
 {
   ExtInfos *infos;
   VisuRendering *currentRenderingMethod;
@@ -186,12 +185,14 @@ void extInfosBuild(VisuData *dataObj)
   if (!infos)
     return;
 
-  currentRenderingMethod = visuRenderingClassGet_current();
+  currentRenderingMethod = visu_object_getRendering(VISU_INSTANCE);
   g_return_if_fail(currentRenderingMethod);
 
   /* Get the camera orientation. */
   glGetFloatv(GL_MODELVIEW_MATRIX, modelView);
 
+  openGLText_initFontList();
+  
   glNewList(extInfos->objectListId, GL_COMPILE);
   glPushAttrib(GL_ENABLE_BIT);
   glDisable(GL_LIGHTING);
@@ -200,11 +201,11 @@ void extInfosBuild(VisuData *dataObj)
   if (!infos->nodes)
     {
       DBG_fprintf(stderr, " | use all the nodes.\n");
-      visuDataIter_new(dataObj, &iter);
-      for (visuDataIter_start(dataObj, &iter); iter.element;
-	   visuDataIter_nextElement(dataObj, &iter))
+      visu_data_iterNew(dataObj, &iter);
+      for (visu_data_iterStart(dataObj, &iter); iter.element;
+	   visu_data_iterNextElement(dataObj, &iter))
 	{
-	  if (iter.element->rendered && iter.element->showNodeInfos)
+	  if (iter.element->rendered)
 	    {
 	      DBG_fprintf(stderr, "Extension Infos: creating glObjectList of node"
 			  " names for '%s'.\n", iter.element->name);
@@ -213,17 +214,17 @@ void extInfosBuild(VisuData *dataObj)
 	      rgba[2] = 1.f - iter.element->rgb[2];
 	      rgba[3] = iter.element->rgb[3];
 	      glColor4fv(rgba);
-	      size = visuRenderingGet_sizeOfElement(currentRenderingMethod,
+	      size = visu_rendering_getSizeOfElement(currentRenderingMethod,
 						      iter.element);
 	      delta[0] = size * modelView[2];
 	      delta[1] = size * modelView[6];
 	      delta[2] = size * modelView[10];
-	      for(visuDataIter_restartNode(dataObj, &iter); iter.node;
-		  visuDataIter_nextNode(dataObj, &iter))
+	      for(visu_data_iterRestartNode(dataObj, &iter); iter.node;
+		  visu_data_iterNextNode(dataObj, &iter))
 		{
 		  if (iter.node->rendered)
 		    {
-		      visuDataGet_nodePosition(dataObj, iter.node, xyz);
+		      visu_data_getNodePosition(dataObj, iter.node, xyz);
 		      glRasterPos3f(xyz[0] + delta[0],
 				    xyz[1] + delta[1],
 				    xyz[2] + delta[2]);
@@ -239,23 +240,23 @@ void extInfosBuild(VisuData *dataObj)
       /* infos->nodes is not NULL, we draw for the given infos->nodes only. */
       for (i = 0; infos->nodes[i] >= 0; i++)
 	{
-	  iter.node = visuDataGet_nodeFromNumber(dataObj, infos->nodes[i]);
+          DBG_fprintf(stderr, " | %d\n", infos->nodes[i]);
+	  iter.node = visu_data_getNodeFromNumber(dataObj, infos->nodes[i]);
 	  g_return_if_fail(iter.node);
 	  iter.element = dataObj->fromIntToVisuElement[iter.node->posElement];
-	  if (iter.element->rendered && iter.element->showNodeInfos &&
-	      iter.node->rendered)
+	  if (iter.element->rendered && iter.node->rendered)
 	    {
 	      rgba[0] = 1.f - iter.element->rgb[0];
 	      rgba[1] = 1.f - iter.element->rgb[1];
 	      rgba[2] = 1.f - iter.element->rgb[2];
 	      rgba[3] = iter.element->rgb[3];
 	      glColor4fv(rgba);
-	      size = visuRenderingGet_sizeOfElement(currentRenderingMethod,
+	      size = visu_rendering_getSizeOfElement(currentRenderingMethod,
 						    iter.element);
 	      delta[0] = size * modelView[2];
 	      delta[1] = size * modelView[6];
 	      delta[2] = size * modelView[10];
-	      visuDataGet_nodePosition(dataObj, iter.node, xyz);
+	      visu_data_getNodePosition(dataObj, iter.node, xyz);
 	      glRasterPos3f(xyz[0] + delta[0],
 			    xyz[1] + delta[1],
 			    xyz[2] + delta[2]);
@@ -266,14 +267,14 @@ void extInfosBuild(VisuData *dataObj)
   glPopAttrib();
   glEndList();
 }
-gboolean extInfosSet_used(VisuData *data, gboolean status)
+gboolean visu_glExt_infos_setOn(VisuData *data, gboolean status)
 {
   if (extInfos->used == (int)status)
     return FALSE;
 
   extInfos->used = (int)status;
   if (status && !extIsBuilt)
-    extInfosBuild(data);
+    visu_glExt_infos_build(data);
 
   return TRUE;
 }
@@ -308,18 +309,18 @@ static ExtInfos* getExtInfos(VisuData *data)
       g_signal_connect(G_OBJECT(data), "NodePopulationIncrease",
 		       G_CALLBACK(onPopulationIncrease), (gpointer)infos);
       g_signal_connect(G_OBJECT(data), "NodePositionChanged",
-		       G_CALLBACK(onPositionUpdate), (gpointer)infos);
+		       G_CALLBACK(onNodeChanged), (gpointer)infos);
       g_signal_connect(G_OBJECT(data), "NodeRenderedChanged",
-		       G_CALLBACK(onElementRender), (gpointer)infos);
-      g_signal_connect(G_OBJECT(data), "ElementRenderedChanged",
-		       G_CALLBACK(onNodeRender), (gpointer)infos);
+		       G_CALLBACK(onNodeChanged), (gpointer)infos);
+      g_signal_connect(G_OBJECT(data), "NodeMaterialChanged",
+		       G_CALLBACK(onNodeChanged), (gpointer)infos);
       g_signal_connect(G_OBJECT(data), "OpenGLThetaPhiOmega",
 		       G_CALLBACK(onCameraMoved), (gpointer)infos);
     }
   return infos;
 }
 static void drawNumber(VisuData *data _U_, VisuElement *element _U_,
-		       VisuNode *node, DataNode *dataNode _U_)
+		       VisuNode *node, VisuDataNode *dataNode _U_)
 {
   gchar str[10];
 
@@ -327,16 +328,16 @@ static void drawNumber(VisuData *data _U_, VisuElement *element _U_,
   openGLText_drawChars(str, TEXT_NORMAL);
 }
 static void drawElement(VisuData *data _U_, VisuElement *element,
-			VisuNode *node _U_, DataNode *dataNode _U_)
+			VisuNode *node _U_, VisuDataNode *dataNode _U_)
 {
   openGLText_drawChars(element->name, TEXT_NORMAL);
 }
 static void drawInfos(VisuData *data, VisuElement *element _U_,
-		      VisuNode *node, DataNode *dataNode)
+		      VisuNode *node, VisuDataNode *dataNode)
 {
   gchar *label;
 
-  label = nodeDataGet_valueAsString(dataNode, data, node);
+  label = visu_data_node_getValueAsString(dataNode, data, node);
   openGLText_drawChars(label, TEXT_NORMAL);
   g_free(label);
 }
@@ -359,7 +360,7 @@ static void onPopulationIncrease(VisuData *data, int *newNodes _U_,
   if (infos->nodes)
     return;
 
-  extInfosBuild(data);
+  visu_glExt_infos_build(data);
 }
 static void onPopulationDecrease(VisuData *data, int *oldNodes, gpointer user_data)
 {
@@ -397,37 +398,18 @@ static void onPopulationDecrease(VisuData *data, int *oldNodes, gpointer user_da
 	}
     }
   if (redraw)
-    extInfosBuild(data);
+    visu_glExt_infos_build(data);
 }
-static void onPositionUpdate(VisuData *data, gpointer user_data _U_)
+static void onNodeChanged(VisuData *data, gpointer user_data _U_)
 {
   if (!extInfos->used)
     return;
 
-  DBG_fprintf(stderr, "Extension Informations: caught the 'NodePositionChanged'"
-	      " signal, rebuild.\n");
-  extInfosBuild(data);
+  DBG_fprintf(stderr, "Extension Informations: caught the 'NodeRenderedChanged',"
+	      "'NodeMaterialChanged' or 'NodePositionChanged' signal, rebuild.\n");
+  visu_glExt_infos_build(data);
 }
-static void onNodeRender(VisuData *data, gpointer user_data _U_)
-{
-  if (!extInfos->used)
-    return;
-
-  DBG_fprintf(stderr, "Extension Informations: caught the 'NodeRenderedChanged'"
-	      " signal, rebuild.\n");
-  extInfosBuild(data);
-}
-static void onElementRender(VisuData *data, VisuElement *element _U_,
-			    gpointer user_data _U_)
-{
-  if (!extInfos->used)
-    return;
-
-  DBG_fprintf(stderr, "Extension Informations: caught the 'ElementRenderedChanged'"
-	      " signal, rebuild.\n");
-  extInfosBuild(data);
-}
-static void onCameraMoved(VisuData *data, OpenGLView *view _U_,
+static void onCameraMoved(VisuData *data, VisuOpenGLView *view _U_,
 			  gpointer user_data _U_)
 {
   if (!extInfos->used)
@@ -435,5 +417,5 @@ static void onCameraMoved(VisuData *data, OpenGLView *view _U_,
 
   DBG_fprintf(stderr, "Extension Informations: caught the 'OpenGLThetaPhiOmega'"
 	      " signal, rebuild.\n");
-  extInfosBuild(data);
+  visu_glExt_infos_build(data);
 }
