@@ -50,17 +50,17 @@
 #include <extraFunctions/dataNode.h>
 
 /**
- * extInfosInit:
+ * initExtInfos:
  *
- * Create the extension, it is called by V_Sim on starup and should not
+ * Create the extension, it is called by V_Sim on startup and should not
  * used elsewhere.
  *
- * Returns: the newly created #OpenGLExtension.
+ * Returns: the newly created #VisuExtension.
  */
-OpenGLExtension* extInfosInit();
+VisuExtension* initExtInfos(void);
 
 /**
- * DrawItem:
+ * VisuGlExtInfosDrawId:
  * @DRAW_NEVER: don't draw any information on nodes ;
  * @DRAW_SELECTED: draw information only on a list of nodes ;
  * @DRAW_ALWAYS: draw information on all nodes.
@@ -72,36 +72,36 @@ typedef enum
     DRAW_NEVER,
     DRAW_SELECTED,
     DRAW_ALWAYS
-  } DrawItem;
+  } VisuGlExtInfosDrawId;
 /**
- * DrawMethod:
- * @DRAW_METH_NONE: draw nothing ;
- * @DRAW_METH_ID: draw the id of nodes ;
- * @DRAW_METH_TYPE: draw the name of node element ;
- * @DRAW_METH_OTHER: other possible draw rendering method.
+ * VisuGlExtInfosDrawMethod:
+ * @EXT_DRAW_METH_NONE: draw nothing ;
+ * @EXT_DRAW_METH_ID: draw the id of nodes ;
+ * @EXT_DRAW_METH_TYPE: draw the name of node element ;
+ * @EXT_DRAW_METH_OTHER: other possible draw rendering method.
  *
  * This enum represents the method for information drawing.
  */
 typedef enum
   {
-    DRAW_METH_NONE,
-    DRAW_METH_ID,
-    DRAW_METH_TYPE,
-    DRAW_METH_OTHER
-  } DrawMethod;
+    EXT_DRAW_METH_NONE,
+    EXT_DRAW_METH_ID,
+    EXT_DRAW_METH_TYPE,
+    EXT_DRAW_METH_OTHER
+  } VisuGlExtInfosDrawMethod;
 
 /**
- * extInfosSet_used:
+ * visu_glExt_infos_setOn:
  * @data: a #VisuData object ;
  * @status: a boolean.
  *
  * Change the status of the informations extension.
  *
- * Returns: TRUE if the calling routine should call visuObjectRedraw().
+ * Returns: TRUE if the calling routine should call visu_object_redraw().
  */
-gboolean extInfosSet_used(VisuData *data, gboolean status);
+gboolean visu_glExt_infos_setOn(VisuData *data, gboolean status);
 /**
- * extInfosSet_number:
+ * visu_glExt_infos_drawIds:
  * @data: a #VisuData object ;
  * @nodes: an integer list, terminated with a negative number.
  *
@@ -112,34 +112,34 @@ gboolean extInfosSet_used(VisuData *data, gboolean status);
  * but must be terminated by a negative integer. This array is then owned by the
  * extension and should not be freed.
  */
-void extInfosSet_number(VisuData *data, int *nodes);
+void visu_glExt_infos_drawIds(VisuData *data, int *nodes);
 /**
- * extInfosSet_element:
+ * visu_glExt_infos_drawElements:
  * @data: a #VisuData object ;
  * @nodes: an integer list, terminated with a negative number.
  *
- * As extInfosSet_number(), but draw the names of elements instead of their
+ * As visu_glExt_infos_drawIds(), but draw the names of elements instead of their
  * numbers.
  */
-void extInfosSet_element(VisuData *data, int *nodes);
+void visu_glExt_infos_drawElements(VisuData *data, int *nodes);
 /**
- * extInfosSet_data:
+ * visu_glExt_infos_drawData:
  * @data: a #VisuData object ;
- * @dataNode: a #DataNode object ;
+ * @dataNode: a #VisuDataNode object ;
  * @nodes: an integer list, terminated with a negative number ;
  *
- * As extInfosSet_number(), but draw some informations instead of their
+ * As visu_glExt_infos_drawIds(), but draw some informations instead of their
  * numbers. The informations are defined by the @dataNode argument.
  */
-void extInfosSet_data(VisuData *data, DataNode *dataNode, int *nodes);
+void visu_glExt_infos_drawData(VisuData *data, VisuDataNode *dataNode, int *nodes);
 /**
- * extInfosBuild:
+ * visu_glExt_infos_build:
  * @dataObj: a #VisuData object.
  *
  * Build the OpenGL list representing the informations associated to the given
- * @dataObj. To associate some, use extInfosSet_number(), or extInfosSet_element()
- * or extInfosSet_data().
+ * @dataObj. To associate some, use visu_glExt_infos_drawIds(), or visu_glExt_infos_drawElements()
+ * or visu_glExt_infos_drawData().
  */
-void extInfosBuild(VisuData *dataObj);
+void visu_glExt_infos_build(VisuData *dataObj);
 
 #endif
