@@ -47,7 +47,6 @@
 #include <visu_object.h>
 #include <visu_tools.h>
 #include <visu_configFile.h>
-#include <renderingBackend/visu_windowInterface.h>
 #include <openGLFunctions/objectList.h>
 #include <openGLFunctions/text.h>
 #include <coreTools/toolColor.h>
@@ -67,7 +66,7 @@
  * position (in the camera basis set) and ends at a lower z.
  */
 
-static OpenGLExtension* extensionFog;
+static VisuExtension* extensionFog;
 
 /* Parameters & resources*/
 /* This is a boolean to control is the axes is render or not. */
@@ -122,8 +121,8 @@ static gboolean fogHasBeenBuilt;
 static void rebuildOpenGLValues(VisuData *dataObj);
 static void onDataReadySignal(GObject *visu, VisuData *dataObj, gpointer data);
 static void onDataNewSignal(GObject *visu, VisuData *dataObj, gpointer data);
-static void onFogParameterChanged(VisuData *dataObj, OpenGLView *view, gpointer data);
-static void onBgImageRescale(VisuData *dataObj, OpenGLView *view, gpointer data);
+static void onFogParameterChanged(VisuData *dataObj, VisuOpenGLView *view, gpointer data);
+static void onBgImageRescale(VisuData *dataObj, VisuOpenGLView *view, gpointer data);
 static void rebuildFogOnResources(GObject *obj, VisuData *dataObj, gpointer data);
 
 /* Local methods */
@@ -131,40 +130,40 @@ static void refreshBgRGB();
 static void createBgImage();
 static void createBgChess();
 
-OpenGLExtension* extFogAndBGInit()
+VisuExtension* initExtFogAndBG()
 {
   char *description = _("Draw a nice fog around the elements and set the color of the background.");
   VisuConfigFileEntry *resourceEntry;
 
   DBG_fprintf(stderr,"Initialising the fog & bg OpenGL extension...\n");
-  extensionFog = OpenGLExtension_new(EXT_FOG_AND_BG_ID,
+  extensionFog = visu_extension_new(VISU_GLEXT_FOG_AND_BG_ID,
 				     _("Fog and background color"),
-				     description, openGLObjectList_new(3),
+				     description, visu_openGL_objectList_new(3),
 				     rebuildOpenGLValues);
-  OpenGLExtensionSet_priority(extensionFog, OPENGL_EXTENSION_PRIORITY_FIRST);
-  OpenGLExtensionSet_saveOpenGLState(extensionFog, TRUE);
+  visu_extension_setPriority(extensionFog, VISU_EXTENSION_PRIORITY_BACKGROUND);
+  visu_extension_setSaveOpenGLState(extensionFog, TRUE);
 
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_FOG_USED,
 					  DESC_RESOURCE_FOG_USED,
 					  1, readFogIsOn);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_FOG_SPECIFIC,
 					  DESC_RESOURCE_FOG_SPECIFIC,
 					  1, readFogSpecific);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_FOG_COLOR,
 					  DESC_RESOURCE_FOG_COLOR,
 					  1, readFogColor);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_FOG_STARTEND,
 					  DESC_RESOURCE_FOG_STARTEND,
 					  1, readFogStartEnd);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_BG_COLOR,
 					  DESC_RESOURCE_BG_COLOR,
 					  1, readBgColor);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesFog);
 
   /* Initialisation des valeurs par dfaut. */
@@ -190,26 +189,26 @@ OpenGLExtension* extFogAndBGInit()
 }
 
 /* Method used to change the value of the parameter fog. */
-int fogSet_values(float rgba[4], int mask)
+int visu_glExt_fog_setValues(float rgba[4], int mask)
 {
   int diff = 0;
   
-  if (mask & MASK_RGB_R && fogRGB[0] != rgba[0])
+  if (mask & TOOL_COLOR_MASK_R && fogRGB[0] != rgba[0])
     {
       fogRGB[0] = rgba[0];
       diff = 1;
     }
-  if (mask & MASK_RGB_G && fogRGB[1] != rgba[1])
+  if (mask & TOOL_COLOR_MASK_G && fogRGB[1] != rgba[1])
     {
       fogRGB[1] = rgba[1];
       diff = 1;
     }
-  if (mask & MASK_RGB_B && fogRGB[2] != rgba[2])
+  if (mask & TOOL_COLOR_MASK_B && fogRGB[2] != rgba[2])
     {
       fogRGB[2] = rgba[2];
       diff = 1;
     }
-  if (mask & MASK_RGB_A && fogRGB[3] != rgba[3])
+  if (mask & TOOL_COLOR_MASK_A && fogRGB[3] != rgba[3])
     {
       fogRGB[3] = rgba[3];
       diff = 1;
@@ -225,12 +224,12 @@ int fogSet_values(float rgba[4], int mask)
 }
 
 /* Get methods. */
-void fogGet_value(float rgba[4])
+void visu_glExt_fog_getValues(float rgba[4])
 {
   memcpy(rgba, fogRGB, sizeof(float) * 4);
 }
 /* Method used to change the value of the parameter axes_is_on. */
-gboolean fogSet_isOn(gboolean value)
+gboolean visu_glExt_fog_setOn(gboolean value)
 {
   if (value == fogIsOn)
     return FALSE;
@@ -248,32 +247,32 @@ gboolean fogSet_isOn(gboolean value)
     
   return (value && !fogHasBeenBuilt);
 }
-gboolean fogGet_isOn()
+gboolean visu_glExt_fog_getOn()
 {
   return fogIsOn;
 }
-gboolean fogSet_useSpecificColor(gboolean value)
+gboolean visu_glExt_fog_setUseSpecificColor(gboolean value)
 {
   if (value == fogColorSpecific)
     return FALSE;
 
   fogColorSpecific = value;
-  fogCreate_color();
+  visu_glExt_fog_create_color();
     
   return fogIsOn;
 }
-gboolean fogGet_useSpecificColor()
+gboolean visu_glExt_fog_getUseSpecificColor()
 {
   return fogColorSpecific;
 }
-gboolean fogSet_startEndValues(float startEnd[2], int mask)
+gboolean visu_glExt_fog_setStartEndValues(float startEnd[2], int mask)
 {
   int diff = 0;
   
-  if (mask & MASK_FOG_START && fog_start != startEnd[0])
+  if (mask & VISU_GLEXT_FOG_MASK_START && fog_start != startEnd[0])
     {
       fog_start = CLAMP(startEnd[0], 0., 1.);
-      if (mask & MASK_FOG_END)
+      if (mask & VISU_GLEXT_FOG_MASK_END)
 	{
 	  if (fog_start >= startEnd[1])
 	    fog_start = startEnd[1] - 0.001;
@@ -283,7 +282,7 @@ gboolean fogSet_startEndValues(float startEnd[2], int mask)
 	  fog_start = fog_end - 0.001;
       diff = 1;
     }
-  if (mask & MASK_FOG_END && fog_end != startEnd[1])
+  if (mask & VISU_GLEXT_FOG_MASK_END && fog_end != startEnd[1])
     {
       fog_end = CLAMP(startEnd[1], 0., 1.);
       if (fog_end <= fog_start)
@@ -294,42 +293,42 @@ gboolean fogSet_startEndValues(float startEnd[2], int mask)
     return FALSE;
   
   /* The method which calls the set method should ask for redraw. */
-/*   fogCreate((GObject*)0, (gpointer)0); */
+/*   visu_glExt_fog_create((GObject*)0, (gpointer)0); */
   fogHasBeenBuilt = FALSE;
   
   return (fogIsOn);
 }
-float fogGet_start()
+float visu_glExt_fog_getStart()
 {
   return fog_start;
 }
-float fogGet_end()
+float visu_glExt_fog_getEnd()
 {
   return fog_end;
 }
 
 /* Method used to change the value of the parameter backgroundColor. */
-int bgSet_values(float rgba[4], int mask)
+int visu_glExt_bg_setValues(float rgba[4], int mask)
 {
   int diff = 0, i, j, c;
   GLubyte chessboard[32][32][3];
 
-  if (mask & MASK_RGB_R && bgRGB[0] != rgba[0])
+  if (mask & TOOL_COLOR_MASK_R && bgRGB[0] != rgba[0])
     {
       bgRGB[0] = rgba[0];
       diff = 1;
     }
-  if (mask & MASK_RGB_G && bgRGB[1] != rgba[1])
+  if (mask & TOOL_COLOR_MASK_G && bgRGB[1] != rgba[1])
     {
       bgRGB[1] = rgba[1];
       diff = 1;
     }
-  if (mask & MASK_RGB_B && bgRGB[2] != rgba[2])
+  if (mask & TOOL_COLOR_MASK_B && bgRGB[2] != rgba[2])
     {
       bgRGB[2] = rgba[2];
       diff = 1;
     }
-  if (mask & MASK_RGB_A && bgRGB[3] != rgba[3])
+  if (mask & TOOL_COLOR_MASK_A && bgRGB[3] != rgba[3])
     {
       bgRGB[3] = rgba[3];
       diff = 1;
@@ -369,17 +368,17 @@ int bgSet_values(float rgba[4], int mask)
   glClearColor(bgRGB[0], bgRGB[1], bgRGB[2], bgRGB[3]);
 
   /* Update the fog color */
-  fogCreate_color();
+  visu_glExt_fog_create_color();
   return 1;
 }
 
 /* Get methods. */
-void bgGet_value(float rgba[4])
+void visu_glExt_bg_getValues(float rgba[4])
 {
   memcpy(rgba, bgRGB, sizeof(float) * 4);
 }
 
-void bgSet_image(const guchar *imageData, guint width, guint height,
+void visu_glExt_bg_setImage(const guchar *imageData, guint width, guint height,
 		 gboolean alpha, const gchar *title, gboolean fit)
 {
   guint n;
@@ -424,7 +423,7 @@ static void onDataReadySignal(GObject *visu _U_, VisuData *dataObj,
     return;
 
   refreshBgRGB();
-  fogCreate(dataObj);
+  visu_glExt_fog_create(dataObj);
 }
 static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj,
 			    gpointer data _U_)
@@ -434,24 +433,20 @@ static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj,
   g_signal_connect(G_OBJECT(dataObj), "OpenGLWidthHeight",
 		   G_CALLBACK(onBgImageRescale), (gpointer)0);
 }
-static void onFogParameterChanged(VisuData *dataObj, OpenGLView *view _U_,
+static void onFogParameterChanged(VisuData *dataObj, VisuOpenGLView *view _U_,
 				  gpointer data _U_)
 {
-  DBG_fprintf(stderr, "Extension Fog : caught the 'OpenGLNearFar' signal, rebuilding"
+  DBG_fprintf(stderr, "Extension Fog: caught the 'OpenGLNearFar' signal, rebuilding"
 	      " fog.\n");
-  fogCreate(dataObj);
+  visu_glExt_fog_create(dataObj);
 }
-static void rebuildFogOnResources(GObject *obj _U_, VisuData *dataObj,
+static void rebuildFogOnResources(GObject *obj _U_, VisuData *dataObj _U_,
 				  gpointer data _U_)
 {
-  DBG_fprintf(stderr, "Extension Fog : caught the 'resourcesLoaded' signal, rebuilding"
+  DBG_fprintf(stderr, "Extension Fog: caught the 'resourcesLoaded' signal, rebuilding"
 	      " fog.\n");
-
-  if (!dataObj)
-    return;
-  fogCreate(dataObj);
 }
-static void onBgImageRescale(VisuData *dataObj _U_, OpenGLView *view _U_,
+static void onBgImageRescale(VisuData *dataObj _U_, VisuOpenGLView *view _U_,
 			     gpointer data _U_)
 {
   DBG_fprintf(stderr, "Extension Bg: caught the 'OpenGLWidthHeight' signal.\n");
@@ -460,16 +455,16 @@ static void onBgImageRescale(VisuData *dataObj _U_, OpenGLView *view _U_,
     createBgImage();
 }
 
-void fogCreate(VisuData *data)
+void visu_glExt_fog_create(VisuData *data)
 {
   float start, stop;
-  OpenGLView *view;
+  VisuOpenGLView *view;
 
   g_return_if_fail(data);
 
   fogHasBeenBuilt = TRUE;
 
-  view = visuDataGet_openGLView(data);
+  view = visu_data_getOpenGLView(data);
   start = (float)(view->window->near +
 		  (view->window->far - view->window->near) * fog_start);
   stop = (float)(view->window->near +
@@ -486,7 +481,7 @@ void fogCreate(VisuData *data)
   glFogf(GL_FOG_END, stop);
 }
 
-void fogCreate_color()
+void visu_glExt_fog_create_color()
 {
   if (fogColorSpecific)
     glFogfv(GL_FOG_COLOR, fogRGB);
@@ -625,8 +620,8 @@ static void rebuildOpenGLValues(VisuData *dataObj)
     {
       glEnable(GL_FOG);
       glFogi(GL_FOG_MODE, GL_LINEAR); 
-      fogCreate_color();
-      fogCreate(dataObj);
+      visu_glExt_fog_create_color();
+      visu_glExt_fog_create(dataObj);
     }
   refreshBgRGB();
   if (bgImage)
@@ -641,9 +636,9 @@ static gboolean readFogIsOn(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  fogSet_isOn(val);
+  visu_glExt_fog_setOn(val);
 
   return TRUE;
 }
@@ -656,9 +651,9 @@ static gboolean readFogSpecific(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  fogSet_useSpecificColor(val);
+  visu_glExt_fog_setUseSpecificColor(val);
 
   return TRUE;
 }
@@ -670,17 +665,17 @@ static gboolean readFogColor(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, val, 4, error))
+  if (!tool_configFile_readFloat(lines[0], position, val, 4, error))
     {
       if (*error)
 	g_error_free(*error);
       *error = (GError*)0;
       /* Read old 3 values. */
-      if (!configFileRead_float(lines[0], position, val, 3, error))
+      if (!tool_configFile_readFloat(lines[0], position, val, 3, error))
 	return FALSE;
       val[3] = 0.f;
     }
-  fogSet_values(val, MASK_RGB_ALL);
+  visu_glExt_fog_setValues(val, TOOL_COLOR_MASK_RGBA);
   return TRUE;
 }
 /* A resource to control the color used for the background. */
@@ -691,9 +686,9 @@ static gboolean readFogStartEnd(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, val, 2, error))
+  if (!tool_configFile_readFloat(lines[0], position, val, 2, error))
     return FALSE;
-  fogSet_startEndValues(val, MASK_FOG_START | MASK_FOG_END);
+  visu_glExt_fog_setStartEndValues(val, VISU_GLEXT_FOG_MASK_START | VISU_GLEXT_FOG_MASK_END);
   return TRUE;
 }
 /* A resource to control the color used for the background. */
@@ -704,17 +699,17 @@ static gboolean readBgColor(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, val, 4, error))
+  if (!tool_configFile_readFloat(lines[0], position, val, 4, error))
     {
       if (*error)
 	g_error_free(*error);
       *error = (GError*)0;
       /* Read old 3 values. */
-      if (!configFileRead_float(lines[0], position, val, 3, error))
+      if (!tool_configFile_readFloat(lines[0], position, val, 3, error))
 	return FALSE;
       val[3] = 1.f;
     }
-  bgSet_values(val, MASK_RGB_ALL);
+  visu_glExt_bg_setValues(val, TOOL_COLOR_MASK_RGBA);
   return TRUE;
 }
 
