@@ -111,7 +111,7 @@ static void exportResourcesScale(GString *data, VisuData *dataObj);
 
 #define SCALE_AUTO_LEGEND "[auto]"
 
-struct _Scale
+struct _VisuGlExtScale
 {
   /* Internal object gestion. */
   GObject parent;
@@ -128,7 +128,7 @@ struct _Scale
   GString *legend;
 };
 
-struct _ScaleClass
+struct _VisuGlExtScaleClass
 {
   GObjectClass parent;
 
@@ -141,10 +141,10 @@ struct _ScaleClass
   guint16 stipple;
 
   /* The drawing hook. */
-  OpenGLExtension* ext;
+  VisuExtension* ext;
 };
 
-static ScaleClass *my_class = NULL;
+static VisuGlExtScaleClass *my_class = NULL;
 
 /* This flag can be set internally to specify that Scale should be recreated. */
 static gboolean scaleHasBeenBuilt;
@@ -155,19 +155,19 @@ static void scale_finalize(GObject* obj);
 
 /* Local methods. */
 static void rebuildScale(VisuData *dataObj);
-static void lineDraw(VisuData *dataObj, int nlat, Scale *scale);
+static void lineDraw(int nlat, VisuGlExtScale *scale);
 
 /* Local callbacks */
-static void onScaleParametersChange(VisuData *dataObj, OpenGLView *view,
+static void onScaleParametersChange(VisuData *dataObj, VisuOpenGLView *view,
 				    gpointer data);
 static void rebuildScaleOnResourcesLoaded(GObject *visu, VisuData *dataObj,
 					  gpointer data);
 static void onDataReadySignal(GObject *visu, VisuData *dataObj, gpointer data);
 static void onDataNewSignal(GObject *visu, VisuData *dataObj, gpointer data);
 
-G_DEFINE_TYPE(Scale, scale, G_TYPE_OBJECT)
+G_DEFINE_TYPE(VisuGlExtScale, visu_glExt_scale, G_TYPE_OBJECT)
 
-static void scale_class_init(ScaleClass *klass)
+static void visu_glExt_scale_class_init(VisuGlExtScaleClass *klass)
 {
   char *name = "Scale";
   char *description = _("Draw scales in the rendering area.");
@@ -181,10 +181,10 @@ static void scale_class_init(ScaleClass *klass)
 
   /* Create the drawing extension. */
   DBG_fprintf(stderr," - initialising the Scale OpenGL extension.\n");
-  klass->ext = OpenGLExtension_new(name, _(name), description,
-				   openGLObjectList_new(1), rebuildScale);
-  OpenGLExtensionSet_saveOpenGLState(klass->ext, TRUE);
-  OpenGLExtensionRegister(klass->ext);
+  klass->ext = visu_extension_new(name, _(name), description,
+				   visu_openGL_objectList_new(1), rebuildScale);
+  visu_extension_setSaveOpenGLState(klass->ext, TRUE);
+  visuExtensions_add(klass->ext);
 
   /* Put the default values. */
   DBG_fprintf(stderr," - set the default values.\n");
@@ -199,32 +199,32 @@ static void scale_class_init(ScaleClass *klass)
 
   /* Create the entries in config files. */
   DBG_fprintf(stderr," - create entries for config file.\n");
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_SCALE_USED,
 					  DESC_RESOURCE_SCALE_USED,
 					  1, readScaleIsOn);
-  visuConfigFileSet_version(resourceEntry, 3.3f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.3f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_SCALE_COLOR,
 					  DESC_RESOURCE_SCALE_COLOR,
 					  1, readScaleColor);
-  visuConfigFileSet_version(resourceEntry, 3.3f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.3f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_SCALE_LINE,
 					  DESC_RESOURCE_SCALE_LINE,
 					  1, readScaleLineWidth);
-  visuConfigFileSet_version(resourceEntry, 3.3f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.3f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_SCALE_DEFINITION,
 					  DESC_RESOURCE_SCALE_DEFINITION,
 					  1, readScaleDefinition);
-  visuConfigFileSet_version(resourceEntry, 3.3f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.3f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_SCALE_STIPPLE,
 					  DESC_RESOURCE_SCALE_STIPPLE,
 					  1, readScaleLineStipple);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesScale);
 
   /* Connect external signals. */
@@ -240,13 +240,15 @@ static void scale_class_init(ScaleClass *klass)
   my_class = klass;
 }
 
-static void scale_init(Scale *obj)
+static void visu_glExt_scale_init(VisuGlExtScale *obj)
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
 
   obj->dispose_has_run = FALSE;
 
-  DBG_fprintf(stderr, "Scale: creating a new scale (%p).\n", (gpointer)obj);
+  klass = VISU_GLEXT_SCALE_GET_CLASS(obj);
+  DBG_fprintf(stderr, "Scale: creating a new scale (%p) (%d).\n",
+              (gpointer)obj, g_list_length(klass->scales));
   obj->drawn         = TRUE;
   obj->origin[0]     = 0.;
   obj->origin[1]     = 0.;
@@ -258,21 +260,34 @@ static void scale_init(Scale *obj)
   obj->legendPattern = (gchar*)0;
   obj->legend        = g_string_new("");
 
-  klass = SCALE_GET_CLASS(obj);
-  klass->scales = g_list_append(klass->scales, obj);
+  klass->scales = g_list_prepend(klass->scales, obj);
   DBG_fprintf(stderr, "Scales: list of scales is now %d long.\n",
 	      g_list_length(klass->scales));
 }
 
-Scale* scaleNew(float origin[3], float orientation[3],
-		float length, const gchar *legend)
+/**
+ * visu_glExt_scale_new:
+ * @origin: the origin ;
+ * @orientation: the orientation in cartesian coordinates ;
+ * @length: the length of the arrow ;
+ * @legend: the text going with the arrow (can be NULL).
+ *
+ * Create a new arrow pointing somewhere in the box with a label.
+ * If @legend is NULL, then the label will be the value of the length.
+ *
+ * Returns: a newly created #VisuGlExtScale object.
+ *
+ * Since: 3.3
+ */
+VisuGlExtScale* visu_glExt_scale_new(float origin[3], float orientation[3],
+                                     float length, const gchar *legend)
 {
-  Scale *scale;
+  VisuGlExtScale *scale;
 
-  g_return_val_if_fail(length > 0.f, (Scale*)0);
+  g_return_val_if_fail(length > 0.f, (VisuGlExtScale*)0);
 
-  scale = SCALE(g_object_new(SCALE_TYPE, NULL));
-  g_return_val_if_fail(scale, (Scale*)0);
+  scale = VISU_GLEXT_SCALE(g_object_new(VISU_GLEXT_SCALE_TYPE, NULL));
+  g_return_val_if_fail(scale, (VisuGlExtScale*)0);
 
   scale->origin[0] = origin[0];
   scale->origin[1] = origin[1];
@@ -298,12 +313,12 @@ static void scale_dispose(GObject* obj)
 {
   DBG_fprintf(stderr, "Scale: dispose object %p.\n", (gpointer)obj);
 
-  if (SCALE(obj)->dispose_has_run)
+  if (VISU_GLEXT_SCALE(obj)->dispose_has_run)
     return;
 
-  SCALE(obj)->dispose_has_run = TRUE;
+  VISU_GLEXT_SCALE(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(scale_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_glExt_scale_parent_class)->dispose(obj);
 }
 /* This method is called once only. */
 static void scale_finalize(GObject* obj)
@@ -313,58 +328,74 @@ static void scale_finalize(GObject* obj)
   DBG_fprintf(stderr, "Scale: finalize object %p.\n", (gpointer)obj);
 
   /* Remove me from the global scale list. */
-  SCALE_GET_CLASS(obj)->scales = g_list_remove(SCALE_GET_CLASS(obj)->scales, obj);
+  VISU_GLEXT_SCALE_GET_CLASS(obj)->scales = g_list_remove(VISU_GLEXT_SCALE_GET_CLASS(obj)->scales, obj);
   DBG_fprintf(stderr, "Scales: list of scales is now %d long.\n",
-	      g_list_length(SCALE_GET_CLASS(obj)->scales));
+	      g_list_length(VISU_GLEXT_SCALE_GET_CLASS(obj)->scales));
 
   /* Free my memory. */
-  if (SCALE(obj)->legendPattern)
-    g_free(SCALE(obj)->legendPattern);
-  g_string_free(SCALE(obj)->legend, TRUE);
+  if (VISU_GLEXT_SCALE(obj)->legendPattern)
+    g_free(VISU_GLEXT_SCALE(obj)->legendPattern);
+  g_string_free(VISU_GLEXT_SCALE(obj)->legend, TRUE);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(scale_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_glExt_scale_parent_class)->finalize(obj);
 }
 
 
-static ScaleClass* scalesGetClass()
+static VisuGlExtScaleClass* scalesGetClass()
 {
   GObject *scale;
 
   if (!my_class)
     {
-      scale = g_object_new(SCALE_TYPE, NULL);
+      scale = g_object_new(VISU_GLEXT_SCALE_TYPE, NULL);
       g_object_unref(scale);
     }
 
   return my_class;
 }
 
-/* Method used to change the value of the parameter scale_color. */
-gboolean scalesSet_defaultRGBValues(float rgba[4], int mask)
+/**
+ * visu_glExt_scale_setDefaultRGBValues:
+ * @rgba: a four floats array with values (0 <= values <= 1) for the
+ * red, the green, the blue and the alpha color. Only values specified by the mask
+ * are really relevant.
+ * @mask: use #TOOL_COLOR_MASK_R, #TOOL_COLOR_MASK_G, #TOOL_COLOR_MASK_B, #TOOL_COLOR_MASK_RGBA or a
+ * combinaison to indicate what values in the rgb array must be taken
+ * into account.
+ *
+ * Method used to change the value of the private parameter
+ * scales_color. This affects all the drawn scales.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if scaleDraw() should be called and then 'OpenGLAskForReDraw'
+ *          signal be emitted.
+ */
+gboolean visu_glExt_scale_setDefaultRGBValues(float rgba[4], int mask)
 {
   gboolean diff = 0;
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
   
   klass = scalesGetClass();
   g_return_val_if_fail(klass, FALSE);
 
-  if (mask & MASK_RGB_R && klass->rgba[0] != rgba[0])
+  if (mask & TOOL_COLOR_MASK_R && klass->rgba[0] != rgba[0])
     {
       klass->rgba[0] = rgba[0];
       diff = TRUE;
     }
-  if (mask & MASK_RGB_G && klass->rgba[1] != rgba[1])
+  if (mask & TOOL_COLOR_MASK_G && klass->rgba[1] != rgba[1])
     {
       klass->rgba[1] = rgba[1];
       diff = TRUE;
     }
-  if (mask & MASK_RGB_B && klass->rgba[2] != rgba[2])
+  if (mask & TOOL_COLOR_MASK_B && klass->rgba[2] != rgba[2])
     {
       klass->rgba[2] = rgba[2];
       diff = TRUE;
     }
-  if (mask & MASK_RGB_A && klass->rgba[3] != rgba[3])
+  if (mask & TOOL_COLOR_MASK_A && klass->rgba[3] != rgba[3])
     {
       klass->rgba[3] = rgba[3];
       diff = TRUE;
@@ -378,9 +409,21 @@ gboolean scalesSet_defaultRGBValues(float rgba[4], int mask)
 }
 
 /* Method used to change the value of the parameter scale_line_width. */
-gboolean scalesSet_defaultLineWidth(float width)
+/**
+ * visu_glExt_scale_setDefaultLineWidth:
+ * @width: value of the desired width.
+ *
+ * Method used to change the value of the parameter
+ * scale_line_width. This affects all the drawn scales.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if scaleDraw() should be called and then 'OpenGLAskForReDraw'
+ *          signal be emitted.
+ */
+gboolean visu_glExt_scale_setDefaultLineWidth(float width)
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
   
   g_return_val_if_fail(width > 0.f && width <= 10.f, FALSE);
   
@@ -396,10 +439,20 @@ gboolean scalesSet_defaultLineWidth(float width)
   return (gboolean)klass->ext->used;
 }
 
-/* Method used to change the value of the parameter scale_is_on. */
-gboolean scalesSet_areOn(gboolean value)
+/**
+ * visu_glExt_scale_setOn:
+ * @value: 1 if a scale must be drawn, 0 otherwise.
+ *
+ * Method used to change the value of the parameter Scale_are_on.
+ *
+ * Since: 3.3
+ *
+ * Returns: 1 if scaleDraw() should be called. In all cases, 'OpenGLAskForReDraw'
+ *          signal should then be emitted.
+ */
+gboolean visu_glExt_scale_setOn(gboolean value)
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
   
   klass = scalesGetClass();
   g_return_val_if_fail(klass, FALSE);
@@ -413,68 +466,136 @@ gboolean scalesSet_areOn(gboolean value)
 }
 
 /* Get methods. */
-float* scalesGet_defaultRGBColor()
+/**
+ * visu_glExt_scale_getDefaultRGBValues:
+ *
+ * All the scales shared a common colour.
+ *
+ * Since: 3.3
+ *
+ * Returns: a four component array.
+ */
+float* visu_glExt_scale_getDefaultRGBValues()
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
 
   klass = scalesGetClass();
   return klass->rgba;
 }
-gboolean scalesGet_areOn()
+/**
+ * visu_glExt_scale_getOn:
+ *
+ * The scales can be turned off or on.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if scale are drawn, FALSE otherwise.
+ */
+gboolean visu_glExt_scale_getOn()
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
 
   klass = scalesGetClass();
   g_return_val_if_fail(klass, FALSE);
   return klass->ext->used;
 }
-float scalesGet_defaultLineWidth()
+/**
+ * visu_glExt_scale_getDefaultLineWidth:
+ *
+ * The scales share a line width for the stick of the arrow.
+ *
+ * Since: 3.3
+ *
+ * Returns: the value of current width.
+ */
+float visu_glExt_scale_getDefaultLineWidth()
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
 
   klass = scalesGetClass();
   g_return_val_if_fail(klass, -1.f);
   return klass->width;
 }
-float scaleGet_length(Scale *scale)
+/**
+ * visu_glExt_scale_getLength:
+ * @scale: the #VisuGlExtScale to poll.
+ *
+ * A #VisuGlExtScale is characterised by its length.
+ *
+ * Since: 3.3
+ *
+ * Returns: a positive floating point value.
+ */
+float visu_glExt_scale_getLength(VisuGlExtScale *scale)
 {
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), -1.f);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), -1.f);
 
   return scale->length;
 }
-float* scaleGet_origin(Scale *scale)
+/**
+ * visu_glExt_scale_getOrigin:
+ * @scale: the #VisuGlExtScale to poll.
+ *
+ * A #VisuGlExtScale is characterised by its origin in cartesian coordinates.
+ *
+ * Since: 3.3
+ *
+ * Returns: three floating point values.
+ */
+float* visu_glExt_scale_getOrigin(VisuGlExtScale *scale)
 {
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), (float*)0);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), (float*)0);
 
   return scale->origin;
 }
-float* scaleGet_orientation(Scale *scale)
+/**
+ * visu_glExt_scale_getOrientation:
+ * @scale: the #VisuGlExtScale to poll.
+ *
+ * A #VisuGlExtScale is characterised by its orientation in cartesian coordinates.
+ *
+ * Since: 3.3
+ *
+ * Returns: three floating point values.
+ */
+float* visu_glExt_scale_getOrientation(VisuGlExtScale *scale)
 {
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), (float*)0);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), (float*)0);
 
   return scale->direction;
 }
 
-/* Set the coordinates of scale origin. */
-gboolean scaleSet_origin(Scale *scale, float xyz[3], int mask)
+/**
+ * visu_glExt_scale_setOrigin:
+ * @scale: the #VisuGlExtScale to modify ;
+ * @xyz: a vector in cartesian coordinates ;
+ * @mask: relevant values in @xyz.
+ *
+ * Routine that changes the origin of the scale.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if visu_glExt_scale_drawAll() should be called.
+ */
+gboolean visu_glExt_scale_setOrigin(VisuGlExtScale *scale, float xyz[3], int mask)
 {
   gboolean difference;
 
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), FALSE);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), FALSE);
 
   difference = FALSE;
 
-  if (mask & MASK_XYZ_X && scale->origin[0] != xyz[0])
+  if (mask & VISU_GLEXT_XYZ_MASK_X && scale->origin[0] != xyz[0])
     {
       scale->origin[0] = xyz[0];
       difference = 1;
     }
-  if (mask & MASK_XYZ_Y && scale->origin[1] != xyz[1])
+  if (mask & VISU_GLEXT_XYZ_MASK_Y && scale->origin[1] != xyz[1])
     {
       scale->origin[1] = xyz[1];
       difference = 1;
     }
-  if (mask & MASK_XYZ_Z && scale->origin[2] != xyz[2])
+  if (mask & VISU_GLEXT_XYZ_MASK_Z && scale->origin[2] != xyz[2])
     {
       scale->origin[2] = xyz[2];
       difference = 1;
@@ -483,29 +604,40 @@ gboolean scaleSet_origin(Scale *scale, float xyz[3], int mask)
     return FALSE;
 
   scaleHasBeenBuilt = FALSE;
-  return SCALE_GET_CLASS(scale)->ext->used;
+  return VISU_GLEXT_SCALE_GET_CLASS(scale)->ext->used;
 }
 
-/* Set the direction of the scale. */
-gboolean scaleSet_orientation(Scale *scale, float xyz[3], int mask)
+/**
+ * visu_glExt_scale_setOrientation:
+ * @scale: the #VisuGlExtScale to modify ;
+ * @xyz: a vector in cartesian coordinates ;
+ * @mask: relevant values in @xyz.
+ *
+ * Routine that changes the direction of the scale.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if visu_glExt_scale_drawAll() should be called.
+ */
+gboolean visu_glExt_scale_setOrientation(VisuGlExtScale *scale, float xyz[3], int mask)
 {
   gboolean difference;
 
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), FALSE);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), FALSE);
 
   difference = FALSE;
 
-  if (mask & MASK_XYZ_X && scale->direction[0] != xyz[0])
+  if (mask & VISU_GLEXT_XYZ_MASK_X && scale->direction[0] != xyz[0])
     {
       scale->direction[0] = xyz[0];
       difference = 1;
     }
-  if (mask & MASK_XYZ_Y && scale->direction[1] != xyz[1])
+  if (mask & VISU_GLEXT_XYZ_MASK_Y && scale->direction[1] != xyz[1])
     {
       scale->direction[1] = xyz[1];
       difference = 1;
     }
-  if (mask & MASK_XYZ_Z && scale->direction[2] != xyz[2])
+  if (mask & VISU_GLEXT_XYZ_MASK_Z && scale->direction[2] != xyz[2])
     {
       scale->direction[2] = xyz[2];
       difference = 1;
@@ -514,24 +646,45 @@ gboolean scaleSet_orientation(Scale *scale, float xyz[3], int mask)
     return FALSE;
 
   scaleHasBeenBuilt = FALSE;
-  return SCALE_GET_CLASS(scale)->ext->used;
+  return VISU_GLEXT_SCALE_GET_CLASS(scale)->ext->used;
 }
-
-gboolean scaleSet_length(Scale *scale, float lg)
+/**
+ * visu_glExt_scale_setLength:
+ * @scale: the #VisuGlExtScale to modify ;
+ * @lg: a positive length.
+ *
+ * Routine that changes the length of the scale.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if visu_glExt_scale_drawAll() should be called.
+ */
+gboolean visu_glExt_scale_setLength(VisuGlExtScale *scale, float lg)
 {
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), FALSE);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), FALSE);
 
   if (lg == scale->length)
     return FALSE;
 
   scale->length = lg;
   scaleHasBeenBuilt = FALSE;
-  return SCALE_GET_CLASS(scale)->ext->used;
+  return VISU_GLEXT_SCALE_GET_CLASS(scale)->ext->used;
 }
-
-gboolean scaleSet_legend(Scale *scale, const gchar *value)
+/**
+ * visu_glExt_scale_setLegend:
+ * @scale: the #VisuGlExtScale to modify ;
+ * @value: a string (can be NULL).
+ *
+ * Routine that changes the legend of the scale. If @value is NULL
+ * then the length of the scale is printed.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if visu_glExt_scale_drawAll() should be called.
+ */
+gboolean visu_glExt_scale_setLegend(VisuGlExtScale *scale, const gchar *value)
 {
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), FALSE);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), FALSE);
 
   if (scale->legendPattern)
     g_free(scale->legendPattern);
@@ -546,17 +699,37 @@ gboolean scaleSet_legend(Scale *scale, const gchar *value)
     g_string_printf(scale->legend, SCALE_LEGEND_DEFAULT, scale->length);
 
   scaleHasBeenBuilt = FALSE;
-  return SCALE_GET_CLASS(scale)->ext->used;
+  return VISU_GLEXT_SCALE_GET_CLASS(scale)->ext->used;
 }
-const gchar* scaleGet_legend(Scale *scale)
+/**
+ * visu_glExt_scale_getLegend:
+ * @scale: the #VisuGlExtScale to poll.
+ *
+ * A #VisuGlExtScale can have a legend. This is not actualy the string printed
+ * on screen but the one used to generate it.
+ *
+ * Since: 3.3
+ *
+ * Returns: a string (private, do not free it).
+ */
+const gchar* visu_glExt_scale_getLegend(VisuGlExtScale *scale)
 {
-  g_return_val_if_fail(IS_SCALE_TYPE(scale), (const gchar*)0);
+  g_return_val_if_fail(VISU_GLEXT_IS_SCALE(scale), (const gchar*)0);
   return scale->legendPattern;
 }
 
-GList* scalesGet_scales()
+/**
+ * visu_glExt_scale_getAll:
+ *
+ * All the available scales can be retrieve with this method.
+ *
+ * Since: 3.3
+ *
+ * Returns: a private #GList.
+ */
+GList* visu_glExt_scale_getAll()
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
 
   klass = scalesGetClass();
   DBG_fprintf(stderr, "Scales: get the scale list (%d).\n",
@@ -564,9 +737,19 @@ GList* scalesGet_scales()
   return klass->scales;
 }
 
-gboolean scalesSet_defaultStipple(guint16 stipple)
+/**
+ * visu_glExt_scale_setDefaultStipple:
+ * @stipple: a pattern for line.
+ *
+ * The scales share a line pattern for the stick of the arrow.
+ *
+ * Since: 3.3
+ *
+ * Returns: TRUE if scale are drawn, FALSE otherwise.
+ */
+gboolean visu_glExt_scale_setDefaultStipple(guint16 stipple)
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
   
   klass = scalesGetClass();
   g_return_val_if_fail(klass, FALSE);
@@ -579,9 +762,18 @@ gboolean scalesSet_defaultStipple(guint16 stipple)
   scaleHasBeenBuilt = FALSE;
   return (gboolean)klass->ext->used;
 }
-guint16 scalesGet_defaultStipple()
+/**
+ * visu_glExt_scale_getDefaultStipple:
+ *
+ * The scales share a line pattern for the stick of the arrow.
+ *
+ * Since: 3.3
+ *
+ * Returns: the value of current stipple pattern.
+ */
+guint16 visu_glExt_scale_getDefaultStipple()
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
 
   klass = scalesGetClass();
   g_return_val_if_fail(klass, 0);
@@ -595,23 +787,29 @@ guint16 scalesGet_defaultStipple()
 
 static void rebuildScale(VisuData *dataObj)
 {
+  VisuOpenGLView *view;
+
   openGLText_rebuildFontList();
   /* Set flag to false to force recreation of Scale. */
   scaleHasBeenBuilt = FALSE;
-  scalesDraw(dataObj);
+  view = visu_data_getOpenGLView(dataObj);
+  visu_glExt_scale_drawAll(view->camera, MIN(view->window->width, view->window->height));
 }
-static void rebuildScaleOnResourcesLoaded(GObject *visu _U_, VisuData *dataObj,
+static void rebuildScaleOnResourcesLoaded(GObject *visu _U_, VisuData *dataObj _U_,
 					  gpointer data _U_)
 {
-  scalesDraw(dataObj);
+  scaleHasBeenBuilt = FALSE;
 }
 static void onDataReadySignal(GObject *visu _U_, VisuData *dataObj, gpointer data _U_)
 {
+  VisuOpenGLView *view;
+
   if (!dataObj)
     return;
 
   scaleHasBeenBuilt = FALSE;
-  scalesDraw(dataObj);
+  view = visu_data_getOpenGLView(dataObj);
+  visu_glExt_scale_drawAll(view->camera, MIN(view->window->width, view->window->height));
 }
 static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj, gpointer data _U_)
 {
@@ -619,29 +817,35 @@ static void onDataNewSignal(GObject *visu _U_, VisuData *dataObj, gpointer data
 		   G_CALLBACK(onScaleParametersChange), (gpointer)0);
   g_signal_connect(G_OBJECT(dataObj), "OpenGLWidthHeight",
 		   G_CALLBACK(onScaleParametersChange), (gpointer)0);
+  g_signal_connect(G_OBJECT(dataObj), "OpenGLThetaPhiOmega",
+		   G_CALLBACK(onScaleParametersChange), (gpointer)0);
 }
 
-static void onScaleParametersChange(VisuData *dataObj, OpenGLView *view _U_,
+static void onScaleParametersChange(VisuData *dataObj _U_, VisuOpenGLView *view,
 				    gpointer data _U_)
 {
   scaleHasBeenBuilt = FALSE;
-  scalesDraw(dataObj);
+  visu_glExt_scale_drawAll(view->camera, MIN(view->window->width, view->window->height));
 }
 
-void scalesDraw(VisuData *dataObj)
+/**
+ * visu_glExt_scale_drawAll:
+ * @camera: a #VisuOpenGLCamera object.
+ * @winSize: the size of the rendering area.
+ *
+ * This method creates a compile list that draw all scales.
+ *
+ * Since: 3.3
+ */
+void visu_glExt_scale_drawAll(VisuOpenGLCamera *camera, guint winSize)
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
   GList *tmpLst;
   int nlat;
   float radius = 0.3;
 
   /* Nothing to draw; */
-  if(!scalesGet_areOn() || scaleHasBeenBuilt) return;
-
-  /* Nothing to draw if no data is associated to
-     the current rendering window. */
-  if (!dataObj)
-    return;
+  if(!visu_glExt_scale_getOn() || scaleHasBeenBuilt) return;
 
   DBG_fprintf(stderr, "Extension Scale: creating scales.\n");
   klass = scalesGetClass();
@@ -649,7 +853,7 @@ void scalesDraw(VisuData *dataObj)
   scaleHasBeenBuilt = TRUE;
 
   openGLText_initFontList();
-  nlat = OpenGLViewGet_numberOfFacettes(visuDataGet_openGLView(dataObj), radius);
+  nlat = VisuOpenGLCameraGet_numberOfFacettes(camera, winSize, radius);
   
   glDeleteLists(klass->ext->objectListId, 1);
 
@@ -672,7 +876,7 @@ void scalesDraw(VisuData *dataObj)
   tmpLst = klass->scales;
   while (tmpLst)
     {
-      lineDraw(dataObj, nlat, SCALE(tmpLst->data));
+      lineDraw(nlat, VISU_GLEXT_SCALE(tmpLst->data));
       tmpLst = g_list_next(tmpLst);
     }
 
@@ -691,9 +895,9 @@ static gboolean readScaleIsOn(gchar **lines, int nbLines,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  scalesSet_areOn(val);
+  visu_glExt_scale_setOn(val);
   return TRUE;
 }
 /* A resource to control the color used to render the lines of the Scale. */
@@ -704,29 +908,29 @@ static gboolean readScaleColor(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, rgb, 4, error))
+  if (!tool_configFile_readFloat(lines[0], position, rgb, 4, error))
     {
       if (*error)
 	g_error_free(*error);
       *error = (GError*)0;
-      if (!configFileRead_float(lines[0], position, rgb, 3, error))
+      if (!tool_configFile_readFloat(lines[0], position, rgb, 3, error))
 	return FALSE;
       rgb[3] = 1.f;
     }
 
-  if (configFileClamp_float(&rgb[0], rgb[0], 0., 1.) ||
-      configFileClamp_float(&rgb[1], rgb[1], 0., 1.) ||
-      configFileClamp_float(&rgb[2], rgb[2], 0., 1.) ||
-      configFileClamp_float(&rgb[3], rgb[3], 0., 1.))
+  if (tool_configFile_clampFloat(&rgb[0], rgb[0], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[1], rgb[1], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[2], rgb[2], 0., 1.) ||
+      tool_configFile_clampFloat(&rgb[3], rgb[3], 0., 1.))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 4 floating points"
 			     "(0 <= v <= 1) must appear after the %s markup.\n"),
 			   position, FLAG_RESOURCE_SCALE_COLOR);
-      scalesSet_defaultRGBValues(scaleRGBDefault, MASK_RGB_ALL);
+      visu_glExt_scale_setDefaultRGBValues(scaleRGBDefault, TOOL_COLOR_MASK_RGBA);
       return FALSE;
     }
-  scalesSet_defaultRGBValues(rgb, MASK_RGB_ALL);
+  visu_glExt_scale_setDefaultRGBValues(rgb, TOOL_COLOR_MASK_RGBA);
 
   return TRUE;
 }
@@ -738,18 +942,18 @@ static gboolean readScaleLineWidth(gchar **lines, int nbLines,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, &width, 1, error))
+  if (!tool_configFile_readFloat(lines[0], position, &width, 1, error))
     return FALSE;
-  if (configFileClamp_float(&width, width, 1., 10.))
+  if (tool_configFile_clampFloat(&width, width, 1., 10.))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 floating point"
 			     "(1 <= v <= 10) must appear after the %s markup.\n"),
 			   position, FLAG_RESOURCE_SCALE_LINE);
-      scalesSet_defaultLineWidth(SCALE_WIDTH_DEFAULT);
+      visu_glExt_scale_setDefaultLineWidth(SCALE_WIDTH_DEFAULT);
       return FALSE;
     }
-  scalesSet_defaultLineWidth(width);
+  visu_glExt_scale_setDefaultLineWidth(width);
 
   return TRUE;
 }
@@ -760,9 +964,9 @@ static gboolean readScaleLineStipple(gchar **lines, int nbLines,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
   
-  if (!configFileRead_integer(lines[0], position, &stipple, 1, error))
+  if (!tool_configFile_readInteger(lines[0], position, &stipple, 1, error))
     return FALSE;
-  scalesSet_defaultStipple((guint16)stipple);
+  visu_glExt_scale_setDefaultStipple((guint16)stipple);
 
   return TRUE;
 }
@@ -777,17 +981,17 @@ static gboolean readScaleDefinition(gchar **lines, int nbLines,
 
   tokens = g_strsplit(g_strchug(lines[0]), " ", 0);
   pos = 0;
-  if (!configFileRead_floatFromTokens(tokens, &pos, xyz, 3, position, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &pos, xyz, 3, position, error))
     {
       g_strfreev(tokens);
       return FALSE;      
     }
-  if (!configFileRead_floatFromTokens(tokens, &pos, orientation, 3, position, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &pos, orientation, 3, position, error))
     {
       g_strfreev(tokens);
       return FALSE;      
     }
-  if (!configFileRead_floatFromTokens(tokens, &pos, &len, 1, position, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &pos, &len, 1, position, error))
     {
       g_strfreev(tokens);
       return FALSE;      
@@ -801,7 +1005,7 @@ static gboolean readScaleDefinition(gchar **lines, int nbLines,
   legend = g_strstrip(remains);
   if (legend && !strcmp(legend, SCALE_AUTO_LEGEND))
     legend = (gchar*)0;
-  scaleNew(xyz, orientation, len, legend);
+  visu_glExt_scale_new(xyz, orientation, len, legend);
   g_free(remains);
 
   return TRUE;
@@ -811,9 +1015,9 @@ static gboolean readScaleDefinition(gchar **lines, int nbLines,
    values of resources to a file. */
 static void exportResourcesScale(GString *data, VisuData *dataObj _U_)
 {
-  ScaleClass *klass;
+  VisuGlExtScaleClass *klass;
   GList *tmpLst;
-  Scale *scale;
+  VisuGlExtScale *scale;
   gchar *legend;
 
   klass = scalesGetClass();
@@ -835,7 +1039,7 @@ static void exportResourcesScale(GString *data, VisuData *dataObj _U_)
   tmpLst = klass->scales;
   while (tmpLst)
     {
-      scale = SCALE(tmpLst->data);
+      scale = VISU_GLEXT_SCALE(tmpLst->data);
       if (scale->legendPattern)
 	legend = scale->legendPattern;
       else
@@ -853,19 +1057,21 @@ static void exportResourcesScale(GString *data, VisuData *dataObj _U_)
 
 
 /* fonction qui dessine la legende*/
-static void lineDraw(VisuData *dataObj _U_, int nlat, Scale *scale)
+static void lineDraw(int nlat, VisuGlExtScale *scale)
 {
   float x2,y2,z2, norm;
   float angles[3]; /*declaration des tableaux angles et coordonnées a 3 cellules*/
-  float coord[3];
-  float radius = 0.3;
+  float coord[3], u, v, s;
+  float radius = 0.3 * (0.25f * log(VISU_GLEXT_SCALE_GET_CLASS(scale)->width) + 1.f);
+  float tl = 1.f;
   GLUquadricObj *obj;
+  float modelView[16];
 
   obj = gluNewQuadric();
 
   norm = scale->length / sqrt(scale->direction[0] * scale->direction[0] +
-		       scale->direction[1] * scale->direction[1] +
-		       scale->direction[2] * scale->direction[2]);
+                              scale->direction[1] * scale->direction[1] +
+                              scale->direction[2] * scale->direction[2]) - tl;
   x2 = scale->origin[0] + scale->direction[0] * norm;
   y2 = scale->origin[1] + scale->direction[1] * norm;
   z2 = scale->origin[2] + scale->direction[2] * norm;
@@ -874,25 +1080,41 @@ static void lineDraw(VisuData *dataObj _U_, int nlat, Scale *scale)
   coord[1] = y2 - scale->origin[1];
   coord[2] = z2 - scale->origin[2];
 
-  matrix_cartesianToSpherical(angles, coord); /*appel de la fonction pour transformé les angles en coordonnée*/
+  tool_matrix_cartesianToSpherical(angles, coord);
 
-  glPushMatrix(); /*aide damien*/
-  glTranslated(scale->origin[0], scale->origin[1], scale->origin[2]); /*aide damien*/
+  glPushMatrix();
+  glTranslated(scale->origin[0], scale->origin[1], scale->origin[2]);
   glRotated(angles[2], 0., 0., 1.);
   glRotated(angles[1], 0., 1., 0.);
-  glTranslated(0., 0., scale->length); /*aide damien*/
-  gluCylinder(obj, radius, 0., 1.0, nlat, 1); /* 20 NOMBRE DE FACETTES */
+  glTranslated(0., 0., angles[0]);
+  gluCylinder(obj, radius, 0., tl, nlat, 1);
   glRotated(180., 1., 0., 0.);
   gluDisk(obj, 0, radius, nlat, 1);
-  glPopMatrix();/*aide damien*/
+  glPopMatrix();
 
-  glBegin (GL_LINES); /*premier ligne */
+  glBegin (GL_LINES);
   glVertex3fv(scale->origin);
   glVertex3f(x2, y2, z2);
   glEnd();
 
-  glRasterPos3fv(scale->origin);
-  openGLText_drawChars(scale->legend->str, TEXT_NORMAL); /*affichage de la
-					      legende*/
+  glGetFloatv(GL_MODELVIEW_MATRIX, modelView);
+  v = -(coord[0] * modelView[0] + coord[1] * modelView[4] + coord[2] * modelView[8]);
+  u = +(coord[0] * modelView[1] + coord[1] * modelView[5] + coord[2] * modelView[9]);
+  s = (v < 0.f)?0.25f:0.75f;
+  if (v > 0.f)
+    {
+      u *= -1.f;
+      v *= -1.f;
+    }
+  coord[0] = scale->origin[0] + s * scale->direction[0] * norm;
+  coord[1] = scale->origin[1] + s * scale->direction[1] * norm;
+  coord[2] = scale->origin[2] + s * scale->direction[2] * norm;
+  norm = 1.f / sqrt(u * u + v * v) * radius * 2.f;
+  coord[0] += (u * modelView[0] + v * modelView[1]) * norm;
+  coord[1] += (u * modelView[4] + v * modelView[5]) * norm;
+  coord[2] += (u * modelView[8] + v * modelView[9]) * norm;
+  glRasterPos3fv(coord);
+  openGLText_drawChars(scale->legend->str, TEXT_NORMAL);
+
   gluDeleteQuadric(obj);
 }
