@@ -47,7 +47,6 @@
 #include <visu_object.h>
 #include <visu_tools.h>
 #include <openGLFunctions/objectList.h>
-#include <renderingBackend/visu_windowInterface.h>
 #include <coreTools/toolColor.h>
 #include <coreTools/toolShade.h>
 
@@ -76,9 +75,6 @@
  * <para>Using dataFileApply_hideOnMinValue(), it is possible to hide
  * some nodes depending on given input data. If the @column argument
  * is -1, it unmask all nodes.</para>
- * <para>Using this module stores several #Shade that can be used by
- * other modules after being initialized using
- * dataFileBuild_presetShadeList().</para>
  */
 
 struct DataFile_struct
@@ -120,7 +116,7 @@ VisuData *cacheVisuData;
 #define DATAFILE_COLUMN_X  -3
 #define DATAFILE_COLUMN_Y  -2
 #define DATAFILE_COLUMN_Z  -1
-#define DATAFILE_SCALE_TYPE_DEFAULT dataFile_normalize
+#define DATAFILE_VISU_GLEXT_SCALE_TYPE_DEFAULT dataFile_normalize
 #define DATAFILE_MIN_NORM_DEFAULT   -1.
 #define DATAFILE_MAX_NORM_DEFAULT   +1.
 #define DATAFILE_COLOR_TYPE_DEFAULT dataFile_hsv
@@ -128,8 +124,9 @@ VisuData *cacheVisuData;
 #define DATAFILE_ID "dataColor_data"
 
 /* Internal variables. */
-static DataNode *dataNode;
+static VisuDataNode *dataNode;
 static GValue dataValue = {0, {{0}, {0}}};
+static GQuark quark;
 
 /* local methods. */
 static void dataFileFree(gpointer data);
@@ -148,20 +145,34 @@ int initDataFileModule()
 {
   cacheDataFile = (DataFile*)0;
   cacheVisuData = (VisuData*)0;
+  quark         =  g_quark_from_static_string("data_file");
 
   /* Register a new NodeData. */
-  dataNode = nodeDataNew(DATAFILE_ID, G_TYPE_FLOAT);
-  nodeDataSet_label(dataNode, _("Colorisation data"));
+  dataNode = VISU_DATA_NODE(visu_data_node_new(DATAFILE_ID, G_TYPE_FLOAT));
+  visu_data_node_setLabel(dataNode, _("Colorisation data"));
 
   g_value_init(&dataValue, G_TYPE_POINTER);
 
   return 1;
 }
 
+/**
+ * dataFileGet_quark:
+ *
+ * Internal routine for error handling.
+ *
+ * Returns: the #GQuark associated to errors related to colour data
+ * files.
+ */
+GQuark dataFileGet_quark()
+{
+  return quark;
+}
+
 void dataFileReDraw(VisuData *data)
 {
-  visuData_createAllNodes(data);
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  visu_data_createAllNodes(data);
+  VISU_ADD_REDRAW;
 }
 
 
@@ -181,7 +192,7 @@ static DataFile* dataFileNew(VisuData *visuData)
   dataFile->file            = (gchar*)0;
   dataFile->readMinMax      = (float*)0;
   dataFile->nbColumns       = 0;
-  dataFile->scaleType       = DATAFILE_SCALE_TYPE_DEFAULT;
+  dataFile->scaleType       = DATAFILE_VISU_GLEXT_SCALE_TYPE_DEFAULT;
   dataFile->minMaxValues[0] = DATAFILE_MIN_NORM_DEFAULT;
   dataFile->minMaxValues[1] = DATAFILE_MAX_NORM_DEFAULT;
   dataFile->shade           = (lst)?shadeCopy((Shade*)lst->data):(Shade*)0;
@@ -230,15 +241,15 @@ void dataFileActivate(VisuData *visuData, gboolean status)
 
   if (status)
     {
-      visuElementSet_updateNodesOnMaterialChange();
-      visuDataSet_ColorFunc(visuData, colorFromUserData);
-      visuDataSet_nodeScalingFunc(visuData, radiusFromUserData);
+      visu_element_setUpdateNodesOnMaterialChange();
+      visu_data_setColorFunc(visuData, colorFromUserData);
+      visu_data_setNodeScalingFunc(visuData, radiusFromUserData);
     }
   else
     {
-      visuElementUnset_updateNodesOnMaterialChange();
-      visuDataSet_ColorFunc(visuData, (setColorFunc)0);
-      visuDataSet_nodeScalingFunc(visuData, (VisuDataScalingFunc)0);
+      visu_element_unsetUpdateNodesOnMaterialChange();
+      visu_data_setColorFunc(visuData, (VisuDataColorFunc)0);
+      visu_data_setNodeScalingFunc(visuData, (VisuDataScalingFunc)0);
     }
 }
 
@@ -270,17 +281,17 @@ static gpointer newOrCopyData(gconstpointer orig, gpointer user_data)
   return (gpointer)data;
 }
 
-int dataFileSet_file(VisuData *attachedVisuData, char* filename,
-		     gboolean *new, GString *message, int *errors)
+gboolean dataFileSet_file(VisuData *dataObj, const char* filename, gboolean *new,
+			  GError **error)
 {
-  int i, err, nb, colUsed[3];
-  FILE *file;
-  char line[MAX_LINE_LENGTH];
-  char *msg;
+  int i, nb, colUsed[3];
+  GIOChannel *readFrom;
+  GIOStatus status;
+  GString *line;
+  gsize term;
   int nAtome;
   float *data;
   gchar **dataRead;
-  gchar *fileUTF8;
   DataFile *dataFile;
   VisuDataIter iter;
   gboolean voidLine;
@@ -291,24 +302,23 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
   gulong fractionTimer;
 #endif
 
-  DBG_fprintf(stderr, "Visu dataFile: set data file to '%s'.\n", filename);
-  g_return_val_if_fail(attachedVisuData && filename && message && new, 0);
+  DBG_fprintf(stderr, "Visu dataFile: set data file to '%s' for %p.\n",
+	      filename, (gpointer)dataObj);
+  g_return_val_if_fail(dataObj && filename, FALSE);
+  g_return_val_if_fail(error && (*error) == (GError*)0 && new, FALSE);
+
   *new = TRUE;
 
   /* Test if this VisuData has already been colorized by testing
      the existence of the 'dataColor_used' property. If not, all required
      memory is allocated. */
-  dataFile = g_object_get_data(G_OBJECT(attachedVisuData), "dataColor_parameters");
+  dataFile = g_object_get_data(G_OBJECT(dataObj), "dataColor_parameters");
   if (!dataFile)
-    dataFile = dataFileNew(attachedVisuData);
+    dataFile = dataFileNew(dataObj);
   else
     *new = FALSE;
   g_return_val_if_fail(dataFile, 0);
 
-  if (!errors)
-    errors = &err;
-  *errors = 0;
-
   /* erase previously stored dataFile informations. */
   dataFile->nbColumns = 0;
   for (i = 0; i < 3; i++)
@@ -329,61 +339,58 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
 
   /* We clear previously stored user data from the current
      visuData structure. */
-  nodeArray = visuDataGet_nodeArray(attachedVisuData);
-  visuNodeFree_property(nodeArray, DATAFILE_ID);
+  nodeArray = visu_data_getNodeArray(dataObj);
+  visu_node_array_freeProperty(nodeArray, DATAFILE_ID);
   prop = (VisuNodeProperty*)0;
-  nodeDataSet_used(dataNode, attachedVisuData, 0);
+  visu_data_node_setUsed(dataNode, dataObj, 0);
 
-  file = fopen(filename, "r");
-  if (!file)
-    {
-      fileUTF8 = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
-      if (fileUTF8)
-	{
-	  g_string_append_printf(message, _("Can't find the '%s' data file.\n"),
-				 fileUTF8);
-	  g_free(fileUTF8);
-	}
-      else
-	g_warning("Can't convert '%s' to UTF8.\n", filename);
-      *errors = 1;
-      return 0;
-    }
-  nAtome = 0;
+  readFrom = g_io_channel_new_file(filename, "r", error);
+  if (!readFrom)
+    return FALSE;
 
+  DBG_fprintf(stderr, "Visu DataFile: begin reading file.\n");
 #if DEBUG == 1
   timer = g_timer_new();
   g_timer_start(timer);
 #endif
-  visuDataIter_new(attachedVisuData, &iter);
-  for (visuDataIter_start(attachedVisuData, &iter); iter.node;
-       visuDataIter_nextNodeNumber(attachedVisuData, &iter))
+
+  line = g_string_new("");
+  nAtome = 0;
+  visu_data_iterNew(dataObj, &iter);
+  for (visu_data_iterStart(dataObj, &iter); iter.node;
+       visu_data_iterNextNodeNumber(dataObj, &iter))
     {
       /* If the file is not finished, we read until a non-void line
 	 and return this line. */
       voidLine = TRUE;
-      if (!feof(file))
+      do
 	{
-	    do
+	  status = g_io_channel_read_line_string(readFrom, line, &term, error);
+	  if (status == G_IO_STATUS_NORMAL)
 	    {
-	      msg = fgets(line, MAX_LINE_LENGTH, file);
-	      if (!msg)
-		continue;
-	      g_strchug(line);
-	      voidLine = (line[0] == '#' || line[0] == '!' || line[0] == '\0');
+	      g_strchug(line->str);
+	      voidLine = (line->str[0] == '#' ||
+			  line->str[0] == '!' ||
+			  line->str[0] == '\0');
 	    }
-	    while (!feof(file) && voidLine);
 	}
-      else
-	line[0] = '\0';
-      voidLine = (line[0] == '#' || line[0] == '!' || line[0] == '\0');
+      while (status == G_IO_STATUS_NORMAL && voidLine);
+      if (status == G_IO_STATUS_ERROR)
+	{
+	  g_string_free(line, TRUE);
+	  dataFileActivate(dataObj, FALSE);
+	  dataFile->used = FALSE;
+	  status = g_io_channel_shutdown(readFrom, FALSE, (GError**)0);
+	  g_io_channel_unref(readFrom);
+	  return FALSE;
+	}
 
       /* If still not done, we test the number of columns. */
       if (dataFile->nbColumns == 0)
 	{
 	  if (!voidLine)
 	    {
-	      dataRead = g_strsplit_set(line, " \t;:\n", MAX_LINE_LENGTH);
+	      dataRead = g_strsplit_set(line->str, " \t;:\n", MAX_LINE_LENGTH);
 	      DBG_fprintf(stderr, "Visu dataFile: looking for number of columns.\n");
 	      dataFile->nbColumns = 0;
 	      for (i = 0; dataRead[i]; i++)
@@ -393,32 +400,35 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
 		    dataFile->nbColumns += 1;
 		  }
 	      g_strfreev(dataRead);
-	      DBG_fprintf(stderr, "Visu dataFile : detected number of columns : %d\n",
+	      DBG_fprintf(stderr, "Visu dataFile: detected number of columns : %d\n",
 			  dataFile->nbColumns);
 	    }
 	  if (dataFile->nbColumns == 0 || voidLine)
 	    {
-	      g_string_append_printf(message, _("Can't find any column of"
-						" data in the given file.\n"));
-	      *errors = 1;
-	      dataFileActivate(attachedVisuData, FALSE);
+	      *error = g_error_new(VISU_ERROR_DATA_FILE, DATA_FILE_ERROR_NO_COLUMN,
+				   _("Can't find any column of"
+				     " data in the given file.\n"));
+	      g_string_free(line, TRUE);
+	      dataFileActivate(dataObj, FALSE);
 	      dataFile->used = FALSE;
-	      return 0;
+	      status = g_io_channel_shutdown(readFrom, FALSE, (GError**)0);
+	      g_io_channel_unref(readFrom);
+	      return FALSE;
 	    }
 	  dataFile->readMinMax = g_malloc(sizeof(float) * 2 * (dataFile->nbColumns));
 	  /* Add a node property with the number of columns. */
-	  prop = visuNodeNew_pointerProperty(nodeArray, DATAFILE_ID,
+	  prop = visu_node_property_newPointer(nodeArray, DATAFILE_ID,
 					     freeData, newOrCopyData,
 					     GINT_TO_POINTER(dataFile->nbColumns));
 	  /* Set the dimensions for the node property. */
-	  nodeDataSet_used(dataNode, attachedVisuData, dataFile->nbColumns);
+	  visu_data_node_setUsed(dataNode, dataObj, dataFile->nbColumns);
 	}
 
       /* We read the data from the line, if not void. */
       data = newOrCopyData((gconstpointer)0, GINT_TO_POINTER(dataFile->nbColumns));
       if (!voidLine)
 	{
-	  dataRead = g_strsplit_set(line, " \t;:\n", MAX_LINE_LENGTH);
+	  dataRead = g_strsplit_set(line->str, " \t;:\n", MAX_LINE_LENGTH);
 	  nb = 0;
 	  for (i = 0; dataRead[i] && nb < dataFile->nbColumns; i++)
 	    {
@@ -434,16 +444,13 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
 	}
       else
 	{
-	  if (*errors == 0)
-	    {
-	      g_string_append_printf(message,
-				     _("There are more nodes than data.\n"));
-	      *errors = 1;
-	    }
+	  if (!*error)
+	    *error = g_error_new(VISU_ERROR_DATA_FILE, DATA_FILE_ERROR_MISSING_DATA,
+				 _("There are more nodes than data.\n"));
 	}
       /* Associates the values to the node. */
       g_value_set_pointer(&dataValue, data);
-      visuNodePropertySet_value(prop, iter.node, &dataValue);
+      visu_node_property_setValue(prop, iter.node, &dataValue);
       /* Check for minMax values for each column. */
       for (i = 0; i < dataFile->nbColumns; i++)
 	{
@@ -462,17 +469,20 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
 	}
       nAtome++;
     }
-  fclose(file);
+  status = g_io_channel_shutdown(readFrom, FALSE, (GError**)0);
+  g_io_channel_unref(readFrom);
+  g_string_free(line, TRUE);
+
   dataFile->file = g_strdup(filename);
 
   if (dataFile->nbColumns == 0)
     {
-      g_string_append_printf(message,
-			     _("Can't find any columns with numbers.\n"
-			       "Valid format are as much numbers as desired, separated"
-			       " by any of the following characters : [ ;:\\t].\n"));
+      *error = g_error_new(VISU_ERROR_DATA_FILE, DATA_FILE_ERROR_NO_COLUMN,
+			   _("Can't find any columns with numbers.\n"
+			     "Valid format are as much numbers as desired, separated"
+			     " by any of the following characters : [ ;:\\t].\n"));
       dataFile->used = FALSE;
-      return 0;
+      return FALSE;
     }
 
   if (DEBUG)
@@ -485,9 +495,9 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
   for (i = 0; i < 3; i++)
     dataFile->colUsed[i] = (colUsed[i] >= dataFile->nbColumns)?-1:colUsed[i];
 
-  dataFileActivate(attachedVisuData, dataFile->used);
+  dataFileActivate(dataObj, dataFile->used);
   cacheDataFile = dataFile;
-  cacheVisuData = attachedVisuData;
+  cacheVisuData = dataObj;
 
 #if DEBUG == 1
   g_timer_stop(timer);
@@ -495,7 +505,7 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
   g_timer_destroy(timer);
 #endif
 
-  return 1;
+  return TRUE;
 }
 
 static DataFile* _get_dataColor(VisuData *data, gboolean create, gboolean *new)
@@ -526,6 +536,28 @@ static DataFile* _get_dataColor(VisuData *data, gboolean create, gboolean *new)
   return dataFile;
 }
 
+/**
+ * dataFileGet_fileSet:
+ * @visuData: a #VisuData object.
+ *
+ * A set of data per node can be associated to a #VisuData. This
+ * routine retrieves if @visuData has it or not.
+ *
+ * Since: 3.6
+ *
+ * Returns: TRUE if @visuData has colour data associated.
+ */
+gboolean dataFileGet_fileSet(VisuData *visuData)
+{
+  DataFile *dataFile;
+
+  dataFile = _get_dataColor(visuData, FALSE, (gboolean*)0);
+
+  if (dataFile && dataFile->file)
+    return TRUE;
+  else
+    return FALSE;
+}
 gchar* dataFileGet_file(VisuData *visuData)
 {
   DataFile *dataFile;
@@ -533,7 +565,7 @@ gchar* dataFileGet_file(VisuData *visuData)
   dataFile = _get_dataColor(visuData, FALSE, (gboolean*)0);
 
   if (dataFile)
-    return dataFile->file;
+    return g_strdup(dataFile->file);
   else
     return (gchar*)0;
 }
@@ -604,7 +636,7 @@ DataFileInputScaleId dataFileGet_scaleType(VisuData *visuData)
   dataFile = _get_dataColor(visuData, FALSE, (gboolean*)0);  
 
   if (!dataFile)
-    return DATAFILE_SCALE_TYPE_DEFAULT;
+    return DATAFILE_VISU_GLEXT_SCALE_TYPE_DEFAULT;
   else
     return dataFile->scaleType;
 }
@@ -785,18 +817,18 @@ gboolean dataFileApply_hideOnMinValue(VisuData *visuData, int column, float valu
   g_return_val_if_fail(column > DATAFILE_NB_COLUMN_DEFAULT && column < dataFile->nbColumns, FALSE);
   
   g_value_init(&data, G_TYPE_POINTER);
-  prop = visuNodeGet_property(visuDataGet_nodeArray(visuData), DATAFILE_ID);
+  prop = visu_node_array_getProperty(visu_data_getNodeArray(visuData), DATAFILE_ID);
 
   redraw = FALSE;
-  visuDataIter_new(visuData, &iter);
-  for (visuDataIter_startVisible(visuData, &iter); iter.node;
-       visuDataIter_nextVisible(visuData, &iter))
+  visu_data_iterNew(visuData, &iter);
+  for (visu_data_iterStartVisible(visuData, &iter); iter.node;
+       visu_data_iterNextVisible(visuData, &iter))
     {
-      visuNodePropertyGet_value(prop, iter.node, &data);
+      visu_node_property_getValue(prop, iter.node, &data);
       storedValues = (float*)g_value_get_pointer(&data);
       g_return_val_if_fail(storedValues, FALSE);
       if (storedValues[column] < value) /* && -storedValues[column] < value) */
-	redraw = visuNodeSet_visibility(iter.node, FALSE) || redraw;
+	redraw = visu_node_setVisibility(iter.node, FALSE) || redraw;
     }
 
   return TRUE;
@@ -837,7 +869,7 @@ static float dataFileGet_valuesFromData(VisuData *visuData _U_,
 }
 
 /*******************/
-/* Color functions */
+/* ToolColor functions */
 /*******************/
 static void colorFromUserData(VisuData *visuData, float rgba[4],
 			      VisuElement *ele, VisuNode* node)
@@ -865,15 +897,15 @@ static void colorFromUserData(VisuData *visuData, float rgba[4],
   storedValues = (float*)0;
   if (useData)
     {
-      visuNodeGet_propertyValue(visuDataGet_nodeArray(visuData), node,
+      visu_node_array_getPropertyValue(visu_data_getNodeArray(visuData), node,
 				DATAFILE_ID, &dataValue);
       storedValues = (float*)g_value_get_pointer(&dataValue);
       g_return_if_fail(storedValues);
     }
   if (useCoord)
     {
-      visuDataGet_nodePosition(visuData, node, coord);
-      visuDataConvert_XYZtoBoxCoordinates(visuData, red, coord);
+      visu_data_getNodePosition(visuData, node, coord);
+      visu_data_convertXYZtoBoxCoordinates(visuData, red, coord);
       if (cacheDataFile->scaleType == dataFile_minMax)
 	{
 	  delta = cacheDataFile->minMaxValues[1] - cacheDataFile->minMaxValues[0];
@@ -908,7 +940,7 @@ static float radiusFromUserData(VisuData *visuData, VisuNode *node)
     return 1.f;
 
   storedValues = (float*)0;
-  visuNodeGet_propertyValue(visuDataGet_nodeArray(visuData), node,
+  visu_node_array_getPropertyValue(visu_data_getNodeArray(visuData), node,
 			    DATAFILE_ID, &dataValue);
   storedValues = (float*)g_value_get_pointer(&dataValue);
   return dataFileGet_valuesFromData(visuData, cacheDataFile->scaleUsed,
