@@ -62,6 +62,27 @@ typedef enum
     dataFile_minMax
   } DataFileInputScaleId;
 
+/**
+ * VISU_ERROR_DATA_FILE: (skip)
+ *
+ * Internal function for error handling.
+ */
+#define VISU_ERROR_DATA_FILE dataFileGet_quark()
+GQuark dataFileGet_quark();
+/**
+ * DataFileErrorFlag:
+ * @DATA_FILE_ERROR_NO_COLUMN: no column can be found in the file ;
+ * @DATA_FILE_ERROR_MISSING_DATA: some data are missing to match the
+ * number of nodes.
+ *
+ * Possible errors when reading a file with column data.
+ */
+typedef enum
+  {
+    DATA_FILE_ERROR_NO_COLUMN,
+    DATA_FILE_ERROR_MISSING_DATA
+  } DataFileErrorFlag;
+
 /**
  * initDataFileModule:
  *
@@ -75,7 +96,7 @@ int initDataFileModule();
  * dataFileReDraw:
  * @data: a #VisuData object that holds the data file informations.
  *
- * This methods is a short-cut to call visuData_createAllNodes() and then emit the
+ * This methods is a short-cut to call visu_data_createAllNodes() and then emit the
  * 'OpenGLAskForReDraw' signal.
  *
  * May become deprecated soon.
@@ -107,19 +128,19 @@ int dataFileGet_used(VisuData *data);
 
 /**
  * dataFileSet_file:
- * @attachedVisuData: a #VisuData object to attach the data file to ;
+ * @data: a #VisuData object to attach the data file to ;
  * @filename: the path to find the data file on the disk ;
  * @new: return TRUE if some data are associated for the first time to
  *       the given #VisuData ;
- * @message: an allocated #GString to store some IO messages ;
- * @errors: an allocated integer to store if some errors occured.
+ * @error: a location to a NULL #GError.
  *
  * Call this method to parse a data file and associate its values to the given #VisuData object.
  *
  * Returns: 0 if nothing is loaded, 1 some data have been loaded.
  */
-int dataFileSet_file(VisuData *attachedVisuData, char* filename, gboolean *new,
-		     GString *message, int *errors);
+gboolean dataFileSet_file(VisuData *data, const char* filename, gboolean *new,
+			  GError **error);
+gboolean dataFileGet_fileSet(VisuData *visuData);
 /**
  * dataFileGet_file:
  * @visuData: a #VisuData object.
@@ -154,7 +175,7 @@ gboolean dataFileGet_fileMinMaxFromColumn(VisuData *visuData, float minMax[2], i
  * See #DataFileInputScaleId for further informations. This method raises
  * a error if no input file has already been associated to the give @visuData.
  *
- * Returns: 1 if visuData_createAllNodes() should be called.
+ * Returns: 1 if visu_data_createAllNodes() should be called.
  */
 gboolean dataFileSet_scaleType(VisuData *visuData, DataFileInputScaleId scale);
 /**
@@ -178,7 +199,7 @@ DataFileInputScaleId dataFileGet_scaleType(VisuData *visuData);
  * to choose the minimum bound. This method raises
  * a error if no input file has already been associated to the give @visuData.
  *
- * Returns: 1 if visuData_createAllNodes() should be called.
+ * Returns: 1 if visu_data_createAllNodes() should be called.
  */
 gboolean dataFileSet_min(VisuData *visuData, float min);
 /**
@@ -191,7 +212,7 @@ gboolean dataFileSet_min(VisuData *visuData, float min);
  * to choose the maximum bound. This method raises
  * a error if no input file has already been associated to the give @visuData.
  *
- * Returns: 1 if visuData_createAllNodes() should be called.
+ * Returns: 1 if visu_data_createAllNodes() should be called.
  */
 gboolean dataFileSet_max(VisuData *visuData, float max);
 /**
@@ -223,7 +244,7 @@ float dataFileGet_max(VisuData *visuData);
  *
  * Choose if the loaded value should change the given channel of the colour.
  *
- * Returns: 1 if visuData_createAllNodes() should be called.
+ * Returns: 1 if visu_data_createAllNodes() should be called.
  */
 gboolean dataFileSet_colUsed(VisuData *visuData, int val, int pos);
 /**
@@ -256,7 +277,7 @@ int dataFileGet_nbColumns(VisuData *visuData);
  * Apply all caracteristic of the given shade to the colorization the
  * the given #VisuObject.
  *
- * Returns: TRUE if visuData_createAllNodes() should be called.
+ * Returns: TRUE if visu_data_createAllNodes() should be called.
  */
 gboolean dataFileSet_shade(VisuData *visuData, Shade *shade);
 /**
@@ -268,7 +289,26 @@ gboolean dataFileSet_shade(VisuData *visuData, Shade *shade);
  * Returns: the Shade used (own by V_Sim).
  */
 Shade* dataFileGet_shade(VisuData *visuData);
+/**
+ * dataFileSet_scalingUsed:
+ * @visuData: a #VisuData object hosting the data values ;
+ * @val: a column id.
+ *
+ * Give the column id to used to take the scaling values from. Set -1
+ * if no scaling used. The scaling is used to change the size of each
+ * node, using an homothetic factor.
+ *
+ * Returns: TRUE if the status changed.
+ */
 gboolean dataFileSet_scalingUsed(VisuData *visuData, int val);
+/**
+ * dataFileGet_scalingUsed:
+ * @visuData: a #VisuData object hosting the data values.
+ *
+ * Retrieve if a column is used as entry to scale the nodes.
+ *
+ * Returns: -1 if no scaling is used.
+ */
 int dataFileGet_scalingUsed(VisuData *visuData);
 
 /**
@@ -281,7 +321,7 @@ int dataFileGet_scalingUsed(VisuData *visuData);
  * lower than the given @value. If @column is -1, then all previous
  * masking are cancelled.
  *
- * Returns: TRUE if visuData_createAllNodes() should be called and
+ * Returns: TRUE if visu_data_createAllNodes() should be called and
  *          "NodeRenderedChanged" signal should be emitted (with a
  *          NULL #VisuElement parameter).
  */
