@@ -55,17 +55,23 @@
  * a way to go from data to strings and reverse, callbacks when the
  * properties is changed...</para>
  * <para>When creating a node property calling
- * visuDataAdd_nodeProperty(), a #DataNode can be created using
- * nodeDataNew(). A #DataNode may not be attached to a specific
+ * visu_node_property_newPointer() for instance, a #VisuDataNode can be created using
+ * visu_data_node_new(). A #VisuDataNode may not be attached to a specific
  * #VisuData and is a global property found on each #VisuData (or
- * potentialy found). The adventage of doing this is to keep track of
+ * potentialy found). The advantage of doing this is to keep track of
  * available properties for #VisuData objects. To get all public
  * properties, call nodeDataGet_list().</para>
  */
 
+struct _VisuDataNodeClass
+{
+  GObjectClass parent;
+};
+
+
 struct internalUsedVisuData_struct
 {
-  /* The #VisuData using this DataNode. */
+  /* The #VisuData using this VisuDataNode. */
   VisuData *dataObj;
   /* Its associated dimension. */
   gint dimension;
@@ -73,28 +79,29 @@ struct internalUsedVisuData_struct
   gulong freeingSignal;
 };
 
-struct DataNode_struct
+struct _VisuDataNode
 {
-  /* Internal object gestion. */
   GObject parent;
+
+  /* Internal object gestion. */
   gboolean dispose_has_run;
 
   /* The key used to store the node property. */
-  const gchar *id;
+  gchar *id;
 
   /* The type of stored data. */
   GType type;
 
   /* These are the routines called when a string is get from values or
      values set from a string. */
-  GetStringFromValueFunc getAsString;
-  GetValueFromStringFunc setAsString;
+  VisuDataNodeToStringFunc getAsString;
+  VisuDataNodeFromStringFunc setAsString;
 
   /* The label. */
   const gchar *label;
 
-  /* The dimension (must be set to use nodeDataSet_valueAsString()
-     or nodeDataGet_valueAsString()), can vary. */
+  /* The dimension (must be set to use visu_data_node_setValueAsString()
+     or visu_data_node_getValueAsString()), can vary. */
   GList *lstVisuData;
 
   /* If TRUE the data are editable and signal may be emitted. */
@@ -102,96 +109,88 @@ struct DataNode_struct
 
   /* To be removed. */
   /* Callbacks method and data associated. */
-  DataNodeCallbackMethod callback;
+  VisuDataNodeCallbackMethod callback;
   gpointer data;
 };
 
 
 enum
   {
-    DATA_NODE_USED_SIGNAL,
-    DATA_NODE_UNUSED_SIGNAL,
-    DATA_NODE_EDITED_SIGNAL,
-    DATA_NODE_VALUE_CHANGED_SIGNAL,
-    DATA_NODE_NB_SIGNAL
+    VISU_DATA_NODE_USED_SIGNAL,
+    VISU_DATA_NODE_UNUSED_SIGNAL,
+    VISU_DATA_NODE_EDITED_SIGNAL,
+    VISU_DATA_NODE_VALUE_CHANGED_SIGNAL,
+    VISU_DATA_NODE_NB_SIGNAL
   };
 
-struct DataNodeClass_struct
-{
-  GObjectClass parent;
-};
-
-
 /* Internal variables. */
 static GList *storedData = (GList*)0;
 static GObjectClass *parent_class = NULL;
-static guint dataNode_signals[DATA_NODE_NB_SIGNAL] = { 0 };
+static guint dataNode_signals[VISU_DATA_NODE_NB_SIGNAL] = { 0 };
 
 
 /* Object gestion methods. */
-static void data_node_class_init(DataNodeClass *klass);
-static void data_node_init      (DataNode *obj);
 static void data_node_dispose   (GObject* obj);
 static void data_node_finalize  (GObject* obj);
 
 /* Local routines. */
-static gchar* valueAsString(DataNode *data, VisuData *dataObj,
+static gchar* valueAsString(VisuDataNode *data, VisuData *dataObj,
 			    VisuNode *node);
-static gboolean valueFromString(DataNode *data, VisuData *dataObj,
+static gboolean valueFromString(VisuDataNode *data, VisuData *dataObj,
 				VisuNode *node, gchar *labelIn,
 				gchar **labelOut, gboolean *modify);
 
 /* Local callbacks. */
 static void onVisuDataFreed(VisuData *dataObj, gpointer data);
 
+G_DEFINE_TYPE(VisuDataNode, visu_data_node, G_TYPE_OBJECT)
 
-GType data_node_get_type(void)
-{
-  static GType data_node_type = 0;
-
-  if (!data_node_type)
-    {
-      static const GTypeInfo data_node_info =
-      {
-        sizeof (DataNodeClass),
-        NULL, /* base_init */
-        NULL, /* base_finalize */
-        (GClassInitFunc)data_node_class_init,
-        NULL, /* class_finalize */
-        NULL, /* class_data */
-        sizeof (DataNode),
-        0,
-        (GInstanceInitFunc)data_node_init,
-	NULL
-      };
-      data_node_type = g_type_register_static(G_TYPE_OBJECT, "DataNodeType",
-						 &data_node_info, 0);
-      DBG_fprintf(stderr, "Data Node : creating the type DataNode %d.\n",
-		  (int)data_node_type);
-    }
-
-  return data_node_type;
-}
-
-static void data_node_class_init(DataNodeClass *klass)
+static void visu_data_node_class_init(VisuDataNodeClass *klass)
 {
   GType paramObj[1] = {G_TYPE_OBJECT};
 
-  DBG_fprintf(stderr, "Data Node : creating the class of the object.\n");
+  DBG_fprintf(stderr, "Data Node: creating the class of the object.\n");
   parent_class = g_type_class_peek_parent(klass);
 
   DBG_fprintf(stderr, "                - adding new signals ;\n");
-  dataNode_signals[DATA_NODE_USED_SIGNAL] =
+  /**
+   * VisuDataNode::propertyUsed:
+   * @data: the #VisuDataNode emitting the signal.
+   * @dataObj: the #VisuData its working on.
+   *
+   * The given property @data gets used by @dataObj.
+   *
+   * Since: 3.3
+   */
+  dataNode_signals[VISU_DATA_NODE_USED_SIGNAL] =
     g_signal_newv("propertyUsed", G_TYPE_FROM_CLASS(klass),
 		  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 		  NULL, NULL, NULL, g_cclosure_marshal_VOID__OBJECT,
 		  G_TYPE_NONE, 1, paramObj);
-  dataNode_signals[DATA_NODE_UNUSED_SIGNAL] =
+  /**
+   * VisuDataNode::propertyUnused:
+   * @data: the #VisuDataNode emitting the signal.
+   * @dataObj: the #VisuData its working on.
+   *
+   * The given property @data gets unused by @dataObj.
+   *
+   * Since: 3.3
+   */
+  dataNode_signals[VISU_DATA_NODE_UNUSED_SIGNAL] =
     g_signal_newv("propertyUnused", G_TYPE_FROM_CLASS(klass),
 		  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 		  NULL, NULL, NULL, g_cclosure_marshal_VOID__OBJECT,
 		  G_TYPE_NONE, 1, paramObj);
-  dataNode_signals[DATA_NODE_VALUE_CHANGED_SIGNAL] =
+  /**
+   * VisuDataNode::valueChanged:
+   * @data: the #VisuDataNode emitting the signal.
+   * @dataObj: the #VisuData its working on.
+   *
+   * The given property @data used by @dataObj has its value changed.
+   *
+   * Since: 3.3
+   */
+  dataNode_signals[VISU_DATA_NODE_VALUE_CHANGED_SIGNAL] =
     g_signal_newv("valueChanged", G_TYPE_FROM_CLASS(klass),
 		  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 		  NULL, NULL, NULL, g_cclosure_marshal_VOID__OBJECT,
@@ -202,26 +201,36 @@ static void data_node_class_init(DataNodeClass *klass)
   G_OBJECT_CLASS(klass)->finalize = data_node_finalize;
 }
 
-static void data_node_init(DataNode *obj)
+static void visu_data_node_init(VisuDataNode *obj)
 {
+#if DEBUG == 1
+  GList *tmpLst;
+#endif
+
   obj->dispose_has_run = FALSE;
 
   obj->id = (gchar*)0;
 
   obj->type = (GType)0;
-  obj->setAsString = (GetValueFromStringFunc)0;
-  obj->getAsString = (GetStringFromValueFunc)0;
+  obj->setAsString = (VisuDataNodeFromStringFunc)0;
+  obj->getAsString = (VisuDataNodeToStringFunc)0;
 
   obj->label = (gchar*)0;
 
   obj->lstVisuData = (GList*)0;
 
   obj->editable = FALSE;
-  obj->callback = (DataNodeCallbackMethod)0;
+  obj->callback = (VisuDataNodeCallbackMethod)0;
   obj->data = (gpointer)0;
 
   /* Add object from allObjects list. */
   storedData = g_list_prepend(storedData, (gpointer)obj);
+  DBG_fprintf(stderr, "Visu DataNode: add %p to the list of dataNode %p.\n",
+              (gpointer)obj, (gpointer)storedData);
+#if DEBUG == 1
+  for (tmpLst = storedData; tmpLst; tmpLst = g_list_next(tmpLst))
+    g_return_if_fail(IS_VISU_DATA_NODE_TYPE(tmpLst->data));
+#endif
 }
 
 /* This method can be called several times.
@@ -229,12 +238,12 @@ static void data_node_init(DataNode *obj)
    GObjects. */
 static void data_node_dispose(GObject* obj)
 {
-  DBG_fprintf(stderr, "Data Node : dispose object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Data Node: dispose object %p.\n", (gpointer)obj);
 
-  if (DATA_NODE(obj)->dispose_has_run)
+  if (VISU_DATA_NODE(obj)->dispose_has_run)
     return;
 
-  DATA_NODE(obj)->dispose_has_run = TRUE;
+  VISU_DATA_NODE(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
   G_OBJECT_CLASS(parent_class)->dispose(obj);
 }
@@ -245,15 +254,12 @@ static void data_node_finalize(GObject* obj)
 
   g_return_if_fail(obj);
 
-  DBG_fprintf(stderr, "Data Node : finalize object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Data Node: finalize object %p.\n", (gpointer)obj);
 
-  lst = DATA_NODE(obj)->lstVisuData;
-  while (lst)
-    {
-      g_free(lst->data);
-      lst = g_list_next(lst);
-    }
-  g_list_free(DATA_NODE(obj)->lstVisuData);
+  g_free(VISU_DATA_NODE(obj)->id);
+  for (lst = VISU_DATA_NODE(obj)->lstVisuData; lst; lst = g_list_next(lst))
+    g_free(lst->data);
+  g_list_free(VISU_DATA_NODE(obj)->lstVisuData);
 
   /* Remove object from allObjects list. */
   storedData = g_list_remove(storedData, (gpointer)obj);
@@ -263,63 +269,88 @@ static void data_node_finalize(GObject* obj)
 }
 
 
-DataNode* nodeDataNew(const gchar *name, GType type)
+/**
+ * visu_data_node_new:
+ * @name: a string used to store the data as a node property ;
+ * @type: the type of data stored (array or not).
+ *
+ * This method creates a new #VisuDataNode and registers it. A #VisuDataNode is
+ * characterised by a string used as a key to store it as a node property
+ * (see visu_node_property_newPointer()). The stored data can be arrays or not.
+ * Notice that @name is copied.
+ *
+ * Returns: (transfer full): a newly created #VisuDataNode.
+ */
+GObject* visu_data_node_new(const gchar *name, GType type)
 {
-  DataNode *data;
+  VisuDataNode *data;
 
-  g_return_val_if_fail(name, (DataNode*)0);
+  g_return_val_if_fail(name, (GObject*)0);
   g_return_val_if_fail(type == G_TYPE_INT || type == G_TYPE_FLOAT ||
 		       type == G_TYPE_BOOLEAN || type == G_TYPE_STRING,
-		       (DataNode*)0);
+		       (GObject*)0);
 
   /* Create the object with defaulty values. */
-  data = DATA_NODE(g_object_new(DATA_NODE_TYPE, NULL));
-  g_return_val_if_fail(data, (DataNode*)0);
+  data = VISU_DATA_NODE(g_object_new(VISU_DATA_NODE_TYPE, NULL));
+  g_return_val_if_fail(data, (GObject*)0);
 
   /* Set specific values. */
-  data->id = name;
+  data->id   = g_strdup(name);
   data->type = type;
   data->setAsString = valueFromString;
   data->getAsString = valueAsString;
 
-  return data;
+  return G_OBJECT(data);
 }
-DataNode* nodeDataNew_withCallbacks(const gchar *name,
-				    GetValueFromStringFunc setAsString,
-				    GetStringFromValueFunc getAsString)
+/**
+ * visu_data_node_newWithCallbacks:
+ * @name: a string used to store the data as a node property ;
+ * @setAsString: (scope call): a custom routine to change node values from a string ;
+ * @getAsString: (scope call): a custom routine to create a string from node values.
+ *
+ * As visu_data_node_new(), but with custom @setAsString and @getAsString routines. This
+ * is used to allow to treat every node related values, not just node properties.
+ *
+ * Returns: (transfer full): a newly created #VisuDataNode.
+ */
+GObject* visu_data_node_newWithCallbacks(const gchar *name,
+                                         VisuDataNodeFromStringFunc setAsString,
+                                         VisuDataNodeToStringFunc getAsString)
 {
-  DataNode *data;
+  VisuDataNode *data;
 
-  g_return_val_if_fail(name, (DataNode*)0);
-  g_return_val_if_fail(setAsString && getAsString, (DataNode*)0);
+  g_return_val_if_fail(name, (GObject*)0);
+  g_return_val_if_fail(setAsString && getAsString, (GObject*)0);
 
   /* Create the object with defaulty values. */
-  data = DATA_NODE(g_object_new(DATA_NODE_TYPE, NULL));
-  g_return_val_if_fail(data, (DataNode*)0);
+  data = VISU_DATA_NODE(g_object_new(VISU_DATA_NODE_TYPE, NULL));
+  g_return_val_if_fail(data, (GObject*)0);
 
   /* Set specific values. */
-  data->id = name;
+  data->id   = g_strdup(name);
   data->type = (GType)0;
   data->setAsString = setAsString;
   data->getAsString = getAsString;
 
-  return data;
+  return G_OBJECT(data);
 }
 
-GList* nodeDataGet_list()
+GList* nodeDataGet_list(void)
 {
+  DBG_fprintf(stderr, "Visu DataNode: get list of DataNode properties (%p %d).\n",
+              (gpointer)storedData, g_list_length(storedData));
   return storedData;
 }
 
-void nodeDataSet_label(DataNode *data, const gchar *label)
+void visu_data_node_setLabel(VisuDataNode *data, const gchar *label)
 {
-  g_return_if_fail(IS_DATA_NODE_TYPE(data));
+  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data));
 
   data->label = label;
 }
-const gchar* nodeDataGet_label(DataNode *data)
+const gchar* visu_data_node_getLabel(VisuDataNode *data)
 {
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data), (const gchar*)0);
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data), (const gchar*)0);
 
   if (data->label)
     return data->label;
@@ -327,7 +358,7 @@ const gchar* nodeDataGet_label(DataNode *data)
     return data->id;
 }
 
-static struct internalUsedVisuData_struct *getInternalStorage(DataNode *data, VisuData *dataObj)
+static struct internalUsedVisuData_struct *getInternalStorage(VisuDataNode *data, VisuData *dataObj)
 {
   struct internalUsedVisuData_struct *storage;
   GList *tmpLst;
@@ -343,17 +374,18 @@ static struct internalUsedVisuData_struct *getInternalStorage(DataNode *data, Vi
   return storage;
 }
 
-void nodeDataSet_used(DataNode *data, VisuData *dataObj, gint nb)
+void visu_data_node_setUsed(VisuDataNode *data, VisuData *dataObj, gint nb)
 {
   struct internalUsedVisuData_struct *storage;
 
-  g_return_if_fail(IS_DATA_NODE_TYPE(data) && IS_VISU_DATA_TYPE(dataObj));
+  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data) && IS_VISU_DATA_TYPE(dataObj));
 
   storage = getInternalStorage(data, dataObj);
   if (nb > 0)
     {
       DBG_fprintf(stderr, "Data Node: associating %p to the node property '%s' (%d).\n",
-		  (gpointer)dataObj, data->id, g_list_length(data->lstVisuData));
+		  (gpointer)dataObj, data->id,
+                  g_list_length(data->lstVisuData));
 
       /* Add a new associated #VisuData or change an already
 	 associated one. */
@@ -365,11 +397,12 @@ void nodeDataSet_used(DataNode *data, VisuData *dataObj, gint nb)
 	  storage->freeingSignal =  g_signal_connect(G_OBJECT(dataObj), "objectFreed",
 						     G_CALLBACK(onVisuDataFreed),
 						     (gpointer)data);
-	  data->lstVisuData = g_list_prepend(data->lstVisuData, (gpointer)storage);
+	  data->lstVisuData = g_list_prepend(data->lstVisuData,
+                                                   (gpointer)storage);
 
 	  DBG_fprintf(stderr, "Data Node: %p emit the 'propertyUsed'.\n",
 		      (gpointer)data);
-	  g_signal_emit(data, dataNode_signals[DATA_NODE_USED_SIGNAL],
+	  g_signal_emit(data, dataNode_signals[VISU_DATA_NODE_USED_SIGNAL],
 			0 , dataObj, NULL);
 	}
       else
@@ -384,37 +417,38 @@ void nodeDataSet_used(DataNode *data, VisuData *dataObj, gint nb)
       data->lstVisuData = g_list_remove(data->lstVisuData, storage);
       g_free(storage);
 
-      DBG_fprintf(stderr, "Data Node : removing association with %p of the"
+      DBG_fprintf(stderr, "Data Node: removing association with %p of the"
 		  " node property '%s' (%d).\n",
-		  (gpointer)dataObj, data->id, g_list_length(data->lstVisuData));
+		  (gpointer)dataObj, data->id,
+                  g_list_length(data->lstVisuData));
 
-      DBG_fprintf(stderr, "Data Node : %p emit the 'propertyUnused'.\n", (gpointer)data);
-      g_signal_emit(data, dataNode_signals[DATA_NODE_UNUSED_SIGNAL],
+      DBG_fprintf(stderr, "Data Node: %p emit the 'propertyUnused'.\n", (gpointer)data);
+      g_signal_emit(data, dataNode_signals[VISU_DATA_NODE_UNUSED_SIGNAL],
 		    0 , dataObj, NULL);
     }
 }
-gboolean nodeDataGet_used(DataNode *data, VisuData *dataObj)
+gboolean visu_data_node_getUsed(VisuDataNode *data, VisuData *dataObj)
 {
   struct internalUsedVisuData_struct *storage;
 
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data) && IS_VISU_DATA_TYPE(dataObj), FALSE);
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) && IS_VISU_DATA_TYPE(dataObj), FALSE);
 
   storage = getInternalStorage(data, dataObj);
   return (storage != (struct internalUsedVisuData_struct *)0);
 }
-void nodeDataEmit_valueChanged(DataNode *data, VisuData *dataObj)
+void visu_data_node_emitValueChanged(VisuDataNode *data, VisuData *dataObj)
 {
   DBG_fprintf(stderr, "Data Node: %p emit the 'valueChanged'.\n", (gpointer)data);
-  g_signal_emit(data, dataNode_signals[DATA_NODE_VALUE_CHANGED_SIGNAL],
+  g_signal_emit(data, dataNode_signals[VISU_DATA_NODE_VALUE_CHANGED_SIGNAL],
 		0 , dataObj, NULL);
 }
 
-gboolean nodeDataSet_valueAsString(DataNode *data, VisuData *dataObj,
+gboolean visu_data_node_setValueAsString(VisuDataNode *data, VisuData *dataObj,
 				   VisuNode *node, gchar *labelIn, gchar **labelOut)
 {
   gboolean valid, modify;
 
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data) &&
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) &&
 		       IS_VISU_DATA_TYPE(dataObj) && node, FALSE);
   g_return_val_if_fail(labelIn && labelOut, FALSE);
   g_return_val_if_fail(data->setAsString, FALSE);
@@ -437,34 +471,43 @@ gboolean nodeDataSet_valueAsString(DataNode *data, VisuData *dataObj,
 
   return valid;
 }
-gchar* nodeDataGet_valueAsString(DataNode *data, VisuData *dataObj,
+gchar* visu_data_node_getValueAsString(VisuDataNode *data, VisuData *dataObj,
 				 VisuNode *node)
 {
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
   g_return_val_if_fail(data->getAsString, (gchar*)0);
   
   return data->getAsString(data, dataObj, node);
 }
 
-void nodeDataSet_callback(DataNode *data, DataNodeCallbackMethod callback,
-			  gpointer user_data)
+/**
+ * visu_data_node_setCallback:
+ * @data: a #VisuDataNode ;
+ * @callback: (scope call): a #VisuDataNodeCallbackMethod method ;
+ * @user_data: a pointer to a location used to store some user data.
+ *
+ * When visu_data_node_setValueAsString(), values may be modified. If true, the given
+ * callback method is called with @user_data as argument.
+ */
+void visu_data_node_setCallback(VisuDataNode *data, VisuDataNodeCallbackMethod callback,
+                                gpointer user_data)
 {
-  g_return_if_fail(IS_DATA_NODE_TYPE(data));
+  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data));
 
   data->editable = TRUE;
   data->callback = callback;
   data->data = user_data;
 }
 
-gboolean nodeDataGet_editable(DataNode *data)
+gboolean visu_data_node_getEditable(VisuDataNode *data)
 {
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data), FALSE);
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data), FALSE);
 
   return data->editable;
 }
-void nodeDataSet_editable(DataNode *data, gboolean status)
+void visu_data_node_setEditable(VisuDataNode *data, gboolean status)
 {
-  g_return_if_fail(IS_DATA_NODE_TYPE(data));
+  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data));
 
   data->editable = status;
 }
@@ -473,7 +516,7 @@ static void onVisuDataFreed(VisuData *dataObj, gpointer data)
 {
   /* The given visuData is to be freed, so we remove it from the list
      of associated VisuData. */
-  nodeDataSet_used(DATA_NODE(data), dataObj, 0);
+  visu_data_node_setUsed(VISU_DATA_NODE(data), dataObj, 0);
 }
 
 
@@ -483,7 +526,7 @@ static void onVisuDataFreed(VisuData *dataObj, gpointer data)
 
 /* Internal fallback routines for the set and get as string when the
    types are integer, float or boolean node properties. */
-static gchar* valueAsString(DataNode *data, VisuData *dataObj,
+static gchar* valueAsString(VisuDataNode *data, VisuData *dataObj,
 			    VisuNode *node)
 {
   GString *str;
@@ -493,7 +536,7 @@ static gchar* valueAsString(DataNode *data, VisuData *dataObj,
   struct internalUsedVisuData_struct *storage;
   GValue val = {0, {{0}, {0}}};
 
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
 
   /* Check if the given property has an association with the given VisuData. */
   DBG_fprintf(stderr, "Data Node: get label for node property '%s'.\n", data->id);
@@ -505,8 +548,8 @@ static gchar* valueAsString(DataNode *data, VisuData *dataObj,
     }
 
   g_value_init(&val, G_TYPE_POINTER);
-  visuNodeGet_propertyValue(visuDataGet_nodeArray(dataObj), node,
-			    (gchar*)data->id, &val);
+  visu_node_array_getPropertyValue(visu_data_getNodeArray(dataObj), node,
+                                   data->id, &val);
   dataValues = g_value_get_pointer(&val);
   if (!dataValues)
     {
@@ -542,7 +585,7 @@ static gchar* valueAsString(DataNode *data, VisuData *dataObj,
 	  g_string_append(str, (gchar*)dataValues);
 	  break;
 	default:
-	  g_warning("Unsupported type for DataNode");
+	  g_warning("Unsupported type for VisuDataNode");
 	}
       if (i < storage->dimension - 1)
 	g_string_append(str, " ; ");
@@ -556,7 +599,7 @@ static gchar* valueAsString(DataNode *data, VisuData *dataObj,
 
   return value;
 }
-static gboolean valueFromString(DataNode *data, VisuData *dataObj,
+static gboolean valueFromString(VisuDataNode *data, VisuData *dataObj,
 				VisuNode *node, gchar *labelIn,
 				gchar **labelOut, gboolean *modify)
 {
@@ -568,14 +611,14 @@ static gboolean valueFromString(DataNode *data, VisuData *dataObj,
   float valueFloat;
   GValue val = {0, {{0}, {0}}};
 
-  g_return_val_if_fail(IS_DATA_NODE_TYPE(data) &&
+  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) &&
 		       IS_VISU_DATA_TYPE(dataObj) && node, FALSE);
   g_return_val_if_fail(labelIn && labelOut && modify, FALSE);
 
   if (!data->editable)
     {
       *labelOut = g_strdup(_("No data"));
-      g_warning("Can't call 'nodeDataSet_valueAsString' since the property"
+      g_warning("Can't call 'visu_data_node_setValueAsString' since the property"
 		" '%s' is not editable.", data->id);
       return FALSE;
     }
@@ -585,20 +628,20 @@ static gboolean valueFromString(DataNode *data, VisuData *dataObj,
   if (!storage)
     {
       *labelOut = g_strdup(_("No data"));
-      g_warning("Can't call 'nodeDataSet_valueAsString' since the property"
+      g_warning("Can't call 'visu_data_node_setValueAsString' since the property"
 		" '%s' has not been associated with the given VisuData.", data->id);
       return FALSE;
     }
   
   /* Grep the property from the low level storage in the VisuData. */
   g_value_init(&val, G_TYPE_POINTER);
-  visuNodeGet_propertyValue(visuDataGet_nodeArray(dataObj), node,
-			    (gchar*)data->id, &val);
+  visu_node_array_getPropertyValue(visu_data_getNodeArray(dataObj), node,
+                                   data->id, &val);
   dataValues = g_value_get_pointer(&val);
   if (data->type != G_TYPE_STRING && !dataValues)
     {
       *labelOut = g_strdup(_("No data"));
-      g_warning("Can't call 'nodeDataSet_valueAsString' since %p has no"
+      g_warning("Can't call 'visu_data_node_setValueAsString' since %p has no"
 		" node property labelled '%s'", (gpointer)dataObj, data->id);
       return FALSE;
     }
@@ -666,11 +709,11 @@ static gboolean valueFromString(DataNode *data, VisuData *dataObj,
 	  str = g_strdup(datas[i]);
 	  g_strstrip(str);
 	  g_value_set_pointer(&val, (gpointer)str);
-	  visuNodeSet_propertyValue(visuDataGet_nodeArray(dataObj), node,
-				    (gchar*)data->id, &val);
+	  visu_node_setpropertyValue(visu_data_getNodeArray(dataObj), node,
+                                     data->id, &val);
 	  break;
 	default:
-	  g_warning("Unsupported type for DataNode");
+	  g_warning("Unsupported type for VisuDataNode");
 	  error = TRUE;
 	}
       if (error)
@@ -685,8 +728,8 @@ static gboolean valueFromString(DataNode *data, VisuData *dataObj,
   if (data->type == G_TYPE_STRING && i == 0)
     {
       g_value_set_pointer(&val, (gpointer)0);
-      visuNodeSet_propertyValue(visuDataGet_nodeArray(dataObj), node,
-				(gchar*)data->id, &val);
+      visu_node_setpropertyValue(visu_data_getNodeArray(dataObj), node,
+                                 data->id, &val);
       i = 1;
     }
   if (i != storage->dimension)
