@@ -56,65 +56,64 @@
 G_BEGIN_DECLS
 
 /**
- * DATA_NODE_TYPE:
+ * VISU_DATA_NODE_TYPE:
  *
- * return the type of #DataNode.
+ * return the type of #VisuDataNode.
  */
-#define DATA_NODE_TYPE	     (data_node_get_type ())
+#define VISU_DATA_NODE_TYPE	     (visu_data_node_get_type ())
 /**
- * DATA_NODE:
+ * VISU_DATA_NODE:
  * @obj: a #GObject to cast.
  *
- * Cast the given @obj into #DataNode type.
+ * Cast the given @obj into #VisuDataNode type.
  */
-#define DATA_NODE(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, DATA_NODE_TYPE, DataNode))
+#define VISU_DATA_NODE(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_DATA_NODE_TYPE, VisuDataNode))
 /**
- * DATA_NODE_CLASS:
- * @klass: a #GClassObject to cast.
+ * VISU_DATA_NODE_CLASS:
+ * @klass: a #GObjectClass to cast.
  *
- * Cast the given @klass into #DataNodeClass.
+ * Cast the given @klass into #VisuDataNodeClass.
  */
-#define DATA_NODE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, DATA_NODE_TYPE, DataNodeClass))
+#define VISU_DATA_NODE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_DATA_NODE_TYPE, VisuDataNodeClass))
 /**
- * IS_DATA_NODE_TYPE:
+ * IS_VISU_DATA_NODE_TYPE:
  * @obj: a #GObject to test.
  *
- * Test if the given @ogj is of the type of #DataNode object.
+ * Test if the given @ogj is of the type of #VisuDataNode object.
  */
-#define IS_DATA_NODE_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, DATA_NODE_TYPE))
+#define IS_VISU_DATA_NODE_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_DATA_NODE_TYPE))
 /**
- * IS_DATA_NODE_CLASS:
- * @klass: a #GClassObject to test.
+ * IS_VISU_DATA_NODE_CLASS:
+ * @klass: a #GObjectClass to test.
  *
- * Test if the given @klass is of the type of #DataNodeClass class.
+ * Test if the given @klass is of the type of #VisuDataNodeClass class.
  */
-#define IS_DATA_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, DATA_NODE_TYPE))
+#define IS_VISU_DATA_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_DATA_NODE_TYPE))
 /**
- * DATA_NODE_GET_CLASS:
+ * VISU_DATA_NODE_GET_CLASS:
  * @obj: a #GObject to get the class of.
  *
  * It returns the class of the given @obj.
  */
-#define DATA_NODE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, DATA_NODE_TYPE, DataNodeClass))
+#define VISU_DATA_NODE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_DATA_NODE_TYPE, VisuDataNodeClass))
 
 /**
- * DataNodeClass:
+ * VisuDataNodeClass:
  *
- * A short way to identify #DataNodeClass_struct structure.
+ * An opaque structure.
  */
-typedef struct DataNodeClass_struct DataNodeClass;
+typedef struct _VisuDataNodeClass VisuDataNodeClass;
 
 /**
- * DataNode:
+ * VisuDataNode:
  *
- * A short wy to address #DataNode_struct objects.
+ * An opaque structure.
  */
-typedef struct DataNode_struct DataNode;
-
+typedef struct _VisuDataNode VisuDataNode;
 
 /**
- * GetValueFromStringFunc:
- * @data: a #DataNode ;
+ * VisuDataNodeFromStringFunc:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object ;
  * @node: a #VisuNode ;
  * @labelIn: a formatted string ;
@@ -128,12 +127,12 @@ typedef struct DataNode_struct DataNode;
  *
  * Returns: TRUE if the string was correctly parsed (modified or not).
  */
-typedef gboolean (*GetValueFromStringFunc)(DataNode *data, VisuData *dataObj,
+typedef gboolean (*VisuDataNodeFromStringFunc)(VisuDataNode *data, VisuData *dataObj,
 					   VisuNode *node, gchar *labelIn,
 					   gchar **labelOut, gboolean *modify);
 /**
- * GetStringFromValueFunc:
- * @data: a #DataNode ;
+ * VisuDataNodeToStringFunc:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object ;
  * @node: a #VisuNode.
  *
@@ -141,12 +140,12 @@ typedef gboolean (*GetValueFromStringFunc)(DataNode *data, VisuData *dataObj,
  *
  * Returns: a newly created string (use g_free()).
  */
-typedef gchar* (*GetStringFromValueFunc)(DataNode *data, VisuData *dataObj,
+typedef gchar* (*VisuDataNodeToStringFunc)(VisuDataNode *data, VisuData *dataObj,
 					 VisuNode *node);
 
 /* Maybe removed if the stuff is converted to GObject. */
 /**
- * DataNodeCallbackMethod:
+ * VisuDataNodeCallbackMethod:
  * @dataObj: the #VisuData object on which the callback is done ;
  * @node: the #VisuNode on which the callback is done ;
  * @data: a user defined pointer.
@@ -156,83 +155,60 @@ typedef gchar* (*GetStringFromValueFunc)(DataNode *data, VisuData *dataObj,
  *
  * WARNING: it may be removed later.
  */
-typedef void (*DataNodeCallbackMethod)(VisuData *dataObj, VisuNode *node, gpointer data);
+typedef void (*VisuDataNodeCallbackMethod)(VisuData *dataObj, VisuNode *node, gpointer data);
 
 /**
- * data_node_get_type:
+ * visu_data_node_get_type:
  *
- * This method returns the type of #DataNode, use DATA_NODE_TYPE instead.
+ * This method returns the type of #VisuDataNode, use VISU_DATA_NODE_TYPE instead.
  *
- * Returns: the type of #DataNode.
+ * Returns: the type of #VisuDataNode.
  */
-GType data_node_get_type(void);
+GType visu_data_node_get_type(void);
 
 
 
-/**
- * nodeDataNew:
- * @name: a string used to store the data as a node property ;
- * @type: the type of data stored (array or not).
- *
- * This method creates a new #DataNode and registers it. A #DataNode is
- * characterised by a string used as a key to store it as a node property
- * (see visuDataAdd_nodeProperty()). The stored data can be arrays or not.
- * Notice that @name is not copied.
- *
- * Returns: a newly created #DataNode.
- */
-DataNode* nodeDataNew(const gchar *name, GType type);
-/**
- * nodeDataNew_withCallbacks:
- * @name: a string used to store the data as a node property ;
- * @setAsString: a custom routine to change node values from a string ;
- * @getAsString: a custom routine to create a string from node values.
- *
- * As nodeDataNew(), but with custom @setAsString and @getAsString routines. This
- * is used to allow to treat every node related values, not just node properties.
- *
- * Returns: a newly created #DataNode.
- */
-DataNode* nodeDataNew_withCallbacks(const gchar *name,
-				    GetValueFromStringFunc setAsString,
-				    GetStringFromValueFunc getAsString);
+GObject* visu_data_node_new(const gchar *name, GType type);
+GObject* visu_data_node_newWithCallbacks(const gchar *name,
+                                         VisuDataNodeFromStringFunc setAsString,
+                                         VisuDataNodeToStringFunc getAsString);
 
 /**
  * nodeDataGet_list:
  *
- * All registered #DataNode are stored in an intern list. This method is
+ * All registered #VisuDataNode are stored in an intern list. This method is
  * used to retrieve it.
  *
- * Returns: a #GList of all registereed #DataNode (this list is owned by V_Sim).
+ * Returns: a #GList of all registereed #VisuDataNode (this list is owned by V_Sim).
  */
-GList* nodeDataGet_list();
+GList* nodeDataGet_list(void);
 
 /**
- * nodeDataSet_label:
- * @data: a #DataNode ;
+ * visu_data_node_setLabel:
+ * @data: a #VisuDataNode ;
  * @label: an UTF8 string (may be translated).
  *
- * A #DataNode can have a label, if not its name is used.
+ * A #VisuDataNode can have a label, if not its name is used.
  * Notice that @label is not copied.
  */
-void nodeDataSet_label(DataNode *data, const gchar *label);
+void visu_data_node_setLabel(VisuDataNode *data, const gchar *label);
 /**
- * nodeDataGet_label:
- * @data: a #DataNode ;
+ * visu_data_node_getLabel:
+ * @data: a #VisuDataNode ;
  *
- * A #DataNode can have a label, if not its name is used.
+ * A #VisuDataNode can have a label, if not its name is used.
  *
  * Returns: the label of the node (in UTF8), this string is owned by V_Sim.
  */
-const gchar* nodeDataGet_label(DataNode *data);
+const gchar* visu_data_node_getLabel(VisuDataNode *data);
 
 /**
- * nodeDataSet_used:
- * @data: a #DataNode ;
+ * visu_data_node_setUsed:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object ;
  * @nb: a positive or null integer.
  *
- * A #DataNode stores data for each node of a given #VisuData. The number of data stored for
+ * A #VisuDataNode stores data for each node of a given #VisuData. The number of data stored for
  * each node is set with this method. When some part wants to set a new node property
  * and wants to make it public, this method can be called. It also can be called when
  * the node property is removed (using a null @nb argument).
@@ -240,10 +216,10 @@ const gchar* nodeDataGet_label(DataNode *data);
  * signal is emitted with @dataObj as argument, instead if the value is changed
  * for null, the "propertyUnused" signal is triggered also with @dataObj as argument.
  */
-void nodeDataSet_used(DataNode *data, VisuData *dataObj, gint nb);
+void visu_data_node_setUsed(VisuDataNode *data, VisuData *dataObj, gint nb);
 /**
- * nodeDataGet_used:
- * @data: a #DataNode ;
+ * visu_data_node_getUsed:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object.
  *
  * Access method to know if the given @dataObj has a public node property of the type
@@ -251,30 +227,30 @@ void nodeDataSet_used(DataNode *data, VisuData *dataObj, gint nb);
  *
  * Returns: TRUE if @dataObj has a node property of the given type.
  */
-gboolean nodeDataGet_used(DataNode *data, VisuData *dataObj);
+gboolean visu_data_node_getUsed(VisuDataNode *data, VisuData *dataObj);
 
 /**
- * nodeDataSet_valueAsString:
- * @data: a #DataNode ;
+ * visu_data_node_setValueAsString:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object ;
  * @node: a #VisuNode ;
  * @labelIn: a formatted string ;
  * @labelOut: a pointer to store a string.
  *
  * If the string is correctly formatted (that means it has the same format as
- * the string returned by nodeDataGet_valueAsString()) the stored values are modified.
+ * the string returned by visu_data_node_getValueAsString()) the stored values are modified.
  * The resulting string is created and put into @labelOut. If the input string @labelIn
  * is unparsable, @labelOut will contain current values. Notice that this method is
- * callable only if the @data is editable (see nodeDataGet_editable()).
+ * callable only if the @data is editable (see visu_data_node_getEditable()).
  *
  * Returns: TRUE if the string was correctly parsed.
  */
-gboolean nodeDataSet_valueAsString(DataNode *data, VisuData *dataObj,
+gboolean visu_data_node_setValueAsString(VisuDataNode *data, VisuData *dataObj,
 				   VisuNode *node, gchar *labelIn,
 				   gchar **labelOut);
 /**
- * nodeDataGet_valueAsString:
- * @data: a #DataNode ;
+ * visu_data_node_getValueAsString:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object ;
  * @node: a #VisuNode.
  *
@@ -282,47 +258,38 @@ gboolean nodeDataSet_valueAsString(DataNode *data, VisuData *dataObj,
  *
  * Returns: a newly created string.
  */
-gchar* nodeDataGet_valueAsString(DataNode *data, VisuData *dataObj, VisuNode *node);
+gchar* visu_data_node_getValueAsString(VisuDataNode *data, VisuData *dataObj, VisuNode *node);
 
+void visu_data_node_setCallback(VisuDataNode *data, VisuDataNodeCallbackMethod callback,
+                                gpointer user_data);
 /**
- * nodeDataSet_callback:
- * @data: a #DataNode ;
- * @callback: a #DataNodeCallbackMethod method ;
- * @user_data: a pointer to a location used to store some user data.
- *
- * When nodeDataSet_valueAsString(), values may be modified. If true, the given
- * callback method is called with @user_data as argument.
- */
-void nodeDataSet_callback(DataNode *data, DataNodeCallbackMethod callback,
-			  gpointer user_data);
-/**
- * nodeDataSet_editable:
- * @data: a #DataNode ;
+ * visu_data_node_setEditable:
+ * @data: a #VisuDataNode ;
  * @status: a boolean value.
  *
  * Set if the values are modifiable.
  */
-void nodeDataSet_editable(DataNode *data, gboolean status);
+void visu_data_node_setEditable(VisuDataNode *data, gboolean status);
 /**
- * nodeDataGet_editable:
- * @data: a #DataNode.
+ * visu_data_node_getEditable:
+ * @data: a #VisuDataNode.
  *
- * If some callback method has been given with nodeDataSet_callback(), then
+ * If some callback method has been given with visu_data_node_setCallback(), then
  * the values are considered editable.
  *
  * Returns: TRUE if values are editable.
  */
-gboolean nodeDataGet_editable(DataNode *data);
+gboolean visu_data_node_getEditable(VisuDataNode *data);
 /**
- * nodeDataEmit_valueChanged:
- * @data: a #DataNode ;
+ * visu_data_node_emitValueChanged:
+ * @data: a #VisuDataNode ;
  * @dataObj: a #VisuData object.
  *
  * Emit the 'valueChanged' signal. This method should be called after
  * all changes have been done to a node property set of nodes. Then routines
  * using this property can update itself.
  */
-void nodeDataEmit_valueChanged(DataNode *data, VisuData *dataObj);
+void visu_data_node_emitValueChanged(VisuDataNode *data, VisuData *dataObj);
 
 
 G_END_DECLS
