@@ -39,53 +39,37 @@
 	knowledge of the CeCILL license and that you accept its terms. You can
 	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
 */
-#include <stdio.h>
 #include <string.h>
-#include <stdlib.h>
-#include <unistd.h>
 
 #include <GL/gl.h>
 
 #include <visu_tools.h>
-#include "scalarFields.h"
-#include "surfaces_points.h"
 #include "isoline.h"
-#include "plane.h"
 
 /**
- * SECTION:isolines
+ * SECTION:isoline
  * @short_description: handle the drawing and the computation of
  * isolines.
  *
- * <para>Reading a #SurfacesPoints object, it is possible to compute
- * isolines and draw them. A isoline is known by a list a couple of
- * vertices to draw lines. Currently, there is no detection of
- * equivalent points like in #Surfaces, but it is not very relevant
- * since the lines are relatively small compared to surfaces.</para>
+ * <para>TODO</para>
  */
 
-struct _Line
+/**
+ * VisuLine:
+ *
+ * Structure representing a curved line in 3D, opaque structure.
+ */
+struct _VisuLine
 {
-  int num_sublines;
-
-  int num_vertices;
-
+  guint num_sublines, num_vertices;
   float **vertex_3dpos;
+
+  double value;
 };
 
 static gboolean Create_line(int *iTab, int ntriangles,
                             double *xline, double *yline, double *zline,
-                            Line **isoline);
-
-/* Tables derived from :
-   http://www.swin.edu.au/astronomy/pbourke/modelling/polygonise/index.html
-   (valid link on February 25, 2002)
-
-   YOU WILL FIND MANY VERY INTERESTING PAGES at Paul Bourke's site:
-   http://astronomy.swin.edu.au/pbourke/
-
-   Other routines by Luc Billard, on March 1, 2002
-*/
+                            VisuLine **isoline);
 
 static int edgeTable[8] =
 {
@@ -107,88 +91,78 @@ static int linTable[5][5] =
 /* DEVELOPMENT AREA
    Methods are copied to be callable without all static stuff everywhere. */
 
-void isolineFree(Line *line)
+/**
+ * visu_line_free:
+ * @line: a set of lines.
+ *
+ * Free the line object.
+ *
+ * Since: 3.4
+ */
+void visu_line_free(VisuLine *line)
 {
   g_return_if_fail(line);
 
+  DBG_fprintf(stderr, "Line: free line %p.\n", (gpointer)line);
   if(line->vertex_3dpos)
     {
       g_free(line->vertex_3dpos[0]);
       g_free(line->vertex_3dpos);
     }
+  DBG_fprintf(stderr, " | Ok.\n");
 }
 
-gboolean isolineBuild(Line **isoline, SurfacesPoints *points,
-		      guint valOffset, gint visibilityOffset, double isoValue)
+/**
+ * visu_line_newFromTriangles:
+ * @data: the lines to be computed ;
+ * @nTriangles: the surface to compute isoline from ;
+ * @isoValue: the value of the computed isoline.
+ *
+ * Create on the fly an isoline from a given set of triangles. If the
+ * lines are created, @isoline will be allocated and should be freed
+ * with visu_line_free() after use.
+ *
+ * Since: 3.6
+ *
+ * Returns: the newly allocated #VisuLine or NULL.
+ */
+VisuLine* visu_line_newFromTriangles(float **data, guint nTriangles, double isoValue)
 {
-
-/* Local variables */
-  Line *isoline_;
-  register int i, j;
-  int n, p, q;
-  int nPoints, nvertices, ntriangles, nedges;
+  /* Local variables */
+  VisuLine *isoline_;
+  guint j, n;
+  int p, q;
+  int nPoints, nedges;
   int *iTab;
-  int *vertices_number;   /* number of vertices in a polygon */
-  int *vertices_index;
-  int **vertices_index_from_triangles;
   /* give edge index in the full edge list with edge j of a given triangle i as input*/
   /* j in [0,1,2] and i in [0,ntriangles-1]*/
   float fac, isov;
   double val0, val1;
   double *xline, *yline, *zline;
   float *coord0, *coord1; /* local vertex coordinates */
-  float **vertices_coord; /* give vertex coordinates with vertex index and x,y,z direction as input*/
-                          /* vertex index in [0,nvertices-1] and x->0, y->1, z->2 */
 
   gboolean status;
-  #if DEBUG == 1
+#if DEBUG == 1
   GTimer *timer;
   gulong fractionTimer;
-  #endif
+#endif
 
-/* Routine code*/
+  /* Routine code*/
   isov = isoValue;
 
-/* Ensure that the pointer is not zero */
+  /* Ensure that the pointer is not zero */
 
-  g_return_val_if_fail(points, FALSE);
-  g_return_val_if_fail(isoline, FALSE);
+  g_return_val_if_fail(data, (VisuLine*)0);
 
-  #if DEBUG == 1
-    timer = g_timer_new();
-    g_timer_start(timer);
-  #endif
+  DBG_fprintf(stderr, "Line: compute isoline at value %g.\n", isoValue);
 
-/* Get data from the points structure */
+#if DEBUG == 1
+  timer = g_timer_new();
+  g_timer_start(timer);
+#endif
 
-  nvertices                      = points->num_points;
-  ntriangles                     = points->num_polys;
-  vertices_number                = points->poly_num_vertices;
-  vertices_index_from_triangles  = points->poly_vertices;
-  vertices_coord                 = points->poly_points_data;
-
-  /* Initialise values. */
-  isoline_ = g_malloc(sizeof(Line));
-  isoline_->num_sublines = 0;
-  isoline_->num_vertices = 0;
-  isoline_->vertex_3dpos = (float**)0;
-
-/* Debug part printing */
-
-  DBG_fprintf(stderr, "drawisoline : compute isoline at value %g.\n", isoValue);
-
-/* Check that surface polygons are indeed all triangles */
-
-  for(i=0; i<ntriangles; i++)
-    g_return_val_if_fail(vertices_number[i] == 3, FALSE);
-
-  #if DEBUG == 1
-    timer = g_timer_new();
-    g_timer_start(timer);
-  #endif
-
-/* Allocate memory*/
-  nedges = 3 * ntriangles;
+  /* Allocate memory*/
+  nedges = 3 * nTriangles;
   iTab   = g_malloc(nedges * sizeof(int));
   xline  = g_malloc(nedges * sizeof(double));
   yline  = g_malloc(nedges * sizeof(double));
@@ -197,20 +171,8 @@ gboolean isolineBuild(Line **isoline, SurfacesPoints *points,
   /* Glance trough the list of edges and search intersection
      between edges and ScalarField */
   nPoints = 0;
-  for(n=0; n<ntriangles; n++)
+  for(n = 0; n < nTriangles; n++)
     {
-      vertices_index = vertices_index_from_triangles[n];
-      if (visibilityOffset >= 0 &&
-	  (!(gboolean)vertices_coord[vertices_index[0]][visibilityOffset] ||
-	   !(gboolean)vertices_coord[vertices_index[1]][visibilityOffset] ||
-	   !(gboolean)vertices_coord[vertices_index[2]][visibilityOffset]))
-	{
-	  iTab[3 * n + 0] = -1;
-	  iTab[3 * n + 1] = -1;
-	  iTab[3 * n + 2] = -1;
-	  continue;
-	}
-
       /* Get the 3D coordinates and scalar field value of each vertex
 	 (0,1) of the current edge*/
       for(j=0; j<3; j++)
@@ -219,17 +181,16 @@ gboolean isolineBuild(Line **isoline, SurfacesPoints *points,
 	     edge of the current triangle*/
 	  p=j;
 	  q=(j == 2)?0:j+1;
-	  val0   = vertices_coord[vertices_index[p]][valOffset];
-	  val1   = vertices_coord[vertices_index[q]][valOffset];
+	  val0 = data[2 * n + 1][p];
+	  val1 = data[2 * n + 1][q];
 
 	  /* Test if edge contains isovalue */
-
-	  if((isov - val0 < 0.0 && isov - val1 >= 0.0) ||
-	     (isov - val0 >= 0.0 && isov - val1 < 0.0))
+	  if((isov - val0 <  0.0 && isov - val1 >= 0.0) ||
+	     (isov - val0 >= 0.0 && isov - val1 <  0.0))
 	    {
 	      fac = (isov - val0) / (val1 - val0);
-	      coord0 = vertices_coord[vertices_index[p]];
-	      coord1 = vertices_coord[vertices_index[q]];
+	      coord0 = data[2 * n + 0] + 3 * p;
+	      coord1 = data[2 * n + 0] + 3 * q;
 	      iTab[3 * n + j] = nPoints;
 	      xline[nPoints] = coord0[0] + fac * (coord1[0]-coord0[0]);
 	      yline[nPoints] = coord0[1] + fac * (coord1[1]-coord0[1]);
@@ -244,32 +205,37 @@ gboolean isolineBuild(Line **isoline, SurfacesPoints *points,
   yline = g_realloc(yline, nPoints * sizeof(double));
   zline = g_realloc(zline, nPoints * sizeof(double));
   DBG_fprintf(stderr, " | found %d points for line.\n", nPoints);
-   #if DEBUG == 1
-    g_timer_stop(timer);
-    fprintf(stderr, "Isoline : compute intersections in %g micro-s.\n",
-	    g_timer_elapsed(timer, &fractionTimer)/1e-6);
-    g_timer_destroy(timer);
-  #endif
+#if DEBUG == 1
+  g_timer_stop(timer);
+  fprintf(stderr, "Isoline : compute intersections in %g micro-s.\n",
+          g_timer_elapsed(timer, &fractionTimer)/1e-6);
+  g_timer_destroy(timer);
+#endif
 
-  #if DEBUG == 1
-    timer = g_timer_new();
-    g_timer_start(timer);
-  #endif
+#if DEBUG == 1
+  timer = g_timer_new();
+  g_timer_start(timer);
+#endif
   if(nPoints == 0)
     {
-      g_warning("no isoline found for value %g.", isoValue);
+      /* g_warning("no isoline found for value %g.", isoValue); */
       status = FALSE;
+      isoline_ = (VisuLine*)0;
     }
   else
-    /* Create lines from the computed points*/
-    status = Create_line(iTab, ntriangles,
-			 xline, yline, zline, &isoline_);
-  #if DEBUG == 1
-    g_timer_stop(timer);
-    fprintf(stderr, "Isoline : build lines in %g micro-s.\n",
-	    g_timer_elapsed(timer, &fractionTimer)/1e-6);
-    g_timer_destroy(timer);
-  #endif
+    {
+      /* Create lines from the computed points*/
+      isoline_ = g_malloc(sizeof(VisuLine));
+      isoline_->value = isoValue;
+      status = Create_line(iTab, nTriangles,
+                           xline, yline, zline, &isoline_);
+    }
+#if DEBUG == 1
+  g_timer_stop(timer);
+  fprintf(stderr, "Isoline : build lines in %g micro-s.\n",
+          g_timer_elapsed(timer, &fractionTimer)/1e-6);
+  g_timer_destroy(timer);
+#endif
 
   g_free(iTab);
   g_free(xline);
@@ -278,12 +244,11 @@ gboolean isolineBuild(Line **isoline, SurfacesPoints *points,
 
   DBG_fprintf(stderr, " | Line exit with status %d.\n", (int)status);
 
-  *isoline = isoline_;
-  return status;
+  return (status)?isoline_:(VisuLine*)0;
 }
 
-/**
- * Create_Line:
+/*
+ * Create_line:
  * @nPoints: an integer giving the number points of the line;
  * @iTab: table containing the number of line points if line exists at this place otherwise -1;
  * @nedges: an integer giving the number of edges;
@@ -299,19 +264,18 @@ gboolean isolineBuild(Line **isoline, SurfacesPoints *points,
  * Create on the fly a line from a list of points.
  * Returns: TRUE if the line is created.
  */
-
 static gboolean Create_line(int *iTab, int ntriangles,
                             double *xline, double *yline, double *zline,
-                            Line **isoline)
+                            VisuLine **isoline)
 {
 
 /* Local variables */
 
   register int i;
   int cubeindex;
-  int e, n;
+  int e;
+  guint n, nlines;
   int m0, m1;
-  int nlines;
   int *vTab;
 
 /* Routine code */
@@ -342,6 +306,7 @@ static gboolean Create_line(int *iTab, int ntriangles,
        {
          g_warning("m1 %d.", i);
 	 g_free(vTab);
+	 g_free(*isoline);
          return FALSE;
        }
        m1 = iTab[3 * i + linTable[e][n+1]];
@@ -400,14 +365,26 @@ static gboolean Create_line(int *iTab, int ntriangles,
   return TRUE;
 }
 
-void isolineDraw(Line *line, float rgb[3])
+/**
+ * visu_line_draw:
+ * @line: a set of points forming a line.
+ * @rgb: a colour.
+ *
+ * Call the OpenGL routine that will draw this line.
+ *
+ * Since: 3.4
+ */
+void visu_line_draw(VisuLine *line, float rgb[3])
 {
-  int i;
+  guint i;
 
   g_return_if_fail(line);
 
   glLineWidth(2.f);
+/*   glPointSize(2.f); */
   glColor3fv(rgb);
+  glDepthMask(0);
+
   glBegin(GL_LINES);
   for ( i = 0; i < line->num_sublines; i++)
     {
@@ -415,12 +392,38 @@ void isolineDraw(Line *line, float rgb[3])
       glVertex3fv(line->vertex_3dpos[2 * i + 1]);
     }
   glEnd();
+
+/*   glEnable(GL_POINT_SMOOTH); */
+/*   glBegin(GL_POINTS); */
+/*   for ( i = 0; i < line->num_sublines; i++) */
+/*     { */
+/*       glVertex3fv(line->vertex_3dpos[2 * i]); */
+/*       glVertex3fv(line->vertex_3dpos[2 * i + 1]); */
+/*     } */
+/*   glEnd(); */
+/*   glDisable(GL_POINT_SMOOTH); */
+
+  glDepthMask(1);
 }
 
-float* isolineProject(Line *line, Plane *plane, gint *nSeg)
+/**
+ * visu_line_project:
+ * @line: a #VisuLine object.
+ * @plane: a #Plane object.
+ * @nSeg: a location to store the size of projection.
+ *
+ * Calculate the projection of each @line vertex on @plane.
+ *
+ * Since: 3.6
+ * 
+ * Returns: a newly allocated array of line segments. The size of this
+ * array is 4 * @nSeg, holding the two plane coordiantes of the two
+ * vertices of a line.
+ */
+float* visu_line_project(VisuLine *line, Plane *plane, guint *nSeg)
 {
   float basis[2][3], center[3], *out;
-  int i;
+  guint i;
 
   g_return_val_if_fail(line && nSeg, (float*)0);
 
@@ -451,3 +454,20 @@ float* isolineProject(Line *line, Plane *plane, gint *nSeg)
 
   return out;
 }
+
+/**
+ * visu_line_getValue:
+ * @line: a #VisuLine object.
+ *
+ * Lines are usually created as iso-values line in a mesh.
+ *
+ * Since: 3.6
+ *
+ * Returns: the value associated to the line.
+ */
+double visu_line_getValue(VisuLine *line)
+{
+  g_return_val_if_fail(line, -1.);
+
+  return line->value;
+}
