@@ -167,23 +167,31 @@ static void propertiesRemoveSurf(gpointer key, gpointer value, gpointer data);
 static void propertiesReallocateSurf(gpointer key, gpointer value, gpointer data);
 
 
-void isosurfacesInit()
+void isosurfacesInit(void)
 {
   VisuConfigFileEntry *entry;
 
   quark = g_quark_from_static_string("visu_isosurfaces");
 
-  entry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  entry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 				  FLAG_RESOURCE_INTRA,
 				  DESC_RESOURCE_INTRA,
 				  1, isosurfaces_read_intra);
-  visuConfigFileSet_version(entry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(entry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   isosurfaces_export_resources);
   
-  isosurfacesResourcesInit();
+  initIsosurfacesResources();
 }
-GQuark isosurfacesGet_quark()
+/**
+ * isosurfacesGet_quark:
+ *
+ * Internal routine for error handling.
+ *
+ * Returns: the #GQuark associated to errors related to surface
+ * files.
+ */
+GQuark isosurfacesGet_quark(void)
 {
   return quark;
 }
@@ -220,7 +228,7 @@ gboolean isosurfacesRemove(Surfaces *surf, int idSurf)
   /* If the resource has no name, then we free it since it is not shared. */
   DBG_fprintf(stderr, " | Additional removing.\n");
   if (!surf->resources[pos]->surfnom)
-    isosurfacesFree_resource(surf->resources[pos]);
+    visu_surfaces_resources_free(surf->resources[pos]);
   for (i = pos; i < surf->nsurf; i++)
     {
       surf->ids[i] = surf->ids[i + 1];
@@ -229,7 +237,7 @@ gboolean isosurfacesRemove(Surfaces *surf, int idSurf)
     }
   surf->ids = g_realloc(surf->ids, sizeof(int) * surf->nsurf);
   surf->resources = g_realloc(surf->resources,
-			      sizeof(SurfaceResource*) * surf->nsurf);
+			      sizeof(VisuSurfacesResources*) * surf->nsurf);
   g_hash_table_foreach(surf->properties, propertiesRemoveSurf, GINT_TO_POINTER(pos));
   
 #if DEBUG == 1
@@ -251,7 +259,7 @@ Surfaces* isosurfacesNew(int bufferSize)
   isosurfacesPointsInit(&surf->volatilePlanes, bufferSize);
 
   surf->ids        = (int*)0;
-  surf->resources  = (SurfaceResource**)0;
+  surf->resources  = (VisuSurfacesResources**)0;
   surf->properties = g_hash_table_new_full(g_str_hash, g_str_equal,
 					   NULL, freeSurfacesProperties);
 
@@ -274,7 +282,7 @@ void isosurfacesFree(Surfaces *surf)
 	 the hashtable. */
       for (i = 0; i < surf->nsurf; i++)
 	if (surf->resources[i] && !surf->resources[i]->surfnom)
-	  isosurfacesFree_resource(surf->resources[i]);
+	  visu_surfaces_resources_free(surf->resources[i]);
       g_free(surf->resources);
     }
   if (surf->properties)
@@ -296,11 +304,11 @@ void isosurfacesAllocate(Surfaces *surf, int nsurf, int npolys, int npoints)
   DBG_fprintf(stderr, "Surfaces: allocate complement.\n");
   /* Allocating pointers. */
   surf->ids       = g_malloc(nsurf * sizeof(int));
-  surf->resources = g_malloc(nsurf * sizeof(SurfaceResource*));
+  surf->resources = g_malloc(nsurf * sizeof(VisuSurfacesResources*));
 
   /* Set initial values. */
   for(i = 0; i < surf->nsurf; i++)
-    surf->resources[i] = (SurfaceResource*)0;
+    surf->resources[i] = (VisuSurfacesResources*)0;
   DBG_fprintf(stderr, " | OK.\n");
 }
 void isosurfacesAddSurfaces(Surfaces *surf, int nsurf, int npolys, int npoints)
@@ -352,7 +360,7 @@ void isosurfacesAddSurfaces(Surfaces *surf, int nsurf, int npolys, int npoints)
   surf->ids                           = g_realloc(surf->ids,
 						  surf->nsurf * sizeof(int));
   surf->resources                     = g_realloc(surf->resources,
-						  surf->nsurf * sizeof(SurfaceResource*));
+						  surf->nsurf * sizeof(VisuSurfacesResources*));
 
   /* Dealing with properties reallocation. */
   g_hash_table_foreach(surf->properties, propertiesReallocateSurf,
@@ -655,7 +663,7 @@ gboolean isosurfacesLoad_file(const char *file, Surfaces **surf, GError **error)
       while (current_line->str[0] == '#');
       g_strdelimit(current_line->str, "\n", ' ');
       g_strstrip(current_line->str);
-      (*surf)->resources[i] = isosurfacesGet_resourceFromName(current_line->str, (gboolean*)0);
+      (*surf)->resources[i] = visu_surfaces_resources_getFromName(current_line->str, (gboolean*)0);
       DBG_fprintf(stderr, "Line %d ('%s' -> %p) read successfully %f\n",
 		  line_number, current_line->str, (gpointer)(*surf)->resources[i],
 		  densityData[i]);
@@ -948,7 +956,7 @@ gboolean isosurfacesHide(Surfaces *surf, Plane **planes)
 		(planes,
 		 ptFr->poly_points_data[ptFr->poly_vertices[boundaryPolys[i]][(k + 1)%n]],
 		 ptFr->poly_points_data[ptFr->poly_vertices[boundaryPolys[i]][k]],
-		 ptTo->poly_points_data[iVertice]);
+		 ptTo->poly_points_data[iVertice], TRUE);
 	      g_return_val_if_fail(valid, redraw);
 	      /* Other values than coordinates are copied. */
 	      memcpy(ptTo->poly_points_data[iVertice] + 3,
@@ -966,7 +974,7 @@ gboolean isosurfacesHide(Surfaces *surf, Plane **planes)
 	      valid = planesGet_intersection
 		(planes, ptFr->poly_points_data[ptFr->poly_vertices[boundaryPolys[i]][k]],
 		 ptFr->poly_points_data[ptFr->poly_vertices[boundaryPolys[i]][(k + 1)%n]],
-		 ptTo->poly_points_data[iVertice]);
+		 ptTo->poly_points_data[iVertice], TRUE);
 	      g_return_val_if_fail(valid, redraw);
 	      memcpy(ptTo->poly_points_data[iVertice] + 3,
 		     ptFr->poly_points_data[ptFr->poly_vertices[boundaryPolys[i]][k]] + 3,
@@ -1027,7 +1035,7 @@ static double z_eye(float mat[16], float points[3])
      mat[15]*1.);
 }
 
-SurfacesOrder* isosurfacesOrder_new()
+SurfacesOrder* isosurfacesOrder_new(void)
 {
   SurfacesOrder *order;
 
@@ -1138,7 +1146,7 @@ void isosurfacesDraw_surfaces(int OpenGLId, Surfaces *surf[], SurfacesOrder *ord
   int nb;
   SurfacesPoints *points;
   int itp_old = -1, idSurf_old = -1;
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
   float rgba[4];
    
   g_return_if_fail(surf && order);
@@ -1174,7 +1182,7 @@ void isosurfacesDraw_surfaces(int OpenGLId, Surfaces *surf[], SurfacesOrder *ord
     isosurfacesOrder_polygons(order, surf);
 
   DBG_fprintf(stderr, " | draw polygons.\n");
-  res = (SurfaceResource*)0;
+  res = (VisuSurfacesResources*)0;
   for(i = 0; i < nb; i++) {
     idSurf = *(order->any_pointer[i] + 1);
     /* ip is index of polygon in surf[idSurf]. */
@@ -1269,7 +1277,7 @@ void isosurfacesDuplicate(int totalList, int simpleBlockList,
 
   DBG_fprintf(stderr, "Isosurfaces: duplicate the primitive block.\n");
   /* Duplicate the surface according to the box extension. */
-  visuDataGet_extension(dataObj, ext);
+  visu_data_getExtension(dataObj, ext);
   
   if (reorder)
     glGetFloatv(GL_MODELVIEW_MATRIX, mat);
@@ -1288,7 +1296,7 @@ void isosurfacesDuplicate(int totalList, int simpleBlockList,
 	  boxTrans[0] = (float)i;
 	  boxTrans[1] = (float)j;
 	  boxTrans[2] = (float)k;
-	  visuDataConvert_boxCoordinatestoXYZ(dataObj, xyzTrans + 3 * n, boxTrans);
+	  visu_data_convertBoxCoordinatestoXYZ(dataObj, xyzTrans + 3 * n, boxTrans);
 	  if (reorder)
 	    z[n] = (mat[ 2] * xyzTrans[3 * n + 0] +
 		    mat[ 6] * xyzTrans[3 * n + 1] +
@@ -1357,19 +1365,19 @@ gboolean isosurfacesGet_surfaceRendered(Surfaces *surf, int surf_index)
 
   return surf->resources[id]->rendered;
 }
-SurfaceResource* isosurfacesGet_surfaceResource(Surfaces *surf, int surf_index)
+VisuSurfacesResources* isosurfacesGet_surfaceResource(Surfaces *surf, int surf_index)
 {
   int id;
 
-  g_return_val_if_fail(surf, (SurfaceResource*)0);
+  g_return_val_if_fail(surf, (VisuSurfacesResources*)0);
 
   id = isosurfacesGet_surfacePosition(surf, surf_index);
-  g_return_val_if_fail(id >= 0 && id < surf->nsurf, (SurfaceResource*)0);
+  g_return_val_if_fail(id >= 0 && id < surf->nsurf, (VisuSurfacesResources*)0);
 
 /*   fprintf(stderr, "%d %p\n", id, (gpointer)surf->resources); */
   return surf->resources[id];
 }
-void isosurfacesSet_surfaceResource(Surfaces *surf, int surf_index, SurfaceResource *res)
+void isosurfacesSet_surfaceResource(Surfaces *surf, int surf_index, VisuSurfacesResources *res)
 {
   int id;
 
@@ -1379,7 +1387,7 @@ void isosurfacesSet_surfaceResource(Surfaces *surf, int surf_index, SurfaceResou
   g_return_if_fail(id >= 0 && id < surf->nsurf);
 
   if (!surf->resources[id]->surfnom)
-    isosurfacesFree_resource(surf->resources[id]);
+    visu_surfaces_resources_free(surf->resources[id]);
   DBG_fprintf(stderr, "Surfaces: set resource %p (%s) to surface %d (%d).\n",
 	      (gpointer)res, res->surfnom, surf_index, id);
   surf->resources[id] = res;
@@ -1439,7 +1447,7 @@ int isosurfacesGet_surfacePosition(Surfaces *surf, int id)
   return -1;
 }
 
-gboolean isosurfacesGet_drawIntra()
+gboolean isosurfacesGet_drawIntra(void)
 {
   return drawIntra;
 }
@@ -1490,7 +1498,7 @@ void isoSurfacesSet_fitToBox(VisuData *data, Surfaces *surf)
   inverted_local_box_matrix[2][1] = 0.;
   inverted_local_box_matrix[2][2] = 1 / surf->local_box[_DZZ];
 
-  visuDataGet_boxMatrix(data, boxCoordinatestoXYZ);
+  visu_data_getBoxMatrix(data, boxCoordinatestoXYZ);
   for(i = 0; i < 3; i++)
     for(j = 0; j < 3; j++)
       transform_box_matrix[i][j] =
@@ -1514,9 +1522,9 @@ void isoSurfacesSet_fitToBox(VisuData *data, Surfaces *surf)
       old_poly_points[3] = surf->basePoints.poly_points_data[i][SurfacesPoints_normalOffset + 0];
       old_poly_points[4] = surf->basePoints.poly_points_data[i][SurfacesPoints_normalOffset + 1];
       old_poly_points[5] = surf->basePoints.poly_points_data[i][SurfacesPoints_normalOffset + 2];
-      matrix_productVector(surf->basePoints.poly_points_data[i],
+      tool_matrix_productVector(surf->basePoints.poly_points_data[i],
 			   transform_box_matrix, old_poly_points);
-      matrix_productVector(surf->basePoints.poly_points_data[i] + SurfacesPoints_normalOffset,
+      tool_matrix_productVector(surf->basePoints.poly_points_data[i] + SurfacesPoints_normalOffset,
 			   transform_box_matrix, old_poly_points + 3);
     }
   surf->local_box[_DXX] = (double)boxCoordinatestoXYZ[0][0];
@@ -1537,7 +1545,7 @@ static gboolean isosurfaces_read_intra(gchar **lines, int nbLines, int position,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &intra, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &intra, 1, error))
     return FALSE;
   drawIntra = intra;
   return TRUE;
