@@ -56,13 +56,20 @@
 #include <openGLFunctions/view.h>
 #include <visu_data.h>
 
-struct Surfaces_struct;
 /**
  * Surfaces:
+ * @nsurf: number of surfaces encoded in this structure ;
+ * @basePoints: the geometric description of surfaces.
+ * @volatilePlanes: a storage for volatile polygons, .
+ * @local_box: the description of the box where surfaces are drawn ;
+ * @resources: for each surface points on a #VisuSurfacesResources ;
+ * @ids: gives a list of ids used to index surfaces ;
+ * @properties: an hashtable of properties.
  *
- * Short name to adress #Surfaces_struct objects.
+ * This structure stores surfaces. Several surfaces are stored in a single
+ * structure for improved performences.
  */
-typedef struct Surfaces_struct Surfaces;
+typedef struct _Surfaces Surfaces;
 
 /**
  * SurfacesOrder_struct:
@@ -77,8 +84,13 @@ struct SurfacesOrder_struct;
  */
 typedef struct SurfacesOrder_struct SurfacesOrder;
 
+/**
+ * VISU_ERROR_ISOSURFACES: (skip)
+ *
+ * Internal function for error handling.
+ */
 #define VISU_ERROR_ISOSURFACES isosurfacesGet_quark()
-GQuark isosurfacesGet_quark();
+GQuark isosurfacesGet_quark(void);
 enum
   {
     VISU_ERROR_FORMAT,
@@ -101,7 +113,7 @@ enum
  *
  * Returns: TRUE if the interior is painted in colour inverse.
  */
-gboolean isosurfacesGet_drawIntra();
+gboolean isosurfacesGet_drawIntra(void);
 /**
  * isosurfacesSet_drawIntra:
  * @status: a boolean.
@@ -187,7 +199,7 @@ void isoSurfacesSet_fitToBox(VisuData *data, Surfaces *surf);
  *
  * Returns: a newly created #SurfacesOrder object without any values.
  */
-SurfacesOrder* isosurfacesOrder_new();
+SurfacesOrder* isosurfacesOrder_new(void);
 /**
  * isosurfacesOrder_free:
  * @order: the object to be freed.
@@ -237,7 +249,7 @@ gboolean isosurfacesGet_surfaceRendered(Surfaces *surf, int surf_index);
  *
  * Returns: the resource of the surface or NULL, if @surf_index is invalid.
  */
-SurfaceResource* isosurfacesGet_surfaceResource(Surfaces *surf, int surf_index);
+VisuSurfacesResources* isosurfacesGet_surfaceResource(Surfaces *surf, int surf_index);
 /**
  * isosurfacesSet_surfaceResource:
  * @surf: the surface object ;
@@ -246,7 +258,7 @@ SurfaceResource* isosurfacesGet_surfaceResource(Surfaces *surf, int surf_index);
  * 
  * This method is used to change the resource of a surface.
  */
-void isosurfacesSet_surfaceResource(Surfaces *surf, int surf_index, SurfaceResource *res);
+void isosurfacesSet_surfaceResource(Surfaces *surf, int surf_index, VisuSurfacesResources *res);
 /**
  * isosurfacesGet_surfaceId:
  * @surf: the surface object ;
@@ -415,7 +427,7 @@ void isosurfacesCheck_consistency(Surfaces* surf);
  *
  * Method used to initialised the surface handling, should not be called.
  */
-void isosurfacesInit();
+void isosurfacesInit(void);
 
 /**
  * isosurfacesSet_showAll:
@@ -427,20 +439,7 @@ void isosurfacesInit();
 void isosurfacesSet_showAll(Surfaces *surf, gboolean show);
 
 /* Private area. */
-/**
- * Surfaces_struct:
- * @nsurf: number of surfaces encoded in this structure ;
- * @basePoints: the geometric description of surfaces.
- * @volatilePlanes: a storage for volatile polygons, .
- * @local_box: the description of the box where surfaces are drawn ;
- * @resources: for each surface points on a #SurfaceResource ;
- * @ids: gives a list of ids used to index surfaces ;
- * @properties: an hashtable of properties.
- *
- * This structure stores surfaces. Several surfaces are stored in a single
- * structure for improved performences.
- */
-struct Surfaces_struct
+struct _Surfaces
 {
   /* Number of different surfaces. */
   int nsurf;
@@ -452,7 +451,7 @@ struct Surfaces_struct
   double local_box[6];
 
   /* Resources for each surfaces. */
-  SurfaceResource **resources;
+  VisuSurfacesResources **resources;
 
   /* Id for each surfaces. */
   int *ids;
