@@ -51,6 +51,13 @@
 #include <visu_configFile.h>
 #include <coreTools/toolConfigFile.h>
 
+/**
+ * SECTION:surfaces_resources
+ * @short_description: Define the rendering parameters of a surface.
+ *
+ * <para>This structure stores all the rendering elements of a set of #Surfaces.</para>
+ */
+
 #define DESC_RESOURCE_COLOR      "Define the colour of one surface ;"	\
   " 4 floats (RGBA) 5 floats (material)"
 #define FLAG_RESOURCE_COLOR      "isosurface_color"
@@ -71,34 +78,46 @@ static gboolean isosurfaces_read_properties(gchar **lines, int nbLines, int posi
 					    VisuData *dataObj, GError **error);
 static void isosurfaces_export_resources(GString *data, VisuData *dataObj);
 
-void isosurfacesResourcesInit()
+/**
+ * initIsosurfacesResources: (skip)
+ *
+ * Internal routine called by isosurfacesInit() at startup. Do not use
+ * it.
+ */
+void initIsosurfacesResources(void)
 {
   VisuConfigFileEntry *entry, *oldEntry;
 
   /* This entry is now obsolete but is kept for backward compatibility. */
-  oldEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  oldEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 				  "isosurface_property",
 				  "Properties of a given isosurface",
 				  1, isosurfaces_read_resources);
-  visuConfigFileSet_version(oldEntry, 3.3f);
-  entry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(oldEntry, 3.3f);
+  entry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 				  FLAG_RESOURCE_COLOR,
 				  "The color and material of a given surface",
 				  1, isosurfaces_read_colour);
-  visuConfigFileSet_version(entry, 3.4f);
-  visuConfigFileSet_replace(entry, oldEntry);
-  entry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(entry, 3.4f);
+  visu_configFile_entry_setReplace(entry, oldEntry);
+  entry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 				  FLAG_RESOURCE_PROPERTIES,
 				  "Properties of a given isosurface",
 				  1, isosurfaces_read_properties);
-  visuConfigFileSet_version(entry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(entry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   isosurfaces_export_resources);
 
   isosurfaces_resources = g_hash_table_new_full(g_str_hash, g_str_equal,
 						NULL, hash_free_resource);
 }
-void isosurfacesFree_resource(SurfaceResource *res)
+/**
+ * visu_surfaces_resources_free:
+ * @res: an allocated #VisuSurfacesResources object to be freed.
+ * 
+ * This method frees the memory used by the given resource.
+ */
+void visu_surfaces_resources_free(VisuSurfacesResources *res)
 {
   g_return_if_fail(res);
 
@@ -109,20 +128,20 @@ void isosurfacesFree_resource(SurfaceResource *res)
   g_free(res->color);
   g_free(res);
 }
-static SurfaceResource* isosurfacesInit_resource()
+static VisuSurfacesResources* isosurfacesInit_resource()
 {
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
   float rgba[4];
   int position;
-  Color *color;
+  ToolColor *color;
 
-  res = g_malloc(sizeof(SurfaceResource));
+  res = g_malloc(sizeof(VisuSurfacesResources));
   rgba[0] = 1.0f;
   rgba[1] = 0.5f;
   rgba[2] = 0.5f;
   rgba[3] = 0.75f;
-  color = colorAdd_floatRGBA(rgba, &position);
-  res->color = g_malloc(sizeof(Color));
+  color = tool_color_addFloatRGBA(rgba, &position);
+  res->color = g_malloc(sizeof(ToolColor));
   for (position = 0; position < 4; position++)
     res->color->rgba[position] = color->rgba[position];
   res->material[0] = 0.2f;
@@ -136,7 +155,14 @@ static SurfaceResource* isosurfacesInit_resource()
 
   return res;
 }
-void isosurfacesCopy_resource(SurfaceResource *res, SurfaceResource *res_old)
+/**
+ * visu_surfaces_resources_copy:
+ * @res: an allocated #VisuSurfacesResources object to receive values ;
+ * @res_old: a #VisuSurfacesResources to read the values from.
+ * 
+ * This method copies all values from @res_old to @res.
+ */
+void visu_surfaces_resources_copy(VisuSurfacesResources *res, VisuSurfacesResources *res_old)
 {
   int i;
 
@@ -144,23 +170,35 @@ void isosurfacesCopy_resource(SurfaceResource *res, SurfaceResource *res_old)
 
   DBG_fprintf(stderr, "Isosurfaces Resources: copy resource from %p to %p.\n",
 	      (gpointer)res_old, (gpointer)res);
-  colorCopy_color(res->color, res_old->color);
+  tool_color_copy(res->color, res_old->color);
   for (i = 0; i < 5; i++)
     res->material[i] = res_old->material[i];
   res->rendered = res_old->rendered;
   res->sensitiveToMaskingPlanes = res_old->sensitiveToMaskingPlanes;
 }
-SurfaceResource* isosurfacesGet_resourceFromName(const gchar *surf_name,
+/**
+ * visu_surfaces_resources_getFromName:
+ * @surf_name: the name of the surface (can be NULL) ;
+ * @new_surf: a location to store a boolean value (can be NULL).
+ * 
+ * This returns the resource information matching the given @surf_name. If
+ * the resource doesn't exist, it is created and @new is set to TRUE. If the given
+ * name (@surf_name) is NULL, then a new resource is created, but it is not stored
+ * and will not be shared by surfaces.
+ *
+ * Returns: the resource (created or retrieved).
+ */
+VisuSurfacesResources* visu_surfaces_resources_getFromName(const gchar *surf_name,
 						 gboolean *nw)
 {
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
 
-  g_return_val_if_fail(isosurfaces_resources, (SurfaceResource*)0);
+  g_return_val_if_fail(isosurfaces_resources, (VisuSurfacesResources*)0);
 
   if (surf_name && surf_name[0])
     res = g_hash_table_lookup(isosurfaces_resources, surf_name);
   else
-    res = (SurfaceResource*)0;
+    res = (VisuSurfacesResources*)0;
   if(!res)
     {    
       res = isosurfacesInit_resource();
@@ -189,12 +227,12 @@ SurfaceResource* isosurfacesGet_resourceFromName(const gchar *surf_name,
 /******************/
 static void hash_free_resource(gpointer res)
 {
-  isosurfacesFree_resource((SurfaceResource*)res);
+  visu_surfaces_resources_free((VisuSurfacesResources*)res);
 }
 static gboolean isosurfaces_read_resources(gchar **lines, int nbLines, int position,
 					   VisuData *dataObj _U_, GError **error)
 {
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
   gboolean rendered;
   float rgba[4];
   float material[5];
@@ -207,7 +245,7 @@ static gboolean isosurfaces_read_resources(gchar **lines, int nbLines, int posit
   
   if (!tokens[0] || !tokens[1])
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Can't parse resource '%s' of"
 			     " iso-surfaces on line %d.\n"),
 			   "isosurface_property", position);
@@ -220,7 +258,7 @@ static gboolean isosurfaces_read_resources(gchar **lines, int nbLines, int posit
 	    &rgba[2], &rgba[3], &material[0], &material[1],
 	    &material[2], &material[3], &material[4]) != 10)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Can't parse resource '%s' of"
 			     " iso-surfaces on line %d.\n"),
 			   "isosurface_property", position);
@@ -229,8 +267,8 @@ static gboolean isosurfaces_read_resources(gchar **lines, int nbLines, int posit
     }
 
   /* Read resources are always made public and added in the hashtable. */
-  res = isosurfacesGet_resourceFromName(tokens[1], (gboolean*)0);
-  res->color = colorAdd_floatRGBA(rgba, &k);
+  res = visu_surfaces_resources_getFromName(tokens[1], (gboolean*)0);
+  res->color = tool_color_addFloatRGBA(rgba, &k);
   res->rendered = rendered;
   for (k = 0; k < 5; k++)
     res->material[k] = material[k];
@@ -242,7 +280,7 @@ static gboolean isosurfaces_read_resources(gchar **lines, int nbLines, int posit
 static gboolean isosurfaces_read_colour(gchar **lines, int nbLines, int position,
 					VisuData *dataObj _U_, GError **error)
 {
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
   float rgba[4];
   float material[5];
   int k;
@@ -254,7 +292,7 @@ static gboolean isosurfaces_read_colour(gchar **lines, int nbLines, int position
   
   if (!tokens[0] || !tokens[1])
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Can't parse resource '%s' of"
 			     " iso-surfaces on line %d.\n"),
 			   FLAG_RESOURCE_COLOR, position);
@@ -266,7 +304,7 @@ static gboolean isosurfaces_read_colour(gchar **lines, int nbLines, int position
 	    &rgba[0], &rgba[1], &rgba[2], &rgba[3], &material[0], &material[1],
 	    &material[2], &material[3], &material[4]) != 9)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Can't parse resource '%s' of"
 			     " iso-surfaces on line %d.\n"),
 			   FLAG_RESOURCE_COLOR, position);
@@ -275,8 +313,8 @@ static gboolean isosurfaces_read_colour(gchar **lines, int nbLines, int position
     }
 
   /* Read resources are always made public and added in the hashtable. */
-  res = isosurfacesGet_resourceFromName(tokens[1], (gboolean*)0);
-  res->color = colorAdd_floatRGBA(rgba, &k);
+  res = visu_surfaces_resources_getFromName(tokens[1], (gboolean*)0);
+  res->color = tool_color_addFloatRGBA(rgba, &k);
   for (k = 0; k < 5; k++)
     res->material[k] = material[k];
   DBG_fprintf(stderr, "Isosurfaces Resources: resources '%s' found for surface '%s'\n",
@@ -288,7 +326,7 @@ static gboolean isosurfaces_read_colour(gchar **lines, int nbLines, int position
 static gboolean isosurfaces_read_properties(gchar **lines, int nbLines, int position,
 					    VisuData *dataObj _U_, GError **error)
 {
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
   int rendered, sensitive;
   gchar **tokens;
 
@@ -298,7 +336,7 @@ static gboolean isosurfaces_read_properties(gchar **lines, int nbLines, int posi
   
   if (!tokens[0] || !tokens[1])
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Can't parse resource '%s' of"
 			     " iso-surfaces on line %d.\n"),
 			   FLAG_RESOURCE_PROPERTIES, position);
@@ -308,7 +346,7 @@ static gboolean isosurfaces_read_properties(gchar **lines, int nbLines, int posi
 
   if(sscanf(tokens[2], "%d %d", &rendered, &sensitive) != 2)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Can't parse resource '%s' of"
 			     " iso-surfaces on line %d.\n"),
 			   FLAG_RESOURCE_PROPERTIES, position);
@@ -317,7 +355,7 @@ static gboolean isosurfaces_read_properties(gchar **lines, int nbLines, int posi
     }
 
   /* Read resources are always made public and added in the hashtable. */
-  res = isosurfacesGet_resourceFromName(tokens[1], (gboolean*)0);
+  res = visu_surfaces_resources_getFromName(tokens[1], (gboolean*)0);
   res->rendered = rendered;
   res->sensitiveToMaskingPlanes = sensitive;
   DBG_fprintf(stderr, "Isosurfaces Resources: resources '%s' found for surface '%s'\n",
@@ -331,9 +369,9 @@ static void isosurfaces_export_one_surf_resources(gpointer key, gpointer value,
 						  gpointer user_data)
 {
   struct foreachFuncExport_struct *str;
-  SurfaceResource *res;
+  VisuSurfacesResources *res;
 
-  res = (SurfaceResource*)value;
+  res = (VisuSurfacesResources*)value;
   str = (struct foreachFuncExport_struct*)user_data;
   DBG_fprintf(stderr, "Isosurfaces Resources: exporting surface '%s' properties...",
 	      (char *)key);
