@@ -50,10 +50,12 @@
 
 #include <coreTools/toolColor.h>
 
+G_BEGIN_DECLS
+
 /**
- * SurfaceResource_struct:
+ * VisuSurfacesResources:
  * @surfnom: the name of the surface (in UTF-8) ;
- * @color: a #Color for the surface ;
+ * @color: a #ToolColor for the surface ;
  * @material: the lighting effects of the surface ;
  * @rendered: boolean for the visibility of the surface ;
  * @sensitiveToMaskingPlanes: boolean for the sensitivity of a surface
@@ -61,13 +63,13 @@
  *
  * This structure defines some drawing properties of a set of #Surfaces.
  */
-struct SurfaceResource_struct
+struct _VisuSurfacesResources
 {
   /* Name used to label the surface. */
   gchar *surfnom;
 
   /* Material used to draw a specific surface. */
-  Color *color;
+  ToolColor *color;
   float material[5];
 
   /* Rendered or not */
@@ -76,49 +78,15 @@ struct SurfaceResource_struct
   /* Sensitive to masking properties of planes. */
   gboolean sensitiveToMaskingPlanes;
 };
-/**
- * SurfaceResource:
- *
- * Short name to adress #SurfaceResource_struct objects.
- */
-typedef struct SurfaceResource_struct SurfaceResource;
+typedef struct _VisuSurfacesResources VisuSurfacesResources;
 
-/**
- * isosurfacesGet_resourceFromName:
- * @surf_name: the name of the surface (can be NULL) ;
- * @new: a location to store a boolean value (can be NULL).
- * 
- * This returns the resource information matching the given @surf_name. If
- * the resource doesn't exist, it is created and @new is set to TRUE. If the given
- * name (@surf_name) is NULL, then a new resource is created, but it is not stored
- * and will not be shared by surfaces.
- *
- * Returns: the resource (created or retrieved).
- */
-SurfaceResource* isosurfacesGet_resourceFromName(const gchar *surf_name,
-						 gboolean *nw);
-/**
- * isosurfacesCopy_resource:
- * @res: an allocated #SurfaceResource object to receive values ;
- * @res_old: a #SurfaceResource to read the values from.
- * 
- * This method copies all values from @res_old to @res.
- */
-void isosurfacesCopy_resource(SurfaceResource *res, SurfaceResource *res_old);
-/**
- * isosurfacesFree_resource:
- * @res: an allocated #SurfaceResource object to be freed.
- * 
- * This method frees the memory used by the given resource.
- */
-void isosurfacesFree_resource(SurfaceResource *res);
+VisuSurfacesResources* visu_surfaces_resources_getFromName(const gchar *surf_name,
+						 gboolean *new_surf);
+void visu_surfaces_resources_copy(VisuSurfacesResources *res, VisuSurfacesResources *res_old);
+void visu_surfaces_resources_free(VisuSurfacesResources *res);
 
-/**
- * isosurfacesResourcesInit:
- *
- * Internal routine called by isosurfacesInit() at startup. Do not use
- * it.
- */
-void isosurfacesResourcesInit();
+void initIsosurfacesResources(void);
+
+G_END_DECLS
 
 #endif
