@@ -43,24 +43,36 @@
 */
 #include "vibration.h"
 
+#include <string.h>
 #include <math.h> /*for sinus*/
 #include <coreTools/toolMatrix.h> /* for spherical coordonates */
 
+#include <visu_object.h>
 #include <visu_rendering.h>
-#include <renderingMethods/renderingSpin.h> /* for SPIN_VALUE*/
-#include "opengl.h" /* for highlight methods*/
+#include <opengl.h> /* for highlight methods*/
 #include <openGLFunctions/objectList.h> /* permit to draw arrow */
 #include <visu_extension.h>
 #include <visu_basic.h>
 
+/**
+ * SECTION:vibration
+ * @short_description: Add a support to animate the node positions
+ * with a phonon frequency.
+ *
+ * <para>Define a way to store vibration or phonons to a #VisuData
+ * object. One can store several phonons in one object, each phonon is
+ * them represented by its id. The phonons can be animated on screen,
+ * using a user defined frequency (visu_vibration_setUserFrequency)
+ * and amplitue (visu_vibration_setAmplitude), by calling
+ * visu_vibration_play().</para>
+ * <para>Phonons are set with visu_vibration_setCharacteristic() and
+ * #VisuNode displacements are set with visu_vibration_setDisplacements().</para>
+ */
+
 #define OMEGA_COEFF 0.05f
 #define AMPL_COEFF 0.5f
 #define PHONON "Vibration"
 
-/**
- * SECTION:vibration
- */
-
 /* Displacement vector per atom is (U+iV) = (Ux + iVx, ...).
    Current applied displacement on one atom is (dx, dy, dz).
    qr is the Q.R part of the exponential. */
@@ -80,7 +92,7 @@ enum
   };
 
 /* Local variables. */
-OpenGLExtension *extSpin = NULL;
+VisuExtension *extSpin = NULL;
 
 /*Local Method */
 static void freeVib(gpointer data);
@@ -118,7 +130,19 @@ typedef struct vibration_
 
 /******************************************************************************************************/
 
-guint vibrationStart_play(VisuData *data)
+/**
+ * visu_vibration_play:
+ * @data : a #VisuData object.
+ *
+ * Make the phonon displace the #VisuNode of @data according to their
+ * definitions (see visu_vibration_setDisplacements() and
+ * visu_vibration_setCurrentMode()).
+ *
+ * Since: 3.5
+ *
+ * Returns: the timer's ID
+ */
+guint visu_vibration_play(VisuData *data)
 {
   Vibration *vib;
   guint timeoutID = 0;
@@ -130,8 +154,17 @@ guint vibrationStart_play(VisuData *data)
  
   return timeoutID;
 }
-
-gboolean vibrationStop_play(guint timeoutID)
+/**
+ * visu_vibration_stop:
+ * @timeoutID: an id.
+ *
+ * Stop the timer with the given @timeoutID.
+ *
+ * Since: 3.5
+ *
+ * Returns: if the timer is indeed removed.
+ */
+gboolean visu_vibration_stop(guint timeoutID)
 {
   /* to stop the timer */
   return g_source_remove(timeoutID);
@@ -175,15 +208,28 @@ static gpointer newOrCopyVibe(gconstpointer obj, gpointer data _U_)
     
   return (gpointer)spinData;
 }
-
-gboolean vibrationInit(VisuData *data, guint n, guint nNodes)
+/**
+ * visu_vibration_init:
+ * @data: a #VisuData object.
+ * @n: number of phonons to set.
+ * @nNodes: number of vibrating nodes.
+ *
+ * Allocate (or reallocate) storage of phonons for @data. The
+ * allocated memory will be automatically freed when @data is
+ * destroyed.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE if @data has no phonons before.
+ */
+gboolean visu_vibration_init(VisuData *data, guint n, guint nNodes)
 {
   Vibration *vib;
   gboolean new;
   VisuNodeArray *nodes;
   guint i;
 
-  nodes = visuDataGet_nodeArray(data);
+  nodes = visu_data_getNodeArray(data);
 
   new = FALSE;
   vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
@@ -242,9 +288,24 @@ static void freeVib(gpointer data)
   g_free(vib->norm);
   g_free(vib->loaded);
 }
-
-gboolean vibrationSet_displacements(VisuData *data, guint iph,
-				    float *vibes, gboolean complex)
+/**
+ * visu_vibration_setDisplacements:
+ * @data: a #VisuData object.
+ * @iph: a phonon id.
+ * @vibes: a set of displacement vectors.
+ * @complex: a flag.
+ *
+ * visu_vibration_init() must have been call before. This routine is
+ * used to define a set of displacement vectors, corresponding to one
+ * phonon. The displacement vectors can be @complex, in that case
+ * @vibes contains 6 values for each #VisuNode.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE on success.
+ */
+gboolean visu_vibration_setDisplacements(VisuData *data, guint iph,
+                                         float *vibes, gboolean complex)
 {
   float *tmpVibeValues, max;
   Vibration *vib;
@@ -289,8 +350,21 @@ gboolean vibrationSet_displacements(VisuData *data, guint iph,
 
   return TRUE;
 }
-
-gboolean vibrationSet_currentMode(VisuData *data, guint iph, GError **error)
+/**
+ * visu_vibration_setCurrentMode:
+ * @data: a #VisuData object.
+ * @iph: a phonon id.
+ * @error: a location for a possible error.
+ *
+ * Set all node displacements to zero and setup the displacement
+ * vector (u+iv) for each #VisuNode. After this call,
+ * visu_vibration_play() will move the nodes according to their vibration.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE if its the first time #VisuNodes are displaced.
+ */
+gboolean visu_vibration_setCurrentMode(VisuData *data, guint iph, GError **error)
 {
   float *tmpVibeValues, xyz[3], *vals;
   VisuDataIter iter;
@@ -310,8 +384,8 @@ gboolean vibrationSet_currentMode(VisuData *data, guint iph, GError **error)
 
   if (!vib->loaded[iph])
     {
-      visuDataFree_population(data);
-      ok = visuBasicLoad_dataFromFile(data, (FileFormat*)0, iph, error);
+      visu_data_freePopulation(data);
+      ok = visu_basic_loadData(data, (ToolFileFormat*)0, iph, error);
       if (!ok)
 	return FALSE;
     }
@@ -319,35 +393,35 @@ gboolean vibrationSet_currentMode(VisuData *data, guint iph, GError **error)
 
   /* We copy for all the nodes the displacements into the PHONON
      node property. */
-  nodes = visuDataGet_nodeArray(data);
-  nodevibe = visuNodeGet_property(nodes, PHONON);
+  nodes = visu_data_getNodeArray(data);
+  nodevibe = visu_node_array_getProperty(nodes, PHONON);
   new = (nodevibe == (VisuNodeProperty*)0);
 
   /*Associate the table to a VisuNodeArray as a new property*/
   if (new)
-    nodevibe = visuNodeNew_pointerProperty(visuDataGet_nodeArray(data),
+    nodevibe = visu_node_property_newPointer(visu_data_getNodeArray(data),
 					   PHONON, freeVibe, newOrCopyVibe,
 					   (gpointer)0 );
 
   /*for each node*/
   i   = 0;
   g_value_init(&vibeValue, G_TYPE_POINTER);
-  visuDataIter_new(data, &iter);
-  for(visuDataIter_start(data, &iter); iter.node;
-      visuDataIter_next(data, &iter))
+  visu_data_iterNew(data, &iter);
+  for(visu_data_iterStart(data, &iter); iter.node;
+      visu_data_iterNext(data, &iter))
     {
-      iNode = visuNodeGet_original(nodes, iter.node->number);
+      iNode = visu_node_array_getOriginal(nodes, iter.node->number);
       iNode = (iNode >= 0)?iNode:(int)iter.node->number;
       vals = vib->u + iph * vib->nUs + iNode * 6;
       if (new)
 	{
 	  tmpVibeValues = newOrCopyVibe(vals, (gpointer)0);
 	  g_value_set_pointer(&vibeValue, tmpVibeValues);
-	  visuNodePropertySet_value(nodevibe, iter.node, &vibeValue);
+	  visu_node_property_setValue(nodevibe, iter.node, &vibeValue);
 	}
       else
 	{
-	  visuNodePropertyGet_value(nodevibe, iter.node, &vibeValue);
+	  visu_node_property_getValue(nodevibe, iter.node, &vibeValue);
 	  tmpVibeValues = (float*)g_value_get_pointer(&vibeValue);
 	  tmpVibeValues[Ux] = vals[0];
 	  tmpVibeValues[Uy] = vals[1];
@@ -360,7 +434,7 @@ gboolean vibrationSet_currentMode(VisuData *data, guint iph, GError **error)
 	  tmpVibeValues[dz] = 0.f;
 	}
       /* Set the phase. */
-      visuDataGet_reducedNodePosition(data, iter.node, xyz);
+      visu_data_getReducedNodePosition(data, iter.node, xyz);
       tmpVibeValues[qr] = 2.f * G_PI *
 	(xyz[0] * vib->q[3 * iph + 0] +
 	 xyz[1] * vib->q[3 * iph + 1] +
@@ -378,9 +452,23 @@ gboolean vibrationSet_currentMode(VisuData *data, guint iph, GError **error)
 
   return new;
 }
-
-gboolean vibrationSet_characteristic(VisuData *data, guint n,
-				     float q[3], float en, float omega)
+/**
+ * visu_vibration_setCharacteristic:
+ * @data: a #VisuData object.
+ * @n: a phonon id.
+ * @q: a reciprocal vector.
+ * @en: the phonon energy.
+ * @omega: the phonon frequency.
+ *
+ * This routine is used to define the characteristics of a given
+ * phonon.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE on success.
+ */
+gboolean visu_vibration_setCharacteristic(VisuData *data, guint n,
+                                          float q[3], float en, float omega)
 {
   Vibration *vib;
 
@@ -397,8 +485,23 @@ gboolean vibrationSet_characteristic(VisuData *data, guint n,
 
   return TRUE;
 }
-gboolean vibrationGet_characteristic(VisuData *data, guint n,
-				     float q[3], float *en, float *omega)
+/**
+ * visu_vibration_getCharacteristic:
+ * @data: a #VisuData object.
+ * @n: a phonon id.
+ * @q: a location for the reciprocal vector.
+ * @en: a locattion for the phonon energy.
+ * @omega: a location for the phonon frequency.
+ *
+ * This routine is used to get the characteristics of a given
+ * phonon, see visu_vibration_setCharacteristic() to set them.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE on success.
+ */
+gboolean visu_vibration_getCharacteristic(VisuData *data, guint n,
+                                          float q[3], float *en, float *omega)
 {
   Vibration *vib;
 
@@ -415,7 +518,19 @@ gboolean vibrationGet_characteristic(VisuData *data, guint n,
 
   return TRUE;
 }
-gboolean vibrationGet_nPhonons(VisuData *data, guint *n)
+/**
+ * visu_vibration_getNPhonons:
+ * @data: a #VisuData object.
+ * @n: a location.
+ *
+ * Retrieves if @data contains phonons or not. Number of stored
+ * phonons is set in @n.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE if @data has phonons.
+ */
+gboolean visu_vibration_getNPhonons(VisuData *data, guint *n)
 {
   Vibration *vib;
 
@@ -428,7 +543,16 @@ gboolean vibrationGet_nPhonons(VisuData *data, guint *n)
 
   return TRUE;
 }
-void vibrationSet_userFrequency(VisuData *data, float freq)
+/**
+ * visu_vibration_setUserFrequency:
+ * @data: a #VisuData object.
+ * @freq: a frequency.
+ *
+ * Change the frequency at which phonons are played with visu_vibration_play().
+ *
+ * Since: 3.5
+ */
+void visu_vibration_setUserFrequency(VisuData *data, float freq)
 {
   Vibration *vib;
   float f;
@@ -446,7 +570,19 @@ void vibrationSet_userFrequency(VisuData *data, float freq)
   /* We update t to keep the same position. */
   vib->t = (gulong)((float)vib->t * f / vib->freq);
 }
-gboolean vibrationSet_amplitude(VisuData *data, float ampl)
+/**
+ * visu_vibration_setAmplitude:
+ * @data: a #VisuData object.
+ * @ampl: an amplitude.
+ *
+ * Change the amplitude at which phonon are displayed on screen when
+ * using visu_vibration_play().
+ * 
+ * Since: 3.5
+ *
+ * Returns: TRUE if amplitude is actually changed.
+ */
+gboolean visu_vibration_setAmplitude(VisuData *data, float ampl)
 {
   Vibration *vib;
 
@@ -461,7 +597,17 @@ gboolean vibrationSet_amplitude(VisuData *data, float ampl)
   vib->ampl = ampl;
   return TRUE;
 }
-guint vibrationGet_currentMode(VisuData *data)
+/**
+ * visu_vibration_getCurrentMode:
+ * @data: a #VisuData object.
+ *
+ * Retrieves the phonon that is currently applied to @data.
+ *
+ * Since: 3.5
+ *
+ * Returns: a phonon id.
+ */
+guint visu_vibration_getCurrentMode(VisuData *data)
 {
   Vibration *vib;
 
@@ -480,7 +626,7 @@ static gboolean getVibration(VisuNodeProperty **nodevibe, Vibration **vib,
   g_return_val_if_fail(*vib, FALSE);
 
   g_value_init(vibeValue, G_TYPE_POINTER);
-  *nodevibe = visuNodeGet_property(visuDataGet_nodeArray(data), PHONON);
+  *nodevibe = visu_node_array_getProperty(visu_data_getNodeArray(data), PHONON);
 
   return TRUE;
 }
@@ -514,12 +660,12 @@ static void vibrationIncr(VisuData *data, gboolean time, gboolean phase)
 
   DBG_fprintf(stderr, " | c = %g, t = %g.\n", c, t);
 
-  visuDataIter_new(data, &iter);
-  for(visuDataIter_start(data, &iter); iter.node;
-      visuDataIter_next(data, &iter))
+  visu_data_iterNew(data, &iter);
+  for(visu_data_iterStart(data, &iter); iter.node;
+      visu_data_iterNext(data, &iter))
     {
       /* Get the vector of vibration of the node (GValue) */
-      visuNodePropertyGet_value(nodevibe, iter.node, &vibeValue );
+      visu_node_property_getValue(nodevibe, iter.node, &vibeValue );
       /* Convert GValue to Float[3]  */
       dxyz = (float*)g_value_get_pointer(&vibeValue);
 
@@ -544,23 +690,42 @@ static void vibrationIncr(VisuData *data, gboolean time, gboolean phase)
      
   /*emit signal for pairs and other things */   
   g_signal_handler_block(G_OBJECT(data), vib->signal);
-  visuDataEmit_nodePositionChanged(data);
+  visu_data_emitNodePositionChanged(data);
   g_signal_handler_unblock(G_OBJECT(data), vib->signal);
   /* re-create the nodes list */
-  visuData_createAllNodes(data);
+  visu_data_createAllNodes(data);
   /* redraw with the new values */
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 static gboolean move(gpointer data)
 {
   vibrationIncr(VISU_DATA(data), TRUE, TRUE);
   return TRUE;
 }
-void vibrationReset_position(VisuData *data)
+/**
+ * visu_vibration_resetPosition:
+ * @data: a #VisuData object.
+ *
+ * Reset the node position of the given VisuData.
+ *
+ * Since: 3.5
+ *
+ * Returns: a boolean
+ */
+void visu_vibration_resetPosition(VisuData *data)
 {
   vibrationIncr(data, FALSE, FALSE);
 }
-void vibrationSet_zeroTime(VisuData *data)
+/**
+ * visu_vibration_setZeroTime:
+ * @data: a #VisuData object.
+ *
+ * Reset the position of phonons to use position at time equals zero
+ * (so applying just the q vector displacement).
+ *
+ * Since: 3.5
+ */
+void visu_vibration_setZeroTime(VisuData *data)
 {
   vibrationIncr(data, FALSE, TRUE);
 }
@@ -587,37 +752,37 @@ static gboolean xyzspin(VisuData *data)
   fact = 2.f * AMPL_COEFF * vib->ampl / vib->norm[vib->iph];
 
   g_value_init(&vibeValue, G_TYPE_POINTER);
-  visuDataIter_new(data, &iter);
-  nodevibe = visuNodeGet_property(visuDataGet_nodeArray(data), PHONON);
+  visu_data_iterNew(data, &iter);
+  nodevibe = visu_node_array_getProperty(visu_data_getNodeArray(data), PHONON);
   g_return_val_if_fail(nodevibe, FALSE);
 
-  for(visuDataIter_start(data, &iter); iter.element;
-      visuDataIter_nextElement(data, &iter))
+  for(visu_data_iterStart(data, &iter); iter.element;
+      visu_data_iterNextElement(data, &iter))
     {
       /* change spin color*/
       openGLSet_highlightColor(iter.element->material,
 			       iter.element->rgb, 1.f);
-      eleSize = visuRenderingGet_sizeOfElement(visuRenderingClassGet_current(),
+      eleSize = visu_rendering_getSizeOfElement(visu_object_getRendering(VISU_INSTANCE),
 					       iter.element);
 
-      for(visuDataIter_restartNode(data, &iter); iter.node;
-	  visuDataIter_nextNode(data, &iter))
+      for(visu_data_iterRestartNode(data, &iter); iter.node;
+	  visu_data_iterNextNode(data, &iter))
 	{
 	  /* Get the vector of vibration of the node (GValue) */
-	  visuNodePropertyGet_value(nodevibe, iter.node, &vibeValue );
+	  visu_node_property_getValue(nodevibe, iter.node, &vibeValue );
 	  /* Convert GValue to Float[3]  */
 	  dxyz = (float*)g_value_get_pointer(&vibeValue);
 
 	  /* Spherical coordonates of dxyz */
-	  matrix_cartesianToSpherical(sph, dxyz);
-	  vals[SPIN_MODULUS] = sph[0];
-	  vals[SPIN_THETA]   = sph[1];
-	  vals[SPIN_PHI]     = sph[2];
+	  tool_matrix_cartesianToSpherical(sph, dxyz);
+	  vals[TOOL_MATRIX_SPHERICAL_MODULUS] = sph[0];
+	  vals[TOOL_MATRIX_SPHERICAL_THETA]   = sph[1];
+	  vals[TOOL_MATRIX_SPHERICAL_PHI]     = sph[2];
 
-	  if (vals[SPIN_MODULUS] > 0.05f * vib->norm[vib->iph])
+	  if (vals[TOOL_MATRIX_SPHERICAL_MODULUS] > 0.05f * vib->norm[vib->iph])
 	    {
 	      /* get the nodes position in the box */
-	      visuDataGet_nodePosition(data, iter.node, xyz);
+	      visu_data_getNodePosition(data, iter.node, xyz);
   
 	      DBG_fprintf(stderr, "Vibration: drawing an arrow for the node \n");
 
@@ -627,13 +792,14 @@ static gboolean xyzspin(VisuData *data)
 	      glTranslated(xyz[0] - dxyz[dx],
 			   xyz[1] - dxyz[dy],
 			   xyz[2] - dxyz[dz]);
-	      glRotated(vals[SPIN_PHI], 0, 0, 1);
-	      glRotated(vals[SPIN_THETA], 0, 1, 0);
+	      glRotated(vals[TOOL_MATRIX_SPHERICAL_PHI], 0, 0, 1);
+	      glRotated(vals[TOOL_MATRIX_SPHERICAL_THETA], 0, 1, 0);
 
 	      /* draw a smooth arrow */
-	      openGLObjectListDraw_smoothArrow
-		(obj, -1, TRUE, vals[SPIN_MODULUS] * fact + 2.5f * eleSize, eleSize * 0.2f, 10, FALSE,
-		 0.5f * eleSize, eleSize * 0.3f, 10, FALSE);
+	      visu_openGL_drawSmoothArrow
+		(obj, -1, VISU_OPENGL_ARROW_TAIL_CENTERED,
+                 vals[TOOL_MATRIX_SPHERICAL_MODULUS] * fact + 2.5f * eleSize,
+                 eleSize * 0.2f, 10, FALSE, 0.5f * eleSize, eleSize * 0.3f, 10, FALSE);
 
 	      glPopMatrix();
 	    }
@@ -644,8 +810,15 @@ static gboolean xyzspin(VisuData *data)
 
   return TRUE;
 }
-
-void vibrationBuild_listSpin(VisuData *data)
+/**
+ * visu_vibration_buildListSpin:
+ * @data: a #VisuData object.
+ *
+ * Make a new list to make OpenGl know that he draw spins or not.
+ *
+ * Since: 3.5
+ */
+void visu_vibration_buildListSpin(VisuData *data)
 {
 
   DBG_fprintf(stderr, "Vibration: rebuilding object list for visuData %p.\n",
@@ -663,16 +836,25 @@ static void spinCreate_openGLExtension()
   int id;
 
   /* Get an OpenGL identifier to store the arrows and labels. */
-  id      = openGLObjectList_new(1);
-  extSpin = OpenGLExtension_new("vibration", "vibration",
+  id      = visu_openGL_objectList_new(1);
+  extSpin = visu_extension_new("vibration", "vibration",
 				"arrows representing node moves.",
-				id, vibrationBuild_listSpin);
-  OpenGLExtensionSet_priority(extSpin, OPENGL_EXTENSION_PRIORITY_FIRST + 1);
+				id, visu_vibration_buildListSpin);
+  visu_extension_setPriority(extSpin, VISU_EXTENSION_PRIORITY_NODE_DECORATIONS);
   extSpin->used = 0;
-  OpenGLExtensionRegister(extSpin);
+  visuExtensions_add(extSpin);
 }
-
-gboolean vibrationSet_useSpin(gboolean value)
+/**
+ * visu_vibration_setUseSpin:
+ * @value: the value of the checkbox that allow to draw spin or not;
+ *
+ * Tells openGl if he has to draw the spin/phonons list
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE if status changed.
+ */
+gboolean visu_vibration_setUseSpin(gboolean value)
 {
   if (!extSpin)
     spinCreate_openGLExtension();
@@ -684,8 +866,17 @@ gboolean vibrationSet_useSpin(gboolean value)
 
   return TRUE;
 }
-
-gboolean vibrationIsSet(VisuData *data)
+/**
+ * visu_vibration_isSet:
+ * @data: a #VisuData object.
+ *
+ * Retrieve if @data has some phonon attached to.
+ *
+ * Since: 3.5
+ *
+ * Returns: TRUE if visu_vibration_init() has been called already.
+ */
+gboolean visu_vibration_isSet(VisuData *data)
 {
   return (g_object_get_data(G_OBJECT(data), PHONON) != (Vibration*)0);
 }
@@ -705,19 +896,19 @@ static void onPopulationChanged(VisuData *dataObj, gint *ids, gpointer data _U_)
     return;
 
   g_value_init(&vibeValue, G_TYPE_POINTER);
-  nodevibe = visuNodeGet_property(visuDataGet_nodeArray(dataObj), PHONON);
+  nodevibe = visu_node_array_getProperty(visu_data_getNodeArray(dataObj), PHONON);
 
   DBG_fprintf(stderr, "Vibration: on population increase recalculate pahse.\n");
   /* We need to recalculate the phase of the new ones. */
   for (i = 2; ids[i] >= 0; i++)
     {
-      node = visuDataGet_nodeFromNumber(dataObj, ids[i]);
+      node = visu_data_getNodeFromNumber(dataObj, ids[i]);
       /* Get the vector of vibration of the node (GValue) */
-      visuNodePropertyGet_value(nodevibe, node, &vibeValue );
+      visu_node_property_getValue(nodevibe, node, &vibeValue );
       /* Convert GValue to Float[3]  */
       dxyz = (float*)g_value_get_pointer(&vibeValue);
       
-      visuDataGet_reducedNodePosition(dataObj, node, xyz);
+      visu_data_getReducedNodePosition(dataObj, node, xyz);
       DBG_fprintf(stderr, " | node %d, %f -> %f.\n", ids[i], dxyz[3],
 		  xyz[0] * vib->q[3 * vib->iph + 0] +
 		  xyz[1] * vib->q[3 * vib->iph + 1] +
@@ -746,16 +937,16 @@ static void onPositionChanged(VisuData *dataObj, gpointer data _U_)
     return;
 
   /* We need to recalculate the phase of the new ones. */
-  visuDataIter_new(dataObj, &iter);
-  for(visuDataIter_start(dataObj, &iter); iter.node;
-      visuDataIter_next(dataObj, &iter))
+  visu_data_iterNew(dataObj, &iter);
+  for(visu_data_iterStart(dataObj, &iter); iter.node;
+      visu_data_iterNext(dataObj, &iter))
     {
       /* Get the vector of vibration of the node (GValue) */
-      visuNodePropertyGet_value(nodevibe, iter.node, &vibeValue );
+      visu_node_property_getValue(nodevibe, iter.node, &vibeValue );
       /* Convert GValue to Float[3]  */
       dxyz = (float*)g_value_get_pointer(&vibeValue);
       
-      visuDataGet_reducedNodePosition(dataObj, iter.node, xyz);
+      visu_data_getReducedNodePosition(dataObj, iter.node, xyz);
       DBG_fprintf(stderr, " | node %d, %f -> %f.\n", iter.node->number, dxyz[qr],
 		  xyz[0] * vib->q[3 * vib->iph + 0] +
 		  xyz[1] * vib->q[3 * vib->iph + 1] +
