@@ -44,14 +44,15 @@
 #include <gtk/gtk.h>
 
 #include "gtk_colorComboBoxWidget.h"
+#include <support.h>
 #include <visu_tools.h>
 #include <visu_object.h>
 
 /**
- * SECTION:colorcombobox
+ * SECTION:gtk_colorComboBoxWidget
  * @short_description: Defines a specialised #GtkComboBox to choose
  * stored colours.
- * @see_also: #Color, #StippleComboBox, #ShadeComboBox
+ * @see_also: #ToolColor, #StippleComboBox, #ShadeComboBox
  * @include: coreTools/toolColor.h
  *
  * <para>This widget looks like a #GtkComboBox and it displays a list
@@ -111,7 +112,7 @@ enum
     COLUMN_COLOR_LABEL_ALPHA,
     /* This is the same label than above but without the alpha value. */
     COLUMN_COLOR_LABEL,
-    /* This a pointer to the #Color as defined in visuTools.h */
+    /* This a pointer to the #ToolColor as defined in visuTools.h */
     COLUMN_COLOR_POINTER_TO,
 
     N_COLUMN_COLOR
@@ -142,7 +143,7 @@ static guint colorComboBox_signals[LAST_SIGNAL] = { 0 };
 struct _ColorComboBox
 {
   GtkComboBox comboColor;
-  Color* previouslySelectedColor;
+  ToolColor* previouslySelectedColor;
 
   gboolean withRanges;
   GtkWidget *expandRanges;
@@ -182,8 +183,8 @@ static void colorComboBox_addButtonClicked(GtkButton *button, gpointer data);
 
 /* Local methods. */
 static void addColorToModel(GtkTreeIter *iter, ColorComboBoxClass* klass,
-			    Color* color);
-static void onNewColorAvailable(GObject *obj, Color* newColor, gpointer data);
+			    ToolColor* color);
+static void onNewColorAvailable(GObject *obj, ToolColor* newColor, gpointer data);
 
 G_DEFINE_TYPE(ColorComboBox, colorComboBox, GTK_TYPE_COMBO_BOX)
 
@@ -197,7 +198,7 @@ static void colorComboBox_class_init(ColorComboBoxClass *klass)
   /**
    * ColorComboBox::color-selected:
    * @combo: the #ColorComboBox that emits the signal ;
-   * @color: the newly selected #Color.
+   * @color: the newly selected #ToolColor.
    *
    * This signal is emitted when a new valid colour is selected,
    * either an existing one or newly created one.
@@ -270,10 +271,10 @@ static void colorComboBox_class_init(ColorComboBoxClass *klass)
 					       G_CALLBACK(onNewColorAvailable),
 					       (gpointer)klass);
   DBG_fprintf(stderr, "                     - add stored colours.\n");
-  colorLst = colorGet_storedColors();
+  colorLst = tool_color_getStoredColors();
   while (colorLst)
     {
-      addColorToModel(&iter, klass, (Color*)colorLst->data);
+      addColorToModel(&iter, klass, (ToolColor*)colorLst->data);
       colorLst = g_list_next(colorLst);
     }
 
@@ -319,7 +320,7 @@ static void colorComboBox_init(ColorComboBox *colorComboBox)
 
   colorComboBox->hasAlphaChannel = TRUE;
   colorComboBox->dispose_has_run = FALSE;
-  colorComboBox->previouslySelectedColor = colorGet_byId(0);
+  colorComboBox->previouslySelectedColor = tool_color_getById(0);
 }
 
 static void buildWidgets(ColorComboBox *colorComboBox)
@@ -529,7 +530,8 @@ static void colorComboBox_changed(GtkWidget *widget _U_, ColorComboBox *colorCom
   float rgba[4];
   GtkTreeIter iter;
   GObjectClass *klass;
-  Color *color;
+  ToolColor *color;
+  GtkColorSelection *colorsel;
 
   selected = gtk_combo_box_get_active(GTK_COMBO_BOX(colorComboBox));
   DBG_fprintf(stderr, "Gtk ColorComboBox : internal combobox changed signal -> %d.\n", selected);
@@ -537,7 +539,7 @@ static void colorComboBox_changed(GtkWidget *widget _U_, ColorComboBox *colorCom
     {
       if (colorComboBox->withRanges)
 	gtk_widget_set_sensitive(colorComboBox->addButton, TRUE);
-      colorComboBox->previouslySelectedColor = (Color*)0;
+      colorComboBox->previouslySelectedColor = (ToolColor*)0;
       return;
     }
 
@@ -593,27 +595,31 @@ static void colorComboBox_changed(GtkWidget *widget _U_, ColorComboBox *colorCom
 
   /* Create the selection. */
   selection = gtk_color_selection_dialog_new(_("Select a color"));
-  gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(selection)->colorsel), colorComboBox->hasAlphaChannel);
+  colorsel = GTK_COLOR_SELECTION
+    (gtk_color_selection_dialog_get_color_selection
+     (GTK_COLOR_SELECTION_DIALOG(selection)));
+  gtk_color_selection_set_has_opacity_control(colorsel,
+					      colorComboBox->hasAlphaChannel);
 /*   createColorSelectionCustomList(GTK_COLOR_SELECTION_DIALOG(selection)); */
 
   /* Initialise its values. */
   if (colorComboBox->hasAlphaChannel)
-    gtk_color_selection_set_current_alpha(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(selection)->colorsel), alpha);
-  gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(selection)->colorsel), &gdkcolor);
+    gtk_color_selection_set_current_alpha(colorsel, alpha);
+  gtk_color_selection_set_current_color(colorsel, &gdkcolor);
 
   /* Run the dialog window. */
   code = gtk_dialog_run(GTK_DIALOG(selection));
   if (code == GTK_RESPONSE_OK || code == GTK_RESPONSE_ACCEPT)
     {
-      gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(selection)->colorsel), &gdkcolor);
+      gtk_color_selection_get_current_color(colorsel, &gdkcolor);
       rgba[0] = (float)gdkcolor.red / 65535.;
       rgba[1] = (float)gdkcolor.green / 65535.;
       rgba[2] = (float)gdkcolor.blue / 65535.;
-      rgba[3] = (float)gtk_color_selection_get_current_alpha(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(selection)->colorsel)) / 65535.;
+      rgba[3] = (float)gtk_color_selection_get_current_alpha(colorsel) / 65535.;
 
       klass = G_OBJECT_GET_CLASS(colorComboBox);
       g_signal_handler_block(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
-      color = colorAdd_floatRGBA(rgba, &selected);
+      color = tool_color_addFloatRGBA(rgba, &selected);
       g_signal_handler_unblock(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
       addColorToModel(&iter, COLOR_COMBOX_CLASS(klass), color);
       gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
@@ -662,7 +668,7 @@ static void colorComboBox_rgbChanged(GtkRange *rg, gpointer data)
   colorComboBox = COLOR_COMBOX(data);
   DBG_fprintf(stderr, "Gtk ColorComboBox : internal color range changed signal.\n");
   rgba = colorComboBoxGet_color(colorComboBox);
-  colorGet_byValues(&i, rgba[0], rgba[1], rgba[2], rgba[3]);
+  tool_color_getByValues(&i, rgba[0], rgba[1], rgba[2], rgba[3]);
   if (i < 0)
     gtk_combo_box_set_active(GTK_COMBO_BOX(colorComboBox), -1);
   else
@@ -684,7 +690,7 @@ static void colorComboBox_addButtonClicked(GtkButton *button _U_, gpointer data)
 {
   GtkTreeIter iter;
   GObjectClass *klass;
-  Color *color;
+  ToolColor *color;
   ColorComboBox *colorComboBox;
   float *rgba;
   int selected;
@@ -697,14 +703,14 @@ static void colorComboBox_addButtonClicked(GtkButton *button _U_, gpointer data)
   rgba = colorComboBoxGet_color(colorComboBox);
   klass = G_OBJECT_GET_CLASS(colorComboBox);
   g_signal_handler_block(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
-  color = colorAdd_floatRGBA(rgba, &selected);
+  color = tool_color_addFloatRGBA(rgba, &selected);
   g_signal_handler_unblock(VISU_INSTANCE, COLOR_COMBOX_CLASS(klass)->colorAddedSignalId);
   addColorToModel(&iter, COLOR_COMBOX_CLASS(klass), color);
   gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
   g_free(rgba);
 }
 
-GdkPixbuf* colorComboBoxBuild_colorStamp(Color *color, gboolean alpha)
+GdkPixbuf* colorComboBoxBuild_colorStamp(ToolColor *color, gboolean alpha)
 {
   GdkPixbuf *pixbufColorBox;
   int rowstride, x, y;
@@ -755,7 +761,7 @@ GdkPixbuf* colorComboBoxBuild_colorStamp(Color *color, gboolean alpha)
 }
 
 static void addColorToModel(GtkTreeIter *iter, ColorComboBoxClass* klass,
-			    Color* color)
+			    ToolColor* color)
 {
   char str[20], strAlpha[20];
   GdkPixbuf *pixbufColorBox;
@@ -784,13 +790,13 @@ static void addColorToModel(GtkTreeIter *iter, ColorComboBoxClass* klass,
 	      strAlpha, gtk_tree_model_get_string_from_iter(GTK_TREE_MODEL(COLOR_COMBOX_CLASS(klass)->listStoredColors), iter));
 }
 
-gboolean colorComboBoxSet_selectionByColor(ColorComboBox* colorComboBox, Color *color)
+gboolean colorComboBoxSet_selectionByColor(ColorComboBox* colorComboBox, ToolColor *color)
 {
   GtkTreeIter iter;
   gboolean validIter;
   GObjectClass *klass;
   GtkListStore *model;
-  Color *tmpColor;
+  ToolColor *tmpColor;
 
   g_return_val_if_fail(color && IS_COLOR_COMBOX(colorComboBox), FALSE);
 
@@ -803,7 +809,7 @@ gboolean colorComboBoxSet_selectionByColor(ColorComboBox* colorComboBox, Color *
       gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
 			 COLUMN_COLOR_POINTER_TO, &tmpColor,
 			 -1);
-      if (tmpColor && colorEqual_color(tmpColor, color))
+      if (tmpColor && tool_color_equal(tmpColor, color))
 	{
 	  gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
 	  return TRUE;
@@ -816,9 +822,9 @@ void colorComboBoxSet_color(ColorComboBox *colorComboBox, float rgba[4],
 			    gboolean raiseSignal)
 {
   int pos, i;
-  Color *color;
+  ToolColor *color;
 
-  color = colorGet_byValues(&pos, rgba[0], rgba[1], rgba[2], rgba[3]);
+  color = tool_color_getByValues(&pos, rgba[0], rgba[1], rgba[2], rgba[3]);
   if (!color)
     {
       gtk_combo_box_set_active(GTK_COMBO_BOX(colorComboBox), -1);
@@ -863,7 +869,7 @@ void colorComboBoxSet_color(ColorComboBox *colorComboBox, float rgba[4],
 }
 
 
-static void onNewColorAvailable(GObject *obj _U_, Color* newColor, gpointer data)
+static void onNewColorAvailable(GObject *obj _U_, ToolColor* newColor, gpointer data)
 {
   ColorComboBoxClass *klass;
   GtkTreeIter iter;
@@ -900,20 +906,20 @@ GdkPixbuf* colorComboBoxGet_selectedPixbuf(ColorComboBox *colorComboBox)
 		       -1);
   return pixbuf;
 }
-Color* colorComboBoxGet_selectedColor(ColorComboBox *colorComboBox)
+ToolColor* colorComboBoxGet_selectedColor(ColorComboBox *colorComboBox)
 {
   gboolean validIter;
   GtkTreeIter iter;
-  Color *color;
+  ToolColor *color;
   GObjectClass *klass;
 
-  g_return_val_if_fail(IS_COLOR_COMBOX(colorComboBox), (Color*)0);
+  g_return_val_if_fail(IS_COLOR_COMBOX(colorComboBox), (ToolColor*)0);
 
   validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
   if (!validIter)
-    return (Color*)0;
+    return (ToolColor*)0;
 
-  color = (Color*)0;
+  color = (ToolColor*)0;
   klass = G_OBJECT_GET_CLASS(colorComboBox);
   gtk_tree_model_get(GTK_TREE_MODEL(COLOR_COMBOX_CLASS(klass)->listStoredColors), &iter,
 		     COLUMN_COLOR_POINTER_TO, &color,
@@ -921,12 +927,12 @@ Color* colorComboBoxGet_selectedColor(ColorComboBox *colorComboBox)
   return color;
 }
 
-GdkPixbuf* colorComboBoxGet_pixbufFromColor(ColorComboBox *colorComboBox, Color *color)
+GdkPixbuf* colorComboBoxGet_pixbufFromColor(ColorComboBox *colorComboBox, ToolColor *color)
 {
   GtkTreeIter iter;
   gboolean validIter;
   GdkPixbuf *pixbuf;
-  Color *cl;
+  ToolColor *cl;
   GtkListStore *model;
 
   g_return_val_if_fail(colorComboBox && color, (GdkPixbuf*)0);
@@ -936,7 +942,7 @@ GdkPixbuf* colorComboBoxGet_pixbufFromColor(ColorComboBox *colorComboBox, Color
   while (validIter)
     {
       pixbuf = (GdkPixbuf*)0;
-      cl = (Color*)0;
+      cl = (ToolColor*)0;
       if (colorComboBox->hasAlphaChannel)
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
 			   COLUMN_COLOR_PIXBUF_ALPHA, &pixbuf,
@@ -947,7 +953,7 @@ GdkPixbuf* colorComboBoxGet_pixbufFromColor(ColorComboBox *colorComboBox, Color
 			   COLUMN_COLOR_PIXBUF, &pixbuf,
 			   COLUMN_COLOR_POINTER_TO, &cl,
 			   -1);
-      if (cl && colorEqual_color(color, cl))
+      if (cl && tool_color_equal(color, cl))
 	return pixbuf;
       validIter = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
     }
