@@ -46,9 +46,10 @@
 #include <visu_gtk.h>
 #include "gtk_dumpDialogWidget.h"
 #include <opengl.h>
+#include <support.h>
 
 /**
- * SECTION:dumpdialog
+ * SECTION:gtk_dumpDialogWidget
  * @short_description: Defines a widget to export into different file
  * formats.
  * 
@@ -86,11 +87,12 @@ struct _DumpDialog
 
   GtkWidget *hBoxOptions;
   GtkWidget *comboType;
-  DumpType  *selectedFileFormat;
-  GtkWidget *expanderFileFormat;
+  VisuDump  *selectedToolFileFormat;
+  GtkWidget *expanderToolFileFormat;
   GtkWidget *checkFileExtension;
   GtkWidget *spinWidth, *spinHeight;
 
+  GtkWidget *infoBar;
   GtkWidget *progressBar;
   GtkWidget *cancelButton;
 
@@ -118,14 +120,14 @@ struct _DumpDialogClass
 static void onWidthHeightChanged(GtkSpinButton *spin, gpointer data);
 static void onSpinPropertyChange(GtkSpinButton *spin, gpointer data);
 static void onCheckPropertyChange(GtkToggleButton *toggle, gpointer data);
-static void onComboFileFormatChange(GtkComboBox *combo, gpointer data);
+static void onComboToolFileFormatChange(GtkComboBox *combo, gpointer data);
 static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data);
 
 G_DEFINE_TYPE(DumpDialog, dumpDialog, GTK_TYPE_DIALOG)
 
 static void dumpDialog_class_init(DumpDialogClass *klass)
 {
-  DBG_fprintf(stderr, "Gtk DumpDialog : creating the class of the widget.\n");
+  DBG_fprintf(stderr, "Gtk DumpDialog: creating the class of the widget.\n");
 
   klass->width  = 0;
   klass->height = 0;
@@ -138,10 +140,10 @@ static void dumpDialog_class_init(DumpDialogClass *klass)
 
 static void dumpDialog_init(DumpDialog *dumpDialog)
 {
-  DBG_fprintf(stderr, "Gtk DumpDialog : initializing new object (%p).\n",
+  DBG_fprintf(stderr, "Gtk DumpDialog: initializing new object (%p).\n",
 	      (gpointer)dumpDialog);
 
-  dumpDialog->selectedFileFormat = (DumpType*)0;
+  dumpDialog->selectedToolFileFormat = (VisuDump*)0;
   dumpDialog->dumpFileName = (gchar*)0;
   dumpDialog->dataObj = (VisuData*)0;
 
@@ -185,32 +187,31 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 {
   DumpDialog *dumpDialog;
   DumpDialogClass *klass;
-  gchar *directory, *labelType;
-  const gchar *filename;
+  gchar *directory;
+  const gchar *filename, *labelType;
   GList *format;
   GtkWidget *hbox2, *hbox;
   GtkWidget *label;
   GtkWidget *wd;
   GtkWidget *vbox;
-  OpenGLView *view;
+  VisuOpenGLView *view;
 
   if (dataObj)
-    view = visuDataGet_openGLView(dataObj);
+    view = visu_data_getOpenGLView(dataObj);
   else
-    view = (OpenGLView*)0;
+    view = (VisuOpenGLView*)0;
 
   if (!parent)
     parent = visuGtkGet_render();
 
-  DBG_fprintf(stderr, "Gtk DumpDialog : creating a new DumpDialog object.\n");
+  DBG_fprintf(stderr, "Gtk DumpDialog: creating a new DumpDialog object.\n");
 
   dumpDialog = DUMP_DIALOG(g_object_new(DUMP_DIALOG_TYPE, NULL));
   gtk_window_set_title(GTK_WINDOW(dumpDialog),
 		       _("Export to a file (image, atomic structures...)"));
   klass = DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
-  gtk_dialog_set_has_separator(GTK_DIALOG(dumpDialog), FALSE);
   /* This is to avoid a bug in gtk 2.4 */
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_window_set_modal(GTK_WINDOW(dumpDialog), TRUE);
 #endif
   gtk_window_set_transient_for(GTK_WINDOW(dumpDialog), GTK_WINDOW(parent));
@@ -223,11 +224,11 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 
   /* Create the file chooser part. */
   dumpDialog->fileChooser = gtk_file_chooser_widget_new(GTK_FILE_CHOOSER_ACTION_SAVE);
-#if GTK_MINOR_VERSION > 7
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 7
   gtk_file_chooser_set_do_overwrite_confirmation
     (GTK_FILE_CHOOSER(dumpDialog->fileChooser), TRUE);
 #endif
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dumpDialog)->vbox),
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dumpDialog))),
 		     dumpDialog->fileChooser, TRUE, TRUE, 2);
   gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
 				       FALSE);
@@ -258,17 +259,18 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   label = gtk_label_new(_("Choose the file format : "));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-  dumpDialog->comboType = gtk_combo_box_new_text();
+  dumpDialog->comboType = gtk_combo_box_text_new();
   /* Set the combo entry that let V_Sim detect the desired format through the extension. */
-  gtk_combo_box_append_text(GTK_COMBO_BOX(dumpDialog->comboType), _("Autodetect format"));
+  gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(dumpDialog->comboType),
+                            (const gchar*)0, _("Autodetect format"));
   gtk_box_pack_start(GTK_BOX(hbox), dumpDialog->comboType, FALSE, FALSE, 0);
   /* Add an expander for file format options. */
-  dumpDialog->expanderFileFormat = gtk_expander_new(_("File format option:"));
-  gtk_widget_set_sensitive(dumpDialog->expanderFileFormat, FALSE);
+  dumpDialog->expanderToolFileFormat = gtk_expander_new(_("File format option:"));
+  gtk_widget_set_sensitive(dumpDialog->expanderToolFileFormat, FALSE);
   gtk_box_pack_start(GTK_BOX(vbox),
-		     dumpDialog->expanderFileFormat, FALSE, FALSE, 0);
+		     dumpDialog->expanderToolFileFormat, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(dumpDialog->comboType), "changed",
-		   G_CALLBACK(onComboFileFormatChange), (gpointer)dumpDialog);
+		   G_CALLBACK(onComboToolFileFormatChange), (gpointer)dumpDialog);
   /* Add a separator. */
   wd = gtk_vseparator_new();
   gtk_box_pack_start(GTK_BOX(dumpDialog->hBoxOptions),
@@ -318,14 +320,31 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   
   /* Create the progress bar part. */
   hbox2 = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dumpDialog)->vbox), hbox2, FALSE, FALSE, 2);
-  /* Label to introduce the rogress bar */
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dumpDialog))),
+		     hbox2, FALSE, FALSE, 2);
+  /* Label to introduce the progress bar */
   label = gtk_label_new(_("Dump progress : "));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
   gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
   dumpDialog->progressBar = gtk_progress_bar_new();
   gtk_box_pack_start(GTK_BOX(hbox2), dumpDialog->progressBar, TRUE, TRUE, 2);
 
+  /* Add an info bar for warning and so on. */
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17 
+  dumpDialog->infoBar = gtk_info_bar_new();
+  gtk_widget_set_no_show_all(dumpDialog->infoBar, TRUE);
+  gtk_info_bar_set_message_type(GTK_INFO_BAR(dumpDialog->infoBar),
+                                GTK_MESSAGE_WARNING);
+  label = gtk_label_new(_("Current box has translations applied,"
+                          " do you want to proceed to exportation anyway?"));
+  gtk_widget_show(label);
+  gtk_container_add
+    (GTK_CONTAINER(gtk_info_bar_get_content_area(GTK_INFO_BAR(dumpDialog->infoBar))),
+     label);
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dumpDialog))),
+		     dumpDialog->infoBar, FALSE, FALSE, 2);
+#endif
+
   /* Setting default values. */
   gtk_widget_set_name(GTK_WIDGET(dumpDialog), "filesel");
   directory = visuGtkGet_lastOpenDirectory();
@@ -335,17 +354,16 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   else if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
 					directory);
-  format = visuDumpGet_allModules();
-  while (format)
+  for (format = visu_dump_getAllModules(); format; format = g_list_next(format))
     {
-      labelType = fileFormatGet_label(((DumpType*)format->data)->fileType);
+      labelType = tool_file_format_getLabel(((VisuDump*)format->data)->fileType);
       if (labelType)
-	gtk_combo_box_append_text(GTK_COMBO_BOX(dumpDialog->comboType), labelType);
-      format = g_list_next(format);
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(dumpDialog->comboType),
+                                  (const gchar*)0, labelType);
     }
   gtk_combo_box_set_active(GTK_COMBO_BOX(dumpDialog->comboType), klass->formatId);
 
-  gtk_widget_show_all(GTK_DIALOG(dumpDialog)->vbox);
+  gtk_widget_show_all(GTK_WIDGET(dumpDialog));
   return GTK_WIDGET(dumpDialog);
 }
 
@@ -355,35 +373,43 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 /*******************/
 static void onSpinPropertyChange(GtkSpinButton *spin, gpointer data)
 {
-  fileFormatSet_propertyInteger((FileFormatProperty*)data,
-				(int)gtk_spin_button_get_value(spin));
+  GValue *val;
+
+  val = tool_option_getValue((ToolOption*)data);
+  g_value_set_int(val, (int)gtk_spin_button_get_value(spin));
 }
 static void onCheckPropertyChange(GtkToggleButton *toggle, gpointer data)
 {
-  fileFormatSet_propertyBoolean((FileFormatProperty*)data,
-				gtk_toggle_button_get_active(toggle));
+  GValue *val;
+
+  val = tool_option_getValue((ToolOption*)data);
+  g_value_set_boolean(val, gtk_toggle_button_get_active(toggle));
+  DBG_fprintf(stderr, "Gtk DumpDialog: set property '%s' to %d.\n",
+              tool_option_getName((ToolOption*)data), g_value_get_boolean(val));
 }
-static void onComboFileFormatChange(GtkComboBox *combo, gpointer data)
+static void onComboToolFileFormatChange(GtkComboBox *combo, gpointer data)
 {
   int formatInt, i;
-  GList *dumpTypes, *formatProperties;
+  GList *dumpTypes;
+  const GList *formatProperties;
   GtkWidget *wd, *label, *hbox, *vbox;
+  GValue *val;
 
   g_return_if_fail(IS_DUMP_DIALOG(data));
 
   /* Empty the expander for properties. */
-  wd = gtk_bin_get_child(GTK_BIN(DUMP_DIALOG(data)->expanderFileFormat));
+  wd = gtk_bin_get_child(GTK_BIN(DUMP_DIALOG(data)->expanderToolFileFormat));
   if (wd)
     gtk_widget_destroy(wd);
 
-  dumpTypes = visuDumpGet_allModules();
+  dumpTypes = visu_dump_getAllModules();
   formatInt = gtk_combo_box_get_active(combo);
   DUMP_DIALOG_GET_CLASS(data)->formatId = (guint)formatInt;
-  DBG_fprintf(stderr, "Gtk DumpDialog : On file format change (%d).\n", formatInt);
+  DBG_fprintf(stderr, "Gtk DumpDialog: On file format change (%d).\n", formatInt);
   /* Select auto file format -> no properties. */
   if (formatInt == 0)
     {
-      gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderFileFormat, FALSE);
+      gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderToolFileFormat, FALSE);
       gtk_widget_set_sensitive(DUMP_DIALOG(data)->checkFileExtension, FALSE);
       return;
     }
@@ -393,64 +419,55 @@ static void onComboFileFormatChange(GtkComboBox *combo, gpointer data)
   /* Set the check box for extension auto completion. */
   gtk_widget_set_sensitive(DUMP_DIALOG(data)->checkFileExtension, TRUE);
   /* Get properties if exist for this format. */
-  formatProperties = fileFormatGet_propertiesList(((DumpType*)(dumpTypes->data))->fileType);
+  formatProperties = tool_file_format_getPropertyList(((VisuDump*)(dumpTypes->data))->fileType);
   if (!formatProperties)
     {
-      gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderFileFormat, FALSE);
+      gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderToolFileFormat, FALSE);
       return;
     }
-  gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderFileFormat, TRUE);
+  gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderToolFileFormat, TRUE);
   vbox = gtk_vbox_new(FALSE, 0);
-  gtk_widget_show(vbox);
-  gtk_container_add(GTK_CONTAINER(DUMP_DIALOG(data)->expanderFileFormat), vbox);
+  gtk_container_add(GTK_CONTAINER(DUMP_DIALOG(data)->expanderToolFileFormat), vbox);
   while (formatProperties)
     {
       hbox = gtk_hbox_new(FALSE, 0);
-      gtk_widget_show(hbox);
       gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-      label = gtk_label_new(fileFormatGet_propertyLabelUTF8((FileFormatProperty*)
-							    (formatProperties->data)));
+      label = gtk_label_new(tool_option_getLabel((ToolOption*)formatProperties->data));
       gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
       gtk_misc_set_padding(GTK_MISC(label), 10, 0);
-      gtk_widget_show(label);
       gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-      switch (fileFormatGet_propertyType((FileFormatProperty*)
-					 (formatProperties->data)))
+      val = tool_option_getValue((ToolOption*)formatProperties->data);
+      switch (tool_option_getType((ToolOption*)formatProperties->data))
 	{
-	case fileFormat_type_integer:
+	case G_TYPE_INT:
 	  wd = gtk_spin_button_new_with_range(0., 100., 1.);
-	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(wd),
-				    (gdouble)fileFormatGet_propertyInteger((FileFormatProperty*)
-									   (formatProperties->data)));
-	  gtk_widget_show(wd);
+	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(wd), (gdouble)g_value_get_int(val));
 	  gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
 	  g_signal_connect(G_OBJECT(wd), "value-changed",
-			   G_CALLBACK(onSpinPropertyChange), (gpointer)(formatProperties->data));
+			   G_CALLBACK(onSpinPropertyChange), formatProperties->data);
 	  break;
-	case fileFormat_type_boolean:
+	case G_TYPE_BOOLEAN:
 	  wd = gtk_check_button_new();
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wd),
-				       fileFormatGet_propertyBoolean((FileFormatProperty*)
-								     (formatProperties->data)));
-	  gtk_widget_show(wd);
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wd), g_value_get_boolean(val));
 	  gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
 	  g_signal_connect(G_OBJECT(wd), "toggled",
-			   G_CALLBACK(onCheckPropertyChange), (gpointer)(formatProperties->data));
+			   G_CALLBACK(onCheckPropertyChange), formatProperties->data);
 	  break;
 	default:
 	  g_warning("Unknown, or nsupprted file format property"
-		    " given to 'onComboFileFormatChange'.");
+		    " given to 'onComboToolFileFormatChange'.");
 	};
 
       formatProperties = g_list_next(formatProperties);
     }
+  gtk_widget_show_all(vbox);
   /* Expand the option expander. */
-  gtk_expander_set_expanded(GTK_EXPANDER(DUMP_DIALOG(data)->expanderFileFormat), TRUE);
+  gtk_expander_set_expanded(GTK_EXPANDER(DUMP_DIALOG(data)->expanderToolFileFormat), TRUE);
 }
 static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 {
   gchar *filename;
-  int formatInt, i;
+  int formatInt;
   gchar *ext, *pattern;
   GList *dumpTypes;
   DumpDialog *dumpDialog;
@@ -482,15 +499,15 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 
   if (formatInt >= 0)
     {
-      dumpTypes = visuDumpGet_allModules();
+      dumpTypes = visu_dump_getAllModules();
       if (formatInt == 0)
 	/* The automatic format has been selected, we look in the pattern list to
 	   find a matching pattern. */
-	while (dumpTypes && !fileFormatUse_match( ((DumpType*)dumpTypes->data)->fileType,
-						  filename))
+	while (dumpTypes && !tool_file_format_match
+               ( ((VisuDump*)dumpTypes->data)->fileType, filename))
 	  dumpTypes = g_list_next(dumpTypes);
       else
-	for(i = 0; i < formatInt - 1; i++) dumpTypes = g_list_next(dumpTypes);
+        dumpTypes = g_list_nth(dumpTypes, formatInt - 1);
       if (!dumpTypes)
 	{
 	  /* Autodetect failed, no format match the given filename */
@@ -501,14 +518,30 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 	  g_signal_stop_emission_by_name(G_OBJECT(dumpDialog), "response");
 	  return;
 	}
+      DBG_fprintf(stderr, "Gtk DumpDialog: export to dump %p.\n", dumpTypes->data);
+
+      /* Special warning for non bitmap exportation with translations. */
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17
+      if (!((VisuDump*)dumpTypes->data)->bitmap &&
+          visu_data_getTranslationStatus(dumpDialog->dataObj) &&
+          !gtk_widget_get_visible(dumpDialog->infoBar))
+        {
+          gtk_widget_show(dumpDialog->infoBar);
+	  g_free(filename);
+	  g_signal_stop_emission_by_name(G_OBJECT(dumpDialog), "response");
+	  return;
+        }
+#endif
       
       if (formatInt > 0 &&
 	  gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dumpDialog->checkFileExtension)))
 	{
-	  if (!fileFormatUse_match( ((DumpType*)dumpTypes->data)->fileType,
-				    filename))
+	  if (tool_file_format_canMatch(((VisuDump*)dumpTypes->data)->fileType) &&
+              !tool_file_format_match( ((VisuDump*)dumpTypes->data)->fileType,
+                                       filename))
 	    {
-	      pattern = (gchar*)(((DumpType*)dumpTypes->data)->fileType->fileType->data);
+	      pattern = (gchar*) tool_file_format_getFilePatterns
+                (((VisuDump*)dumpTypes->data)->fileType)->data;
 	      ext = g_strrstr(pattern, ".");
 	      dumpDialog->dumpFileName = g_strdup_printf("%s%s", filename, ext);
 	      g_free(filename);
@@ -518,9 +551,9 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 	}
       else
 	dumpDialog->dumpFileName = filename;
-      dumpDialog->selectedFileFormat = (DumpType*)dumpTypes->data;
-      DBG_fprintf(stderr, "Gtk DumpDialog : '%s' file format chosen.\n",
-		  dumpDialog->selectedFileFormat->fileType->description);
+      dumpDialog->selectedToolFileFormat = (VisuDump*)dumpTypes->data;
+      DBG_fprintf(stderr, "Gtk DumpDialog: '%s' file format chosen.\n",
+		  tool_file_format_getName(dumpDialog->selectedToolFileFormat->fileType));
       /* Save the filename in a property of the VisuData object. */
       filename = g_path_get_basename(dumpDialog->dumpFileName);
       g_object_set_data_full(G_OBJECT(dumpDialog->dataObj), "dumpDialog_filename",
@@ -546,18 +579,18 @@ gchar* dumpDialogGet_fileName(DumpDialog *dialog)
   g_return_val_if_fail(dialog, (gchar*)0);
   return dialog->dumpFileName;
 }
-DumpType* dumpDialogGet_dumpType(DumpDialog *dialog)
+VisuDump* dumpDialogGet_dumpType(DumpDialog *dialog)
 {
-  g_return_val_if_fail(dialog, (DumpType*)0);
-  return dialog->selectedFileFormat;
+  g_return_val_if_fail(dialog, (VisuDump*)0);
+  return dialog->selectedToolFileFormat;
 }
-FileFormat* dumpDialogGet_fileFormat(DumpDialog *dialog)
+ToolFileFormat* dumpDialogGet_fileFormat(DumpDialog *dialog)
 {
-  g_return_val_if_fail(dialog, (FileFormat*)0);
-  if (dialog->selectedFileFormat)
-    return dialog->selectedFileFormat->fileType;
+  g_return_val_if_fail(dialog, (ToolFileFormat*)0);
+  if (dialog->selectedToolFileFormat)
+    return dialog->selectedToolFileFormat->fileType;
   else
-    return (FileFormat*)0;
+    return (ToolFileFormat*)0;
 }
 GtkProgressBar* dumpDialogGet_progressBar(DumpDialog *dialog)
 {
