@@ -54,35 +54,45 @@
 
 G_BEGIN_DECLS
 /**
- * DUMP_DIALOG_TYPE
+ * DUMP_DIALOG_TYPE:
  *
  * Return the associated #GType to the DumpDialog objects.
  */
 #define DUMP_DIALOG_TYPE         (dumpDialog_get_type ())
 /**
  * DUMP_DIALOG:
+ * @obj: the widget to cast.
  *
  * Cast the given object to a #DumpDialog object.
  */
 #define DUMP_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), DUMP_DIALOG_TYPE, DumpDialog))
 /**
- * DUMP_DIALOG_CLASS
+ * DUMP_DIALOG_CLASS:
+ * @klass: the class to cast.
  *
  * Cast the given class to a #DumpDialogClass object.
  */
 #define DUMP_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DUMP_DIALOG_TYPE, DumpDialogClass))
 /**
- * IS_DUMP_DIALOG
+ * IS_DUMP_DIALOG:
+ * @obj: the object to test.
  *
  * Return if the given object is a valid #DumpDialog object.
  */
 #define IS_DUMP_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DUMP_DIALOG_TYPE))
 /**
- * IS_DUMP_DIALOG_CLASS
+ * IS_DUMP_DIALOG_CLASS:
+ * @klass: the class to test.
  *
  * Return if the given class is a valid #DumpDialogClass class.
  */
 #define IS_DUMP_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DUMP_DIALOG_TYPE))
+/**
+ * DUMP_DIALOG_GET_CLASS:
+ * @obj: the widget to get the class of.
+ *
+ * Get the class of the given object.
+ */
 #define DUMP_DIALOG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, DUMP_DIALOG_TYPE, DumpDialogClass))
 
 /**
@@ -136,20 +146,20 @@ gchar* dumpDialogGet_fileName(DumpDialog *dialog);
  * dumpDialogGet_dumpType:
  * @dialog: a #DumpDialog object.
  *
- * Retrieve the chosen DumpType.
+ * Retrieve the chosen VisuDump.
  *
- * Returns: the selected format (FileFormat and write method).
+ * Returns: the selected format (ToolFileFormat and write method).
  */
-DumpType* dumpDialogGet_dumpType(DumpDialog *dialog);
+VisuDump* dumpDialogGet_dumpType(DumpDialog *dialog);
 /**
  * dumpDialogGet_fileFormat:
  * @dialog: a #DumpDialog object.
  *
  * Retrieve the chosen fileFormat.
  *
- * Returns: the selected format, only FileFormat.
+ * Returns: the selected format, only ToolFileFormat.
  */
-FileFormat* dumpDialogGet_fileFormat(DumpDialog *dialog);
+ToolFileFormat* dumpDialogGet_fileFormat(DumpDialog *dialog);
 /**
  * dumpDialogGet_progressBar:
  * @dialog: a #DumpDialog object.
