@@ -41,12 +41,12 @@
 	knowledge of the CeCILL license and that you accept its terms. You can
 	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
 */
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 
 #include "gtk_numericalEntryWidget.h"
 
 /**
- * SECTION:numericalentry
+ * SECTION:gtk_numericalEntryWidget
  * @short_description: Defines a widget to enter numerical values without
  * any boundary or precision constrains.
  * 
