@@ -50,7 +50,7 @@
 #include <coreTools/toolConfigFile.h>
 
 /**
- * SECTION:shadecombobox
+ * SECTION:gtk_shadeComboBoxWidget
  * @short_description: Defines a specialised #GtkComboBox to choose
  * pre-built shades.
  * @see_also: #StippleComboBox, #Shade
@@ -137,7 +137,7 @@ static void shadeComboBox_changed(GtkWidget *widget, ShadeComboBox *shadeComboBo
 /* Local methods. */
 static void addShadeToModel(GtkTreeIter *iter, ShadeComboBoxClass* klass,
 			    Shade* shade);
-static void buildWidgets(ShadeComboBox *shadeComboBox);
+static void buildWidgets(ShadeComboBox *shadeComboBox, gboolean showNames);
 static gboolean readFavShade(gchar **lines, int nbLines, int position,
 			     VisuData *dataObj, GError **error);
 static void exportParameters(GString *data, VisuData* dataObj);
@@ -150,7 +150,7 @@ static void shadeComboBox_class_init(ShadeComboBoxClass *klass)
   GList *shadeLst;
   VisuConfigFileEntry *resourceEntry;
   
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : creating the class of the widget.\n");
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: creating the class of the widget.\n");
   DBG_fprintf(stderr, "                     - adding new signals ;\n");
   /**
    * ShadeComboBox::shade-selected:
@@ -187,12 +187,12 @@ static void shadeComboBox_class_init(ShadeComboBoxClass *klass)
   klass->favShade = 0;
 
   /* Dealing with parameters. */
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_FAVSHADE,
 					  DESC_PARAMETER_FAVSHADE,
 					  1, readFavShade);
-  visuConfigFileSet_version(resourceEntry, 3.5f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(resourceEntry, 3.5f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParameters);
 
   /* Connect freeing methods. */
@@ -204,7 +204,7 @@ static void shadeComboBox_class_init(ShadeComboBoxClass *klass)
 
 static void shadeComboBox_dispose(GObject *obj)
 {
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : dispose object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: dispose object %p.\n", (gpointer)obj);
 
   if (SHADE_COMBOX(obj)->dispose_has_run)
     return;
@@ -217,7 +217,7 @@ static void shadeComboBox_finalize(GObject *obj)
 {
   g_return_if_fail(obj);
 
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : finalize object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: finalize object %p.\n", (gpointer)obj);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(shadeComboBox_parent_class)->finalize(obj);
@@ -228,7 +228,7 @@ static void shadeComboBox_finalize(GObject *obj)
 
 static void shadeComboBox_init(ShadeComboBox *shadeComboBox)
 {
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : initializing new object (%p).\n",
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: initializing new object (%p).\n",
 	      (gpointer)shadeComboBox);
 
   shadeComboBox->hasAlphaChannel = TRUE;
@@ -236,7 +236,7 @@ static void shadeComboBox_init(ShadeComboBox *shadeComboBox)
   shadeComboBox->previouslySelectedShade = (Shade*)0;
 }
 
-static void buildWidgets(ShadeComboBox *shadeComboBox)
+static void buildWidgets(ShadeComboBox *shadeComboBox, gboolean showNames)
 {
   GObjectClass *klass;
   GtkCellRenderer *renderer;
@@ -249,16 +249,19 @@ static void buildWidgets(ShadeComboBox *shadeComboBox)
   gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(shadeComboBox), renderer, FALSE);
   gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(shadeComboBox), renderer,
 				"pixbuf", COLUMN_SHADE_PIXBUF);
-  renderer = gtk_cell_renderer_text_new();
-  g_object_set(G_OBJECT(renderer), "foreground", "#505050", NULL);
-  g_object_set(G_OBJECT(renderer), "xpad", 3, NULL);
-  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(shadeComboBox), renderer, FALSE);
-  gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(shadeComboBox), renderer,
-				"markup", COLUMN_SHADE_ID);
-  renderer = gtk_cell_renderer_text_new();
-  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(shadeComboBox), renderer, FALSE);
-  gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(shadeComboBox), renderer,
-				"text", COLUMN_SHADE_LABEL);
+  if (showNames)
+    {
+      renderer = gtk_cell_renderer_text_new();
+      g_object_set(G_OBJECT(renderer), "foreground", "#505050", NULL);
+      g_object_set(G_OBJECT(renderer), "xpad", 3, NULL);
+      gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(shadeComboBox), renderer, FALSE);
+      gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(shadeComboBox), renderer,
+				    "markup", COLUMN_SHADE_ID);
+      renderer = gtk_cell_renderer_text_new();
+      gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(shadeComboBox), renderer, FALSE);
+      gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(shadeComboBox), renderer,
+				    "text", COLUMN_SHADE_LABEL);
+    }
 
   if ((gint)SHADE_COMBOX_CLASS(klass)->favShade < gtk_tree_model_iter_n_children
       (GTK_TREE_MODEL(SHADE_COMBOX_CLASS(klass)->listStoredShades), (GtkTreeIter*)0))
@@ -270,19 +273,19 @@ static void buildWidgets(ShadeComboBox *shadeComboBox)
 		   G_CALLBACK(shadeComboBox_changed), (gpointer)shadeComboBox);
 }
 
-GtkWidget* shadeComboBox_new(gboolean hasAlphaChannel)
+GtkWidget* shadeComboBox_new(gboolean hasAlphaChannel, gboolean showNames)
 {
   ShadeComboBox *shadeComboBox;
 
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : creating new object with alpha : %d.\n",
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: creating new object with alpha: %d.\n",
 	      hasAlphaChannel);
 
   shadeComboBox = SHADE_COMBOX(g_object_new(shadeComboBox_get_type (), NULL));
   shadeComboBox->hasAlphaChannel = hasAlphaChannel;
 
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : build widgets.\n");
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: build widgets.\n");
 
-  buildWidgets(shadeComboBox);
+  buildWidgets(shadeComboBox, showNames);
 
   return GTK_WIDGET(shadeComboBox);
 }
@@ -295,11 +298,11 @@ static void shadeComboBox_changed(GtkWidget *widget _U_, ShadeComboBox *shadeCom
   Shade *shade;
 
   selected = gtk_combo_box_get_active(GTK_COMBO_BOX(shadeComboBox));
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : internal combobox changed signal -> %d.\n", selected);
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: internal combobox changed signal -> %d.\n", selected);
   if (selected < 0)
     {
       shadeComboBox->previouslySelectedShade = (Shade*)0;
-/*       DBG_fprintf(stderr, "Gtk ShadeComboBox : emitting 'shade-selected' signal.\n"); */
+/*       DBG_fprintf(stderr, "Gtk ShadeComboBox: emitting 'shade-selected' signal.\n"); */
 /*       g_signal_emit(G_OBJECT(shadeComboBox), */
 /* 		    shadeComboBox_signals[SHADE_SELECTED_SIGNAL], 0, (gpointer)0, NULL); */
       return;
@@ -313,12 +316,12 @@ static void shadeComboBox_changed(GtkWidget *widget _U_, ShadeComboBox *shadeCom
   if (shade != shadeComboBox->previouslySelectedShade)
     {
       shadeComboBox->previouslySelectedShade = shade;
-      DBG_fprintf(stderr, "Gtk ShadeComboBox : emitting 'shade-selected' signal.\n");
+      DBG_fprintf(stderr, "Gtk ShadeComboBox: emitting 'shade-selected' signal.\n");
       g_signal_emit(G_OBJECT(shadeComboBox),
 		    shadeComboBox_signals[SHADE_SELECTED_SIGNAL], 0, (gpointer)shade, NULL);
     }
   else
-    DBG_fprintf(stderr, "Gtk ShadeComboBox : aborting 'shade-selected' signal.\n");
+    DBG_fprintf(stderr, "Gtk ShadeComboBox: aborting 'shade-selected' signal.\n");
 }
 
 GdkPixbuf* shadeComboBoxBuild_shadeStamp(Shade *shade, GdkPixbuf *pixbuf)
@@ -385,7 +388,7 @@ static void addShadeToModel(GtkTreeIter *iter, ShadeComboBoxClass* klass,
 
   g_return_if_fail(iter && klass && shade);
 
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : appending a new shade '%s'.\n",
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: appending a new shade '%s'.\n",
 	      shadeGet_label(shade));
   gtk_list_store_append(klass->listStoredShades, iter);
   path = gtk_tree_model_get_path(GTK_TREE_MODEL(klass->listStoredShades), iter);
@@ -399,7 +402,7 @@ static void addShadeToModel(GtkTreeIter *iter, ShadeComboBoxClass* klass,
 		     COLUMN_SHADE_POINTER_TO  , (gpointer)shade,
 		     -1);
   g_free(idLbl);
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : appending a new shade '%s' at position '%s'.\n",
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: appending a new shade '%s' at position '%s'.\n",
 	      shadeGet_label(shade), gtk_tree_model_get_string_from_iter
 	      (GTK_TREE_MODEL(SHADE_COMBOX_CLASS(klass)->listStoredShades), iter));
 }
@@ -412,13 +415,19 @@ gboolean shadeComboBoxSet_selectionByShade(ShadeComboBox* shadeComboBox, Shade *
   GtkListStore *model;
   Shade *tmpShade;
 
-  g_return_val_if_fail(shade && IS_SHADE_COMBOX(shadeComboBox), FALSE);
+  g_return_val_if_fail(IS_SHADE_COMBOX(shadeComboBox), FALSE);
+
+  DBG_fprintf(stderr, "Gtk ShadeComboBox: select a new shade %p.\n", (gpointer)shade);
+  if (!shade)
+    {
+      gtk_combo_box_set_active(GTK_COMBO_BOX(shadeComboBox), -1);
+      return TRUE;
+    }
 
-  DBG_fprintf(stderr, "Gtk ShadeComboBox : select a new shade %p.\n", (gpointer)shade);
   klass = G_OBJECT_GET_CLASS(shadeComboBox);
   model = GTK_LIST_STORE(SHADE_COMBOX_CLASS(klass)->listStoredShades);
-  validIter = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
-  while (validIter)
+  for (validIter = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+       validIter; validIter = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter))
     {
       gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
 			 COLUMN_SHADE_POINTER_TO, &tmpShade,
@@ -428,7 +437,6 @@ gboolean shadeComboBoxSet_selectionByShade(ShadeComboBox* shadeComboBox, Shade *
 	  gtk_combo_box_set_active_iter(GTK_COMBO_BOX(shadeComboBox), &iter);
 	  return TRUE;
 	}
-      validIter = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
     }
   return FALSE;
 }
@@ -509,11 +517,11 @@ static gboolean readFavShade(gchar **lines, int nbLines, int position,
   g_return_val_if_fail(my_class, FALSE);
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_integer(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readInteger(lines[0], position, &val, 1, error))
     return FALSE;
   if (val < 0)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: prefered shade must be positive.\n"),
 			   position);
       return FALSE;
