@@ -53,10 +53,9 @@
 #include <gtk_main.h>
 #include <visu_gtk.h>
 #include <gtk_renderingWindowWidget.h>
-#include "renderingBackend/visu_windowInterface.h"
 
 /**
- * SECTION:toolpanel
+ * SECTION:gtk_toolPanelWidget
  * @short_description: Defines a widget that hold a set of V_Sim panel.
  * 
  * <para>This widget is a complex association of a #GtkComboBox and a
@@ -201,8 +200,8 @@ static void onMainMenuShowClicked(GtkMenuItem *menuitem, gpointer user_data);
 static void onMainMenuHideClicked(GtkMenuItem *menuitem, gpointer user_data);
 static void onMainMenuSelected(GtkMenuShell *menushell, gpointer user_data);
 static gboolean onKillDockWindowEvent(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-static void onPageChanged(GtkNotebook *book, GtkNotebookPage *page,
-			  guint num, gpointer data);
+static void onPageChanged(GtkNotebook *book, GtkWidget *child,
+			  gint num, gpointer data);
 static void onComboChanged(GtkComboBox *combo, gpointer data);
 
 static void toolPanel_class_init(ToolPanelClass *klass)
@@ -283,6 +282,8 @@ static void toolPanel_finalize(GObject *obj)
     g_free(toolPanel->tabLabel);
   if (toolPanel->id)
     g_free(toolPanel->id);
+  if (toolPanel->headerWidget)
+    g_object_unref(toolPanel->headerWidget);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(toolPanel_parent_class)->finalize(obj);
@@ -363,7 +364,7 @@ GtkWidget* toolPanelNew_withIconFromStock(gchar *id, gchar* name, gchar *tabName
 GtkWidget* toolPanelGet_headerWidget(ToolPanel *toolPanel)
 {
   GtkWidget *label, *wd, *image, *align;
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 #endif
 
@@ -373,7 +374,7 @@ GtkWidget* toolPanelGet_headerWidget(ToolPanel *toolPanel)
      we do it now. */
   if (!toolPanel->headerWidget)
     {
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
       tooltips = gtk_tooltips_new ();
 #endif
 
@@ -457,7 +458,7 @@ GtkWindow* toolPanelGet_containerWindow(ToolPanel *toolPanel)
       if (toolPanel->container->window)
 	return GTK_WINDOW(toolPanel->container->window);
       else
-	return GTK_WINDOW(gtkMainClassGet_currentPanel());
+	return GTK_WINDOW(visu_uiMainClass_getCurrentPanel());
     }
   else
     return (GtkWindow*)0;
@@ -643,7 +644,7 @@ static DockWindow* buildDockWindow(gchar *name, gboolean withWindow)
   GtkWidget *wd, *image, *align;
   GtkCellRenderer *renderer;
 /*   GtkBindingSet *keys; */
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
@@ -697,7 +698,7 @@ static DockWindow* buildDockWindow(gchar *name, gboolean withWindow)
 
   /* Define the key bindings. */
 /*   keys = gtk_binding_set_new("commandPanel"); */
-/*   gtk_binding_entry_add_signal(keys, GDK_space, 0, "clicked", 1, (gpointer)window); */
+/*   gtk_binding_entry_add_signal(keys, GDK_KEY_space, 0, "clicked", 1, (gpointer)window); */
 
   /* Raise render area. */
   wd = gtk_button_new();
@@ -797,25 +798,25 @@ static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
 			      gpointer data)
 {
   DBG_fprintf(stderr, "Gtk ToolPanel: get key pressed.\n");
-  if(event->keyval == GDK_Home)
+  if(event->keyval == GDK_KEY_Home)
     {
       onRaiseButtonClicked((GtkButton*)0, data);
       return TRUE;
     }
   return FALSE;
 }
-static void onPageChanged(GtkNotebook *book, GtkNotebookPage *page _U_,
-			  guint num, gpointer data)
+static void onPageChanged(GtkNotebook *book, GtkWidget *child,
+			  gint num, gpointer data)
 {
-  GtkWidget *wd;
   DockWindow *window;
   int numOld;
+#if GTK_MAJOR_VERSION == 2
+  child = gtk_notebook_get_nth_page(book, num);
+#endif
 
   window = (DockWindow*)data;
   g_return_if_fail(window);
-
-  wd = gtk_notebook_get_nth_page(book, num);
-  g_return_if_fail(IS_TOOL_PANEL(wd));
+  g_return_if_fail(IS_TOOL_PANEL(child));
 
   DBG_fprintf(stderr, "Gtk ToolPanel: caught 'page-switch' signal, jump to %d.\n", num);
   /* Change the visibility of the header labels. */
@@ -838,7 +839,7 @@ static void onPageChanged(GtkNotebook *book, GtkNotebookPage *page _U_,
   gtk_combo_box_set_active(GTK_COMBO_BOX(window->combo), num);
   g_signal_handler_unblock(G_OBJECT(window->combo), window->comboChanged);
 
-  g_idle_add(emitPageEnter, wd);
+  g_idle_add(emitPageEnter, child);
 }
 
 static void onComboChanged(GtkComboBox *combo, gpointer data)
@@ -1121,7 +1122,7 @@ static void onRaiseButtonClicked(GtkButton *button _U_, gpointer data _U_)
 /* Class methods. */
 /******************/
 
-DockWindow* toolPanelClassGet_commandPanel()
+DockWindow* toolPanelClassGet_commandPanel(void)
 {
   GObject *dummy;
 
@@ -1169,8 +1170,9 @@ void toolPanelClassSet_windowSize(const gchar *id, guint width, guint height)
 
   /* Before setting (width, height), we check that it is coherent with
      the screen size. */
-  if (GDK_IS_DRAWABLE(dock->window->window))
-    screen = gdk_drawable_get_screen(GDK_DRAWABLE(dock->window->window));
+  if (gtk_widget_is_drawable(dock->window))
+    screen = gdk_window_get_screen
+      (GDK_WINDOW(gtk_widget_get_window(dock->window)));
   else
     screen = gdk_screen_get_default();
   widthScreen = gdk_screen_get_width(screen);
@@ -1200,8 +1202,9 @@ void toolPanelClassSet_windowPosition(const gchar *id, guint x, guint y)
 
   /* Before setting (x, y), we check that it is coherent with
      the screen definition. */
-  if (GDK_IS_DRAWABLE(dock->window->window))
-    screen = gdk_drawable_get_screen(GDK_DRAWABLE(dock->window->window));
+  if (gtk_widget_is_drawable(dock->window))
+    screen = gdk_window_get_screen
+      (GDK_WINDOW(gtk_widget_get_window(dock->window)));
   else
     screen = gdk_screen_get_default();
   xScreen = gdk_screen_get_width(screen);
@@ -1284,7 +1287,7 @@ DockWindow* toolPanelClassGet_container(const gchar *id)
 
   return window;
 }
-GList* toolPanelClassGet_allToolPanels()
+GList* toolPanelClassGet_allToolPanels(void)
 {
   GObject *dummy;
   GList *tmplst, *returnlst;
@@ -1319,7 +1322,7 @@ GList* toolPanelClassGet_allToolPanels()
   returnlst = g_list_concat(returnlst, g_list_copy(local_class->orphanToolPanel));
   return returnlst;
 }
-GList* toolPanelClassGet_allWindows()
+GList* toolPanelClassGet_allWindows(void)
 {
   GObject *dummy;
   GList *returnlst;
@@ -1397,5 +1400,5 @@ GtkWidget* dockWindowGet_window(DockWindow *dock)
   if (dock->window)
     return dock->window;
   else
-    return GTK_WIDGET(gtkMainClassGet_currentPanel());
+    return GTK_WIDGET(visu_uiMainClass_getCurrentPanel());
 }
