@@ -52,31 +52,35 @@
 
 G_BEGIN_DECLS
 /**
- * TOOL_PANEL_TYPE
+ * TOOL_PANEL_TYPE:
  *
  * Return the associated #GType to the ToolPanel objects.
  */
 #define TOOL_PANEL_TYPE         (toolPanel_get_type ())
 /**
  * TOOL_PANEL:
+ * @obj: the widget to cast.
  *
  * Cast the given object to a #ToolPanel object.
  */
 #define TOOL_PANEL(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), TOOL_PANEL_TYPE, ToolPanel))
 /**
- * TOOL_PANEL_CLASS
+ * TOOL_PANEL_CLASS:
+ * @klass: the class to cast.
  *
  * Cast the given class to a #ToolPanelClass object.
  */
 #define TOOL_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TOOL_PANEL_TYPE, ToolPanelClass))
 /**
- * IS_TOOL_PANEL
+ * IS_TOOL_PANEL:
+ * @obj: the object to test.
  *
  * Return if the given object is a valid #ToolPanel object.
  */
 #define IS_TOOL_PANEL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TOOL_PANEL_TYPE))
 /**
- * IS_TOOL_PANEL_CLASS
+ * IS_TOOL_PANEL_CLASS:
+ * @klass: the class to test.
  *
  * Return if the given class is a valid #ToolPanelClass class.
  */
@@ -353,7 +357,7 @@ void toolPanelClassSet_headerVisibility(gboolean status);
  *
  * Returns: the #DockWindow that is inside the command panel.
  */
-DockWindow* toolPanelClassGet_commandPanel();
+DockWindow* toolPanelClassGet_commandPanel(void);
 /**
  * toolPanelClassGet_container:
  * @id: a #DockWindow identifier.
@@ -381,7 +385,7 @@ ToolPanel* toolPanelClassGet_toolPanelById(const gchar *id);
  *
  * Returns: a newly created list (use g_list_free() on it after use).
  */
-GList* toolPanelClassGet_allToolPanels();
+GList* toolPanelClassGet_allToolPanels(void);
 /**
  * toolPanelClassGet_allWindows:
  *
@@ -389,7 +393,7 @@ GList* toolPanelClassGet_allToolPanels();
  *
  * Returns: a newly created list (use g_list_free() on it after use).
  */
-GList* toolPanelClassGet_allWindows();
+GList* toolPanelClassGet_allWindows(void);
 /**
  * toolPanelClassGet_windowCharacteristics:
  * @dock: a #DockWindow object ;
