@@ -51,6 +51,12 @@
 #include "visu_basic.h"
 #include "visu_plugins.h"
 
+/**
+ * SECTION: gtk_about
+ * @short_description: The about dialog with a readme, the copyright,
+ * the author list, the plug-in list and the version notes.
+ */
+
 #define V_SIM_LICENCE_FILE   _("licence.en.txt")
 /* Translate if there is a authors file in another language. */
 #define V_SIM_AUTHORS_FILE   _("authors")
@@ -77,7 +83,7 @@ static void setChangelog(const gchar* buffer, gssize size, GtkTextBuffer *text);
 
 
 /* create the window. */
-void gtkAboutBuild_window(GtkMain *main)
+void gtkAboutBuild_window(VisuUiMain *main)
 {
   GtkWidget *wd, *note;
   gchar *buffer, *utf8Buffer, *start, *end;
@@ -93,19 +99,19 @@ void gtkAboutBuild_window(GtkMain *main)
   gtk_widget_set_name(main->aboutDialog, "message");
 
   wd = lookup_widget(main->aboutDialog, "labelInfoVersion");
-  gtk_label_set_text(GTK_LABEL(wd), V_SIM_VERSION);
+  gtk_label_set_text(GTK_LABEL(wd), VISU_VERSION);
   wd = lookup_widget(main->aboutDialog, "labelInfoReleaseDate");
   gtk_label_set_text(GTK_LABEL(wd), V_SIM_RELEASE_DATE);
   wd = lookup_widget(main->aboutDialog, "labelInfoWebSite");
-/* #if GTK_MINOR_VERSION > 9 */
+/* #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 9 */
 /*   gtk_widget_destroy(wd); */
 /*   wd = lookup_widget(main->aboutDialog, "table4"); */
-/*   gtk_table_attach(GTK_TABLE(wd), gtk_link_button_new(V_SIM_WEB_SITE), */
+/*   gtk_table_attach(GTK_TABLE(wd), gtk_link_button_new(VISU_WEB_SITE), */
 /* 		   1, 2, 2, 3, GTK_SHRINK, GTK_SHRINK, 5, 0); */
 /*   gtk_widget_show_all(wd); */
 /* #else */
   gtk_label_set_markup(GTK_LABEL(wd), "<span font_desc=\"monospace\"><u>"
-		       V_SIM_WEB_SITE"</u></span>");
+		       VISU_WEB_SITE"</u></span>");
 /* #endif */
 
   note = lookup_widget(main->aboutDialog, "notebookAbout");
@@ -185,7 +191,7 @@ void gtkAboutBuild_window(GtkMain *main)
 
       wd = lookup_widget(main->aboutDialog, "textviewChangelog");
       gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(wd), GTK_WRAP_WORD);
-      gtk_text_view_set_justification (GTK_TEXT_VIEW(wd), GTK_JUSTIFY_FILL);
+      gtk_text_view_set_justification (GTK_TEXT_VIEW(wd), GTK_JUSTIFY_LEFT);
       text = gtk_text_view_get_buffer(GTK_TEXT_VIEW(wd));
       
       /* Parse here the XML to get only the relevant entries. */
@@ -279,7 +285,7 @@ void gtkAboutBuild_window(GtkMain *main)
 /*   return FALSE; */
 /* } */
 
-static void buildPluginsTab(GtkMain *main)
+static void buildPluginsTab(VisuUiMain *main)
 {
   GtkListStore *liststore;
   GtkTreeIter iter;
@@ -288,6 +294,8 @@ static void buildPluginsTab(GtkMain *main)
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
   GdkPixbuf *pixbuf;
+  const gchar *str;
+  VisuPlugin *plug;
 
   liststore = gtk_list_store_new(N_GTK_PLUGINS_COLUMNS,
 				 GDK_TYPE_PIXBUF,
@@ -297,28 +305,28 @@ static void buildPluginsTab(GtkMain *main)
   gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(liststore),
 				       GTK_PLUGINS_COLUMN_NAME, GTK_SORT_ASCENDING);
 
-  pnt = visuPluginsGet_listLoaded();
-  while(pnt)
+  for (pnt = visu_plugins_getListLoaded(); pnt; pnt = g_list_next(pnt))
     {
-      if (((VisuPlugin*)pnt->data)->getIcon)
-	pixbuf = gdk_pixbuf_new_from_file_at_size(((VisuPlugin*)pnt->data)->getIcon(),
-						  32, 32, (GError**)0);
+      plug = (VisuPlugin*)pnt->data;
+      str = visu_plugin_getIconPath(plug);
+      if (str)
+        pixbuf = gdk_pixbuf_new_from_file_at_size(str, 32, 32, (GError**)0);
       else
 	pixbuf = (GdkPixbuf*)0;
       gtk_list_store_append(liststore, &iter);
       gtk_list_store_set(liststore, &iter,
 			 GTK_PLUGINS_COLUMN_ICON, pixbuf,
-			 GTK_PLUGINS_COLUMN_NAME, ((VisuPlugin*)pnt->data)->name,
-			 GTK_PLUGINS_COLUMN_DESCRIPTION, ((VisuPlugin*)pnt->data)->getDescription(),
-			 GTK_PLUGINS_COLUMN_AUTHORS, ((VisuPlugin*)pnt->data)->getAuthors(),
+			 GTK_PLUGINS_COLUMN_NAME, visu_plugin_getName(plug),
+			 GTK_PLUGINS_COLUMN_DESCRIPTION, visu_plugin_getDescription(plug),
+			 GTK_PLUGINS_COLUMN_AUTHORS, visu_plugin_getAuthors(plug),
 			 -1);
-      pnt = g_list_next(pnt);
     }
 
   /* Build the treeview. */
   tree= gtk_tree_view_new_with_model(GTK_TREE_MODEL(liststore));
   
-  gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(tree)), GTK_SELECTION_NONE);
+  gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(tree)),
+                              GTK_SELECTION_NONE);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tree), TRUE);
 
   renderer = gtk_cell_renderer_pixbuf_new();
@@ -411,7 +419,7 @@ static void aboutXML_element(GMarkupParseContext *context _U_,
 	{
 	  if (!strcmp(attribute_names[i], PICK_PARSER_ATTRIBUTES_VERSION))
 	    {
-	      refVersion = g_strsplit_set(V_SIM_VERSION, ".-", 4);
+	      refVersion = g_strsplit_set(VISU_VERSION, ".-", 4);
 	      version    = g_strsplit_set(attribute_values[i], ".", 3);
 	      refMinor   = (atoi(refVersion[2]) == 99)?
 		atoi(refVersion[1]) + 1:atoi(refVersion[1]);
@@ -546,7 +554,7 @@ static void setChangelog(const gchar* buffer, gssize size, GtkTextBuffer *text)
   g_markup_parse_context_free(xmlContext);
 
   if (!status && error)
-    g_warning(error->message);
+    g_warning("%s", error->message);
 
   if (error)
     g_error_free(error);
