@@ -53,7 +53,7 @@
  *
  * Create the about window.
  */
-void gtkAboutBuild_window(GtkMain *main);
+void gtkAboutBuild_window(VisuUiMain *main);
 
 
 #endif
