@@ -49,16 +49,19 @@
 #include "gtk_main.h"
 #include "visu_gtk.h"
 #include "visu_object.h"
-#include "visu_pickMesure.h"
 
 #include "gtk_pick.h"
 #include "gtk_move.h"
 #include "gtk_renderingWindowWidget.h"
-#include "renderingBackend/visu_windowInterface.h"
 #include "openGLFunctions/interactive.h"
 #include "extraGtkFunctions/gtk_numericalEntryWidget.h"
 #include "extraGtkFunctions/gtk_orientationChooser.h"
 
+/**
+ * SECTION: gtk_interactive
+ * @short_description: The interactive dialog.
+ */
+
 /* Local types. */
 typedef struct ActionInterface_
 {
@@ -78,7 +81,7 @@ typedef struct ActionInterface_
 static ActionInterface* currentAction;
 static guint n_actions = 0;
 static GList *actions;
-static gulong onStop_id;
+static VisuInteractive *interObserve;
 
 /* Callbacks. */
 static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
@@ -88,9 +91,9 @@ static void onVisuData(GObject *obj, VisuData *dataObj, gpointer data);
 static void observeMethodChanged(GtkToggleButton* button, gpointer data);
 static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_data);
 static void onCloseButtonClicked(GtkButton *button, gpointer user_data);
-static void refreshCameraSpinValues(VisuData *obj, OpenGLView *view, gpointer data);
-static void onTabActionChanged(GtkNotebook *book, GtkNotebookPage *page,
-			       guint num, gpointer data);
+static void refreshCameraSpinValues(VisuData *obj, VisuOpenGLView *view, gpointer data);
+static void onTabActionChanged(GtkNotebook *book, GtkWidget *child,
+			       gint num, gpointer data);
 static void onOrientationChooser(GtkButton *button, gpointer data);
 static void onAngleChanged(GtkSpinButton *spin, gpointer data);
 static void onTranslationChanged(GtkSpinButton *spin, gpointer data);
@@ -99,17 +102,18 @@ static void onPerspChanged(GtkSpinButton *spin, gpointer data);
 static gboolean onKillWindowEvent(GtkWidget *widget, GdkEvent *event,
 				  gpointer user_data);
 static void onRadioToggled(GtkToggleButton *toggle, gpointer data);
-static void onObserveStart(RenderingWindow *window);
-static void onObserveStop(RenderingWindow *window);
+static void onObserveStart(VisuRenderingWindow *window);
+static void onObserveStop(VisuRenderingWindow *window);
+static void onObserveClickStop(VisuInteractive *inter _U_, gpointer data);
 
 /* Local methods. */
 static void connectSignalsObservePick();
-static void setNamesGtkWidgetObservePick(GtkMain *main);
-static GtkWidget* gtkObserveBuild_interface(GtkMain *main, gchar **label,
+static void setNamesGtkWidgetObservePick(VisuUiMain *main);
+static GtkWidget* gtkObserveBuild_interface(VisuUiMain *main, gchar **label,
 					    gchar **help, GtkWidget **radio);
 
 /* Widgets */
-static GtkWidget *observeWindow;
+static GtkWidget *observeWindow, *infoBar;
 static GtkWidget *orientationChooser;
 static GtkWidget *spinTheta, *spinPhi, *spinOmega;
 static GtkWidget *spinXs, *spinYs;
@@ -145,6 +149,19 @@ void gtkInteractiveInit()
 			   gtkMoveStart, gtkMoveStop);
 }
 
+/**
+ * gtkInteractiveAdd_action:
+ * @build: a routine to build a tab.
+ * @start: a routine to run when session is selected.
+ * @stop: a routine to run when session is stopped.
+ *
+ * One can add new interactive mode with specific tab in the
+ * interactive dialog.
+ *
+ * Since: 3.6
+ *
+ * Returns: an id for this new action.
+ */
 guint gtkInteractiveAdd_action(GtkInteractiveBuild build,
 			       GtkInteractiveStartStop start,
 			       GtkInteractiveStartStop stop)
@@ -165,7 +182,7 @@ guint gtkInteractiveAdd_action(GtkInteractiveBuild build,
   return action->id;
 }
 
-static GtkWidget* gtkObserveBuild_interface(GtkMain *main _U_, gchar **label,
+static GtkWidget* gtkObserveBuild_interface(VisuUiMain *main _U_, gchar **label,
 					    gchar **help, GtkWidget **radio)
 {
   *label = g_strdup("Observe");
@@ -175,21 +192,25 @@ static GtkWidget* gtkObserveBuild_interface(GtkMain *main _U_, gchar **label,
   return (GtkWidget*)0;
 }
 
-void gtkInteractiveBuild_window(GtkMain *main)
+void gtkInteractiveBuild_window(VisuUiMain *main)
 {
   GtkWidget *labelHelp, *wd;
-  RenderingWindow *window;
+  VisuRenderingWindow *window;
   VisuData *data;
   GList *tmpLst;
   ActionInterface *action;
   gchar *msg;
   GSList *lst;
  
-  window = visuRenderingWindowGet_current();
-  g_return_if_fail(window);
-  data = renderingWindowGet_visuData(window);
+  window = visu_uiMainClass_getDefaultRendering();
+  data = visu_rendering_window_getVisuData(window);
   g_return_if_fail(data);
 
+  interObserve = visuInteractiveNew(interactive_observe);
+  g_object_ref(G_OBJECT(interObserve));
+  g_signal_connect(G_OBJECT(interObserve), "stop",
+		   G_CALLBACK(onObserveClickStop), (gpointer)window);
+
   DBG_fprintf(stderr, "Gtk observePick: creating the window.\n");
   main->interactiveDialog = create_observeDialog();
   observeWindow = main->interactiveDialog;
@@ -200,11 +221,14 @@ void gtkInteractiveBuild_window(GtkMain *main)
 		   G_CALLBACK(onHomePressed), (gpointer)observeWindow);
 
   /* Create the actions parts. */
+  DBG_fprintf(stderr, "Gtk Interactive: Create the actions parts.\n");
   lst = (GSList*)0;
   for (tmpLst = actions; tmpLst; tmpLst = g_list_next(tmpLst))
     {
       action = ((ActionInterface*)tmpLst->data);
+      g_return_if_fail(action->build);
       wd = action->build(main, &action->label, &msg, &action->radio);
+      DBG_fprintf(stderr, " | action '%s'\n", action->label);
       action->help = g_markup_printf_escaped("<span size=\"smaller\">%s</span>", msg);
       g_free(msg);
       if (wd)
@@ -216,6 +240,7 @@ void gtkInteractiveBuild_window(GtkMain *main)
       lst = gtk_radio_button_get_group(GTK_RADIO_BUTTON(action->radio));
       g_signal_connect(G_OBJECT(action->radio), "toggled",
 		       G_CALLBACK(onRadioToggled), (gpointer)action);
+      DBG_fprintf(stderr, " | action '%s' OK\n", action->label);
     }
 
   /* Create and Set the help text. */
@@ -223,16 +248,43 @@ void gtkInteractiveBuild_window(GtkMain *main)
   labelHelp = lookup_widget(main->interactiveDialog, "labelInfoObservePick");
   gtk_label_set_markup(GTK_LABEL(labelHelp), action->help);
 
+  /* Add an info bar for warning and so on. */
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17 
+  infoBar = gtk_info_bar_new();
+  gtk_widget_set_no_show_all(infoBar, TRUE);
+  gtk_info_bar_add_button(GTK_INFO_BAR(infoBar),
+                          GTK_STOCK_OK, GTK_RESPONSE_OK);
+  g_signal_connect(infoBar, "response",
+                   G_CALLBACK(gtk_widget_hide), NULL);
+  wd = gtk_label_new("");
+  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+  gtk_container_add(GTK_CONTAINER(gtk_info_bar_get_content_area(GTK_INFO_BAR(infoBar))), wd);
+  gtk_widget_show(wd);
+#else
+  infoBar = gtk_label_new("");
+  gtk_misc_set_alignment(GTK_MISC(infoBar), 0., 0.5);
+#endif
+  gtk_box_pack_end(GTK_BOX(lookup_widget(observeWindow, "vbox20")),
+                   infoBar, FALSE, FALSE, 2);
+
   /* connect the signals to the spins. */
   connectSignalsObservePick(main);
 
+  DBG_fprintf(stderr, "Gtk Interactive: Setup initial values.\n");
   onNewData((GObject*)0, data, (gpointer)0);
   /* set the initial values for the spins. */
-  refreshCameraSpinValues((VisuData*)0, visuDataGet_openGLView(data), (gpointer)0);
+  refreshCameraSpinValues((VisuData*)0, visu_data_getOpenGLView(data), (gpointer)0);
 }
 
-/* Methods dealing with observe & pick session. */
-static void onStop(VisuInteractive *inter _U_, gpointer data)
+/**
+ * gtkInteractiveToggle:
+ *
+ * The user can switch between a current specific interactive action
+ * and the observe mode. This routine is used to do this.*
+ *
+ * Since: 3.6
+ */
+void gtkInteractiveToggle()
 {
   GtkWidget *wd;
   guint id;
@@ -247,22 +299,15 @@ static void onStop(VisuInteractive *inter _U_, gpointer data)
     id = action_observe;
   action = (ActionInterface*)g_list_nth_data(actions, id);
 
-  /* We stop the current action. */
-  currentAction->onStop(RENDERING_WINDOW(data));
-
   /* We toggle on the radio of the new action. */
   if (action->radio)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(action->radio), TRUE);
 }
 
-void gtkInteractiveInit_session(RenderingWindow *window, VisuInteractive *inter)
+void gtkInteractiveInit_session(VisuRenderingWindow *window)
 {
   DBG_fprintf(stderr, "Gtk Interactive: initialise session.\n");
 
-  /* We attach the new signals. */
-  onStop_id = g_signal_connect(G_OBJECT(inter), "stop",
-			       G_CALLBACK(onStop), (gpointer)window);
-
   /* We empty the status bar. */
   renderingWindowPush_message(window, "");
 
@@ -272,21 +317,49 @@ void gtkInteractiveInit_session(RenderingWindow *window, VisuInteractive *inter)
 
 static void gtkInteractiveStop()
 {
-  VisuInteractive *inter;
-  RenderingWindow *window;
+  VisuRenderingWindow *window;
 
-  window = RENDERING_WINDOW(currentRenderingWindow);
-  inter = renderingWindowGet_interactive(window);
+  window = visu_uiMainClass_getDefaultRendering();
 
-  currentAction->onStop(window);
-
-  /* We reset the status bar. */
   renderingWindowPop_message(window);
-  /* We unblock the default mode. */
-  renderingWindowUnblock_defaultIneractiveMode(window);
-
-  g_signal_handler_disconnect(G_OBJECT(inter), onStop_id);
+  currentAction->onStop(window);
 }
+/**
+ * gtkInteractive_setMessage:
+ * @message: a string.
+ * @type: the type of message.
+ *
+ * Show a message in the interactive dialog.
+ *
+ * Since: 3.6
+ */
+void gtkInteractive_setMessage(const gchar *message, GtkMessageType type)
+{
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17 
+  GList *lst;
+
+  gtk_info_bar_set_message_type(GTK_INFO_BAR(infoBar), type);
+  lst = gtk_container_get_children(GTK_CONTAINER(gtk_info_bar_get_content_area(GTK_INFO_BAR(infoBar))));
+  gtk_label_set_text(GTK_LABEL(lst->data), message);
+  g_list_free(lst);
+#else
+  gtk_label_set_text(GTK_LABEL(infoBar), message);
+#endif
+  gtk_widget_show(infoBar);
+}
+/**
+ * gtkInteractive_unsetMessage:
+ *
+ * Hide any message from the interactive dialog. See also
+ * gtkInteractive_setMessage().
+ *
+ * Since: 3.6
+ */
+void gtkInteractive_unsetMessage()
+{
+  gtk_widget_hide(infoBar);
+}
+
 static gboolean onKillWindowEvent(GtkWidget *widget _U_, GdkEvent *event _U_,
 				  gpointer user_data _U_)
 {
@@ -300,7 +373,7 @@ static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
 {
   DBG_fprintf(stderr, "Gtk interactive: click on close button.\n");
 
-  if (!GTK_WIDGET_VISIBLE(observeWindow))
+  if (!gtk_widget_get_visible(observeWindow))
     return;
   gtkInteractiveStop();
 }
@@ -338,13 +411,13 @@ static void connectSignalsObservePick()
   /* The observe widgets. */
   wd = lookup_widget(observeWindow, "spinTheta");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(MASK_THETA));
+		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_CAMERA_THETA));
   wd = lookup_widget(observeWindow, "spinPhi");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(MASK_PHI));
+		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_CAMERA_PHI));
   wd = lookup_widget(observeWindow, "spinOmega");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(MASK_OMEGA));
+		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_CAMERA_OMEGA));
   wd = lookup_widget(observeWindow, "spinDx");
   g_signal_connect(G_OBJECT(wd), "value_changed",
 		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(MASK_XS));
@@ -386,21 +459,22 @@ static void onVisuData(GObject *obj _U_, VisuData *dataObj, gpointer data)
     gtk_button_clicked(GTK_BUTTON(data));
 }
 
-static void onObserveStart(RenderingWindow *window)
+static void onObserveClickStop(VisuInteractive *inter _U_, gpointer data)
 {
-  visuInteractiveSet_type(renderingWindowGet_interactive(window),
-			  interactive_observe);
+  gtkInteractiveToggle(RENDERING_WINDOW(data));
 }
-static void onObserveStop(RenderingWindow *window)
+static void onObserveStart(VisuRenderingWindow *window)
 {
-  visuInteractiveSet_type(renderingWindowGet_interactive(window),
-			  interactive_none);
+  renderingWindowPush_interactive(window, interObserve);
+}
+static void onObserveStop(VisuRenderingWindow *window)
+{
+  renderingWindowPop_interactive(window, interObserve);
 }
 
 static void observeMethodChanged(GtkToggleButton* button, gpointer data)
 {
   VisuInteractiveMethod method;
-  RenderingWindow *window;
 
   if (!gtk_toggle_button_get_active(button))
     return;
@@ -409,13 +483,11 @@ static void observeMethodChanged(GtkToggleButton* button, gpointer data)
   visuInteractiveClassSet_preferedObserveMethod(method);
   if (method == interactive_constrained)
     {
-      window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-      g_return_if_fail(window);
-
       gtk_widget_set_sensitive(spinOmega, FALSE);
-      if (visuDataSet_angleOfView(renderingWindowGet_visuData(window),
-				  0., 0., 0., MASK_OMEGA))
-	g_idle_add(visuObjectRedraw, (gpointer)0);
+      if (visu_data_setAngleOfView(visu_rendering_window_getVisuData
+				  (visu_uiMainClass_getDefaultRendering()),
+				  0., 0., 0., VISU_CAMERA_OMEGA))
+	VISU_ADD_REDRAW;
     }
   else
     gtk_widget_set_sensitive(spinOmega, TRUE);
@@ -424,7 +496,7 @@ static void observeMethodChanged(GtkToggleButton* button, gpointer data)
 
 /* Ask the OpenGL server to refresh the values of the spins
    controlling the position of the camera. */
-static void refreshCameraSpinValues(VisuData *obj _U_, OpenGLView *view,
+static void refreshCameraSpinValues(VisuData *obj _U_, VisuOpenGLView *view,
 				    gpointer data _U_)
 {
   g_return_if_fail(view && view->camera);
@@ -441,7 +513,7 @@ static void refreshCameraSpinValues(VisuData *obj _U_, OpenGLView *view,
 
 /* Give a name to the widgets present in this window
    to be able to affect them with a theme. */
-static void setNamesGtkWidgetObservePick(GtkMain *main)
+static void setNamesGtkWidgetObservePick(VisuUiMain *main)
 {
   GtkWidget *wd;
   int method;
@@ -494,7 +566,7 @@ static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
   GtkWindow *window;
 
   DBG_fprintf(stderr, "Gtk Interactive: get key pressed.\n");
-  if(event->keyval == GDK_Home)
+  if(event->keyval == GDK_KEY_Home)
     {
       window = visuGtkGet_render();
       g_return_val_if_fail(window, FALSE);
@@ -507,80 +579,77 @@ static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
 static void onAngleChanged(GtkSpinButton *spin, gpointer data)
 {
   int reDrawNeeded;
-  RenderingWindow *window;
 
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_if_fail(window);
-
-  reDrawNeeded = visuDataSet_angleOfView(renderingWindowGet_visuData(window),
+  reDrawNeeded = visu_data_setAngleOfView(visu_rendering_window_getVisuData
+					 (visu_uiMainClass_getDefaultRendering()),
 					 (float)gtk_spin_button_get_value(spin),
 					 (float)gtk_spin_button_get_value(spin),
 					 (float)gtk_spin_button_get_value(spin),
 					 GPOINTER_TO_INT(data));
   if (reDrawNeeded)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 static void onTranslationChanged(GtkSpinButton *spin, gpointer data)
 {
   int reDrawNeeded;
-  RenderingWindow *window;
 
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_if_fail(window);
-
-  reDrawNeeded = visuDataSet_positionOfView(renderingWindowGet_visuData(window),
+  reDrawNeeded = visu_data_setPositionOfView(visu_rendering_window_getVisuData
+					    (visu_uiMainClass_getDefaultRendering()),
 					    (float)gtk_spin_button_get_value(spin),
 					    (float)gtk_spin_button_get_value(spin),
 					    GPOINTER_TO_INT(data));
   if (reDrawNeeded)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 static void onZoomChanged(GtkSpinButton *spin, gpointer data _U_)
 {
   int reDrawNeeded;
-  RenderingWindow *window;
 
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_if_fail(window);
-
-  reDrawNeeded = visuDataSet_zoomOfView(renderingWindowGet_visuData(window),
+  reDrawNeeded = visu_data_setZoomOfView(visu_rendering_window_getVisuData
+					(visu_uiMainClass_getDefaultRendering()),
 					(float)gtk_spin_button_get_value(spin));
   if (reDrawNeeded)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 static void onPerspChanged(GtkSpinButton *spin, gpointer data _U_)
 {
   int reDrawNeeded;
-  RenderingWindow *window;
 
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_if_fail(window);
-
-  reDrawNeeded = visuDataSet_perspectiveOfView(renderingWindowGet_visuData(window),
+  reDrawNeeded = visu_data_setPerspectiveOfView(visu_rendering_window_getVisuData
+					       (visu_uiMainClass_getDefaultRendering()),
 					       (float)gtk_spin_button_get_value(spin));
   if (reDrawNeeded)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 
 static void onRadioToggled(GtkToggleButton *toggle, gpointer data)
 {
   GtkWidget *labelHelp;
+  VisuRenderingWindow *window;
 
   if (!gtk_toggle_button_get_active(toggle))
     return;
 
+  window = visu_uiMainClass_getDefaultRendering();
+  
+  /* Before setting up the current action, we pop
+     the previous one. */
+  if (currentAction)
+    currentAction->onStop(window);
+
+  /* Get the new action. */
   currentAction = (ActionInterface*)data;
   DBG_fprintf(stderr, "Gtk Interactive: set the action %d current.\n",
 	      currentAction->id);
@@ -588,7 +657,7 @@ static void onRadioToggled(GtkToggleButton *toggle, gpointer data)
   labelHelp = lookup_widget(observeWindow, "labelInfoObservePick");
   gtk_label_set_markup(GTK_LABEL(labelHelp), currentAction->help);
 
-  currentAction->onStart(RENDERING_WINDOW(currentRenderingWindow));
+  currentAction->onStart(window);
 }
 
 static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_data _U_)
@@ -608,16 +677,13 @@ static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_dat
     gtk_widget_set_sensitive(spinOmega, value);
 }
 
-static void onTabActionChanged(GtkNotebook *book _U_, GtkNotebookPage *page _U_,
-			       guint num, gpointer data _U_)
+static void onTabActionChanged(GtkNotebook *book _U_, GtkWidget *child _U_,
+			       gint num, gpointer data _U_)
 {
   ActionInterface *action;
 
   DBG_fprintf(stderr, "Gtk Interactive: change the action tab to %d.\n", num);
 
-  /* We stop the current action. */
-  currentAction->onStop(RENDERING_WINDOW(currentRenderingWindow));
-
   action = (ActionInterface*)g_list_nth_data(actions, num + 1);
   if (action->radio)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(action->radio), TRUE);
@@ -634,11 +700,11 @@ static void onOrientationChanged(OrientationChooser *orientationChooser,
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), values[0]);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi), values[1]);
 
-  reDrawNeeded = visuDataSet_angleOfView
-    (renderingWindowGet_visuData(RENDERING_WINDOW(visuRenderingWindowGet_current())),
-     values[0], values[1], 0., MASK_THETA | MASK_PHI);
+  reDrawNeeded = visu_data_setAngleOfView
+    (visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering()),
+     values[0], values[1], 0., VISU_CAMERA_THETA | VISU_CAMERA_PHI);
   if (reDrawNeeded)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
 {
@@ -646,8 +712,7 @@ static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
   gboolean reDrawNeeded;
   VisuData *dataObj;
 
-  dataObj = renderingWindowGet_visuData
-    (RENDERING_WINDOW(visuRenderingWindowGet_current()));
+  dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
   if (!orientationChooser)
     {
       orientationChooser = orientationChooserNew
@@ -659,11 +724,11 @@ static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
 					 values);
       g_signal_connect(G_OBJECT(orientationChooser), "values-changed",
 		       G_CALLBACK(onOrientationChanged), (gpointer)0);
+      gtk_widget_show(orientationChooser);
     }
   else
-    gdk_window_raise(GDK_WINDOW(orientationChooser->window));
+    gtk_window_present(GTK_WINDOW(orientationChooser));
   
-  gtk_widget_show(orientationChooser);
   switch (gtk_dialog_run(GTK_DIALOG(orientationChooser)))
     {
     case GTK_RESPONSE_ACCEPT:
@@ -673,10 +738,10 @@ static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
       DBG_fprintf(stderr, "Gtk Observe: reset values on orientation.\n");
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), values[0]);
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi), values[1]);
-      reDrawNeeded = visuDataSet_angleOfView
-	(dataObj, values[0], values[1], 0., MASK_THETA | MASK_PHI);
+      reDrawNeeded = visu_data_setAngleOfView
+	(dataObj, values[0], values[1], 0., VISU_CAMERA_THETA | VISU_CAMERA_PHI);
       if (reDrawNeeded)
-	g_idle_add(visuObjectRedraw, (gpointer)0);
+	VISU_ADD_REDRAW;
     }
   DBG_fprintf(stderr, "Gtk Observe: orientation object destroy.\n");
   gtk_widget_destroy(orientationChooser);
