@@ -54,6 +54,7 @@
  * @action_observe: interactive session is observe ;
  * @action_pick: interactive session is pick ;
  * @action_move: interactive session is geometry changes.
+ * @n_preset_actions: private.
  *
  * Possibe actions.
  */
@@ -62,12 +63,36 @@ typedef enum
     action_observe,
     action_pick,
     action_move,
+    /*< private >*/
     n_preset_actions
   } GtkInteractiveActionId;
 
-typedef GtkWidget* (*GtkInteractiveBuild)(GtkMain *main, gchar **label,
+/**
+ * GtkInteractiveBuild:
+ * @main: the main interface.
+ * @label: a location to store the name of the tab ;
+ * @help: a location to store the help message to be shown at the
+ * bottom of the window ;
+ * @radio: a location on the radio button that will be toggled when
+ * the desired action is used.
+ *
+ * One can create new tab in the interactive dialog window by
+ * providing routines with this prototype.
+ *
+ * Returns: a new container to be include as a tab in the interactive
+ * dialog window.
+ */
+typedef GtkWidget* (*GtkInteractiveBuild)(VisuUiMain *main, gchar **label,
 					  gchar **help, GtkWidget **radio); 
-typedef void (*GtkInteractiveStartStop)(RenderingWindow *window); 
+/**
+ * GtkInteractiveStartStop:
+ * @window: the rendering window that starts or stops the interaction
+ * defined in the tab.
+ *
+ * Routines of this prototype are called each time the interactive
+ * mode should be changed.
+ */
+typedef void (*GtkInteractiveStartStop)(VisuRenderingWindow *window); 
 
 guint gtkInteractiveAdd_action(GtkInteractiveBuild build,
 			       GtkInteractiveStartStop start,
@@ -80,6 +105,7 @@ guint gtkInteractiveAdd_action(GtkInteractiveBuild build,
  * signals, give names to widgets...
  */
 void gtkInteractiveInit();
+void gtkInteractiveToggle();
 
 /**
  * gtkInteractiveBuild_window:
@@ -87,13 +113,17 @@ void gtkInteractiveInit();
  *
  * create the window.
  */
-void gtkInteractiveBuild_window(GtkMain *main);
+void gtkInteractiveBuild_window(VisuUiMain *main);
 
 /**
  * gtkInteractiveInit_session:
+ * @window: the current rendering widget.
  * 
  * Start the observe & pick session.
  */
-void gtkInteractiveInit_session(RenderingWindow *window, VisuInteractive *inter);
+void gtkInteractiveInit_session(VisuRenderingWindow *window);
+
+void gtkInteractive_setMessage(const gchar *message, GtkMessageType type);
+void gtkInteractive_unsetMessage();
 
 #endif
