@@ -46,20 +46,25 @@
 
 #include <gtk/gtk.h>
 
-#include "visu_pickMesure.h"
 #include "gtk_main.h"
 #include "gtk_renderingWindowWidget.h"
 
 /**
  * gtkMoveBuild_interface:
+ * @main: the main interface.
+ * @label: a location to store the name of the move tab ;
+ * @help: a location to store the help message to be shown at the
+ * bottom of the window ;
+ * @radio: a location on the radio button that will be toggled when
+ * the move action is used.
  * 
  * This routine should be called in conjonction to the
  * create_observeDialog() one. It completes the creation of widgets
  * (and also initialisation of values) for the move tab.
  */
-GtkWidget* gtkMoveBuild_interface(GtkMain *main, gchar **label,
+GtkWidget* gtkMoveBuild_interface(VisuUiMain *main, gchar **label,
 				  gchar **help, GtkWidget **radio);
-void gtkMoveStart(RenderingWindow *window);
-void gtkMoveStop(RenderingWindow *window);
+void gtkMoveStart(VisuRenderingWindow *window);
+void gtkMoveStop(VisuRenderingWindow *window);
 
 #endif
