@@ -48,10 +48,15 @@
 #include "gtk/gtk.h"
 
 #include <GL/gl.h>
+#include <GL/glu.h>
 
+#include "support.h"
 #include "gtk_openGLWidget.h"
 #include "OSOpenGL/visu_openGL.h"
 #include "visu_tools.h"
+#include "visu_extension.h"
+#include "visu_gtk.h"
+#include "opengl.h"
 #include "openGLFunctions/text.h"
 
 /* OpenGL implementation dependencies */
@@ -73,7 +78,7 @@
 #endif
 
 /**
- * SECTION:openglwidget
+ * SECTION:gtk_openGLWidget
  * @short_description: defines an OpenGL capable GtkWidget.
  *
  * <para>This is a simple implementation of GtkGlExt to create an
@@ -95,8 +100,12 @@ struct _OpenGLWidget
   RedrawMethod redraw;
   VisuData *redrawData;
 
+  /* Default background pixbuf. */
+  GdkPixbuf *backLogo;
+
   /* OpenGL part, OS dependent. */
   gboolean isContextDirect;
+  GdkVisual *visual;
 #ifdef IMPL_GTKGLEXT
   GdkGLConfig *glconfig;
   GdkGLWindow *glwindow;
@@ -127,9 +136,15 @@ G_DEFINE_TYPE(OpenGLWidget, openGLWidget, GTK_TYPE_WIDGET)
 static OpenGLWidgetClass *myClass = (OpenGLWidgetClass*)0;
 
 /* Local callbacks. */
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static gboolean openGLWidgetEvent_expose(GtkWidget *widget, GdkEventExpose *event);
-static gboolean openGLWidgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event);
 static void openGLWidgetEvent_sizeRequest(GtkWidget *widget, GtkRequisition *requisition);
+#else
+static gboolean openGLWidgetEvent_draw(GtkWidget *widget, cairo_t *cr);
+static void openGLWidgetEvent_getWidth(GtkWidget *widget, gint *minWidth, gint *width);
+static void openGLWidgetEvent_getHeight(GtkWidget *widget, gint *minHeight, gint *height);
+#endif
+static gboolean openGLWidgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event);
 static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation);
 static void openGLWidgetEvent_realise(GtkWidget *widget);
 
@@ -142,10 +157,12 @@ static void openGLWidgetEvent_finalize(GObject *obj);
 static void openGLWidgetFree_openGL(OpenGLWidget *render);
 
 /* Miscellaneous methods. */
-static void openGLWidgetSet_viewport(OpenGLWidget *render, guint width,
+static void setViewport(OpenGLWidget *render, guint width,
 				     guint height, gboolean redraw);
-static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render);
 static void openGLWidgetSet_pixelFormat(OpenGLWidget *render);
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
+static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render);
+#endif
 
 static void openGLWidget_class_init(OpenGLWidgetClass *class)
 {
@@ -159,10 +176,16 @@ static void openGLWidget_class_init(OpenGLWidgetClass *class)
 
   /* Dealing with widget events. */
   widget_class = GTK_WIDGET_CLASS(class);
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
   widget_class->expose_event  = openGLWidgetEvent_expose;
-  widget_class->visibility_notify_event  = openGLWidgetEvent_visibility;
-  widget_class->realize       = openGLWidgetEvent_realise;
   widget_class->size_request  = openGLWidgetEvent_sizeRequest;
+#else
+  widget_class->draw          = openGLWidgetEvent_draw;
+  widget_class->get_preferred_width  = openGLWidgetEvent_getWidth;
+  widget_class->get_preferred_height = openGLWidgetEvent_getHeight;
+#endif
+  widget_class->visibility_notify_event = openGLWidgetEvent_visibility;
+  widget_class->realize       = openGLWidgetEvent_realise;
   widget_class->size_allocate = openGLWidgetEvent_sizeAllocate;
 
   class->contextCurrent = (OpenGLWidget*)0;
@@ -179,7 +202,10 @@ static void openGLWidget_init(OpenGLWidget *render)
   render->redraw = (RedrawMethod)0;
   render->redrawData = (gpointer)0;
 
+  render->backLogo = (GdkPixbuf*)0;
+
   render->isContextDirect = FALSE;
+  render->visual   = (GdkVisual*)0;
 #ifdef IMPL_GTKGLEXT
   render->glconfig = (GdkGLConfig*)0;
   render->glwindow = (GdkGLWindow*)0;
@@ -199,6 +225,7 @@ static void openGLWidget_init(OpenGLWidget *render)
   /* Cancel the GTK double buffering since it is taken into
      account by OpenGL itself. */
   gtk_widget_set_double_buffered(GTK_WIDGET(render), FALSE);
+  gtk_widget_set_has_window(GTK_WIDGET(render), TRUE);
 }
 
 GtkWidget* openGLWidgetNew(gboolean contextIsDirect)
@@ -219,8 +246,12 @@ static void openGLWidgetEvent_dispose(GObject *obj)
 
   if (OPENGL_WIDGET(obj)->dispose_has_run)
     return;
-
   OPENGL_WIDGET(obj)->dispose_has_run = TRUE;
+
+  if (OPENGL_WIDGET(obj)->backLogo)
+    g_object_unref(OPENGL_WIDGET(obj)->backLogo);
+  openGLWidgetFree_openGL(OPENGL_WIDGET(obj));
+
   /* Chain up to the parent class */
   G_OBJECT_CLASS(openGLWidget_parent_class)->dispose(obj);
 }
@@ -228,81 +259,104 @@ static void openGLWidgetEvent_finalize(GObject *obj)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): finalize event for object %p.\n", (gpointer)obj);
 
-  openGLWidgetFree_openGL(OPENGL_WIDGET(obj));
-
   /* Chain up to the parent class */
   G_OBJECT_CLASS(openGLWidget_parent_class)->finalize(obj);
 }
-static gboolean openGLWidgetEvent_expose(GtkWidget *widget, GdkEventExpose *event)
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
+static gboolean openGLWidgetEvent_expose(GtkWidget *widget, GdkEventExpose *event _U_)
 {
-  OpenGLWidget *render;
-
   DBG_fprintf(stderr, "Gtk OpenGL (events): expose event for object %p.\n", (gpointer)widget);
-
-  render = OPENGL_WIDGET(widget);
-  if (render->redraw)
-    openGLWidgetRedraw(render);
-  else
-    {
-      DBG_fprintf(stderr, " | clear window.\n");
-      gdk_window_clear_area(widget->window, event->area.x, event->area.y,
-			    event->area.width, event->area.height);
-    }
+  openGLWidgetRedraw(OPENGL_WIDGET(widget));
 
   return FALSE;
 }
+#else
+static gboolean openGLWidgetEvent_draw(GtkWidget *widget, cairo_t *cr _U_)
+{
+  DBG_fprintf(stderr, "Gtk OpenGL (events): draw event for object %p.\n", (gpointer)widget);
+  openGLWidgetRedraw(OPENGL_WIDGET(widget));
+
+  return FALSE;
+}
+#endif
 static gboolean openGLWidgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event)
 {
-  OpenGLWidget *render;
-
   if (event->state != GDK_VISIBILITY_UNOBSCURED)
     return FALSE;
 
   DBG_fprintf(stderr, "Gtk OpenGL (events): visibility event for object %p.\n", (gpointer)widget);
-  render = OPENGL_WIDGET(widget);
-  if (render->redraw)
-    openGLWidgetRedraw(render);
-  else
-    {
-      DBG_fprintf(stderr, " | clear window.\n");
-      gdk_window_clear(widget->window);
-    }
+  openGLWidgetRedraw(OPENGL_WIDGET(widget));
+  DBG_fprintf(stderr, "Gtk OpenGL (events): visibility OK.\n");
 
   return FALSE;
 }
-static void openGLWidgetEvent_sizeRequest(GtkWidget *widget, GtkRequisition *requisition)
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
+static void openGLWidgetEvent_sizeRequest(GtkWidget *widget,
+					  GtkRequisition *requisition)
 {
   OpenGLWidget *render;
-  int width, height;
+  GtkAllocation allocation;
 
-  DBG_fprintf(stderr, "Gtk OpenGL (events): size request event (%dx%d).\n", requisition->width, requisition->height);
+  DBG_fprintf(stderr, "Gtk OpenGL (events): size request event.\n");
 
   render = OPENGL_WIDGET(widget);
   if (render->sizeAllocation_has_run)
     {
-      width = widget->allocation.width;
-      height = widget->allocation.height;
+      gtk_widget_get_allocation(widget, &allocation);
+      requisition->width  = allocation.width;
+      requisition->height = allocation.height;
     }
   else
     {
-      width = 200;
-      height = 200;
+      requisition->width  = 200;
+      requisition->height = 200;
     }
-  widget->requisition.width = width;
-  widget->requisition.height = height;
+
   /* Chain up to default that simply reads current requisition */
-  GTK_WIDGET_CLASS(openGLWidget_parent_class)->size_request(widget, requisition);
+/*   GTK_WIDGET_CLASS(openGLWidget_parent_class)->size_request(widget, requisition); */
+
+  DBG_fprintf(stderr, "Gtk OpenGL (events): size request event (%dx%d).\n",
+	      requisition->width, requisition->height);
 }
+#else
+static void openGLWidgetEvent_getSize(GtkWidget *widget _U_, GtkOrientation orientation,
+                                      gint *minSize, gint *size)
+{
+  DBG_fprintf(stderr, "Gtk OpenGL (events): size request event.\n");
+
+  if (orientation == GTK_ORIENTATION_HORIZONTAL)
+    {
+      *minSize = 200;
+      *size = 450;
+    }
+  else
+    {
+      *minSize = 200;
+      *size = 450;
+    }
+}
+static void openGLWidgetEvent_getWidth(GtkWidget *widget, gint *minWidth, gint *width)
+{
+  openGLWidgetEvent_getSize(widget, GTK_ORIENTATION_HORIZONTAL, minWidth, width);
+}
+static void openGLWidgetEvent_getHeight(GtkWidget *widget, gint *minHeight, gint *height)
+{
+  openGLWidgetEvent_getSize(widget, GTK_ORIENTATION_HORIZONTAL, minHeight, height);
+}
+#endif
 static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation)
 {
   OpenGLWidget *render;
+  GtkAllocation wdAllocation;
 
   render = OPENGL_WIDGET(widget);
-  if ((widget->allocation.width == allocation->width) &&
-      (widget->allocation.height == allocation->height))
+  gtk_widget_get_allocation(widget, &wdAllocation);
+  if ((wdAllocation.width  == allocation->width) &&
+      (wdAllocation.height == allocation->height))
     return;
 
-  DBG_fprintf(stderr, "Gtk OpenGL (events): size allocation event (%dx%d).\n", allocation->width, allocation->height);
+  DBG_fprintf(stderr, "Gtk OpenGL (events): size allocation event (%dx%d).\n",
+	      allocation->width, allocation->height);
 
   render->sizeAllocation_has_run = TRUE;
   /* Chain up to default that simply reads current requisition */
@@ -312,36 +366,48 @@ static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *all
   glXWaitX();
 #endif
 
-  openGLWidgetSet_viewport(render, widget->allocation.width, widget->allocation.height, FALSE);
+  setViewport(render, allocation->width, allocation->height, FALSE);
 }
 static void openGLWidgetEvent_realise(GtkWidget *widget)
 {
   OpenGLWidget *render;
   GdkWindowAttr attributes;
   gint attributes_mask;
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
   GdkColormap *colormap;
+#else
+#define GDK_WA_COLORMAP 0
+#endif
+  GdkWindow *window;
+  GtkAllocation allocation;
 
   DBG_fprintf(stderr, "Gtk OpenGL (events): realise event for %p.\n",
 	      (gpointer)widget);
 
+  gtk_widget_set_realized(widget, TRUE);
+
   render = OPENGL_WIDGET(widget);
 
 #ifndef IMPL_BUILTIN_WIN32
   openGLWidgetSet_pixelFormat(render);
 #endif
 
+  gtk_widget_get_allocation(widget, &allocation);
+  attributes.window_type = GDK_WINDOW_CHILD;
+  attributes.x      = allocation.x;
+  attributes.y      = allocation.y;
+  attributes.width  = allocation.width;
+  attributes.height = allocation.height;
+  attributes.wclass = GDK_INPUT_OUTPUT;
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
   colormap = openGLWidgetGet_openGLColormap(render);
   DBG_fprintf(stderr, "Gtk OpenGL (debug): colormap is %p.\n",
 	      (gpointer)colormap);
-
-  attributes.window_type = GDK_WINDOW_CHILD;
-  attributes.x = widget->allocation.x;
-  attributes.y = widget->allocation.y;
-  attributes.width = widget->allocation.width;
-  attributes.height = widget->allocation.height;
-  attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.visual = gdk_colormap_get_visual(colormap);
   attributes.colormap = colormap;
+#else
+  attributes.visual = render->visual;
+#endif
   attributes.event_mask = GDK_EXPOSURE_MASK |
     GDK_VISIBILITY_NOTIFY_MASK |
     GDK_BUTTON_PRESS_MASK |
@@ -357,18 +423,25 @@ static void openGLWidgetEvent_realise(GtkWidget *widget)
   attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 #endif
 
-  widget->window = gdk_window_new(gtk_widget_get_parent_window(widget), 
-				  &attributes, attributes_mask);
-  gdk_window_set_user_data(widget->window, render);
+  window = gdk_window_new(gtk_widget_get_parent_window(widget), 
+			  &attributes, attributes_mask);
+  gtk_widget_set_window(widget, window);
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
+  gdk_window_set_back_pixmap(window, NULL, FALSE);
+#else
+  gdk_window_set_background_pattern(window, NULL);
+#endif
+  gdk_window_set_user_data(window, widget);
+
   DBG_fprintf(stderr, "Gtk OpenGL (debug): GdkWindow is %p.\n",
-	      (gpointer)widget->window);
+	      (gpointer)window);
 
-  widget->style = gtk_style_attach(widget->style, widget->window);
-  gtk_style_set_background(widget->style, widget->window, GTK_STATE_NORMAL);
+  gtk_widget_style_attach(widget);
+  gdk_window_set_background(window,
+                            &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL]);
 
-  GTK_WIDGET_SET_FLAGS(widget, GTK_CAN_FOCUS);
-  GTK_WIDGET_SET_FLAGS(widget, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS(widget, GTK_REALIZED);
+  gtk_widget_set_can_focus(widget, TRUE);
+  gtk_widget_set_can_default(widget, TRUE);
 
   gdk_display_sync(gtk_widget_get_display(widget));
 #ifdef IMPL_BUILTIN_X11
@@ -391,8 +464,8 @@ OpenGLWidget* openGLWidgetClassGet_currentContext()
   return myClass->contextCurrent;
 }
 
-static void openGLWidgetSet_viewport(OpenGLWidget *render, guint width,
-				     guint height, gboolean redraw)
+static void setViewport(OpenGLWidget *render, guint width,
+			guint height, gboolean redraw)
 {
   g_return_if_fail(IS_OPENGL_WIDGET(render));
 
@@ -411,6 +484,78 @@ static void openGLWidgetSet_viewport(OpenGLWidget *render, guint width,
       openGLWidgetSwap_buffers(render);
     }
 }
+static void drawToEmpty(OpenGLWidget *render)
+{
+  int widthImg, heightImg;
+  guchar *imageData;
+  gboolean alpha;
+  int x, y;
+  float rgb[3];
+  int viewport[4];
+  GtkStyle *style;
+
+  DBG_fprintf(stderr, "Gtk OpenGL (action): Rebuild default background.\n");
+
+  style = gtk_widget_get_style(GTK_WIDGET(render));
+  rgb[0] = (float)style->bg[0].red / 65536.;
+  rgb[1] = (float)style->bg[0].green / 65536.;
+  rgb[2] = (float)style->bg[0].blue / 65536.;
+  DBG_fprintf(stderr, "Gtk OpenGL (action): set background color to (%f,%f,%f).\n",
+	      rgb[0], rgb[1], rgb[2]);
+
+  if (!render->backLogo)
+    {
+      DBG_fprintf(stderr, "Gtk OpenGL (action): load the pixbuf 'logo_grey.png'.\n");
+      render->backLogo = visuGtkCreate_pixbuf("logo_grey.png");
+    }
+
+  glPushAttrib(GL_ENABLE_BIT);
+  glClearColor(rgb[0], rgb[1], rgb[2], 0.25f);
+  glDrawBuffer(GL_BACK);
+  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+  if (render->backLogo)
+    {
+      imageData = gdk_pixbuf_get_pixels(render->backLogo);
+      alpha = gdk_pixbuf_get_has_alpha(render->backLogo);
+      widthImg = gdk_pixbuf_get_width(render->backLogo);
+      heightImg = gdk_pixbuf_get_height(render->backLogo);
+
+      glDisable(GL_FOG);
+      glEnable(GL_BLEND);
+      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+      /* We can use fixed value for widthImg and heightImg since we project then
+	 in a 2D ortho with these values. */
+      glGetIntegerv(GL_VIEWPORT, viewport);
+      DBG_fprintf(stderr, "Gtk OpenGL (action): Get viewport %dx%d.\n", viewport[2], viewport[3]);
+      x = (viewport[2] - widthImg) / 2;
+      y = (viewport[3] + heightImg) / 2;
+      DBG_fprintf(stderr, "Gtk OpenGL (action): draw at %dx%d.\n", x, y);
+      glMatrixMode(GL_PROJECTION);
+      glPushMatrix();
+      glLoadIdentity();
+      gluOrtho2D(0.0, (float)viewport[2], 0., (float)viewport[3]);
+   
+      glMatrixMode(GL_MODELVIEW);
+      glPushMatrix();
+      glLoadIdentity();
+
+      glRasterPos2i(x, y);
+
+      glPixelZoom(1., -1.);
+      if (alpha)
+	glDrawPixels(widthImg, heightImg, GL_RGBA, GL_UNSIGNED_BYTE, imageData);
+      else
+	glDrawPixels(widthImg, heightImg, GL_RGB, GL_UNSIGNED_BYTE, imageData);
+      glPixelZoom(1., 1.);
+
+      glPopMatrix();
+      glMatrixMode(GL_PROJECTION);
+      glPopMatrix();
+      glMatrixMode(GL_MODELVIEW);
+    }
+  glPopAttrib();
+}
 void openGLWidgetSet_redraw(OpenGLWidget *render, RedrawMethod method, VisuData *data)
 {
   g_return_if_fail(IS_OPENGL_WIDGET(render));
@@ -421,63 +566,87 @@ void openGLWidgetSet_redraw(OpenGLWidget *render, RedrawMethod method, VisuData
 }
 void openGLWidgetRedraw(OpenGLWidget *render)
 {
+#if DEBUG == 1
+  GTimer *timer;
+  gulong fractionTimer;
+#endif
+
   g_return_if_fail(IS_OPENGL_WIDGET(render));
 
-  if (!render->redraw)
-    return;
+#if DEBUG == 1
+  timer = g_timer_new();
+  g_timer_start(timer);
+#endif
 
   DBG_fprintf(stderr, "Gtk OpenGL (action) : redraw OpenGL area for %p.\n", (gpointer)render);
+  DBG_fprintf(stderr, " | set current.\n");
+  openGLWidgetSet_current(render, FALSE);
+  DBG_fprintf(stderr, " | redraw inside.\n");
   if (render->redraw)
-    {
-      DBG_fprintf(stderr, " | set current.\n");
-      openGLWidgetSet_current(render, FALSE);
-      DBG_fprintf(stderr, " | redraw inside.\n");
-      render->redraw((const char**)0, render->redrawData);
-      DBG_fprintf(stderr, " | swap buffers.\n");
-      openGLWidgetSwap_buffers(render);
-    }
+    render->redraw((const char**)0, render->redrawData);
+  else
+    drawToEmpty(render);
+  DBG_fprintf(stderr, " | swap buffers.\n");
+  openGLWidgetSwap_buffers(render);
+#if DEBUG == 1
+  g_timer_stop(timer);
+  fprintf(stderr, "Gtk OpenGL: total redraw in %g micro-s.\n",
+          g_timer_elapsed(timer, &fractionTimer)*1e6);
+  g_timer_destroy(timer);
+#endif
 }
 
-guchar* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
+GArray* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
 				   int *height, gboolean offScreen, gboolean hasAlpha)
 {
   GtkWidget *wd;
-  guchar *image;
-  DumpImage *dumpData;
+  GArray *image;
+  VisuPixmapContext *dumpData;
+  VisuOpenGLView *view;
+  float *ext;
+  GtkAllocation allocation;
 
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), (guchar*)0);
-  g_return_val_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render, (guchar*)0);
-  g_return_val_if_fail(render->redraw, (guchar*)0);
-  g_return_val_if_fail(width && height, (guchar*)0);
+  g_return_val_if_fail(IS_OPENGL_WIDGET(render), (GArray*)0);
+  g_return_val_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render, (GArray*)0);
+  g_return_val_if_fail(render->redraw, (GArray*)0);
+  g_return_val_if_fail(width && height, (GArray*)0);
+  g_return_val_if_fail(render->redrawData, (GArray*)0);
 
   wd = GTK_WIDGET(render);
+  gtk_widget_get_allocation(wd, &allocation);
 
   if (!offScreen)
     {
-      *width = wd->allocation.width;
-      *height = wd->allocation.height;
+      *width = allocation.width;
+      *height = allocation.height;
       return visuOpenGLGet_pixmapData(*width, *height, hasAlpha);
     }
 
   /* If a method is given, then we draw
      in memory to a pixmap. */
-  *width = (*width > 0)?*width:wd->allocation.width;
-  *height = (*height > 0)?*height:wd->allocation.height;
+  *width = (*width > 0)?*width:allocation.width;
+  *height = (*height > 0)?*height:allocation.height;
   
   /* We create a pixmap context and make this context current. */
-  dumpData = visuOpenGLNew_pixmapContext((guint)*width, (guint)*height);
+  dumpData = visu_pixmap_context_new((guint)*width, (guint)*height);
   if (!dumpData)
     {
       /* Switch back to on-screen copy. */
       g_warning("can't create off-screen pixmap, will screenshot"
 		" the rendering area instead. Make sure that it is"
 		" free of any other windows.");
-      *width = wd->allocation.width;
-      *height = wd->allocation.height;
+      *width = allocation.width;
+      *height = allocation.height;
       return visuOpenGLGet_pixmapData(*width, *height, hasAlpha);
     }
+  view = visu_data_getOpenGLView(render->redrawData);
   /* We set the glViewport of this new context. */
-  glViewport(0, 0, *width, *height);
+  openGLInit_context();
+  openGLModelize(view->camera);
+  visu_data_setSizeOfView(render->redrawData, (guint)*width, (guint)*height);
+  ext = visu_data_getBoxExtens(render->redrawData);
+  openGLProject(view->window, view->camera, ext[1]);
+  visuExtensions_rebuildAllLists(render->redrawData);
   /* We call the given draw method. */
   render->redraw((const char**)0, render->redrawData);
   /* We copy the pixmap into generic data. */
@@ -485,7 +654,7 @@ guchar* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
   /* We change back the context to the current rendering area. */
   openGLWidgetSet_current(render, TRUE);
   /* We free the pixmap context. */
-  visuOpenGLFree_pixmapContext(dumpData);
+  visu_pixmap_context_free(dumpData);
 
   return image;
 }
@@ -498,8 +667,8 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
 
   DBG_fprintf(stderr, "Gtk OpenGL (glext): choose visual for %p.\n", render);
   /* Get the screen. */
-  if (GDK_IS_DRAWABLE(GTK_WIDGET(render)->window))
-    screen = gdk_drawable_get_screen(GDK_DRAWABLE(GTK_WIDGET(render)->window));
+  if (gtk_widget_get_visible(GTK_WIDGET(render)))
+    screen = gtk_widget_get_screen(GTK_WIDGET(render));
   else
     screen = gdk_screen_get_default();
   DBG_fprintf(stderr, " | get a screen number %d.\n",
@@ -581,7 +750,7 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
   OPENGL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
-  openGLWidgetSet_viewport(render, wd->allocation.width, wd->allocation.height, FALSE);
+  setViewport(render, wd->allocation.width, wd->allocation.height, FALSE);
 
   return TRUE;
 }
@@ -605,25 +774,27 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
 {
   gint screenId;
   gboolean built;
+  GdkScreen *screen;
 
-  built = GDK_IS_DRAWABLE(GTK_WIDGET(render)->window);
+  built = gtk_widget_get_visible(GTK_WIDGET(render));
   DBG_fprintf(stderr, "Gtk OpenGL (X11): choose visual for %p.\n", (gpointer)render);
   if (built)
-    render->dpy = gdk_x11_drawable_get_xdisplay(GDK_DRAWABLE(GTK_WIDGET(render)->window));
+    render->dpy = GDK_DISPLAY_XDISPLAY(gtk_widget_get_display(GTK_WIDGET(render)));
   else
     render->dpy = gdk_x11_get_default_xdisplay();
   DBG_fprintf(stderr, " | get the display %p.\n", (gpointer)render->dpy);
 
   /* Get the screen id. */
   if (built)
-    screenId = gdk_x11_screen_get_screen_number
-      (gdk_drawable_get_screen(GDK_DRAWABLE(GTK_WIDGET(render)->window)));
+    screen = gtk_widget_get_screen(GTK_WIDGET(render));
   else
-    screenId = gdk_x11_get_default_screen();
+    screen = gdk_screen_get_default();
+  screenId = gdk_screen_get_number(screen);
   DBG_fprintf(stderr, " | get a screen number %d.\n", screenId);
 
   render->vinfo = visuOpenGLGet_visualInfo(render->dpy, screenId);
   DBG_fprintf(stderr, " | get a visual %d.\n", (int)render->vinfo->visualid);
+  render->visual = gdk_x11_screen_lookup_visual(screen, render->vinfo->visualid);
 }
 static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDirect)
 {
@@ -683,6 +854,7 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
   int res;
   GtkWidget *wd;
   XID windowId;
+  GtkAllocation alloc;
   
   g_return_val_if_fail(IS_OPENGL_WIDGET(render), FALSE);
 
@@ -699,7 +871,7 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
 
   DBG_fprintf(stderr, "Gtk OpenGL (X11): %p is set current.\n", (gpointer)render);
 
-  windowId = gdk_x11_drawable_get_xid(GDK_DRAWABLE(GTK_WIDGET(render)->window));
+  windowId = GDK_WINDOW_XID(GDK_WINDOW(gtk_widget_get_window(GTK_WIDGET(render))));
   DBG_fprintf(stderr, "Gtk OpenGL (X11): widget windowID 0x%x.\n", (int)windowId);
 
   res = glXMakeCurrent(render->dpy, (GLXDrawable)windowId,
@@ -725,7 +897,8 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
   OPENGL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
-  openGLWidgetSet_viewport(render, wd->allocation.width, wd->allocation.height, FALSE);
+  gtk_widget_get_allocation(wd, &alloc);
+  setViewport(render, alloc.width, alloc.height, FALSE);
 
   return TRUE;
 }
@@ -734,9 +907,11 @@ void openGLWidgetSwap_buffers(OpenGLWidget *render)
   g_return_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
   DBG_fprintf(stderr, "Gtk OpenGL (X11): swap buffers of area %p.\n", (gpointer)render);
-  glXSwapBuffers(render->dpy, (GLXDrawable)gdk_x11_drawable_get_xid
-		 (GDK_DRAWABLE(GTK_WIDGET(render)->window)));
+  glXSwapBuffers(render->dpy,
+                 (GLXDrawable)GDK_WINDOW_XID(GDK_WINDOW(gtk_widget_get_window(GTK_WIDGET(render)))));
+  DBG_fprintf(stderr, "Gtk OpenGL (X11): swap OK.\n");
 }
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
 {
   g_return_val_if_fail(IS_OPENGL_WIDGET(render), (GdkColormap*)0);
@@ -745,6 +920,7 @@ static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
   return gdk_colormap_new(gdkx_visual_get(render->vinfo->visualid), FALSE);
 }
 #endif
+#endif
 #ifdef IMPL_BUILTIN_WIN32
 static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
 {
@@ -755,6 +931,8 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
   DBG_fprintf(stderr, " | get the hdc %d.\n", (int)render->hdc);
 
   visuOpenGLSetup_pixelFormat(render->hdc);
+  
+  render->visual = gdk_screen_get_system_visual(gdk_screen_get_default());
 }
 static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDirect)
 {
@@ -786,7 +964,7 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force _U_)
   OPENGL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
-  openGLWidgetSet_viewport(render, wd->allocation.width, wd->allocation.height, FALSE);
+  setViewport(render, wd->allocation.width, wd->allocation.height, FALSE);
 
   return TRUE;
 }
@@ -797,6 +975,7 @@ void openGLWidgetSwap_buffers(OpenGLWidget *render)
   DBG_fprintf(stderr, "Gtk OpenGL (action) : swap buffers of area %p.\n", (gpointer)render);
   SwapBuffers(render->hdc);
 }
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
 {
   g_return_val_if_fail(IS_OPENGL_WIDGET(render), (GdkColormap*)0);
@@ -804,3 +983,4 @@ static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
   return gdk_screen_get_system_colormap(gdk_screen_get_default());
 }
 #endif
+#endif
