@@ -99,7 +99,7 @@ void gtkPairsInit();
  *
  * Create the dialog window for pairs.
  */
-void gtkPairsBuild_window(GtkMain *main);
+void gtkPairsBuild_window(VisuUiMain *main);
 /**
  * gtkPairsBuild_pairs:
  * @main: the command panel the about dialog is associated to ;
@@ -111,7 +111,8 @@ void gtkPairsBuild_window(GtkMain *main);
  * gtkPairsBuild_window() has been called. The job is done only if the
  * window is visible or if the @force argument is used.
  */
-void gtkPairsBuild_pairs(GtkMain *main, VisuData *dataObj, gboolean force);
+void gtkPairsBuild_pairs(VisuUiMain *main, VisuData *dataObj, gboolean force);
+void gtkPairsShow(VisuUiMain *main);
 
 /**
  * gtkPairsSet_specificLabels:
@@ -128,7 +129,7 @@ void gtkPairsSet_specificLabels(GtkTreeIter *iter, const gchar *label);
  * gtkPairs_createPairs:
  *
  * Wrapper to get the current rendering window, retrieve its VisuData and call
- * visuPairBuild() with appropriate arguments and then emit 'OpenGLAskForReDraw'
+ * visu_pair_build() with appropriate arguments and then emit 'OpenGLAskForReDraw'
  * if needed.
  */
 void gtkPairs_createPairs();
