@@ -47,22 +47,26 @@
 
 #include <glib.h>
 
-#include "visu_pickMesure.h"
 #include "gtk_main.h"
 #include "gtk_renderingWindowWidget.h"
 
 /**
  * gtkPickBuild_interface:
  * @main: the main interface.
+ * @label: a location to store the name of the pick tab ;
+ * @help: a location to store the help message to be shown at the
+ * bottom of the window ;
+ * @radio: a location on the radio button that will be toggled when
+ * the pick action is used.
  * 
  * This routine should be called in conjonction to the
  * create_observeDialog() one. It completes the creation of widgets
  * (and also initialisation of values) for the pick tab.
  */
-GtkWidget* gtkPickBuild_interface(GtkMain *main, gchar **label,
+GtkWidget* gtkPickBuild_interface(VisuUiMain *main, gchar **label,
 				  gchar **help, GtkWidget **radio);
-void gtkPickStart(RenderingWindow *window);
-void gtkPickStop(RenderingWindow *window);
+void gtkPickStart(VisuRenderingWindow *window);
+void gtkPickStop(VisuRenderingWindow *window);
 /**
  * gtkPickGet_nodeSelection:
  *
@@ -91,4 +95,6 @@ void gtkPick_onClose();
  */
 gboolean gtkPickParse_XMLFile(const gchar* filename, VisuData *data, GError **error);
 
+void initGtkPick();
+
 #endif
