@@ -54,9 +54,15 @@
 #include "visu_configFile.h"
 #include "visu_object.h"
 #include "visu_tools.h"
+#include "visu_basic.h"
 #include "gtk_renderingWindowWidget.h"
 #include "visu_commandLine.h"
 
+/**
+ * SECTION: gtk_save
+ * @short_description: The load/save dialog for resources and parameters.
+ */
+
 static guint saveResourcesContextId, saveParametersContextId;
 static gchar *lastParsedDir;
 static GtkWidget *checkXMLResources, *checkXMLParameters, *checkXMLCommandLine;
@@ -89,6 +95,8 @@ void gtkSaveInit()
   gchar *directory, *file;
   GList *resList;
   GtkListStore *listOfFiles;
+  const gchar *currentResPath;
+  int i, j;
 
   saveDialog = create_saveDialog();
   gtk_widget_set_name(saveDialog, "message");
@@ -122,7 +130,7 @@ void gtkSaveInit()
 
   /* Set default values. */
   wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
-  if (renderingWindowGet_visuData(RENDERING_WINDOW(currentRenderingWindow)))
+  if (visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering()))
     gtk_widget_set_sensitive(wd, TRUE);
   else
     gtk_widget_set_sensitive(wd, FALSE);
@@ -155,59 +163,58 @@ void gtkSaveInit()
 
   wd = lookup_widget(saveDialog, "comboboxentryParameters");
   gtk_widget_set_name(wd, "message_entry");
-  resList = visuConfigFileGet_pathList(VISU_CONFIGFILE_PARAMETER);
-  if (resList)
-    {
-      do
-	{
-	  file = visuConfigFileGet_nextValidPath(VISU_CONFIGFILE_PARAMETER, W_OK, &resList, 1);
-	  if (file)
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(wd), file);
-	}
-      while(file);
-    }
+  resList = visu_configFile_getPathList(VISU_CONFIGFILE_PARAMETER);
+  for (file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_PARAMETER,
+					      W_OK, &resList, 1);
+       file;
+       file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_PARAMETER,
+					      W_OK, &resList, 1))
+    gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(wd), (const gchar*)0, file);
   completion = gtk_entry_completion_new();
   gtk_entry_completion_set_model(completion, GTK_TREE_MODEL(listOfFiles));
   gtk_entry_completion_set_text_column(completion, GTK_SAVE_FILE_NAME);
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_entry_completion_set_inline_completion(completion, TRUE);
 #endif
-  gtk_entry_set_completion(GTK_ENTRY(GTK_BIN(wd)->child), completion);
-  g_signal_connect(G_OBJECT(GTK_BIN(wd)->child), "changed",
+  gtk_entry_set_completion(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(wd))), completion);
+  g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(wd))), "changed",
 		   G_CALLBACK(onTextEntryChange), (gpointer)0);
   gtk_combo_box_set_active(GTK_COMBO_BOX(wd), 0);
 
 
   wd = lookup_widget(saveDialog, "comboboxentryResources");
   gtk_widget_set_name(wd, "message_entry");
-  resList = visuConfigFileGet_pathList(VISU_CONFIGFILE_RESOURCE);
-  if (resList)
+  currentResPath = visu_configFile_getPathToResources();
+  j = i = 0;
+  resList = visu_configFile_getPathList(VISU_CONFIGFILE_RESOURCE);
+  for (file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_RESOURCE,
+					      W_OK, &resList, 1);
+       file;
+       file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_RESOURCE,
+					      W_OK, &resList, 1))
     {
-      do
-	{
-	  file = visuConfigFileGet_nextValidPath(VISU_CONFIGFILE_RESOURCE, W_OK, &resList, 1);
-	  if (file)
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(wd), file);
-	}
-      while(file);
+      if (!strcmp(file, currentResPath))
+	j = i;
+      gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(wd), (const gchar*)0, file);
+      i += 1;
     }
   completion = gtk_entry_completion_new();
   gtk_entry_completion_set_model(completion, GTK_TREE_MODEL(listOfFiles));
   gtk_entry_completion_set_text_column(completion, GTK_SAVE_FILE_NAME);
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_entry_completion_set_inline_completion(completion, TRUE);
 #endif
-  gtk_entry_set_completion(GTK_ENTRY(GTK_BIN(wd)->child), completion);
-  g_signal_connect(G_OBJECT(GTK_BIN(wd)->child), "changed",
+  gtk_entry_set_completion(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(wd))), completion);
+  g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(wd))), "changed",
 		   G_CALLBACK(onTextEntryChange), (gpointer)0);
-  gtk_combo_box_set_active(GTK_COMBO_BOX(wd), 0);
+  gtk_combo_box_set_active(GTK_COMBO_BOX(wd), j);
 
   wd = lookup_widget(saveDialog, "labelTipsResources");
   gtk_label_set_line_wrap(GTK_LABEL(wd), FALSE);
   gtk_label_set_markup(GTK_LABEL(wd), _("A description of all resource markups is"
 					" available on:"
 					"\n   <span font_desc=\"monospace\"><u>"
-					V_SIM_WEB_SITE"/sample.html#resources"
+					VISU_WEB_SITE"/sample.html#resources"
 					"</u></span>."));
 
   /* Set callbacks. */
@@ -259,7 +266,7 @@ void gtkSaveInit()
   gtk_label_set_markup(GTK_LABEL(label), _("A description of all parameter markups is"
 					   " available on:\n"
 					   "   <span font_desc=\"monospace\"><u>"
-					   V_SIM_WEB_SITE"/sample.html#parameters"
+					   VISU_WEB_SITE"/sample.html#parameters"
 					   "</u></span>."));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
   gtk_box_pack_end(GTK_BOX(wd), label, FALSE, FALSE, 10);
@@ -318,9 +325,9 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   visuGtkSet_lastOpenDirectory(directory, VISU_DIR_CONF);
   g_free(directory);
 
-  dataObj = renderingWindowGet_visuData(currentRenderingWindow);
+  dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
   error = (GError*)0;
-  res = visuConfigFileLoad(VISU_CONFIGFILE_RESOURCE, filename, dataObj, &error);
+  res = visu_configFile_load(VISU_CONFIGFILE_RESOURCE, filename, dataObj, &error);
   if (error)
     {
       visuGtkRaise_warningLong(_("Loading a file"), error->message,
@@ -340,8 +347,12 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   g_string_free(message, TRUE);
   g_free(basename);
 
-  if (res)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+  if (res && dataObj)
+    {
+      /* We rebuild all list. */
+      visuExtensions_rebuildAllLists(dataObj);
+      VISU_ADD_REDRAW;
+    }
 }
 
 static void onSaveResButtonClicked(GtkButton *button _U_, gpointer data)
@@ -350,7 +361,8 @@ static void onSaveResButtonClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(GTK_IS_DIALOG(data));
 
-  entry = GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryResources"))->child;
+  entry = gtk_bin_get_child
+    (GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryResources")));
   saveAction(VISU_CONFIGFILE_RESOURCE, GTK_WIDGET(data), GTK_ENTRY(entry));
   gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
 }
@@ -361,7 +373,8 @@ static void onSaveParButtonClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(GTK_IS_DIALOG(data));
 
-  entry = GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryParameters"))->child;
+  entry = gtk_bin_get_child
+    (GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryParameters")));
   saveAction(VISU_CONFIGFILE_PARAMETER, GTK_WIDGET(data), GTK_ENTRY(entry));
   gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
 }
@@ -389,7 +402,7 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   if (g_file_test(file, G_FILE_TEST_IS_DIR))
     {
       tmpFile=
-	g_build_filename(file, visuConfigFileGet_defaultFileName(type), NULL);
+	g_build_filename(file, visu_configFile_getDefaultFilename(type), NULL);
       g_free(file);
       file = tmpFile;
     }
@@ -398,8 +411,7 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
     {
       wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wd)))
-	dataObj = renderingWindowGet_visuData
-	  (RENDERING_WINDOW(currentRenderingWindow));
+	dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
       else
 	dataObj = (VisuData*)0;
     }
@@ -410,15 +422,15 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   lines = 0;
   if (type == VISU_CONFIGFILE_RESOURCE && checkXMLResources &&
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLResources)))
-    resOk = visuConfigFileExport_toXML(file, VISU_CONFIGFILE_RESOURCE, &error);
+    resOk = visu_configFile_exportToXML(file, VISU_CONFIGFILE_RESOURCE, &error);
   else if (type == VISU_CONFIGFILE_PARAMETER && checkXMLParameters &&
 	   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLParameters)))
-    resOk = visuConfigFileExport_toXML(file, VISU_CONFIGFILE_PARAMETER, &error);
+    resOk = visu_configFile_exportToXML(file, VISU_CONFIGFILE_PARAMETER, &error);
   else if (type == VISU_CONFIGFILE_PARAMETER && checkXMLCommandLine &&
 	   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLCommandLine)))
     resOk = commandLineExport(file, &error);
   else
-    resOk = visuConfigFileSave(type, file, &lines, dataObj, &error);
+    resOk = visu_configFile_save(type, file, &lines, dataObj, &error);
   if (!resOk)
     {
       visuGtkRaise_warningLong(_("Saving a file"), error->message,
