@@ -53,12 +53,26 @@
 
 #include <string.h>
 
+/**
+ * SECTION:renderingMode
+ * @short_description: Controls the way OpenGL renders objects.
+ * 
+ * <para>
+ * This modules creates an interface to access to the way OpenGL
+ * renders the objects (glPolygonMode() and glShadeModel()
+ * functions). There are then three rendering modes available in
+ * V_Sim: wireframe, flat and smooth. They are controls by an enum
+ * #RenderingModeId. When openGLApply_renderingMode() is called, the
+ * current rendering mode is changed for all future drawing calls that
+ * uses polygons.
+ * </para>
+ */
 
 #define FLAG_PARAMETER_OPENGL_RENDERING "opengl_render"
 #define DESC_PARAMETER_OPENGL_RENDERING "Rules the way OpenGl draws objects in general ; 4 possible strings : Wireframe, Flat, Smooth and SmoothAndEdge"
 #define PARAMETER_OPENGL_RENDERING_DEFAULT Smooth
 
-static RenderingModeId renderingOption;
+static VisuRenderingModeId renderingOption;
 static gboolean readOpenGLRendering(gchar **lines, int nbLines, int position,
 				    VisuData *dataObj, GError **error);
 static void exportParametersRenderingMode(GString *data, VisuData *dataObj);
@@ -68,16 +82,16 @@ static const char *renderingStrings[nb_renderingModes + 1] =
 static const char *renderingStringsI18n[nb_renderingModes + 1];
 
 
-void openGLInit_renderingMode()
+void openGLInit_renderingMode(void)
 {
   VisuConfigFileEntry *confEntry;
 
   DBG_fprintf(stderr, "OpenGl RenderingMode : initialization.\n");
-  confEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  confEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 				      FLAG_PARAMETER_OPENGL_RENDERING,
 				      DESC_PARAMETER_OPENGL_RENDERING,
 				      1, readOpenGLRendering);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParametersRenderingMode);
 
   renderingOption = PARAMETER_OPENGL_RENDERING_DEFAULT;
@@ -89,7 +103,7 @@ void openGLInit_renderingMode()
 }
 
 /* This function change the value of the parameter renderingOption. */
-void openGLApply_renderingMode(RenderingModeId mode)
+void openGLApply_renderingMode(VisuRenderingModeId mode)
 {
   switch (mode)
     {
@@ -115,7 +129,7 @@ void openGLApply_renderingMode(RenderingModeId mode)
   DBG_fprintf(stderr, "Rendering Mode : switch rendering mode to '%s'.\n",
 	      renderingStrings[mode]);
 }
-gboolean openGLSet_globalRenderingMode(RenderingModeId value)
+gboolean openGLSet_globalRenderingMode(VisuRenderingModeId value)
 {
   g_return_val_if_fail(value < nb_renderingModes, FALSE);
   
@@ -128,19 +142,19 @@ gboolean openGLSet_globalRenderingMode(RenderingModeId value)
   return 1;
 }
 /* This function retrieve the value of the parameter renderingOption. */
-RenderingModeId openGLGet_globalRenderingOption()
+VisuRenderingModeId openGLGet_globalRenderingOption(void)
 {
   return renderingOption;
 }
-const char** openGLGet_allRenderingModesI18n()
+const char** openGLGet_allRenderingModesI18n(void)
 {
   return renderingStringsI18n;
 }
-const char** openGLGet_allRenderingModes()
+const char** openGLGet_allRenderingModes(void)
 {
   return renderingStrings;
 }
-gboolean openGLGet_renderingFromName(const char* name, RenderingModeId *id)
+gboolean openGLGet_renderingFromName(const char* name, VisuRenderingModeId *id)
 {
   g_return_val_if_fail(name && id, FALSE);
 
@@ -153,16 +167,16 @@ gboolean openGLGet_renderingFromName(const char* name, RenderingModeId *id)
 static gboolean readOpenGLRendering(gchar **lines, int nbLines, int position,
 				    VisuData *dataObj _U_, GError **error)
 {
-  RenderingModeId id;
+  VisuRenderingModeId id;
   gchar **val;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_string(lines[0], position, &val, 1, FALSE, error))
+  if (!tool_configFile_readString(lines[0], position, &val, 1, FALSE, error))
     return FALSE;
   if (!openGLGet_renderingFromName(val[0], &id))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: the shape '%s' is unknown.\n"),
 			   position, val[0]);
 
