@@ -47,7 +47,7 @@
 #include <glib.h>
 
 /**
- * RenderingModeId:
+ * VisuRenderingModeId:
  * @Wireframe: objects are rendered with lines only ;
  * @Flat: objects are rendered with polygons whose colours are uniform
  *        on each polygon ;
@@ -68,7 +68,7 @@ typedef enum
     SmoothAndEdge,
     nb_renderingModes,
     followGeneralSetting
-  } RenderingModeId;
+  } VisuRenderingModeId;
 
 /**
  * openGLInit_renderingMode:
@@ -76,7 +76,7 @@ typedef enum
  * This method is used by opengl.c to initialise this module (declare config file
  * options...). It should not be called elsewhere.
  */
-void openGLInit_renderingMode();
+void openGLInit_renderingMode(void);
 
 /**
  * openGLSet_globalRenderingMode:
@@ -87,7 +87,7 @@ void openGLInit_renderingMode();
  *
  * Returns: TRUE if the signal OpenGLAskForReDraw should be emitted.
  */
-gboolean openGLSet_globalRenderingMode(RenderingModeId value);
+gboolean openGLSet_globalRenderingMode(VisuRenderingModeId value);
 /**
  * openGLGet_globalRenderingOption:
  *
@@ -95,7 +95,7 @@ gboolean openGLSet_globalRenderingMode(RenderingModeId value);
  *
  * Returns: the identifier of the current rendering option.
  */
-RenderingModeId openGLGet_globalRenderingOption();
+VisuRenderingModeId openGLGet_globalRenderingOption(void);
 /**
  * openGLGet_renderingFromName:
  * @name: a string ;
@@ -105,7 +105,7 @@ RenderingModeId openGLGet_globalRenderingOption();
  *
  * Returns: TRUE if the name exists.
  */
-gboolean openGLGet_renderingFromName(const char* name, RenderingModeId *id);
+gboolean openGLGet_renderingFromName(const char* name, VisuRenderingModeId *id);
 /**
  * openGLGet_allRenderingModes:
  *
@@ -113,7 +113,7 @@ gboolean openGLGet_renderingFromName(const char* name, RenderingModeId *id);
  *
  * Returns: an array of string, NULL terminated that is private (not to be freed).
  */
-const char** openGLGet_allRenderingModes();
+const char** openGLGet_allRenderingModes(void);
 /**
  * openGLGet_allRenderingModesI18n:
  *
@@ -121,14 +121,14 @@ const char** openGLGet_allRenderingModes();
  *
  * Returns: an array of string, NULL terminated that is private (not to be freed).
  */
-const char** openGLGet_allRenderingModesI18n();
+const char** openGLGet_allRenderingModesI18n(void);
 /**
  * openGLApply_renderingMode:
  * @mode: an integer.
  *
  * Change the rendering mode of current OpenGL context.
  */
-void openGLApply_renderingMode(RenderingModeId mode);
+void openGLApply_renderingMode(VisuRenderingModeId mode);
 
 
 
