@@ -48,6 +48,15 @@
 #include <visu_tools.h>
 #include <OSOpenGL/visu_openGL.h>
 
+/**
+ * SECTION:text
+ * @short_description: Enables capabilities to write some text on rendering screen.
+ * 
+ * <para>For the moment, this module is very basic and the only fonts
+ * available is the helvetica 12 one. This module is currently broken
+ * under Windows.</para>
+ */
+
 static GLuint BASE;  /* for the font display list */
 static GLuint SMALL; /* for the small font display list */
 static gboolean textListHaveBeenBuilt = FALSE;
@@ -82,11 +91,18 @@ void openGLText_initFontList()
 
 void openGLText_rebuildFontList()
 {
-  DBG_fprintf(stderr, "OpenGL Text: force rebuilding font list.\n");
-  textListHaveBeenBuilt = FALSE;
+  DBG_fprintf(stderr, "OpenGL Text: rebuilding font list.\n");
   openGLText_initFontList();
 }
 
+/**
+ * openGLText_onNewContext:
+ *
+ * Set the flag for text list build to FALSE. It will force to rebuild
+ * the text lists at next call of openGLText_initFontList().
+ *
+ * Since: 3.6
+ */
 void openGLText_onNewContext()
 {
   DBG_fprintf(stderr, "OpenGL Text: new context, forgetting fonts.\n");
