@@ -55,14 +55,36 @@
 #include "openGLFunctions/interactive.h"
 #include "openGLFunctions/view.h"
 #include "openGLFunctions/objectList.h"
-#include "renderingBackend/visu_windowInterface.h"
 #include "coreTools/toolConfigFile.h"
 #include "coreTools/toolColor.h"
 
+/**
+ * SECTION:opengl
+ * @short_description: This part is responsible for the pseudo3D
+ * rendering through OpenGl and gives methods to adapt the view.
+ *
+ * <para>There is a last parameter which controls when render is
+ * done. There are two states : whenever a changing occurs (in fact
+ * when the OpenGLAskForReDraw signal is received) or only the
+ * OpenGLForceReDraw is received.</para>
+ *
+ * <para>Except when high performances are required, this module never
+ * makes a redraw by itself, even when parameters such as the camera
+ * position are changed. The redraw must be asked by the client by
+ * emitting the OpenGLAskForReDraw signal or the OpenGLForceReDraw
+ * signal. This is to avoid situations when the client makes different
+ * changes but want just only one redraw at the end. All set methods
+ * return a boolean which informs the client of the opportunity to
+ * redraw after the set occurs. For example, if the client call a set
+ * change on theta or phi but the server returns FALSE, it means that
+ * not emission of OpenGLAskForReDraw is needed (for example because
+ * theta or phi had already these values).</para>
+ */
+
 /******************************************************************************/
 
 /* static int stereo; */
-static LightEnvironnement *currentLights;
+static LightEnvironnement *currentLights = NULL;
 
 #define FLAG_PARAMETER_OPENGL_IMMEDIATE   "opengl_immediateDrawing"
 #define DESC_PARAMETER_OPENGL_IMMEDIATE   "If true, changes of parameters means immediate redrawing ; boolean 0 or 1"
@@ -104,57 +126,51 @@ static gboolean readOpenGLStereo(gchar **lines, int nbLines, int position,
 
 /* Local methods. */
 static void exportParametersOpenGL(GString *data, VisuData *dataObj);
-
-void glSetAntiAlias();
-/* Private - This initialise the opengl redering (light...) */
-void gl_new_data(GenericRenderingWindow window, VisuData *data);
+static void glSetAntiAlias();
 
 /******************************************************************************/
 
-int initOpengl()
+/**
+ * initOpengl:
+ *
+ * This initialises the drawing window and all the variables used
+ * by this module. It must be called once by the main program and should
+ * not be used otherwise.
+ */
+void initOpengl()
 {
   VisuConfigFileEntry *resourceEntry;
 
   DBG_fprintf(stderr, "OpenGl: initialization.\n");
 
-/*   glViewport(0, 0, width, height); */
-
-  /* Deals with lights. */
-  currentLights = lightEnvironnement_new();
-  lightEnvironnementAdd_light(currentLights, light_newDefault());
-
   /* Parameters */
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_TRANS,
 					  DESC_PARAMETER_OPENGL_TRANSS,
 					  1, readOpenGLTransparency);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_ANTIALIAS,
 					  DESC_PARAMETER_OPENGL_ANTIALIAS,
 					  1, readOpenGLAntialias);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_IMMEDIATE,
 					  DESC_PARAMETER_OPENGL_IMMEDIATE,
 					  1, readOpenGLImmediate);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_ANGLE,
 					  DESC_PARAMETER_OPENGL_ANGLE,
 					  1, readOpenGLStereoAngle);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_STEREO,
 					  DESC_PARAMETER_OPENGL_STEREO,
 					  1, readOpenGLStereo);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParametersOpenGL);
   
-  /* Initialise others sub-modules dealing with OpenGL. */
-  openGLObjectList_init();
-  openGLInit_renderingMode();
-  OpenGLViewInit();
-  visuInteractive_get_type();
+  g_type_class_ref(visuInteractive_get_type());
 
   antialias = PARAMETER_OPENGL_ANTIALIAS_DEFAULT;
   fakeBackingStore = PARAMETER_OPENGL_FAKEBS_DEFAULT;
@@ -162,16 +178,54 @@ int initOpengl()
   stereoAngles[0] = +PARAMETER_OPENGL_ANGLE_DEFAULT;
   stereoAngles[1] = -PARAMETER_OPENGL_ANGLE_DEFAULT;
 
-  return 1;
+  initObjectList();
+}
+/**
+ * initOpenglGraphics:
+ *
+ * Internal use only. Call at startup to call OpenGL initialisation routines.
+ *
+ * Since: 3.6
+ */
+void initOpenglGraphics()
+{
+  /* Deals with lights. */
+  currentLights = lightEnvironnement_new();
+  lightEnvironnementAdd_light(currentLights, light_newDefault());
+
+  /* Initialise others sub-modules dealing with OpenGL. */
+  openGLInit_renderingMode();
+  VisuOpenGLViewInit();
+
+  /* Charge toutes les extensions OpenGL. */
+  DBG_fprintf(stderr,"--- Initialising external OpenGL Extensions ---\n");
+  loadExtensions();
 }
 
+/**
+ * openGLGet_currentLights:
+ *
+ * V_Sim proposes a wrapper around the OpenGL light definitions.
+ *
+ * Returns: the set of current lights.
+ */
 LightEnvironnement* openGLGet_currentLights()
 {
+  if (!currentLights)
+    initOpenglGraphics();
+
   return currentLights;
 }
 
 /******************************************************************************/
 
+/**
+ * openGLSet_color:
+ * @material: a 5 elements array with the material properties ;
+ * @rgba: a 4 elements array with the color values.
+ *
+ * This method call glMaterial to create the right shiningness, emission, diffuse...
+ */
 void openGLSet_color(float* material, float* rgba)
 {
   float mm[4] = {0.0f, 0.0f, 0.0f, 0.0f};
@@ -197,21 +251,38 @@ void openGLSet_color(float* material, float* rgba)
   mm[2] = material[material_emi] * rgba[2];
   glMaterialfv(GL_FRONT, GL_EMISSION, mm);
 }
+/**
+ * openGLSet_highlightColor:
+ * @material: a 5 elements array with the material properties ;
+ * @rgb: a 3 elements array with the color values.
+ * @alpha: the alpha channel.
+ *
+ * This method try to set a colour that will contrast with @rgb.
+ */
 void openGLSet_highlightColor(float material[5], float rgb[3], float alpha)
 {
   float rgba[4], hsl[3];
   
-  color_RGBtoHSL(hsl, rgb);
+  tool_color_convertRGBtoHSL(hsl, rgb);
   hsl[0] = fModulo(0.5f + hsl[0], 1);
   hsl[1] = 1.f;
   hsl[2] = .5f;
-  color_HSLtoRGB(rgba, hsl);
+  tool_color_convertHSLtoRGB(rgba, hsl);
   rgba[3] = alpha;
   openGLSet_color(material, rgba);
 }
 
+/**
+ * openGLInit_context:
+ *
+ * This method is called when an OpenGL surface is created for the first time.
+ * It sets basic OpenGL options and calls other OpenGLFunctions used in V_Sim.
+ */
 void openGLInit_context()
 {
+  if (!currentLights)
+    initOpengl();
+
   /* Set the openGL flags. */
   glEnable(GL_DEPTH_TEST);
   glDepthFunc(GL_LEQUAL);
@@ -230,18 +301,25 @@ void openGLInit_context()
   openGLApply_renderingMode(openGLGet_globalRenderingOption());
 
   glSetAntiAlias();
-
-/*   OpenGLViewSet_windowSize(view, wi, he); */
 }
 
 /******************************************************************************/
 
+/**
+ * openGL_reDraw:
+ * @lists: (array zero-terminated=1) (allow-none): a string array, NULL terminated.
+ * @data: the #VisuData to redraw.
+ *
+ * Basic drawing method : it clears the OpenGL area and call all lists if @lists
+ * is NULL, or draw only the given lists.
+ */
 void openGL_reDraw(const char **lists, VisuData *data)
 {
   int i, i_stereo, stereo;
   static int stereo_buf[2] = {GL_BACK_LEFT, GL_BACK_RIGHT};
-  OpenGLView *view;
+  VisuOpenGLView *view;
   GLboolean glStereo;
+  float centre[3];
 
 #if DEBUG == 1
   GTimer *timer;
@@ -255,144 +333,101 @@ void openGL_reDraw(const char **lists, VisuData *data)
   
   g_return_if_fail(IS_VISU_DATA_TYPE(data));
 
-  view = visuDataGet_openGLView(VISU_DATA(data));
+  view = visu_data_getOpenGLView(data);
+  visu_data_getBoxCentre(data, centre);
 
   glGetBooleanv(GL_STEREO, &glStereo);
   stereo = (view && glStereo && stereoStatus)?1:0;
   for(i_stereo = 0; i_stereo <= stereo; i_stereo++)
     {
-      
       if (stereo == 1)
-	{   
-	  glRotatef(stereoAngles[i_stereo],
-		    view->camera->up[0],
-		    view->camera->up[1],
-		    view->camera->up[2]);
-	  glDrawBuffer(stereo_buf[i_stereo]);
-	  DBG_fprintf(stderr, "OpenGL: draw on buffer %d.\n", i_stereo);
-	}
+        {
+          glRotatef(stereoAngles[i_stereo],
+        	    view->camera->up[0],
+        	    view->camera->up[1],
+        	    view->camera->up[2]);
+          glDrawBuffer(stereo_buf[i_stereo]);
+          DBG_fprintf(stderr, "OpenGL: draw on buffer %d.\n", i_stereo);
+        }
       else
-	glDrawBuffer(GL_BACK);
+        glDrawBuffer(GL_BACK);
 
       glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
-      glEnable(GL_DEPTH_TEST);
-      if (trueTransparency)
-	{
-	  glDepthMask(1);
-	  glEnable(GL_ALPHA_TEST);
-	  glAlphaFunc(GL_EQUAL, 1.);
-	}
-      else
-	glDisable(GL_ALPHA_TEST);
-
       glPushMatrix();
-      glTranslated(-view->box->dxxs2, -view->box->dyys2, -view->box->dzzs2);
-      if (lists)
-	for (i = 0; lists[i]; i++)
-	  OpenGLExtensionCall_list(lists[i], FALSE);
-      else
-	OpenGLExtensionCall_allLists();
-      if (trueTransparency)
-	{
-	  DBG_fprintf(stderr, "OpenGL: second pass for transparency.\n");
-	  glAlphaFunc(GL_LESS, 1.);
-	  glDepthMask(0);
-	  if (lists)
-	    for (i = 0; lists[i]; i++)
-	      OpenGLExtensionCall_list(lists[i], FALSE);
-	  else
-	    OpenGLExtensionCall_allLists();
-	  glDepthMask(1);
-	  glAlphaFunc(GL_ALWAYS, 1.);
-	}
-      if (lists)
-	for (i = 0; lists[i]; i++)
-	  OpenGLExtensionCall_list(lists[i], TRUE);
-      else
-	OpenGLExtensionCall_lastLists();
-      glPopMatrix();  
+      glTranslated(-centre[0], -centre[1], -centre[2]);
 
+      glEnable(GL_DEPTH_TEST);
+
+      if (!lists && !trueTransparency)
+        {
+          visuExtensions_callAllLists();
+          visuExtensions_callAllLastLists();
+        }
+      else if (!lists && trueTransparency)
+        {
+          glDepthMask(1);
+          glEnable(GL_ALPHA_TEST);
+          glAlphaFunc(GL_EQUAL, 1.);
+          visuExtensions_callAllLists();
+          DBG_fprintf(stderr, "OpenGL: second pass for transparency.\n");
+          glAlphaFunc(GL_LESS, 1.);
+          glDepthMask(0);
+          visuExtensions_callAllLists();
+          glDepthMask(1);
+          glAlphaFunc(GL_ALWAYS, 1.);
+          glDisable(GL_ALPHA_TEST);
+          visuExtensions_callAllLastLists();
+        }
+      else if (!trueTransparency)
+        {
+          for (i = 0; lists[i]; i++)
+            visuExtensions_callList(lists[i], FALSE);
+          for (i = 0; lists[i]; i++)
+            visuExtensions_callList(lists[i], TRUE);
+        }
+      else
+        {
+          glDepthMask(1);
+          glEnable(GL_ALPHA_TEST);
+          glAlphaFunc(GL_EQUAL, 1.);
+          for (i = 0; lists[i]; i++)
+            visuExtensions_callList(lists[i], FALSE);
+          DBG_fprintf(stderr, "OpenGL: second pass for transparency.\n");
+          glAlphaFunc(GL_LESS, 1.);
+          glDepthMask(0);
+          for (i = 0; lists[i]; i++)
+            visuExtensions_callList(lists[i], FALSE);
+          glDepthMask(1);
+          glAlphaFunc(GL_ALWAYS, 1.);
+          glDisable(GL_ALPHA_TEST);
+          for (i = 0; lists[i]; i++)
+            visuExtensions_callList(lists[i], TRUE);
+        }
+
+      glPopMatrix();
     }
 
 #if DEBUG == 1
   glFlush();
   g_timer_stop(timer);
-  fprintf(stderr, "OpenGL: lists drawn in %g micro-s.\n", g_timer_elapsed(timer, &fractionTimer)/1e-6);
+  fprintf(stderr, "OpenGL: lists drawn in %g micro-s.\n",
+          g_timer_elapsed(timer, &fractionTimer)*1e6);
   g_timer_destroy(timer);
 #endif
 }
 
-void openGL_drawToEmpty(const char **lists _U_, VisuData *data _U_)
-{
-  gpointer image;
-  int widthImg, heightImg;
-  guchar *imageData;
-  gboolean alpha;
-  int x, y;
-  float rgb[3];
-  int viewport[4];
-
-  DBG_fprintf(stderr, "Opengl: Rebuild default background.\n");
-  glPushAttrib(GL_ENABLE_BIT);
-  visuRenderingWindowGet_backgroundColor(visuRenderingWindowGet_current(), rgb);
-  DBG_fprintf(stderr, "Opengl: set background color to (%f,%f,%f).\n",
-	      rgb[0], rgb[1], rgb[2]);
-  glClearColor(rgb[0], rgb[1], rgb[2], 0.25f);
-  glDrawBuffer(GL_BACK);
-  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-  image = visuRenderingWindowGet_backgroundImage(visuRenderingWindowGet_current(),
-						 &imageData, &alpha,
-						 &widthImg, &heightImg);
-  if (image)
-    {
-      glDisable(GL_FOG);
-      glEnable(GL_BLEND);
-      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-
-      /* We can use fixed value for widthImg and heightImg since we project then
-	 in a 2D ortho with these values. */
-      glGetIntegerv(GL_VIEWPORT, viewport);
-      DBG_fprintf(stderr, "Opengl: Get viewport %dx%d.\n", viewport[2], viewport[3]);
-      x = (viewport[2] - widthImg) / 2;
-      y = (viewport[3] + heightImg) / 2;
-      DBG_fprintf(stderr, "Opengl: draw at %dx%d.\n", x, y);
-      glMatrixMode(GL_PROJECTION);
-      glPushMatrix();
-      glLoadIdentity();
-      gluOrtho2D(0.0, (float)viewport[2], 0., (float)viewport[3]);
-   
-      glMatrixMode(GL_MODELVIEW);
-      glPushMatrix();
-      glLoadIdentity();
-
-      glRasterPos2i(x, y);
-
-      glPixelZoom(1., -1.);
-      if (alpha)
-	glDrawPixels(widthImg, heightImg, GL_RGBA, GL_UNSIGNED_BYTE, imageData);
-      else
-	glDrawPixels(widthImg, heightImg, GL_RGB, GL_UNSIGNED_BYTE, imageData);
-      glPixelZoom(1., 1.);
-
-      glPopMatrix();
-      glMatrixMode(GL_PROJECTION);
-      glPopMatrix();
-      glMatrixMode(GL_MODELVIEW);
-    }
-  glPopAttrib();
-} 
-
 /******************************************************************************/
 
 /* To set the antialiasing on lines. */
-void glSetAntiAlias()
+static void glSetAntiAlias()
 {
   if (antialias)
     {
       /* Set blend if not present */
       glEnable(GL_BLEND);
       glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+/*       glBlendFunc(GL_SRC_ALPHA_SATURATE,GL_ONE); */
 
       /* Antialias */
       glEnable(GL_LINE_SMOOTH);
@@ -404,7 +439,7 @@ void glSetAntiAlias()
 /*       glDisable(GL_BLEND); */
     }
 }
-int setAntialias(int value)
+int openGLSet_antialias(int value)
 {
   if (value == antialias)
     return 0;
@@ -415,7 +450,7 @@ int setAntialias(int value)
   return 1;
 }
 /* Get the value of the antialiasing parameter. */
-int getAntialias()
+int openGLGet_antialias()
 {
   return antialias;
 }
@@ -493,9 +528,9 @@ static gboolean readOpenGLAntialias(gchar **lines, int nbLines, int position,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  setAntialias((int)val);
+  openGLSet_antialias((int)val);
 
   return TRUE;
 }
@@ -507,7 +542,7 @@ static gboolean readOpenGLImmediate(gchar **lines, int nbLines, int position,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
   openGLSet_immediate((int)val);
 
@@ -520,7 +555,7 @@ static gboolean readOpenGLTransparency(gchar **lines, int nbLines, int position,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
   openGLSet_trueTransparency(val);
 
@@ -533,7 +568,7 @@ static gboolean readOpenGLStereo(gchar **lines, int nbLines, int position,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
   openGLSet_stereo(val);
 
@@ -546,11 +581,11 @@ static gboolean readOpenGLStereoAngle(gchar **lines, int nbLines, int position,
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readFloat(lines[0], position, &val, 1, error))
     return FALSE;
   if (val <= 0.f)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: angle must be positive.\n"),
 			   position);
       return FALSE;
