@@ -57,54 +57,32 @@
 /* Public part */
 /***************/
 
-/**
- * setOpenGlMaterial:
- * @material: a 5 elements array with the material properties ;
- * @rgba: a 4 elements array with the color values.
- *
- * This method call glMaterial to create the right shiningness, emission, diffuse...
- */
 void openGLSet_color(float* material, float* rgba);
 void openGLSet_highlightColor(float material[5], float rgb[3], float alpha);
 
-
-/* Object to deal with quadrics. */
-/* GLUquadricObj *obj; */
-
-/**
- * initOpengl:
- *
- * This initialises the drawing window and all the variables used
- * by this module. It must be called once by the main program and should
- * not be used otherwise.
- *
- * Returns: 1 if everything goes right.
- */
-int initOpengl();
+void initOpengl();
+void initOpenglGraphics();
 
 /* Objects to play with lights. */
 LightEnvironnement* openGLGet_currentLights();
 
-
-/* Draw methods */
-
 /**
- * setAntialias:
+ * openGLSet_antialias:
  * @value: a boolean to activate or not the lines antialias.
  *
  * To set the antialiasing on lines.
  *
  * Returns: TRUE if the signal OpenGLAskForReDraw should be emitted.
  */
-int setAntialias(int value);
+int openGLSet_antialias(int value);
 /**
- * getAntialias:
+ * openGLGet_antialias:
  *
  * Get the value of the antialiasing parameter.
  *
  * Returns: wether or not the antialising for lines is activated.
  */
-int getAntialias();
+int openGLGet_antialias();
 
 /**
  * openGLSet_immediate:
@@ -185,29 +163,7 @@ void openGLSet_stereo(gboolean status);
 gboolean openGLGet_stereo();
 
 /* redraw methods */
-/**
- * openGL_reDraw:
- * @lists: a string array, NULL terminated.
- * @data: the #VisuData to redraw.
- *
- * Basic drawing method : it clears the OpenGL area and call all lists if @lists
- * is NULL, or draw only the given lists.
- */
 void openGL_reDraw(const char **lists, VisuData *data);
-/**
- * openGL_drawToEmpty:
- * @lists: always NULL.
- * @data: always NULL.
- *
- * Basic drawing method when no data is loaded: it draws the V_Sim logo.
- */
-void openGL_drawToEmpty(const char **lists, VisuData *data);
-/**
- * openGLInit_context:
- *
- * This method is called when an OpenGL surface is created for the first time.
- * It sets basic OpenGL options and calls other OpenGLFunctions used in V_Sim.
- */
 void openGLInit_context();
 
 
