@@ -72,7 +72,7 @@
  */
 
 static int listCylinder;
-static PairsExtension* pointerToPairExtension_cylinder;
+static VisuPairExtension* pointerToPairExtension_cylinder;
 
 #define FLAG_RESOURCES_PAIR_RADIUS "pairCylinder_pairRadius"
 #define DESC_RESOURCES_PAIR_RADIUS "This value is the radius for specific pairs drawn as cylinders ; element1 elemen2 0 < real < 10"
@@ -99,12 +99,17 @@ static gboolean readCylinderColorType(gchar **lines, int nbLines, int position,
 static void exportResourcesCylinder(GString *data, VisuData *dataObj);
 
 
-PairsExtension* cylinderGet_static()
+/**
+ * cylinderGet_static:
+ *
+ * Internal use only to get the cylinder extension.
+ */
+VisuPairExtension* cylinderGet_static()
 {
   return pointerToPairExtension_cylinder;
 }
 
-int setCylinderGeneralRadius(float val)
+int cylinderSet_generalRadius(float val)
 {
   DBG_fprintf(stderr, "Pairs Cylinder : set the general cylinder radius to %f.\n", val);
   val = CLAMP(val, RESOURCES_CYLINDER_RADIUS_MIN, RESOURCES_CYLINDER_RADIUS_MAX);
@@ -112,16 +117,16 @@ int setCylinderGeneralRadius(float val)
   if (val == cylinderRadius)
     return 0;
 
-  visuPairSet_outOfDate();
+  visu_pair_setOutOfDate();
   cylinderRadius = val;
   return 1;
 }
-float getCylinderGeneralRadius()
+float cylinderGet_generalRadius()
 {
   return cylinderRadius;
 }
 
-int setCylinderRadius(VisuPairData *data, float val)
+int cylinderSet_radius(VisuPairData *data, float val)
 {
   float *radius;
 
@@ -131,47 +136,47 @@ int setCylinderRadius(VisuPairData *data, float val)
   DBG_fprintf(stderr, "Pairs Cylinder : set the cylinder radius to %f.\n", val);
   val = CLAMP(val, RESOURCES_CYLINDER_RADIUS_MIN, RESOURCES_CYLINDER_RADIUS_MAX);
 
-  radius = (float*)visuPairGet_linkProperty(data, "radius");
+  radius = (float*)visu_pair_data_getProperty(data, "radius");
   if (!radius)
     {
       radius = g_malloc(sizeof(float));
-      visuPairSet_linkProperty(data, "radius", (gpointer)radius);
+      visu_pair_data_setProperty(data, "radius", (gpointer)radius);
       *radius = val;
-      visuPairSet_outOfDate();
+      visu_pair_setOutOfDate();
       return 1;
     }
   else
     if (*radius != val)
       {
 	*radius = val;
-	visuPairSet_outOfDate();
+	visu_pair_setOutOfDate();
 	return 1;
       }
   return 0;
 }
-float getCylinderRadius(VisuPairData *data)
+float cylinderGet_radius(VisuPairData *data)
 {
   float *radius;
 
   if (!data)
     return -1.;
 
-  radius = (float*)visuPairGet_linkProperty(data, "radius");
+  radius = (float*)visu_pair_data_getProperty(data, "radius");
   if (radius)
     return *radius;
   else
     return cylinderRadius;
 }
-int setCylinderColorType(int val)
+int cylinderSet_colorType(int val)
 {
   DBG_fprintf(stderr, "Pairs Cylinder : set the cylinder color type to %d.\n", val);
   g_return_val_if_fail(val >= 0 && val < cylinder_nb_color, 0);
 
   cylinderColorType = val;
-  visuPairSet_outOfDate();
+  visu_pair_setOutOfDate();
   return 1;
 }
-int getCylinderColorType()
+int cylinderGet_colorType()
 {
   return cylinderColorType;
 }
@@ -180,12 +185,12 @@ void setColorAndWidthForCylinder(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
 				 VisuPairData *data)
 {
   float rgba[4], mm[5] = {0.5, 0.5, 0., 0. , 0.};
-  Color *color;
+  ToolColor *color;
 
   switch (cylinderColorType)
     {
     case cylinder_user_color:
-      color = (Color*)visuPairGet_linkProperty(data, "color");
+      color = (ToolColor*)visu_pair_data_getProperty(data, "color");
       if (!color)
 	return;
       rgba[0] = color->rgba[0];
@@ -198,15 +203,15 @@ void setColorAndWidthForCylinder(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
     default:
       break;
     }
-  visuPairSet_outOfDate();
+  visu_pair_setOutOfDate();
 }
 
 void drawCylinderPairs(VisuElement *ele1, VisuElement *ele2, VisuPairData *data,
-		       OpenGLView *view, double x1, double y1, double z1,
-		       double x2, double y2, double z2, float d2, float alphaColour)
+		       VisuOpenGLView *view, double x1, double y1, double z1,
+		       double x2, double y2, double z2, float d2, float alphaColorur)
 {
   float rgba[4], mm[5] = {0.5, 0.5, 0., 0. , 0.};
-  Color *color;
+  ToolColor *color;
   int mat1, mat2, nlat;
   double vNorm[3]; /* vecteur normal aux vecteurs (0,0,1) et (x2-x1, y2-y1, z2-z1) */
   double vDest[3]; /* vecteur (x2-x1, y2-y1, z2-z1) */
@@ -216,13 +221,12 @@ void drawCylinderPairs(VisuElement *ele1, VisuElement *ele2, VisuPairData *data,
   float radius, *tmpRad;
   GLUquadricObj *obj;
 
-
-  tmpRad = visuPairGet_linkProperty(data, "radius");
+  tmpRad = visu_pair_data_getProperty(data, "radius");
   if (tmpRad)
     radius = *tmpRad;
   else
     radius = cylinderRadius;
-  nlat = OpenGLViewGet_numberOfFacettes(view, radius);
+  nlat = VisuOpenGLCameraGet_numberOfFacettes(view->camera, MIN(view->window->width, view->window->height), radius);
   vDest[0] = x2 - x1;
   vDest[1] = y2 - y1;
   vDest[2] = z2 - z1;
@@ -252,13 +256,13 @@ void drawCylinderPairs(VisuElement *ele1, VisuElement *ele2, VisuPairData *data,
   switch (cylinderColorType)
     {
     case cylinder_user_color:
-      color = (Color*)visuPairGet_linkProperty(data, "color");
+      color = (ToolColor*)visu_pair_data_getProperty(data, "color");
       if (!color)
 	return;
       rgba[0] = color->rgba[0];
       rgba[1] = color->rgba[1];
       rgba[2] = color->rgba[2];
-      rgba[3] = alphaColour;
+      rgba[3] = alphaColorur;
       openGLSet_color(mm, rgba);
 
       glTranslated(x1, y1, z1);
@@ -267,8 +271,8 @@ void drawCylinderPairs(VisuElement *ele1, VisuElement *ele2, VisuPairData *data,
 		  (GLdouble)sqrt(d2), (GLint)nlat, (GLint)1);
       break;
     case cylinder_element_color:
-      mat1 = visuElementGet_identifierMaterial(ele1);
-      mat2 = visuElementGet_identifierMaterial(ele2);
+      mat1 = visu_element_getIdentifierMaterial(ele1);
+      mat2 = visu_element_getIdentifierMaterial(ele2);
       if (mat1 <= 0 || mat2 <= 0)
 	g_warning("Can't draw cylinders because either ele1"
 		  "or ele2 has no identifier for material.\n");
@@ -292,44 +296,42 @@ void drawCylinderPairs(VisuElement *ele1, VisuElement *ele2, VisuPairData *data,
   gluDeleteQuadric(obj);
 }
 
-PairsExtension* initPairsCylinder()
+VisuPairExtension* initPairsCylinder()
 {
   char *name = _("Cylinder pairs");
   char *desc = _("Pairs are rendered by cylinders."
 		 " The color and the width can by chosen.");
-  PairsExtension *extension;
+  VisuPairExtension *extension;
   VisuConfigFileEntry *resourceEntry, *oldEntry;
 
-  extension = visuPairExtensionNew("Cylinder pairs", name, desc, TRUE,
-				   (initEndOpenGlPairsFunc)0,
-				   (initEndOpenGlPairsFunc)0,
-				   setColorAndWidthForCylinder, (startEndPairsFunc)0,
+  extension = visu_pair_extension_new("Cylinder pairs", name, desc, TRUE,
+				   setColorAndWidthForCylinder, (VisuPairStartEndFunc)0,
 				   drawCylinderPairs);
 
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCES_CYLINDER_COLOR_TYPE,
 					  DESC_RESOURCES_CYLINDER_COLOR_TYPE,
 					  1, readCylinderColorType);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCES_CYLINDER_RADIUS,
 					  DESC_RESOURCES_CYLINDER_RADIUS,
 					  1, readCylinderDefaultRadius);
-  oldEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  oldEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 				     FLAG_RESOURCES_PAIR_RADIUS,
 				     DESC_RESOURCES_PAIR_RADIUS,
 				     1, readCylinderRadius);
-  visuConfigFileSet_version(resourceEntry, 3.1f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.1f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCES_LINK_RADIUS,
 					  DESC_RESOURCES_LINK_RADIUS,
 					  1, readLinkRadius);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileSet_replace(resourceEntry, oldEntry);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_entry_setReplace(resourceEntry, oldEntry);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesCylinder);
 
 
-  listCylinder = openGLObjectList_new(2);
+  listCylinder = visu_openGL_objectList_new(2);
 
   cylinderRadius = RESOURCES_CYLINDER_RADIUS_DEFAULT;
   cylinderColorType = cylinder_user_color;
@@ -355,13 +357,13 @@ static gboolean readLinkRadius(gchar **lines, int nbLines, int position,
 
   tokens = g_strsplit_set(lines[0], " \n", MAX_LINE_LENGTH);
   id = 0;
-  if (!visuPairRead_linkFromTokens(tokens, &id, &data, position, error))
+  if (!visu_pair_readLinkFromTokens(tokens, &id, &data, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
   /* Read the associated radius. */
-  if (!configFileRead_floatFromTokens(tokens, &id, &radius, 1, position, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &id, &radius, 1, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
@@ -372,14 +374,14 @@ static gboolean readLinkRadius(gchar **lines, int nbLines, int position,
   if (radius < RESOURCES_CYLINDER_RADIUS_MIN ||
       radius > RESOURCES_CYLINDER_RADIUS_MAX)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: radius (%g) must be in %g-%g.\n"),
 			   position, radius, RESOURCES_CYLINDER_RADIUS_MIN,
 			   RESOURCES_CYLINDER_RADIUS_MAX);
       return FALSE;
     }
   /* Set the value. */
-  setCylinderRadius(data, radius);
+  cylinderSet_radius(data, radius);
 
   return TRUE;
 }
@@ -390,18 +392,18 @@ static gboolean readCylinderDefaultRadius(gchar **lines, int nbLines, int positi
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_float(lines[0], position, &radius, 1, error))
+  if (!tool_configFile_readFloat(lines[0], position, &radius, 1, error))
     return FALSE;
   if (radius < RESOURCES_CYLINDER_RADIUS_MIN ||
       radius > RESOURCES_CYLINDER_RADIUS_MAX)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: radius must be in %g-%g.\n"),
 			   position, RESOURCES_CYLINDER_RADIUS_MIN,
 			   RESOURCES_CYLINDER_RADIUS_MAX);
       return FALSE;
     }
-  setCylinderGeneralRadius(radius);
+  cylinderSet_generalRadius(radius);
   return TRUE;
 }
 static gboolean readCylinderColorType(gchar **lines, int nbLines, int position,
@@ -411,17 +413,17 @@ static gboolean readCylinderColorType(gchar **lines, int nbLines, int position,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_integer(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readInteger(lines[0], position, &val, 1, error))
     return FALSE;
   if (val < 0 || val >= cylinder_nb_color)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 integer value must"
 			     " appear after the %s markup.\n"),
 			   position, FLAG_RESOURCES_CYLINDER_COLOR_TYPE);
       return FALSE;
     }
-  setCylinderColorType(val);
+  cylinderSet_colorType(val);
 
   return TRUE;
 }
@@ -431,7 +433,7 @@ static void exportPairsRadius(VisuElement *ele1, VisuElement *ele2,
   struct foreachFuncExport_struct *str;
   float *radius;
 
-  radius = (float*)visuPairGet_linkProperty(data, "radius");
+  radius = (float*)visu_pair_data_getProperty(data, "radius");
   if (radius)
     {
       str = ( struct foreachFuncExport_struct*)userData;
@@ -450,8 +452,8 @@ static void exportPairsRadius(VisuElement *ele1, VisuElement *ele2,
       g_string_append_printf(str->data,
 			     "%s:\n"
 			     "    %s %s  %4.3f %4.3f  %4.3f\n", FLAG_RESOURCES_LINK_RADIUS,
-			     ele1->name, ele2->name, data->minMax[PAIRS_MIN],
-			     data->minMax[PAIRS_MAX], *radius);
+			     ele1->name, ele2->name, data->minMax[VISU_PAIR_DISTANCE_MIN],
+			     data->minMax[VISU_PAIR_DISTANCE_MAX], *radius);
     }
 }
 static void exportResourcesCylinder(GString *data, VisuData *dataObj)
@@ -469,7 +471,7 @@ static void exportResourcesCylinder(GString *data, VisuData *dataObj)
   str.data           = data;
   str.dataObj        = dataObj;
   g_string_append_printf(data, "# %s\n", DESC_RESOURCES_PAIR_RADIUS);
-  visuPairForeach(exportPairsRadius, &str);
+  visu_pair_foreach(exportPairsRadius, &str);
   g_string_append_printf(data, "\n");
 }
 
@@ -492,24 +494,24 @@ static gboolean readCylinderRadius(gchar **lines, int nbLines, int position _U_,
   token = 0;
 
   /* Get the two elements. */
-  if (!configFileRead_elementFromTokens(tokens, &token, ele, 2, nbLines, error))
+  if (!tool_configFile_readElementFromTokens(tokens, &token, ele, 2, nbLines, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
 
-  data = visuPairGet_linkFromId(ele[0], ele[1], 0);
+  data = visu_pair_getPairDataFromId(ele[0], ele[1], 0);
   g_return_val_if_fail(data, FALSE);
 
   /* Read 1 float. */
-  if (!configFileRead_floatFromTokens(tokens, &token, &radius, 1, nbLines, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &token, &radius, 1, nbLines, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
   radius = CLAMP(radius, RESOURCES_CYLINDER_RADIUS_MIN,
 		 RESOURCES_CYLINDER_RADIUS_MAX);
-  setCylinderRadius(data, radius);
+  cylinderSet_radius(data, radius);
 
   g_strfreev(tokens);
   return TRUE;
