@@ -50,23 +50,23 @@
 #include "cylinder.h"
 
 /**
- * PairsExtensionInitFunc:
+ * VisuPairExtensionInitFunc:
  *
  * Prototype of the functions used to initialise a new pair models.
  *
  * Returns: a newly allocated pair model.
  */
-typedef PairsExtension* (*PairsExtensionInitFunc) (void);
+typedef VisuPairExtension* (*VisuPairExtensionInitFunc) (void);
 
 /**
  * listInitPairsFunc:
  * 
  * blabla
  */
-static PairsExtensionInitFunc listInitPairsFunc[] = {
+static VisuPairExtensionInitFunc listInitPairsFunc[] = {
   initPairsWire,
   initPairsCylinder,
-  (PairsExtensionInitFunc)0};
+  (VisuPairExtensionInitFunc)0};
 
 
 #endif
