@@ -51,6 +51,12 @@
 
 #include "cylinder.h"
 
+/**
+ * SECTION: gtk_cylinder
+ * @short_description: The additional widgets displayed in the pair
+ * dialog to handle cylinder pairs.
+ */
+
 int colorForCurve;
 int colorDescr;
 
@@ -74,91 +80,59 @@ void gtkPairsCylinderInit(void)
 
 GtkWidget* gtkPairsCylinderBuild_widgets()
 {
-  GtkWidget *hbox1;
-  GtkWidget *vbox1;
-  GtkWidget *label1;
-  GtkWidget *alignment1;
-  GtkObject *spinCylinderRadius_adj;
-  GtkWidget *vseparator1;
-  GtkWidget *vbox2;
-  GtkWidget *label2;
-  GtkWidget *alignment2;
-  GtkWidget *hbox2;
+  GtkWidget *hbox, *vbox;
+  GtkWidget *label;
   GSList *radioCylinderUser_group = NULL;
 
-  hbox1 = gtk_hbox_new (FALSE, 0);
+  vbox = gtk_vbox_new(FALSE, 0);
 
-  vbox1 = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show (vbox1);
-  gtk_box_pack_start (GTK_BOX (hbox1), vbox1, FALSE, FALSE, 0);
+  hbox = gtk_hbox_new(FALSE, 10);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-  label1 = gtk_label_new (_("Radius:"));
-  gtk_widget_show (label1);
-  gtk_box_pack_start (GTK_BOX (vbox1), label1, FALSE, FALSE, 0);
-  gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
+  label = gtk_label_new(_("Radius:"));
+  gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+  gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+  spinCylinderRadius = gtk_spin_button_new_with_range(RESOURCES_CYLINDER_RADIUS_MIN,
+                                                      RESOURCES_CYLINDER_RADIUS_MAX,
+                                                      RESOURCES_CYLINDER_RADIUS_STEP);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), cylinderGet_generalRadius());
+  gtk_box_pack_start(GTK_BOX(hbox), spinCylinderRadius, FALSE, FALSE, 0);
 
-  alignment1 = gtk_alignment_new (1, 0.5, 0, 1);
-  gtk_widget_show (alignment1);
-  gtk_box_pack_start (GTK_BOX (vbox1), alignment1, FALSE, FALSE, 0);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment1), 0, 0, 15, 0);
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-  spinCylinderRadius_adj = gtk_adjustment_new (getCylinderGeneralRadius(),
-					RESOURCES_CYLINDER_RADIUS_MIN,
-					RESOURCES_CYLINDER_RADIUS_MAX,
-					RESOURCES_CYLINDER_RADIUS_STEP,
-					RESOURCES_CYLINDER_RADIUS_STEP * 5., 0);
-  spinCylinderRadius = gtk_spin_button_new (GTK_ADJUSTMENT (spinCylinderRadius_adj), 1, 2);
-  gtk_widget_show (spinCylinderRadius);
-  gtk_container_add (GTK_CONTAINER (alignment1), spinCylinderRadius);
+  label = gtk_label_new(_("Color:"));
+  gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+  gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 
-  vseparator1 = gtk_vseparator_new ();
-  gtk_widget_show (vseparator1);
-  gtk_box_pack_start (GTK_BOX (hbox1), vseparator1, FALSE, FALSE, 4);
-
-  vbox2 = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show (vbox2);
-  gtk_box_pack_start (GTK_BOX (hbox1), vbox2, TRUE, TRUE, 0);
-
-  label2 = gtk_label_new (_("Use color scheme:"));
-  gtk_widget_show (label2);
-  gtk_box_pack_start (GTK_BOX (vbox2), label2, FALSE, FALSE, 0);
-  gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
-
-  alignment2 = gtk_alignment_new (1, 0.5, 0, 1);
-  gtk_widget_show (alignment2);
-  gtk_box_pack_start (GTK_BOX (vbox2), alignment2, FALSE, FALSE, 0);
-
-  hbox2 = gtk_hbox_new (FALSE, 0);
-  gtk_widget_show (hbox2);
-  gtk_container_add (GTK_CONTAINER (alignment2), hbox2);
-
-  radioCylinderUser = gtk_radio_button_new_with_mnemonic (NULL, _("User defined"));
+  radioCylinderUser = gtk_radio_button_new_with_mnemonic(NULL, _("_user defined"));
   gtk_widget_set_name(radioCylinderUser, "message_radio");
-  gtk_widget_show (radioCylinderUser);
-  gtk_box_pack_start (GTK_BOX (hbox2), radioCylinderUser, FALSE, FALSE, 0);
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radioCylinderUser), radioCylinderUser_group);
-  radioCylinderUser_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radioCylinderUser));
-  if (getCylinderColorType() == 0)
+  gtk_box_pack_start(GTK_BOX(hbox), radioCylinderUser, FALSE, FALSE, 0);
+  gtk_radio_button_set_group(GTK_RADIO_BUTTON(radioCylinderUser),
+                             radioCylinderUser_group);
+  radioCylinderUser_group =
+    gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioCylinderUser));
+  if(cylinderGet_colorType() == 0)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioCylinderUser), TRUE);
 
-  radioCylinderElement = gtk_radio_button_new_with_mnemonic (NULL, _("Follow elements"));
+  radioCylinderElement = gtk_radio_button_new_with_mnemonic(NULL, _("_elements"));
   gtk_widget_set_name(radioCylinderElement, "message_radio");
-  gtk_widget_show (radioCylinderElement);
-  gtk_box_pack_start (GTK_BOX (hbox2), radioCylinderElement, FALSE, FALSE, 0);
-  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radioCylinderElement), radioCylinderUser_group);
-  radioCylinderUser_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radioCylinderElement));
-  if (getCylinderColorType() == 1)
+  gtk_box_pack_start(GTK_BOX(hbox), radioCylinderElement, FALSE, FALSE, 0);
+  gtk_radio_button_set_group(GTK_RADIO_BUTTON(radioCylinderElement),
+                             radioCylinderUser_group);
+  if (cylinderGet_colorType() == 1)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioCylinderElement), TRUE);
 
-  signalSpinCylinderRadiusId = g_signal_connect(G_OBJECT(spinCylinderRadius), "value-changed",
-						G_CALLBACK(changeCylinderRadius), (gpointer)0);
+  signalSpinCylinderRadiusId =
+    g_signal_connect(G_OBJECT(spinCylinderRadius), "value-changed",
+                     G_CALLBACK(changeCylinderRadius), (gpointer)0);
 
   g_signal_connect(G_OBJECT(radioCylinderUser), "toggled",
 		   G_CALLBACK(changeCylinderColorType), GINT_TO_POINTER(0));
   g_signal_connect(G_OBJECT(radioCylinderElement), "toggled",
 		   G_CALLBACK(changeCylinderColorType), GINT_TO_POINTER(1));
 
-  return hbox1;
+  return vbox;
 }
 
 void changeCylinderRadius(GtkSpinButton *spin, gpointer data _U_)
@@ -176,7 +150,7 @@ void changeCylinderRadius(GtkSpinButton *spin, gpointer data _U_)
        gtkPairsIter_nextSelected(&iter))
     {
       /* We change the value for this pair. */
-      res = setCylinderRadius(iter.data,
+      res = cylinderSet_radius(iter.data,
 			      (float)gtk_spin_button_get_value(spin)) || res;
       if (!label)
 	label = gtkPairsCylinderGet_valuesAsLabel(iter.data);
@@ -200,7 +174,7 @@ void changeCylinderColorType(GtkToggleButton *button, gpointer data)
   color = GPOINTER_TO_INT(data);
   g_return_if_fail(color >= 0 && color < cylinder_nb_color);
 
-  res = setCylinderColorType(color);
+  res = cylinderSet_colorType(color);
   if (res)
     gtkPairs_createPairs();
 }
@@ -213,8 +187,8 @@ void changeCylinderColorType(GtkToggleButton *button, gpointer data)
 /*     return; */
 
 /*   DBG_fprintf(stderr, "Gtk Cylinder : catch the 'resourcesLoaded' signal, updating values.\n"); */
-/*   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), getCylinderGeneralRadius()); */
-/*   val = getCylinderColorType(); */
+/*   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), cylinderGet_generalRadius()); */
+/*   val = cylinderGet_colorType(); */
 /*   switch (val) */
 /*     { */
 /*     case cylinder_user_color: */
@@ -231,11 +205,11 @@ void gtkPairsCylinderSet_values(VisuPairData *data)
   float *radius;
   float val;
 
-  radius = (float*)visuPairGet_linkProperty(data, "radius");
+  radius = (float*)visu_pair_data_getProperty(data, "radius");
   if (radius)
     val = *radius;
   else
-    val = getCylinderGeneralRadius();
+    val = cylinderGet_generalRadius();
 
   g_signal_handler_block(G_OBJECT(spinCylinderRadius), signalSpinCylinderRadiusId);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), val);
@@ -248,14 +222,14 @@ gchar* gtkPairsCylinderGet_valuesAsLabel(VisuPairData *data)
   float *radius;
   float val;
 
-  radius = (float*)visuPairGet_linkProperty(data, "radius");
+  radius = (float*)visu_pair_data_getProperty(data, "radius");
   if (radius)
     val = *radius;
   else
-    val = getCylinderGeneralRadius();
+    val = cylinderGet_generalRadius();
 
   /* a.u. is for arbitrary units. */
-  str = g_strdup_printf("%3.2f%s", val, _("a.u."));
+  str = g_strdup_printf("%s %3.2f%s", _("cyl.:"), val, _("a.u."));
 
   return str;
 }
