@@ -56,9 +56,18 @@
 #include <coreTools/toolColor.h>
 #include <coreTools/toolConfigFile.h>
 
-static PairsExtension* pointerToPairExtension_wire;
-static void changeLightForWire();
-static void restoreLightAfterWire();
+/**
+ * SECTION:wire
+ * @short_description:Gives methods to draw lines as OpenGl objects
+ * pairing two elements.
+ *
+ * <para>The wire pair module is the simplest way to draw pairs
+ * between elements : using lines. The size of lines can be chosen but
+ * is limited by OpenGL implementation that usually only allow line
+ * width of 10 pixels as maximum size.</para>
+ */
+
+static VisuPairExtension* pointerToPairExtension_wire;
 
 /* This function details how to read what is needed by PairsData. */
 static gboolean readWireGeneralWidth(gchar **lines, int nbLines, int position,
@@ -72,6 +81,8 @@ static gboolean readLinkStipple(gchar **lines, int nbLines, int position,
 /* This function details how to read the parameter FLAG_PARAMETER_PAIRS. */
 static gboolean readWireNonLinear(gchar **lines, int nbLines, int position,
 				  VisuData *dataObj, GError **error);
+static gboolean readWireShade(gchar **lines, int nbLines, int position,
+			      VisuData *dataObj, GError **error);
 /* This function writes the parameter. */
 static void exportParametersWire(GString *data, VisuData *dataObj);
 /* This function save the resources. */
@@ -80,7 +91,10 @@ static void exportResourcesWire(GString *data, VisuData *dataObj);
 #define FLAG_PARAMETER_WIRE   "wire_nonLinear"
 #define DESC_PARAMETER_WIRE   "If the color of the pairs are corrected by their length ; boolean 0 or 1"
 #define PARAMETER_WIRE_DEFAULT 0
-static int wireNonLinear;
+
+#define FLAG_PARAMETER_SHADE  "wire_shade"
+#define DESC_PARAMETER_SHADE  "If positive, use a shade to colourise pairs depending on length ; -1 or a positive shade id"
+static Shade *wireShade;
 
 #define FLAG_RESOURCES_PAIR_WIDTH "pairWire_pairWidth"
 #define DESC_RESOURCES_PAIR_WIDTH "Widths detail for each pair drawn ; 0 < integer < 10"
@@ -95,14 +109,16 @@ static int wireWidth;
 #define FLAG_RESOURCES_LINK_STIPPLE "pairWire_linkStipple"
 #define DESC_RESOURCES_LINK_STIPPLE "Dot scheme detail for each drawn link ; 0 < integer < 2^16"
 
-/* The variation of the color intensity if stored in
-   an array whose values are stored when wireNonLinear became true.
-   The size of the array is controlled by a define. */
-#define NB_SAMPLE_COLOR_LENGTH 101
-static float **colorLengthSample;
-
-
-PairsExtension* wireGet_static()
+/**
+ * wireGet_static:
+ *
+ * Internal function to access the #VisuPairExtension wire.
+ * 
+ * Since: 3.6
+ *
+ * Returns: the #VisuPairExtension wire.
+ */
+VisuPairExtension* wireGet_static()
 {
   return pointerToPairExtension_wire;
 }
@@ -110,58 +126,56 @@ PairsExtension* wireGet_static()
 static void beginPairLink(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
 			  VisuPairData *data)
 {
-  Color *color;
+  ToolColor *color;
   int *width;
   guint16 *stipple;
 
-  width = (int*)visuPairGet_linkProperty(data, "width");
+  width = (int*)visu_pair_data_getProperty(data, "width");
   if (width)
     glLineWidth(*width);
   else
     glLineWidth(wireWidth);
-  color = (Color*)visuPairGet_linkProperty(data, "color");
+  color = (ToolColor*)visu_pair_data_getProperty(data, "color");
   if (color)
     glColor3fv(color->rgba);
-  stipple = (guint16*)visuPairGet_linkProperty(data, "stipple");
+  stipple = (guint16*)visu_pair_data_getProperty(data, "stipple");
   if (stipple)
     {
       glEnable(GL_LINE_STIPPLE);
       glLineStipple(1, *stipple);
     }
+  glDisable(GL_LIGHTING);
+  glDisable(GL_DITHER);
 }
 
 static void endPairLink(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
 			VisuPairData *data _U_)
 {
   glDisable(GL_LINE_STIPPLE);
+  glEnable(GL_DITHER); /* WARNING: it is the default! */
+  glEnable(GL_LIGHTING);
 }
 
 static void drawPairLink(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
-			 VisuPairData *data, OpenGLView *view _U_,
+			 VisuPairData *data, VisuOpenGLView *view _U_,
 			 double x1, double y1, double z1,
 			 double x2, double y2, double z2, float d2, float alpha)
 {
-  float length;
-  int prop;
-  Color *color;
+  float ratio;
+  ToolColor *color;
+  float rgba[4];
 
-  if (wireNonLinear)
+  if (wireShade)
     {
-      length = sqrt(d2);
-      prop = CLAMP((int)( (length - data->minMax[PAIRS_MIN]) /
-			  (data->minMax[PAIRS_MAX] - data->minMax[PAIRS_MIN]) *
-			  (float)(NB_SAMPLE_COLOR_LENGTH - 1) ),
-		   0, NB_SAMPLE_COLOR_LENGTH - 1);
-      
-/*       fprintf(stderr, "This length %f is at position %d %f (%f %f)\n", length, prop, colorLengthSample[0][prop], data->minMax[PAIRS_MAX], data->minMax[PAIRS_MIN]); */
-      glColor4f(colorLengthSample[0][prop],
-		colorLengthSample[1][prop],
-		colorLengthSample[2][prop],
-		alpha);
+      ratio = (sqrt(d2) - data->minMax[VISU_PAIR_DISTANCE_MIN]) /
+	(data->minMax[VISU_PAIR_DISTANCE_MAX] - data->minMax[VISU_PAIR_DISTANCE_MIN]);
+      shadeGet_valueTransformedInRGB(wireShade, rgba, ratio);
+      rgba[3] = alpha;
+      glColor4fv(rgba);
     }
   else
     {
-      color = (Color*)visuPairGet_linkProperty(data, "color");
+      color = (ToolColor*)visu_pair_data_getProperty(data, "color");
       if (color)
 	glColor4f(color->rgba[0],
 		  color->rgba[1],
@@ -175,74 +189,59 @@ static void drawPairLink(VisuElement *ele1 _U_, VisuElement *ele2 _U_,
   glEnd();
 }
 
-PairsExtension* initPairsWire()
+VisuPairExtension* initPairsWire()
 {
   char *name = _("Wire pairs");
   char *desc = _("Pairs are rendered by flat lines."
 		 " The color and the width can by chosen.");
-  PairsExtension *extension;
+  VisuPairExtension *extension;
   VisuConfigFileEntry *resourceEntry, *oldEntry;
-  int i, j;
 
-  extension = visuPairExtensionNew("Wire pairs", name, desc, FALSE,
-				   changeLightForWire, restoreLightAfterWire,
+  extension = visu_pair_extension_new("Wire pairs", name, desc, FALSE,
 				   beginPairLink, endPairLink, drawPairLink);
 
   wireWidth = RESOURCES_WIRE_WIDTH_DEFAULT;
-  wireNonLinear = PARAMETER_WIRE_DEFAULT;
+  wireShade = (Shade*)0;
 
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCES_WIRE_WIDTH,
 					  DESC_RESOURCES_WIRE_WIDTH,
 					  1, readWireGeneralWidth);
-  oldEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  oldEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 				     FLAG_RESOURCES_PAIR_WIDTH,
 				     DESC_RESOURCES_PAIR_WIDTH,
 				     1, readWireWidth);
-  visuConfigFileSet_version(resourceEntry, 3.1f);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.1f);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCES_LINK_WIDTH,
 					  DESC_RESOURCES_LINK_WIDTH,
 					  1, readLinkWidth);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileSet_replace(resourceEntry, oldEntry);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_entry_setReplace(resourceEntry, oldEntry);
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCES_LINK_STIPPLE,
 					  DESC_RESOURCES_LINK_STIPPLE,
 					  1, readLinkStipple);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportResourcesWire);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  oldEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_WIRE,
 					  DESC_PARAMETER_WIRE,
 					  1, readWireNonLinear);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
+					  FLAG_PARAMETER_SHADE,
+					  DESC_PARAMETER_SHADE,
+					  1, readWireShade);
+  visu_configFile_entry_setVersion(resourceEntry, 3.6f);
+  visu_configFile_entry_setReplace(resourceEntry, oldEntry);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParametersWire);
 
-  colorLengthSample = g_malloc(sizeof(float*) * 3);
-  for (i = 0; i < 3; i++)
-    {
-      colorLengthSample[i] = g_malloc(sizeof(float) * NB_SAMPLE_COLOR_LENGTH);
-      for ( j = 0; j < NB_SAMPLE_COLOR_LENGTH; j++)
-	colorLengthSample[i][j] = (float)j / (float)(NB_SAMPLE_COLOR_LENGTH - 1);
-    }
-
   pointerToPairExtension_wire = extension;
   return extension;
 }
 
-static void changeLightForWire()
-{
-  glDisable(GL_LIGHTING);
-  glDisable(GL_DITHER);
-}
-static void restoreLightAfterWire()
-{
-  glEnable(GL_DITHER); /* WARNING: it is the default! */
-  glEnable(GL_LIGHTING);
-}
-
 gboolean wireSet_stipple(VisuPairData *data, guint16 stipple)
 {
   guint16 *stipple_;
@@ -250,20 +249,20 @@ gboolean wireSet_stipple(VisuPairData *data, guint16 stipple)
   g_return_val_if_fail(data, FALSE);
 
   DBG_fprintf(stderr, "Pairs Wire: set the wire pattern to %d.\n", stipple);
-  stipple_ = (guint16*)visuPairGet_linkProperty(data, "stipple");
+  stipple_ = (guint16*)visu_pair_data_getProperty(data, "stipple");
   if (!stipple_)
     {
       stipple_ = g_malloc(sizeof(guint16));
-      visuPairSet_linkProperty(data, "stipple", (gpointer)stipple_);
+      visu_pair_data_setProperty(data, "stipple", (gpointer)stipple_);
       *stipple_ = stipple;
-      visuPairSet_outOfDate();
+      visu_pair_setOutOfDate();
       return TRUE;
     }
   else
     if (*stipple_ != stipple)
       {
 	*stipple_ = stipple;
-	visuPairSet_outOfDate();
+	visu_pair_setOutOfDate();
 	return TRUE;
       }
 
@@ -275,85 +274,99 @@ guint16 wireGet_stipple(VisuPairData *data)
 
   g_return_val_if_fail(data, (guint16)1);
 
-  stipple_ = visuPairGet_linkProperty(data, "stipple");
+  stipple_ = visu_pair_data_getProperty(data, "stipple");
   if (stipple_)
     return *stipple_;
   else
     return (guint16)65535;
 }
-int setWireGeneralWidth(int val)
+int wireSet_generalWidth(int val)
 {
   DBG_fprintf(stderr, "Pairs Wire: set the wire thickness to %d.\n", val);
   if (val <= 0 || val > RESOURCES_WIRE_WIDTH_MAX || val == wireWidth)
     return 0;
 
-  visuPairSet_outOfDate();
+  visu_pair_setOutOfDate();
   wireWidth = val;
   return 1;
 }
-int getWireGeneralWidth()
+int wireGet_generalWidth()
 {
   return wireWidth;
 }
-int setWireWidth(VisuPairData *data, int val)
+int wireSet_width(VisuPairData *data, int val)
 {
   int *width;
 
   if (!data)
     return 0;
 
-  width = visuPairGet_linkProperty(data, "width");
+  width = visu_pair_data_getProperty(data, "width");
   if (!width)
     {
       width = g_malloc(sizeof(int));
-      visuPairSet_linkProperty(data, "width", (gpointer)width);
+      visu_pair_data_setProperty(data, "width", (gpointer)width);
       *width = CLAMP(val, 0, RESOURCES_WIRE_WIDTH_MAX);
-      visuPairSet_outOfDate();
+      visu_pair_setOutOfDate();
       return 1;
     }
   else
     if (*width != val)
       {
 	*width = CLAMP(val, 0, RESOURCES_WIRE_WIDTH_MAX);
-	visuPairSet_outOfDate();
+	visu_pair_setOutOfDate();
 	return 1;
       }
 
   return 0;
 }
-int getWireWidth(VisuPairData *data)
+int wireGet_width(VisuPairData *data)
 {
   int *width;
 
   if (!data)
     return 0;
 
-  width = visuPairGet_linkProperty(data, "width");
+  width = visu_pair_data_getProperty(data, "width");
   if (width)
     return *width;
   else
     return wireWidth;
 }
-int setWireNonLinear(int val)
+/**
+ * wireSet_shade:
+ * @shade: a #Shade object (can be NULL).
+ *
+ * If @shade is not NULL, make the colour of each pair varies with its
+ * length according to @shade colour scheme.
+ *
+ * Since: 3.6
+ *
+ * Returns: TRUE if shade is changed.
+ */
+gboolean wireSet_shade(Shade *shade)
 {
-  DBG_fprintf(stderr, "Pairs Wire : set the wire color dependent of wire length to %d.\n", val);
-  if (val == wireNonLinear)
-    return 0;
+  DBG_fprintf(stderr, "Pairs Wire: set the shade %p for the wire color.\n",
+	      (gpointer)shade);
+  if (shade == wireShade)
+    return FALSE;
 
-  visuPairSet_outOfDate();
-  wireNonLinear = val;
-  return 1;
+  visu_pair_setOutOfDate();
+  wireShade = shade;
+  return TRUE;
 }
-int getWireNonLinear()
+/**
+ * wireGet_shade:
+ *
+ * Colour of wires can depend on length, following a #Shade scheme.
+ *
+ * Since: 3.6
+ *
+ * Returns: the #Shade scheme if used, or NULL.
+ */
+Shade* wireGet_shade()
 {
-  return wireNonLinear;
-}
-float* getLengthSampleForColor(int color, int *size)
-{
-  g_return_val_if_fail(color >= 0 && color < 3 && size, (float*)0);
-  
-  *size = NB_SAMPLE_COLOR_LENGTH;
-  return colorLengthSample[color];
+  return wireShade;
 }
 
 /*****************************************/
@@ -371,13 +384,13 @@ static gboolean readLinkInteger(gchar **lines, int nbLines,
 
   tokens = g_strsplit_set(lines[0], " \n", MAX_LINE_LENGTH);
   id = 0;
-  if (!visuPairRead_linkFromTokens(tokens, &id, data, position, error))
+  if (!visu_pair_readLinkFromTokens(tokens, &id, data, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
   /* Read the associated integer. */
-  if (!configFileRead_integerFromTokens(tokens, &id, value, 1, position, error))
+  if (!tool_configFile_readIntegerFromTokens(tokens, &id, value, 1, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
@@ -410,12 +423,12 @@ static gboolean readLinkWidth(gchar **lines, int nbLines, int position,
   /* Check. */
   if (width <= 0 || width > RESOURCES_WIRE_WIDTH_MAX)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: width must be in %d-%d.\n"),
 			   position, 0, RESOURCES_WIRE_WIDTH_MAX);
       return FALSE;
     }
-  setWireWidth(data, width);
+  wireSet_width(data, width);
   return TRUE;
 }
 /* This function details how to read what is needed by PairsData. */
@@ -426,36 +439,55 @@ static gboolean readWireGeneralWidth(gchar **lines, int nbLines, int position,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_integer(lines[0], position, &width, 1, error))
+  if (!tool_configFile_readInteger(lines[0], position, &width, 1, error))
     return FALSE;
   if (width <= 0 || width > RESOURCES_WIRE_WIDTH_MAX)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: width must be in %d-%d.\n"),
 			   position, 0, RESOURCES_WIRE_WIDTH_MAX);
       return FALSE;
     }
-  setWireGeneralWidth(width);
+  wireSet_generalWidth(width);
   return TRUE;
 }
 /* This function details how to read the parameter FLAG_PARAMETER_PAIRS. */
-static gboolean readWireNonLinear(gchar **lines, int nbLines, int position,
-				  VisuData *dataObj _U_, GError **error)
+static gboolean readWireShade(gchar **lines, int nbLines, int position,
+			      VisuData *dataObj _U_, GError **error)
 {
-  gboolean val;
+  int val;
+  GList *list;
+  Shade *sh;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readInteger(lines[0], position, &val, 1, error))
     return FALSE;
-  setWireNonLinear(val);
+
+  sh = (Shade*)0;
+  if (val >= 0)
+    {
+      list = toolShadeBuild_presetList();
+      if (val >= (int)g_list_length(list))
+	*error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
+			     _("Parse error at line %d: shade id must be lower than %d.\n"),
+			     position, g_list_length(list));
+      else
+	sh = (Shade*)g_list_nth_data(list, val);
+    }
+  wireSet_shade(sh);
+
   return TRUE;
 }
 /* This function writes the parameter. */
 static void exportParametersWire(GString *data, VisuData *dataObj _U_)
 {
-  g_string_append_printf(data, "# %s\n", DESC_PARAMETER_WIRE);
-  g_string_append_printf(data, "%s: %i\n\n", FLAG_PARAMETER_WIRE, wireNonLinear);
+  GList *list;
+  
+  list = toolShadeBuild_presetList();
+  g_string_append_printf(data, "# %s\n", DESC_PARAMETER_SHADE);
+  g_string_append_printf(data, "%s: %d\n\n", FLAG_PARAMETER_SHADE,
+			 g_list_index(list, wireShade));
 }
 void exportPairsWidth(VisuElement *ele1, VisuElement *ele2,
 		      VisuPairData *data, gpointer userData)
@@ -465,7 +497,7 @@ void exportPairsWidth(VisuElement *ele1, VisuElement *ele2,
   guint16 *stipple;
   gboolean output;
 
-  width = (int*)visuPairGet_linkProperty(data, "width");
+  width = (int*)visu_pair_data_getProperty(data, "width");
   if (width)
     {
       str = ( struct foreachFuncExport_struct*)userData;
@@ -486,10 +518,10 @@ void exportPairsWidth(VisuElement *ele1, VisuElement *ele2,
 			       "%s:\n"
 			       "    %s %s  %4.3f %4.3f  %d\n",
 			       FLAG_RESOURCES_LINK_WIDTH,
-			       ele1->name, ele2->name, data->minMax[PAIRS_MIN],
-			       data->minMax[PAIRS_MAX], *width);
+			       ele1->name, ele2->name, data->minMax[VISU_PAIR_DISTANCE_MIN],
+			       data->minMax[VISU_PAIR_DISTANCE_MAX], *width);
     }
-  stipple = (guint16*)visuPairGet_linkProperty(data, "stipple");
+  stipple = (guint16*)visu_pair_data_getProperty(data, "stipple");
   if (stipple)
     {
       str = ( struct foreachFuncExport_struct*)userData;
@@ -510,8 +542,8 @@ void exportPairsWidth(VisuElement *ele1, VisuElement *ele2,
 			       "%s:\n"
 			       "    %s %s  %4.3f %4.3f  %d\n",
 			       FLAG_RESOURCES_LINK_STIPPLE,
-			       ele1->name, ele2->name, data->minMax[PAIRS_MIN],
-			       data->minMax[PAIRS_MAX], *stipple);
+			       ele1->name, ele2->name, data->minMax[VISU_PAIR_DISTANCE_MIN],
+			       data->minMax[VISU_PAIR_DISTANCE_MAX], *stipple);
     }
 }
 static void exportResourcesWire(GString *data, VisuData *dataObj)
@@ -523,7 +555,7 @@ static void exportResourcesWire(GString *data, VisuData *dataObj)
   str.data           = data;
   str.dataObj        = dataObj;
   g_string_append_printf(data, "# %s\n", DESC_RESOURCES_LINK_WIDTH);
-  visuPairForeach(exportPairsWidth, &str);
+  visu_pair_foreach(exportPairsWidth, &str);
   g_string_append_printf(data, "\n");
 }
 
@@ -547,24 +579,46 @@ static gboolean readWireWidth(gchar **lines, int nbLines, int position _U_,
   token = 0;
 
   /* Get the two elements. */
-  if (!configFileRead_elementFromTokens(tokens, &token, ele, 2, nbLines, error))
+  if (!tool_configFile_readElementFromTokens(tokens, &token, ele, 2, nbLines, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
 
-  data = visuPairGet_linkFromId(ele[0], ele[1], 0);
+  data = visu_pair_getPairDataFromId(ele[0], ele[1], 0);
   g_return_val_if_fail(data, FALSE);
 
   /* Read 1 int. */
-  if (!configFileRead_floatFromTokens(tokens, &token, &radius, 1, nbLines, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &token, &radius, 1, nbLines, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
   val = CLAMP((int)radius, 0, RESOURCES_WIRE_WIDTH_MAX);
-  setWireWidth(data, val);
+  wireSet_width(data, val);
   
   g_strfreev(tokens);
   return TRUE;
 }
+static gboolean readWireNonLinear(gchar **lines, int nbLines, int position,
+				  VisuData *dataObj _U_, GError **error)
+{
+  gboolean val;
+  GList *list;
+  Shade *sh;
+  
+  g_return_val_if_fail(nbLines == 1, FALSE);
+
+  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
+    return FALSE;
+
+  sh = (Shade*)0;
+  if (val)
+    {
+      list = toolShadeBuild_presetList();
+      sh = (Shade*)g_list_nth_data(list, 0);
+    }
+  wireSet_shade(sh);
+
+  return TRUE;
+}
