@@ -105,8 +105,6 @@ static guint element_callback_ids[10];
 
 static int need_redraw = 1;
 
-static GList* currentListElement;
-
 static gulong configResourcesLoadedId;
 
 struct FileChooserSpin_struct
@@ -132,7 +130,7 @@ static void fileUpdatePreview(GtkFileChooser *chooser,
 /* Callbacks */
 void global_resource_callback(GtkWidget* widget, gpointer data);
 void element_resource_callback(GtkWidget* widget, gpointer data);
-void changeSomethingSpin(GList *eleList);
+static void changeSomethingSpin();
 GtkWidget* createGtkInterfaceForSpinMethod();
 static void onPolicyChanged(GtkToggleButton *toggle, gpointer data);
 static void onPolicyAtomicChanged(GtkToggleButton *toggle, gpointer data);
@@ -154,18 +152,17 @@ static void sync_local_resources(GObject *trash, gpointer data);
 /* See h file for more info */
 void panelElementSpinInit_gtkPanel()
 {
-  panelElements_setInterfaceMethods(visuRenderingClassGet_methodByName
-				    (VISU_RENDERING_SPIN),
+  panelElements_setInterfaceMethods(visu_rendering_getByName
+				    (VISU_RENDERING_SPIN_NAME),
 				    changeSomethingSpin,
 				    createGtkInterfaceForSpinMethod);
-  currentListElement = (GList*)0;
 }
 
 /* See h file for more info */
 void panelElementSpinInit_gtkConfig()
 {
-  panelMethodSet_renderingInterface(visuRenderingClassGet_methodByName
-				    (VISU_RENDERING_SPIN),
+  panelMethodSet_renderingInterface(visu_rendering_getByName
+				    (VISU_RENDERING_SPIN_NAME),
 				    createGtkConfigForSpinMethod,
 				    destroyGtkConfigForSpinMethod);
 }
@@ -180,7 +177,7 @@ static GtkWidget *gtk_spin_create_direction(float *cartesian_values,
   GtkWidget* label_z = gtk_label_new(_("z:"));
   GtkWidget* label_theta = gtk_label_new("\316\270:");
   GtkWidget* label_phi = gtk_label_new("\317\206:");
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new();
@@ -227,12 +224,12 @@ static GtkWidget *gtk_spin_create_direction(float *cartesian_values,
   gtkw_cone_theta_angle = gtk_spin_button_new_with_range(0, 180., 3);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_cone_theta_angle), spherical_values[1]);
   g_signal_connect(gtkw_cone_theta_angle, "value-changed",
-		   G_CALLBACK(global_resource_callback), GINT_TO_POINTER(spin_globalConeTheta));
+		   G_CALLBACK(global_resource_callback), GINT_TO_POINTER(0));
 
   gtkw_cone_phi_angle = gtk_spin_button_new_with_range(0, 360., 3);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_cone_phi_angle), spherical_values[2]);
   g_signal_connect(gtkw_cone_phi_angle, "value-changed",
-		   G_CALLBACK(global_resource_callback), GINT_TO_POINTER(spin_globalConePhi));
+		   G_CALLBACK(global_resource_callback), GINT_TO_POINTER(1));
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(gtkw_cone_phi_angle), TRUE);
 
   gtkw_set_view = gtk_button_new_with_label (_("Set ortho."));
@@ -269,7 +266,7 @@ static GtkWidget *gtk_spin_create_color_wheel(float color_wheel_angle)
   gtkw_color_wheel_angle = gtk_spin_button_new_with_range(0, 360., 3);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_color_wheel_angle), color_wheel_angle);
   g_signal_connect(gtkw_color_wheel_angle, "value-changed",
-		   G_CALLBACK(global_resource_callback), GINT_TO_POINTER(spin_globalColorWheel));
+		   G_CALLBACK(global_resource_callback), GINT_TO_POINTER(2));
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(gtkw_color_wheel_angle), TRUE);
 
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 1);
@@ -286,6 +283,7 @@ GtkWidget* createHidingModeRadioWidgets()
 {
   GtkWidget *hbox;
   GSList *radiobutton_group;
+  SpinDrawingPolicy policy;
 
   hbox = gtk_hbox_new(FALSE, 0);
   radioAlwaysSpin = gtk_radio_button_new_with_label(NULL, _("always"));
@@ -306,7 +304,9 @@ GtkWidget* createHidingModeRadioWidgets()
   gtk_box_pack_start(GTK_BOX(hbox), radioAtomicSpin, TRUE, TRUE, 1);
   g_signal_connect(G_OBJECT(radioAtomicSpin), "toggled",
 		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(policyAtomicNullSpin));
-  switch (rspin_getGlobalResource_uint(spin_globalHidingMode))
+  g_object_get(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
+               "hiding-mode", &policy, NULL);
+  switch (policy)
     {
     case policyAlwaysSpin:
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioAlwaysSpin), TRUE);
@@ -330,23 +330,24 @@ static GtkWidget* createGtkConfigForSpinMethod()
 {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
   GtkWidget *label2 = gtk_label_new(_("Color cone orientation:"));
-  float cartesian[3];
-  float spherical[3];
+  float cartesian[3], spherical[3], wheel;
   GtkWidget *labelPolicy;
   GtkWidget *hbox, *check, *label, *align;
   GSList *radiobutton_group;
   SpinModulusPolicy modPol;
+  VisuRendering *spin;
+  gboolean atomic;
 
   DBG_fprintf(stderr, "Gtk Spin : building specific spin rendering method config widget.\n");
+  spin = visu_rendering_getByName(VISU_RENDERING_SPIN_NAME);
 
   spherical[0] = 1;
-  spherical[1] = rspin_getGlobalResource_float(spin_globalConeTheta);
-  spherical[2] = rspin_getGlobalResource_float(spin_globalConePhi);
+  g_object_get(G_OBJECT(spin), "cone-theta", spherical + 1, "cone-phi", spherical + 2, NULL);
 
-  matrix_sphericalToCartesian(cartesian, spherical);
+  tool_matrix_sphericalToCartesian(cartesian, spherical);
 
   /* Use modulus. */
-  modPol = rspin_getGlobalResource_uint(spin_globalModulus);
+  g_object_get(G_OBJECT(spin), "modulus-scaling", &modPol, NULL);
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new(_("Spin lenght is proportional to modulus: "));
@@ -394,8 +395,8 @@ static GtkWidget* createGtkConfigForSpinMethod()
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 3);
   check = gtk_check_button_new();
   gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 10);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
-			       rspin_getGlobalResource_boolean(spin_globalAtomic));
+  g_object_get(G_OBJECT(spin), "use-atomic", &atomic, NULL);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), atomic);
   g_signal_connect(G_OBJECT(check), "toggled",
 		   G_CALLBACK(onPolicyAtomicChanged), (gpointer)0);
 
@@ -419,14 +420,14 @@ static GtkWidget* createGtkConfigForSpinMethod()
   gtk_box_pack_start(GTK_BOX(vbox), align, FALSE, FALSE, 3);
   gtk_container_add(GTK_CONTAINER(align), label);
 
-  gtk_box_pack_start(GTK_BOX(vbox),
-		     gtk_spin_create_color_wheel(rspin_getGlobalResource_float
-						 (spin_globalColorWheel)),
-		     FALSE, FALSE, 3);
+  g_object_get(G_OBJECT(spin), "cone-omega", &wheel, NULL);
+  gtk_box_pack_start(GTK_BOX(vbox), 
+		     gtk_spin_create_color_wheel(wheel), FALSE, FALSE, 3);
 
   gtk_box_pack_start(GTK_BOX(vbox), label2, FALSE, FALSE, 3);
   gtk_misc_set_alignment(GTK_MISC(label2), 0., 0.5);
-  gtk_box_pack_start(GTK_BOX(vbox), gtk_spin_create_direction(cartesian, spherical), FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(vbox),
+                     gtk_spin_create_direction(cartesian, spherical), FALSE, FALSE, 3);
 
   gtk_widget_show_all(vbox);
 
@@ -437,7 +438,7 @@ static GtkWidget* createGtkConfigForSpinMethod()
 }
 static void destroyGtkConfigForSpinMethod()
 {
-  DBG_fprintf(stderr, "Gtk Spin : remove signal from config rendering widget.\n");
+  DBG_fprintf(stderr, "Gtk Spin: remove signal from config rendering widget.\n");
   g_signal_handler_disconnect(VISU_INSTANCE, configResourcesLoadedId);
 }
 static void onPolicyChanged(GtkToggleButton *toggle, gpointer data)
@@ -448,9 +449,8 @@ static void onPolicyChanged(GtkToggleButton *toggle, gpointer data)
   if (!gtk_toggle_button_get_active(toggle))
     return;
 
-  if (!rspin_setGlobalResource_uint(spin_globalHidingMode,
-				    (guint)GPOINTER_TO_INT(data)))
-    return;
+  g_object_set(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
+               "hiding-mode", (guint)GPOINTER_TO_INT(data), NULL);
 
   atomic = (gtk_toggle_button_get_active(toggle) ||
 	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioAtomicSpin)));
@@ -464,17 +464,16 @@ static void onPolicyChanged(GtkToggleButton *toggle, gpointer data)
   dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  visuData_createAllNodes(dataObj);  
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  visu_data_createAllNodes(dataObj);  
+  VISU_ADD_REDRAW;
 }
 static void onPolicyAtomicChanged(GtkToggleButton *toggle, gpointer data _U_)
 {
   VisuData *dataObj;
   gboolean atomic;
 
-  if (!rspin_setGlobalResource_boolean(spin_globalAtomic,
-				       gtk_toggle_button_get_active(toggle)))
-    return;
+  g_object_set(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
+               "use-atomic", gtk_toggle_button_get_active(toggle), NULL);
 
   atomic = (gtk_toggle_button_get_active(toggle) ||
 	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioAtomicSpin)));
@@ -488,9 +487,9 @@ static void onPolicyAtomicChanged(GtkToggleButton *toggle, gpointer data _U_)
   dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  visuData_createAllElements(dataObj);
-  visuData_createAllNodes(dataObj);  
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  visu_data_createAllElements(dataObj);
+  visu_data_createAllNodes(dataObj);  
+  VISU_ADD_REDRAW;
 }
 static void onPolicyModulusChanged(GtkToggleButton *toggle, gpointer data)
 {
@@ -512,23 +511,24 @@ static void onPolicyModulusChanged(GtkToggleButton *toggle, gpointer data)
     modPol = (SpinModulusPolicy)data;
   gtk_widget_set_sensitive(radioGlobalMod, gtk_toggle_button_get_active(toggle));
   gtk_widget_set_sensitive(radioPerTypeMod, gtk_toggle_button_get_active(toggle));
-  if (!rspin_setGlobalResource_uint(spin_globalModulus, modPol))
-    return;
+
+  g_object_set(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
+               "modulus-mode", modPol, NULL);
 
   dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  visuData_createAllElements(dataObj);
-  visuData_createAllNodes(dataObj);  
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  visu_data_createAllElements(dataObj);
+  visu_data_createAllNodes(dataObj);  
+  VISU_ADD_REDRAW;
 }
 
 /* Initialise the gtk methods associated with
    the spin rendering method. */
 void panelElementSpinInit_gtkMain()
 {
-  visuGtkSet_renderingSpecificMethods(visuRenderingClassGet_methodByName
-				      (VISU_RENDERING_SPIN),
+  visuGtkSet_renderingSpecificMethods(visu_rendering_getByName
+				      (VISU_RENDERING_SPIN_NAME),
 				      gtkSpinCreate_fileChooser);
 }
 
@@ -537,7 +537,8 @@ void panelElementSpinInit_gtkMain()
 static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
 {
   GtkWidget *fileSelection;
-  GList *tmpLst, *tmpLst2;
+  GList *lst, *tmpLst;
+  const GList *tmpLst2;
   GtkWidget *vbox, *wd;
   gchar* directory;
   GtkFileFilter *filterPos, *filterSpin, *filterAll;
@@ -550,7 +551,7 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
   gint status;
   VisuRendering *spin;
 
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
@@ -573,41 +574,35 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
   gtk_window_set_position(GTK_WINDOW(fileSelection), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(fileSelection), TRUE);
 
-  spin = visuRenderingClassGet_methodByName(VISU_RENDERING_SPIN);
+  spin = visu_rendering_getByName(VISU_RENDERING_SPIN_NAME);
 
   DBG_fprintf(stderr, "Gtk Spin: filter for position.\n");
-  tmpLst = visuRenderingGet_fileType(spin, FILE_KIND_POSITION);
   filterPos = gtk_file_filter_new ();
-  while(tmpLst)
-    {
-      tmpLst2 = ((FileFormat*)tmpLst->data)->fileType;
-      while (tmpLst2)
-	{
-	  DBG_fprintf(stderr, " | add pattern '%s'.\n", (char*)tmpLst2->data);
-	  gtk_file_filter_add_pattern (filterPos, (char*)tmpLst2->data);
-	  tmpLst2 = g_list_next(tmpLst2);
-	}
-      tmpLst = g_list_next(tmpLst);
-    }
-  gtk_file_filter_set_name(filterPos, visuRenderingGet_fileTypeName
+  lst = visu_rendering_getFileFormat(spin, FILE_KIND_POSITION); 
+  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
+    for (tmpLst2 = tool_file_format_getFilePatterns((ToolFileFormat*)tmpLst->data);
+         tmpLst2; tmpLst2 = g_list_next(tmpLst2))
+      {
+        DBG_fprintf(stderr, " | add pattern '%s'.\n", (char*)tmpLst2->data);
+        gtk_file_filter_add_pattern (filterPos, (char*)tmpLst2->data);
+      }
+  g_list_free(lst);
+  gtk_file_filter_set_name(filterPos, visu_rendering_getFileTypeName
 			   (spin, FILE_KIND_POSITION));
 
   DBG_fprintf(stderr, "Gtk Spin: filter for spin.\n");
-  tmpLst = visuRenderingGet_fileType(spin, FILE_KIND_SPIN);
   filterSpin = gtk_file_filter_new ();
-  while(tmpLst)
-    {
-      tmpLst2 = ((FileFormat*)tmpLst->data)->fileType;
-      while (tmpLst2)
-	{
-	  DBG_fprintf(stderr, " | add pattern '%s'.\n", (char*)tmpLst2->data);
-	  gtk_file_filter_add_pattern (filterSpin, (char*)tmpLst2->data);
-	  tmpLst2 = g_list_next(tmpLst2);
-	}
-      tmpLst = g_list_next(tmpLst);
-    }
+  lst = visu_rendering_getFileFormat(spin, FILE_KIND_SPIN); 
+  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
+    for (tmpLst2 = tool_file_format_getFilePatterns((ToolFileFormat*)tmpLst->data);
+         tmpLst2; tmpLst2 = g_list_next(tmpLst2))
+      {
+        DBG_fprintf(stderr, " | add pattern '%s'.\n", (char*)tmpLst2->data);
+        gtk_file_filter_add_pattern (filterSpin, (char*)tmpLst2->data);
+      }
+  g_list_free(lst);
   gtk_file_filter_set_name(filterSpin,
-			   visuRenderingGet_fileTypeName(spin, FILE_KIND_SPIN));
+			   visu_rendering_getFileTypeName(spin, FILE_KIND_SPIN));
   filterAll = gtk_file_filter_new ();
   gtk_file_filter_add_pattern (filterAll, "*");
   gtk_file_filter_set_name(filterAll, _("All files"));
@@ -767,10 +762,10 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
 	  if (fileChooserSpin.files[FILE_KIND_POSITION] &&
 	      fileChooserSpin.files[FILE_KIND_SPIN])
 	    {
-	      visuDataAdd_file(data, fileChooserSpin.files[FILE_KIND_POSITION],
-			       FILE_KIND_POSITION, (FileFormat*)0);
-	      visuDataAdd_file(data, fileChooserSpin.files[FILE_KIND_SPIN],
-			       FILE_KIND_SPIN, (FileFormat*)0);
+	      visu_data_addFile(data, fileChooserSpin.files[FILE_KIND_POSITION],
+			       FILE_KIND_POSITION, (ToolFileFormat*)0);
+	      visu_data_addFile(data, fileChooserSpin.files[FILE_KIND_SPIN],
+			       FILE_KIND_SPIN, (ToolFileFormat*)0);
 	      g_free(fileChooserSpin.files[FILE_KIND_POSITION]);
 	      g_free(fileChooserSpin.files[FILE_KIND_SPIN]);
 
@@ -923,7 +918,9 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   GtkWidget* hbox[7], *vbox, *label, *vboxAtomic;
   GtkWidget* shapeLabel, *hLabel, *rhLabel, *lLabel, *rlLabel, *ratioLabel, *lengthLabel;
   int i, j = 0;
-  gboolean atomic;
+  SpinDrawingPolicy hide;
+  gboolean atomic, useAt;
+  VisuRendering *spin;
 
   vbox = gtk_vbox_new(FALSE, 0);
 
@@ -944,7 +941,6 @@ GtkWidget* createGtkInterfaceForSpinMethod()
     }
       
   /* Labels creation */
-
   shapeLabel = gtk_label_new("");
   gtk_label_set_markup(GTK_LABEL(shapeLabel), _("<i>Spin shape:</i>"));
   gtk_misc_set_alignment(GTK_MISC(shapeLabel), 0., 0.5);
@@ -975,7 +971,6 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   gtk_widget_show(rlLabel);
 
   /* Spin buttons creation */
-
   heightResourceSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[0] = g_signal_connect((gpointer)heightResourceSpin, "value-changed",
 					     G_CALLBACK(element_resource_callback),
@@ -1018,10 +1013,11 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   gtk_widget_show(gtkw_use_element_color_hat);
 
   /* Combo boxes creation */
-  gtkw_element_shape_number = gtk_combo_box_new_text();
-  for (i=0; i<arrow_shape_nb; i++)
-    gtk_combo_box_append_text(GTK_COMBO_BOX(gtkw_element_shape_number),
-			      rspin_shape_number_to_translated_name(i));
+  gtkw_element_shape_number = gtk_combo_box_text_new();
+  for (i=0; i<nbSpinShapes; i++)
+    gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(gtkw_element_shape_number),
+                              (const gchar*)0,
+			      visu_renderingSpin_getShapeNameI18n(i));
   /* set callback for the combo button. */
   element_callback_ids[6] = g_signal_connect(gtkw_element_shape_number, "changed",
 					     G_CALLBACK(element_resource_callback),
@@ -1063,9 +1059,10 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   gtk_widget_show(labelAtomic);
   gtk_label_set_use_markup(GTK_LABEL(labelAtomic), TRUE);
 
-  atomic = (rspin_getGlobalResource_boolean(spin_globalAtomic) ||
-	    rspin_getGlobalResource_uint(spin_globalHidingMode) ==
-	    policyAtomicNullSpin);
+  spin = visu_rendering_getByName(VISU_RENDERING_SPIN_NAME);
+  g_object_get(G_OBJECT(spin), "hiding-mode", &hide,
+               "use-atomic", &useAt, NULL);
+  atomic = (useAt || hide == policyAtomicNullSpin);
   gtk_widget_set_sensitive(expandAtomic, atomic);
   gtk_expander_set_expanded(GTK_EXPANDER(expandAtomic), atomic);
   if (atomic)
@@ -1074,7 +1071,6 @@ GtkWidget* createGtkInterfaceForSpinMethod()
     gtk_widget_show(labelAtomic);
 
   /* Displaying every widget created so far */
-
   gtk_box_pack_start(GTK_BOX(hbox[j]), shapeLabel, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(hbox[j]), gtkw_element_shape_number, FALSE, FALSE, 3);
   gtk_box_pack_start(GTK_BOX(vbox), hbox[j], FALSE, FALSE, 2);
@@ -1117,28 +1113,23 @@ GtkWidget* createGtkInterfaceForSpinMethod()
 }
 
 /* This function is called whenever the current element is changed in the gtk panel. */
-void changeSomethingSpin(GList *eleList)
+static void changeSomethingSpin(GList *eleList)
 {
   VisuElement *ele;
 
-  DBG_fprintf(stderr, "Gtk Spin : changing values on element change.\n");
-
-  /* We copy the list of given elements. */
-  if (currentListElement)
-    g_list_free(currentListElement);
-  currentListElement = g_list_copy(eleList);
-
-  DBG_fprintf(stderr, "Gtk Spin : give the element change to the atomic part.\n");
-  panelElementAtomicCallback_onElementChange(eleList);
-
-  /* If the list has only one element, we continue
-     and update the values on the widgets. */
-  if (g_list_next(eleList))
+  DBG_fprintf(stderr, "Gtk Spin: changing values on element change for %p.\n",
+              (gpointer)eleList);
+  if (!eleList)
     return;
 
+  DBG_fprintf(stderr, "Gtk Spin: give the element change to the atomic part.\n");
+  panelElementAtomicCallback_onElementChange(eleList);
+
   ele = (VisuElement*)eleList->data;
+
   need_redraw = 0;
 
+  DBG_fprintf(stderr, "Gtk Spin: change all values on element change.\n");
   g_signal_handler_block (heightResourceSpin, element_callback_ids[0] );  
   g_signal_handler_block (rheightResourceSpin, element_callback_ids[1] );  
   g_signal_handler_block (lengthResourceSpin, element_callback_ids[2] );  
@@ -1191,7 +1182,7 @@ void changeSomethingSpin(GList *eleList)
 void element_resource_callback(GtkWidget* widget, gpointer data)
 {
   gboolean refresh;
-  GList *tmpLst;
+  GList *tmpLst, *eleList;
   VisuElement *ele;
   SpinElementResources property;
   gboolean new_bool;
@@ -1199,13 +1190,16 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
   float new_float;
   VisuData *dataObj;
   int id;
+  VisuOpenGLView *view;
+  VisuRendering *method;
+
+  eleList = panelElementsGet_selected();
+  if (!eleList)
+    return;
 
   property = GPOINTER_TO_INT(data);
-  g_return_if_fail(property < spin_nbElementResources);
-
   refresh = FALSE;
-  tmpLst = currentListElement;
-  while (tmpLst)
+  for (tmpLst = eleList; tmpLst; tmpLst = g_list_next(tmpLst))
     {
       ele = (VisuElement*)tmpLst->data;
       switch (property)
@@ -1225,7 +1219,7 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
 	  DBG_fprintf(stderr, "GtkSpin : Set element '%d' property to %d\n",
 		      property, new_int);
 	  refresh = rspin_setElementResource_uint(ele, property, new_int) || refresh;
-	  if (new_int == arrow_ellipsoid || new_int == arrow_torus)
+	  if (new_int == VISU_RENDERING_SPIN_ELLIPSOID || new_int == VISU_RENDERING_SPIN_TORUS)
 	    {
 	      gtk_widget_show(vboxElipsoidShape);
 	      gtk_widget_hide(vboxArrowShape);
@@ -1253,7 +1247,6 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
 	  g_warning("Unknown property '%d' in callback for spin element values.", property);
 	  return;
 	}
-      tmpLst = g_list_next(tmpLst);
     }
 
   if(need_redraw && refresh)
@@ -1262,67 +1255,71 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
       if (!dataObj)
 	return;
 
-      for(tmpLst = currentListElement; tmpLst; tmpLst = g_list_next(tmpLst))
-	{
-	  ele = (VisuElement*)tmpLst->data;
-	  id = rspin_createShapeSpin(dataObj, ele);
-	  ele->openGLIdentifier = id;
-	}
-      visuData_createAllNodes(dataObj);  
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      method = visu_object_getRendering(VISU_INSTANCE);
+      view = visu_data_getOpenGLView(dataObj);
+      for(tmpLst = eleList; tmpLst; tmpLst = g_list_next(tmpLst))
+        id = visu_rendering_createElement(method, (VisuElement*)tmpLst->data, view->camera,
+                                          MIN(view->window->width, view->window->height));
+      visu_data_createAllNodes(dataObj);  
+      VISU_ADD_REDRAW;
     }
+
+  g_list_free(eleList);
 }
 
 /* This is the callback func for each global resource. */
 void global_resource_callback(GtkWidget* button, gpointer data)
 {
-  SpinGlobalResources property;
   int value;
-  gboolean refresh;
   VisuData *dataObj;
+  VisuRendering *spin;
 
   value = GPOINTER_TO_INT(data);
   if (value >= 0)
     {
-      property = (SpinGlobalResources)value;
-      g_return_if_fail(property < spin_nbGlobalResources);
-      switch (property)
+      spin = visu_rendering_getByName(VISU_RENDERING_SPIN_NAME);
+      switch (value)
 	{
-	case spin_globalConeTheta:
-	case spin_globalConePhi:
-	case spin_globalColorWheel:
-	  refresh = rspin_setGlobalResource_float
-	    (property, gtk_spin_button_get_value(GTK_SPIN_BUTTON(button)));
-
-	  if(need_redraw && refresh)
-	    {
-	      float spherical[3];
-	      float cartesian[3];
-	      int i;
-
-	      need_redraw = 0;
-	  
-	      spherical[0] = 1;
-	      spherical[1] = rspin_getGlobalResource_float(spin_globalConeTheta);
-	      spherical[2] = rspin_getGlobalResource_float(spin_globalConePhi);
-
-	      matrix_sphericalToCartesian(cartesian, spherical);
-
-	      for(i=0; i<3; i++)
-		if(cartesian[i] < 0.01 && cartesian [i] > -0.01)
-		  cartesian[i] = 0;
-	  
-	      gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_x), cartesian[0]);
-	      gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_y), cartesian[1]);
-	      gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_z), cartesian[2]);
-
-	      need_redraw = 1;
-	    }
-	  break;
+	case 0:
+          g_object_set(G_OBJECT(spin), "cone-theta",
+                       gtk_spin_button_get_value(GTK_SPIN_BUTTON(button)), NULL);
+          break;
+	case 1:
+          g_object_set(G_OBJECT(spin), "cone-phi",
+                       gtk_spin_button_get_value(GTK_SPIN_BUTTON(button)), NULL);
+          break;
+	case 2:
+          g_object_set(G_OBJECT(spin), "cone-omega",
+                       gtk_spin_button_get_value(GTK_SPIN_BUTTON(button)), NULL);
+          break;
 	default:
-	  g_warning("Unknown property '%d' in callback for spin global values.", property);
+	  g_warning("Unknown property '%d' in callback for spin global values.", value);
 	  return;
 	}
+      if(need_redraw)
+        {
+          float spherical[3];
+          float cartesian[3];
+          int i;
+
+          need_redraw = 0;
+	  
+          spherical[0] = 1;
+          g_object_get(G_OBJECT(spin),
+                       "cone-theta", spherical + 1, "cone-phi", spherical + 2, NULL);
+
+          tool_matrix_sphericalToCartesian(cartesian, spherical);
+
+          for(i=0; i<3; i++)
+            if(cartesian[i] < 0.01 && cartesian [i] > -0.01)
+              cartesian[i] = 0;
+	  
+          gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_x), cartesian[0]);
+          gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_y), cartesian[1]);
+          gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_z), cartesian[2]);
+
+          need_redraw = 1;
+        }
     }
   else
     {
@@ -1340,7 +1337,7 @@ void global_resource_callback(GtkWidget* button, gpointer data)
 	  cartesian[1] = y;
 	  cartesian[2] = z;
 	  
-	  matrix_cartesianToSpherical(spherical, cartesian);
+	  tool_matrix_cartesianToSpherical(spherical, cartesian);
 
 	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_cone_theta_angle), spherical[1]);
 	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_cone_phi_angle), spherical[2]);
@@ -1355,10 +1352,8 @@ void global_resource_callback(GtkWidget* button, gpointer data)
       if (!dataObj)
 	return;
 
-      g_signal_emit(VISU_INSTANCE,VISU_SIGNALS[SPINAXES_SIGNAL],
-		    0 , dataObj, NULL);
-      visuData_createAllNodes(dataObj);  
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      visu_data_createAllNodes(dataObj);  
+      VISU_ADD_REDRAW;
     }
 }
 
@@ -1367,12 +1362,12 @@ void set_view(GtkWidget* button _U_, gpointer data _U_)
   float theta;
   float phi;
   VisuData *dataObj;
-  OpenGLView *view;
+  VisuOpenGLView *view;
 
   dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  view = visuDataGet_openGLView(dataObj);
+  view = visu_data_getOpenGLView(dataObj);
 
   theta = fModulo(view->camera->theta, 360);
   if(theta > 180)
@@ -1391,20 +1386,20 @@ void set_view(GtkWidget* button _U_, gpointer data _U_)
 static void sync_global_resources(GObject *object _U_, VisuData *dataObj _U_,
 				  gpointer data _U_)
 {
-  float spherical[3];
-  float cartesian[3];
+  float spherical[3], cartesian[3], wheel;
   int i;
 
-  DBG_fprintf(stderr, "Gtk Spin : caught the 'resourcesLoaded' signal.\n");
+  DBG_fprintf(stderr, "Gtk Spin: caught the 'resourcesLoaded' signal.\n");
 
   if(gtkw_cone_theta_angle == NULL)
     return;
 
   spherical[0] = 1;
-  spherical[1] = rspin_getGlobalResource_float(spin_globalConeTheta);
-  spherical[2] = rspin_getGlobalResource_float(spin_globalConePhi);
+  g_object_get(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
+               "cone-theta", spherical + 1, "cone-phi", spherical + 2,
+               "cone-omega", &wheel, NULL);
 
-  matrix_sphericalToCartesian(cartesian, spherical);
+  tool_matrix_sphericalToCartesian(cartesian, spherical);
 
   for(i=0; i<3; i++)
     if(cartesian[i] < 0.01 && cartesian [i] > -0.01)
@@ -1418,20 +1413,26 @@ static void sync_global_resources(GObject *object _U_, VisuData *dataObj _U_,
 
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_cone_theta_angle), spherical[1]);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_cone_phi_angle), spherical[2]); 
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_color_wheel_angle),
-			    rspin_getGlobalResource_float(spin_globalColorWheel)); 
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtkw_color_wheel_angle), wheel);
 
   need_redraw = 1;  
 }      
 
 static void sync_local_resources(GObject *trash _U_, gpointer data _U_)
 {
+  GList *eleList;
   VisuElement *ele;
 
-  if(heightResourceSpin == NULL || currentListElement == NULL)
+  if(heightResourceSpin == NULL)
     return;
   
-  ele = (VisuElement*)currentListElement->data;
+  eleList = panelElementsGet_selected();
+  if (!eleList)
+    return;
+
+  ele = (VisuElement*)eleList->data;
+  g_list_free(eleList);
+
   need_redraw = 0;
 
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(heightResourceSpin),
