@@ -43,20 +43,25 @@
 */
 #include "panelConfig.h"
 
+#include <support.h>
 #include <visu_gtk.h>
 #include <visu_tools.h>
 #include <visu_object.h>
 #include <visu_basic.h>
 #include <visu_data.h>
 #include <visu_configFile.h>
+#include <gtk_renderingWindowWidget.h>
 #include <extraGtkFunctions/gtk_numericalEntryWidget.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
-#include <renderingBackend/visu_windowInterface.h>
 #include <coreTools/toolColor.h>
 #include <coreTools/toolConfigFile.h>
 
 #include <sys/stat.h>
 
+/**
+ * SECTION: panelConfig
+ * @short_description: The tab where miscellaneous options are setup.
+ */
 
 #define FLAG_PARAMETER_TABVIEW_CONFIG   "config_subPanelTabView"
 #define FLAG_PARAMETER_SKIN_CONFIG      "config_skin"
@@ -109,14 +114,16 @@ static GtkWidget *visuConfigData;
 static GtkWidget *checkShowTab;
 static GtkWidget *checkRefreshAuto;
 static GtkWidget *checkStorePositions;
+static GtkWidget *checkRedCoord;
 
 /* Callbacks */
 static void checkShowTabToggled(GtkToggleButton *button, gpointer data);
-void checkRememberToggled(GtkToggleButton *button, gpointer data);
+static void checkRememberToggled(GtkToggleButton *button, gpointer data);
+static void checkRefreshToggled(GtkToggleButton *button, gpointer data);
+static void checkRedCoordToggled(GtkToggleButton *button, gpointer data);
 void entryRcFilesChanged(GtkEntry *entry, gpointer data);
 void directorySelectedForResources(GtkButton *button, gpointer user_data);
 void openRcFileSelector(GtkButton *button, gpointer data);
-void checkRefreshToggled(GtkToggleButton *button, gpointer data);
 static void onRefreshPeriodChanged(GtkSpinButton* button, gpointer data);
 void onDataReadySignal(GObject *obj, VisuData *dataObj, gpointer data);
 gboolean treePathClicked(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
@@ -129,32 +136,32 @@ ToolPanel* panelConfigInit()
   char *tl = _("Configuration");
   VisuConfigFileEntry *resourceEntry;
 
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_TABVIEW_CONFIG,
 					  DESC_PARAMETER_TABVIEW_CONFIG,
 					  1, readConfigTabView);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_SKIN_CONFIG,
 					  DESC_PARAMETER_SKIN_CONFIG,
 					  1, readConfigSkin);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_REFRESH_CONFIG,
 					  DESC_PARAMETER_REFRESH_CONFIG,
 					  1, readConfigRefresh);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_PERIOD_CONFIG,
 					  DESC_PARAMETER_PERIOD_CONFIG,
 					  1, readConfigPeriod);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParametersPanelConfig);
 
-  defaultSkinPath = g_build_filename(visuBasicGet_dataDir(), "v_sim.rc", NULL);
-  userSkinPath    = g_build_filename(visuBasicGet_localDir(), "v_sim.rc", NULL);
+  defaultSkinPath = g_build_filename(visu_basic_getDataDir(), "v_sim.rc", NULL);
+  userSkinPath    = g_build_filename(visu_basic_getLocalDir(), "v_sim.rc", NULL);
   config_subPanelTabView = PARAMETER_CONFIG_TABVIEW_DEFAULT;
   config_refreshPeriod = -1;
   config_refreshIsOn = -1;
-  panelConfigSet_refreshPeriod((RenderingWindow*)0, PARAMETER_CONFIG_PERIOD_DEFAULT);
-  panelConfigSet_automaticRefresh((RenderingWindow*)0, PARAMETER_CONFIG_REFRESH_DEFAULT);
+  panelConfigSet_refreshPeriod((VisuRenderingWindow*)0, PARAMETER_CONFIG_PERIOD_DEFAULT);
+  panelConfigSet_automaticRefresh((VisuRenderingWindow*)0, PARAMETER_CONFIG_REFRESH_DEFAULT);
 
   /* Now that everything has a value, we create the panel. */
   visuConfigData = toolPanelNew_withIconFromStock("Panel_configuration",
@@ -193,106 +200,70 @@ static void initPanelConfigGtkPart()
 
 GtkWidget *createInteriorConfig()
 {
-  GtkWidget *vbox, *vbox2;
+  GtkWidget *vbox;
   GtkWidget *hbox;
   GtkWidget *label;
-  GtkWidget *table;
-  GtkWidget *align;
-  GtkObject *adj;
-  GtkWidget *scrollView;
   GtkWidget *spinRefresh;
   const gchar **units;
   int i;
  
-#if GTK_MINOR_VERSION < 12 
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12 
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
 #endif
 
-  scrollView = gtk_scrolled_window_new((GtkAdjustment*)0,
-				       (GtkAdjustment*)0);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollView),
-				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollView), GTK_SHADOW_NONE);
-
   vbox = gtk_vbox_new(FALSE, 0);
-  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrollView), vbox);
 
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
-  label = gtk_label_new(_("Always show labels in tabs: "));
-  gtk_widget_set_name(label, "label_head");
-  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-  checkShowTab = gtk_check_button_new();
+  checkShowTab = gtk_check_button_new_with_mnemonic(_("Always show _labels in tabs"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkShowTab),
 			       (gboolean)config_subPanelTabView);
-  gtk_box_pack_start(GTK_BOX(hbox), checkShowTab, FALSE, FALSE, 2);
+  gtk_box_pack_start(GTK_BOX(vbox), checkShowTab, FALSE, FALSE, 3);
 
-  table = gtk_table_new(2, 1, FALSE);
-  gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 5);
-  align = gtk_alignment_new(0., 0.5, 0., 0.);
-  gtk_table_attach(GTK_TABLE(table), align, 0, 1, 0, 1, GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 0);
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_container_add(GTK_CONTAINER(align), hbox);
-  label = gtk_label_new(_("Automatic refresh: "));
-  gtk_widget_set_name(label, "label_head");
-  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-  checkRefreshAuto = gtk_check_button_new();
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
+  checkRefreshAuto = gtk_check_button_new_with_mnemonic(_("Automatic _refresh"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRefreshAuto),
 			       (gboolean)config_refreshIsOn);
   gtk_box_pack_start(GTK_BOX(hbox), checkRefreshAuto, FALSE, FALSE, 0);
-  align = gtk_alignment_new(1., 0.5, 0., 0.);
-  gtk_table_attach(GTK_TABLE(table), align, 0, 1, 1, 2, GTK_FILL | GTK_EXPAND, GTK_SHRINK, 2, 0);
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_container_add(GTK_CONTAINER(align), hbox);
-  label = gtk_label_new(_("Refresh period: "));
-  gtk_widget_set_name(label, "label_head");
-  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-  adj = gtk_adjustment_new(100., 10., 10000., 10., 100., 0.);
-  spinRefresh = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 0.05, 0);
+  label = gtk_label_new(_(" ms"));
+  gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+  spinRefresh = gtk_spin_button_new_with_range(10., 10000., 10.);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinRefresh),
 			    config_refreshPeriod);
-  gtk_box_pack_start(GTK_BOX(hbox), spinRefresh, FALSE, FALSE, 0);
-  label = gtk_label_new(_(" ms"));
-  gtk_widget_set_name(label, "label_head");
-  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+  gtk_box_pack_end(GTK_BOX(hbox), spinRefresh, FALSE, FALSE, 0);
+  label = gtk_label_new(_("period:"));
+  gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
-  vbox2 = gtk_vbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), vbox2, FALSE, FALSE, 5);
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
-  label = gtk_label_new(_("Remember windows positions:"));
-  gtk_widget_set_name(label, "label_head");
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
-  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-  checkStorePositions = gtk_check_button_new();
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
+  checkStorePositions = gtk_check_button_new_with_mnemonic(_("Remember _windows positions"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStorePositions),
 			       (gboolean)TRUE);
-  gtk_box_pack_start(GTK_BOX(hbox), checkStorePositions, FALSE, FALSE, 2);
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
-  label = gtk_label_new(_("(because I've a bad WM)"));
-  gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
-  gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 1);
+  gtk_box_pack_start(GTK_BOX(hbox), checkStorePositions, FALSE, FALSE, 0);
+  label = gtk_label_new(_("<span size=\"small\">(because I've a bad WM)</span>"));
+  gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+  gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+
+  checkRedCoord = gtk_check_button_new_with_mnemonic(_("Display _coordinates in reduce"));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRedCoord),
+			       (gboolean)visu_rendering_window_getDisplayCoordinatesInReduce());
+  gtk_box_pack_start(GTK_BOX(vbox), checkRedCoord, FALSE, FALSE, 3);
 
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
   label = gtk_label_new(_("Set the prefered unit:"));
-  gtk_widget_set_name(label, "label_head");
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 
-  comboUnit = gtk_combo_box_new_text();
-  units = visuToolsGet_unitNames();
+  comboUnit = gtk_combo_box_text_new();
+  units = tool_physic_getUnitNames();
   for (i = 0; units[i]; i++)
-    gtk_combo_box_append_text(GTK_COMBO_BOX(comboUnit), units[i]);
-  gtk_combo_box_set_active(GTK_COMBO_BOX(comboUnit), visuBasicGet_preferedUnit());
+    gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboUnit), (const gchar*)0, units[i]);
+  gtk_combo_box_set_active(GTK_COMBO_BOX(comboUnit), visu_basic_getPreferedUnit());
   g_signal_connect(G_OBJECT(comboUnit), "changed",
 		   G_CALLBACK(onUnitChanged), (gpointer)0);
   gtk_box_pack_start(GTK_BOX(hbox), comboUnit, FALSE, FALSE, 0);
 
-  gtk_widget_show_all(scrollView);
-
   /* Set the callbacks. */
   g_signal_connect(G_OBJECT(checkShowTab), "toggled",
 		   G_CALLBACK(checkShowTabToggled), (gpointer)0);
@@ -300,11 +271,13 @@ GtkWidget *createInteriorConfig()
 		   G_CALLBACK(checkRememberToggled), (gpointer)0);
   g_signal_connect(G_OBJECT(checkRefreshAuto), "toggled",
 		   G_CALLBACK(checkRefreshToggled), (gpointer)0);
+  g_signal_connect(G_OBJECT(checkRedCoord), "toggled",
+		   G_CALLBACK(checkRedCoordToggled), (gpointer)0);
   g_signal_connect(G_OBJECT(spinRefresh), "value-changed",
 		   G_CALLBACK(onRefreshPeriodChanged), (gpointer)0);
-  
-  
-  return scrollView;
+    
+  gtk_widget_show_all(vbox);
+  return vbox;
 }
 
 /*************/
@@ -314,9 +287,9 @@ static void checkShowTabToggled(GtkToggleButton *button _U_, gpointer data _U_)
 {
   panelConfigSet_tabView(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkShowTab)));
 }
-void checkRememberToggled(GtkToggleButton *button, gpointer data _U_)
+static void checkRememberToggled(GtkToggleButton *button, gpointer data _U_)
 {
-  gtkMainClassSet_rememberPosition(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
+  visu_uiMainClass_setRememberPosition(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
 }
 static void onConfigEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
 {
@@ -324,25 +297,23 @@ static void onConfigEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
     initPanelConfigGtkPart();
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStorePositions),
-			       gtkMainClassGet_rememberPosition());
+			       visu_uiMainClass_getRememberPosition());
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRedCoord),
+			       visu_rendering_window_getDisplayCoordinatesInReduce());
 }
-void checkRefreshToggled(GtkToggleButton *button, gpointer data _U_)
+static void checkRefreshToggled(GtkToggleButton *button, gpointer data _U_)
 {
-  RenderingWindow *window;
-
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_if_fail(window);
-
-  panelConfigSet_automaticRefresh(window, gtk_toggle_button_get_active(button));
+  panelConfigSet_automaticRefresh(visu_uiMainClass_getDefaultRendering(),
+				  gtk_toggle_button_get_active(button));
+}
+static void checkRedCoordToggled(GtkToggleButton *button, gpointer data _U_)
+{
+  visu_rendering_window_setDisplayCoordinatesInReduce(gtk_toggle_button_get_active(button));
 }
 static void onRefreshPeriodChanged(GtkSpinButton* button, gpointer data _U_)
 {
-  RenderingWindow *window;
-
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_if_fail(window);
-
-  panelConfigSet_refreshPeriod(window, (float)gtk_spin_button_get_value(button));
+  panelConfigSet_refreshPeriod(visu_uiMainClass_getDefaultRendering(),
+			       (float)gtk_spin_button_get_value(button));
 }
 void openRcFileSelector(GtkButton *button _U_, gpointer data _U_)
 {
@@ -373,6 +344,7 @@ static void setSkin(char* label)
     return;
   gtk_rc_parse(tmp);
 
+  DBG_fprintf(stderr, "Panel Config: get the settings.\n");
   settings = gtk_settings_get_default ();
   gtk_rc_reparse_all_for_settings(settings, TRUE);
   DBG_fprintf(stderr,"Panel Config: applying RC file OK.\n");
@@ -392,7 +364,7 @@ void autoReloadAddTimeout(VisuData *data, guint time, gpointer user_data)
       *timeoutId = 0;
     }
   if (!*timeoutId)
-    *timeoutId = visuDataAdd_timeout(data, time, automaticReload, user_data);
+    *timeoutId = visu_data_addTimeout(data, time, automaticReload, user_data);
 }
 void autoReloadRemoveTimeout(VisuData *data)
 {
@@ -403,7 +375,7 @@ void autoReloadRemoveTimeout(VisuData *data)
   timeoutId = (guint*)g_object_get_data(G_OBJECT(data), "autoLoad_timeoutId");
   if (timeoutId)
     {
-      visuDataRemove_timeout(data, *timeoutId);
+      visu_data_removeTimeout(data, *timeoutId);
       *timeoutId = 0;
     }
 }
@@ -415,7 +387,7 @@ static gboolean automaticReload(gpointer data)
   time_t modTime;
   int kind, nbKind;
   gboolean reloadNeeded, ok;
-  GenericRenderingWindow window;
+  VisuRenderingWindow *window;
   VisuData *dataObj;
   time_t *lastReadTime;
   GError *error;
@@ -424,7 +396,7 @@ static gboolean automaticReload(gpointer data)
   window = RENDERING_WINDOW(data);
   g_return_val_if_fail(window, TRUE);
 
-  dataObj = renderingWindowGet_visuData(window);
+  dataObj = visu_rendering_window_getVisuData(window);
   if (!dataObj)
     {
       DBG_fprintf(stderr, "Panel Config : automatic reload aborted, no file available.\n");
@@ -435,10 +407,10 @@ static gboolean automaticReload(gpointer data)
   g_return_val_if_fail(lastReadTime, TRUE);
 
   reloadNeeded = FALSE;
-  nbKind = visuRenderingGet_nbFileType(visuRenderingClassGet_current());
+  nbKind = visu_rendering_getNFileTypes(visu_object_getRendering(VISU_INSTANCE));
   for (kind = 0; kind < nbKind; kind++)
     {
-      file = visuDataGet_file(dataObj, kind, (FileFormat**)0);
+      file = visu_data_getFile(dataObj, kind, (ToolFileFormat**)0);
       if (!file)
 	return TRUE;
 
@@ -456,23 +428,23 @@ static gboolean automaticReload(gpointer data)
   if (reloadNeeded)
     {
       DBG_fprintf(stderr, "Panel Config : automatic reloading in progress...\n");
-      iSet = visuDataGet_setId(dataObj);
-      visuDataFree_population(dataObj);
+      iSet = visu_data_getISubset(dataObj);
+      visu_data_freePopulation(dataObj);
       error = (GError*)0;
-      ok = visuBasicLoad_dataFromFile(dataObj, (FileFormat*)0, iSet, &error);
+      ok = visu_basic_loadData(dataObj, (ToolFileFormat*)0, iSet, &error);
       if (!ok)
 	{
 	  visuGtkRaise_warning(_("Automatic file reloading"), error->message,
 			       (GtkWindow*)0);
 	  g_error_free(error);
-	  visuRenderingWindowSet_visuData(window, (VisuData*)0);
+	  visu_rendering_window_setData(window, (VisuData*)0);
 	}
       else
 	{
-	  visuRenderingWindowSet_visuData(window, dataObj);
-	  visuData_createAllNodes(dataObj);
+	  visu_rendering_window_setData(window, dataObj);
+	  visu_data_createAllNodes(dataObj);
 	}
-      visuObjectRedraw((gpointer)0);
+      visu_object_redraw((gpointer)0);
     }
   return TRUE;
 }
@@ -489,11 +461,11 @@ void onDataReadySignal(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 
   DBG_fprintf(stderr, "Panel Config: caught the 'dataReadyForRendering' signal,"
 	      " set acces time for VisuData %p.\n", (gpointer)dataObj);
-  nbKind = visuRenderingGet_nbFileType(visuRenderingClassGet_current());
+  nbKind = visu_rendering_getNFileTypes(visu_object_getRendering(VISU_INSTANCE));
   lastReadTime = g_malloc(sizeof(time_t) * nbKind);
   for (kind = 0; kind < nbKind; kind++)
     {
-      file = visuDataGet_file(dataObj, kind, (FileFormat**)0);
+      file = visu_data_getFile(dataObj, kind, (ToolFileFormat**)0);
       if (!file)
 	lastReadTime[kind] = 0;
       else
@@ -509,11 +481,11 @@ void onDataReadySignal(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 			 lastReadTime, g_free);
   if (config_refreshIsOn)
     autoReloadAddTimeout(dataObj, config_refreshPeriod,
-			 (gpointer)visuDataGet_renderingWindow(dataObj));
+			 (gpointer)visu_uiMainClass_getDefaultRendering());
 }
 static void onUnitChanged(GtkComboBox *combo, gpointer data _U_)
 {
-  visuBasicSet_preferedUnit(gtk_combo_box_get_active(combo));
+  visu_basic_setPreferedUnit(gtk_combo_box_get_active(combo));
 }
 
 
@@ -534,7 +506,7 @@ void panelConfigSet_tabView(gboolean viewed)
   /* set the associated parameter. */
   config_subPanelTabView = viewed;
 }
-void panelConfigSet_automaticRefresh(RenderingWindow *window, int bool)
+void panelConfigSet_automaticRefresh(VisuRenderingWindow *window, int bool)
 {
   DBG_fprintf(stderr, "Panel Config : set refresh to %d (previously %d).\n",
 	      bool, config_refreshIsOn);
@@ -543,16 +515,16 @@ void panelConfigSet_automaticRefresh(RenderingWindow *window, int bool)
     return;
 
   config_refreshIsOn = bool;
-  if (window && renderingWindowGet_visuData(window))
+  if (window && visu_rendering_window_getVisuData(window))
     {
       if (bool)
-	autoReloadAddTimeout(renderingWindowGet_visuData(window),
+	autoReloadAddTimeout(visu_rendering_window_getVisuData(window),
 			     config_refreshPeriod, (gpointer)window);
       else
-	autoReloadRemoveTimeout(renderingWindowGet_visuData(window));
+	autoReloadRemoveTimeout(visu_rendering_window_getVisuData(window));
     }
 }
-void panelConfigSet_refreshPeriod(RenderingWindow *window, float val)
+void panelConfigSet_refreshPeriod(VisuRenderingWindow *window, float val)
 {
   VisuData *dataObj;
 
@@ -563,7 +535,7 @@ void panelConfigSet_refreshPeriod(RenderingWindow *window, float val)
     return;
 
   config_refreshPeriod = val;
-  dataObj = (window)?renderingWindowGet_visuData(window):(VisuData*)0;
+  dataObj = (window)?visu_rendering_window_getVisuData(window):(VisuData*)0;
   if (dataObj && config_refreshIsOn)
     {
       DBG_fprintf(stderr, "Panel Config : stopping the callback of refresh "
@@ -587,7 +559,7 @@ static gboolean readConfigTabView(gchar **lines, int nbLines, int position,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_boolean(lines[0], position, &viewed, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &viewed, 1, error))
     return FALSE;
   panelConfigSet_tabView(viewed);
   
@@ -602,7 +574,7 @@ static gboolean readConfigSkin(gchar **lines, int nbLines, int position,
 
   if (!lines[0][0])
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 string value must appear"
 			     " after the %s markup.\n"), position,
 			   FLAG_PARAMETER_SKIN_CONFIG);
@@ -620,14 +592,12 @@ static gboolean readConfigRefresh(gchar **lines, int nbLines, int position,
 				  VisuData *dataObj _U_, GError **error)
 {
   gboolean bool;
-  RenderingWindow *window;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  if (!configFileRead_boolean(lines[0], position, &bool, 1, error))
+  if (!tool_configFile_readBoolean(lines[0], position, &bool, 1, error))
     return FALSE;
-  panelConfigSet_automaticRefresh(window, bool);
+  panelConfigSet_automaticRefresh(visu_uiMainClass_getDefaultRendering(), bool);
 
   return TRUE;
 }
@@ -635,15 +605,14 @@ static gboolean readConfigPeriod(gchar **lines, int nbLines, int position,
 				 VisuData *dataObj _U_, GError **error)
 {
   float val;
-  RenderingWindow *window;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  if (!configFileRead_float(lines[0], position, &val, 1, error))
+  if (!tool_configFile_readFloat(lines[0], position, &val, 1, error))
     return FALSE;
   config_refreshPeriod = val;
-  panelConfigSet_refreshPeriod(window, config_refreshPeriod);
+  panelConfigSet_refreshPeriod(visu_uiMainClass_getDefaultRendering(),
+			       config_refreshPeriod);
 
   return TRUE;
 }
