@@ -61,6 +61,12 @@
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 #include <extraGtkFunctions/gtk_shadeComboBoxWidget.h>
 
+/**
+ * SECTION: panelDataFile
+ * @short_description: The tab where to configure the action of an
+ * external data file on colourisation of nodes.
+ */
+
 /* Local variables. */
 static GtkWidget *panelDataFile;
 static int nbColumns;
@@ -104,7 +110,7 @@ char* labelHSV[3];
 static void createInteriorDataFile();
 static void updateNormalisationWidgets(VisuData *data);
 static void updateStatusBar(gchar *file, int nb);
-static void updateColourWidgets(VisuData *data);
+static void updateColorWidgets(VisuData *data);
 static void updatePostWidgets(VisuData *data);
 static void makeColorPreview(VisuData *data);
 
@@ -176,7 +182,16 @@ static gboolean readFileExt(gchar **lines, int nbLines, int position,
 static void exportParameters(GString *data, VisuData* dataObj);
 
 
-
+/**
+ * panelDataFileInit: (skip)
+ *
+ * Should be used in the list declared in externalModules.h to be loaded by
+ * V_Sim on start-up. This routine will create the #ToolPanel where the colouring
+ * stuff can be done, such as choosing a colour shade, opening a file,
+ * setting boundaries...
+ *
+ * Returns: a newly created #ToolPanel object.
+ */
 ToolPanel* panelDataFileInit()
 {
   char *cl = _("Colorize with data");
@@ -207,12 +222,12 @@ ToolPanel* panelDataFileInit()
   currentDataFile = (gchar*)0;
 
   /* Dealing with parameters. */
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_FILEEXT,
 					  DESC_PARAMETER_FILEEXT,
 					  1, readFileExt);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParameters);
 
   /* Local callbacks. */
@@ -245,18 +260,12 @@ static void createInteriorDataFile()
   GtkWidget *label16;
   GtkWidget *label20;
   GtkWidget *label21;
-  GtkObject *spinbuttonDataChA1_adj;
-  GtkObject *spinbuttonDataChA2_adj;
-  GtkObject *spinbuttonDataChA3_adj;
-  GtkObject *spinbuttonDataChB1_adj;
-  GtkObject *spinbuttonDataChB2_adj;
-  GtkObject *spinbuttonDataChB3_adj;
   GtkWidget *expanderTransformation;
   GtkWidget *hrule;
   GtkWidget *hboxPreSetColorRange;
   gint i;
   VisuData *dataObj;
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
@@ -338,6 +347,19 @@ static void createInteriorDataFile()
   vboxLimits = gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(alignment3), vboxLimits);
 
+/*   label = gtk_label_new(_("<b>Read min/max values:</b>")); */
+/*   gtk_label_set_use_markup(GTK_LABEL(label), TRUE); */
+/*   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5); */
+/*   gtk_box_pack_start(GTK_BOX(vboxLimits), label, FALSE, FALSE, 0); */
+
+  readMinMaxValues = gtk_alignment_new (0.5, 0.5, 0.8, 1);
+  gtk_box_pack_start (GTK_BOX(vboxLimits), readMinMaxValues, FALSE, FALSE, 0);
+
+  label = gtk_label_new(MIN_MAX_NO_DATA_FILE);
+  gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+  gtk_container_add(GTK_CONTAINER(readMinMaxValues), label);
+
   label = gtk_label_new(_("<b>Input data bounds:</b>"));
   gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
@@ -374,19 +396,6 @@ static void createInteriorDataFile()
                     (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label8), 1, 0.5);
 
-  label = gtk_label_new(_("<b>Read min/max values:</b>"));
-  gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
-  gtk_box_pack_start(GTK_BOX(vboxLimits), label, FALSE, FALSE, 0);
-
-  readMinMaxValues = gtk_alignment_new (0.5, 0.5, 0.8, 1);
-  gtk_box_pack_start (GTK_BOX(vboxLimits), readMinMaxValues, FALSE, FALSE, 0);
-
-  label = gtk_label_new(MIN_MAX_NO_DATA_FILE);
-  gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
-  gtk_container_add(GTK_CONTAINER(readMinMaxValues), label);
-
 
   /* Bar */
   alignment2 = gtk_alignment_new(0.5, 0.5, 0.3, 0);
@@ -409,7 +418,7 @@ static void createInteriorDataFile()
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
   gtk_box_pack_start(GTK_BOX(hboxPreSetColorRange), label, TRUE, TRUE, 0);
   
-  comboPreSetColorRange = shadeComboBox_new(FALSE);
+  comboPreSetColorRange = shadeComboBox_new(FALSE, TRUE);
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboPreSetColorRange), -1);
   gtk_box_pack_start(GTK_BOX (hboxPreSetColorRange), comboPreSetColorRange, FALSE, FALSE, 0);
 
@@ -427,7 +436,7 @@ static void createInteriorDataFile()
   hbox6 = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vboxTransformation), hbox6, FALSE, FALSE, 0);
 
-  label = gtk_label_new(_("<b>Colour space: </b>"));
+  label = gtk_label_new(_("<b>Color space: </b>"));
   gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
   gtk_box_pack_start (GTK_BOX (hbox6), label, TRUE, TRUE, 0);
@@ -508,43 +517,43 @@ static void createInteriorDataFile()
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  spinbuttonDataChA1_adj = gtk_adjustment_new (1, -99, 99, 0.01, 0.1, 0.);
-  spinbuttonDataChA[0] = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDataChA1_adj), 0.001, 2);
+  spinbuttonDataChA[0] = gtk_spin_button_new_with_range(-99, 99, 0.01);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDataChA[0]), 1.);
   gtk_table_attach (GTK_TABLE (tableLinearShade), spinbuttonDataChA[0], 4, 5, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbuttonDataChA[0]), TRUE);
 
-  spinbuttonDataChA2_adj = gtk_adjustment_new (1, -99, 99, 0.01, 0.1, 0.);
-  spinbuttonDataChA[1] = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDataChA2_adj), 0.001, 2);
+  spinbuttonDataChA[1] = gtk_spin_button_new_with_range(-99, 99, 0.01);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDataChA[1]), 1.);
   gtk_table_attach (GTK_TABLE (tableLinearShade), spinbuttonDataChA[1], 4, 5, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbuttonDataChA[1]), TRUE);
 
-  spinbuttonDataChA3_adj = gtk_adjustment_new (1, -99, 99, 0.01, 0.1, 0.);
-  spinbuttonDataChA[2] = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDataChA3_adj), 0.001, 2);
+  spinbuttonDataChA[2] = gtk_spin_button_new_with_range(-99, 99, 0.01);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDataChA[2]), 1.);
   gtk_table_attach (GTK_TABLE (tableLinearShade), spinbuttonDataChA[2], 4, 5, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbuttonDataChA[2]), TRUE);
 
-  spinbuttonDataChB1_adj = gtk_adjustment_new (0, -99, 99, 0.01, 0.1, 0.);
-  spinbuttonDataChB[0] = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDataChB1_adj), 0.001, 2);
+  spinbuttonDataChB[0] = gtk_spin_button_new_with_range(-99, 99, 0.01);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDataChB[0]), 0.);
   gtk_table_attach (GTK_TABLE (tableLinearShade), spinbuttonDataChB[0], 2, 3, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbuttonDataChB[0]), TRUE);
 
-  spinbuttonDataChB2_adj = gtk_adjustment_new (0, -99, 99, 0.01, 0.1, 0.);
-  spinbuttonDataChB[1] = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDataChB2_adj), 0.001, 2);
+  spinbuttonDataChB[1] = gtk_spin_button_new_with_range(-99, 99, 0.01);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDataChB[1]), 0.);
   gtk_table_attach (GTK_TABLE (tableLinearShade), spinbuttonDataChB[1], 2, 3, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbuttonDataChB[1]), TRUE);
 
-  spinbuttonDataChB3_adj = gtk_adjustment_new (0, -99, 99, 0.01, 0.1, 0.);
-  spinbuttonDataChB[2] = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDataChB3_adj), 0.001, 2);
+  spinbuttonDataChB[2] = gtk_spin_button_new_with_range(-99, 99, 0.01);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDataChB[2]), 0.);
   gtk_table_attach (GTK_TABLE (tableLinearShade), spinbuttonDataChB[2], 2, 3, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
@@ -552,11 +561,11 @@ static void createInteriorDataFile()
 
   for (i = 0; i < 3; i++)
     {
-      comboboxDataCh[i] = gtk_combo_box_new_text ();
-      gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_ONE);
-      gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_COORD_X);
-      gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_COORD_Y);
-      gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_COORD_Z);
+      comboboxDataCh[i] = gtk_combo_box_text_new();
+      gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboboxDataCh[i]), (const gchar*)0, COL_ONE);
+      gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboboxDataCh[i]), (const gchar*)0, COL_COORD_X);
+      gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboboxDataCh[i]), (const gchar*)0, COL_COORD_Y);
+      gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboboxDataCh[i]), (const gchar*)0, COL_COORD_Z);
       gtk_combo_box_set_active(GTK_COMBO_BOX(comboboxDataCh[i]), 0);
       gtk_table_attach (GTK_TABLE (tableLinearShade), comboboxDataCh[i], 6, 7, i, i + 1,
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -564,7 +573,7 @@ static void createInteriorDataFile()
     }
 
   hbox8 = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox8, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vboxTransformation), hbox8, FALSE, FALSE, 0);
 
   label = gtk_label_new(_("Color range preview: "));
   gtk_box_pack_start (GTK_BOX (hbox8), label, FALSE, FALSE, 0);
@@ -636,7 +645,7 @@ static void createInteriorDataFile()
   gtk_box_pack_start(GTK_BOX(hbox3), checkScaleRadius, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkScaleRadius), FALSE);
   
-  comboboxDataCh[i] = gtk_combo_box_new_text ();
+  comboboxDataCh[i] = gtk_combo_box_text_new();
 /*   gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_ONE); */
 /*   gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_COORD_X); */
 /*   gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), COL_COORD_Y); */
@@ -651,7 +660,9 @@ static void createInteriorDataFile()
   statusbarDataFile = gtk_statusbar_new();
   gtk_box_pack_end(GTK_BOX(containerDataFilePanel),
 		   statusbarDataFile, FALSE, FALSE, 0);
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24
   gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbarDataFile), FALSE);
+#endif
   statusDataFileContextId =
     gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbarDataFile),
 				 _("Description of loaded data file."));
@@ -746,7 +757,7 @@ static void updateNormalisationWidgets(VisuData *data)
     gtk_widget_destroy(childMinMax);
 
   /* Special case without VisuData or without stored data. */
-  if (!data || !dataFileGet_file(data))
+  if (!data || !dataFileGet_fileSet(data))
     {
       label = gtk_label_new(MIN_MAX_NO_DATA_FILE);
       gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
@@ -781,9 +792,9 @@ static void updateNormalisationWidgets(VisuData *data)
   g_return_if_fail(nbColumns > 0);
 
   table = gtk_table_new(nbColumns + 1, 3, FALSE);
-  label = gtk_label_new(_("Column number"));
-  gtk_widget_set_name(label, "label_head");
-  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_SHRINK, GTK_SHRINK, 2, 0);
+/*   label = gtk_label_new(_("Column number")); */
+/*   gtk_widget_set_name(label, "label_head"); */
+/*   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_SHRINK, GTK_SHRINK, 2, 0); */
   label = gtk_label_new(_("Min value"));
   gtk_widget_set_name(label, "label_head");
   gtk_table_attach(GTK_TABLE(table), label, 1, 2, 0, 1, GTK_EXPAND, GTK_SHRINK, 2, 0);
@@ -821,7 +832,7 @@ static void updateNormalisationWidgets(VisuData *data)
 
   gtk_container_add(GTK_CONTAINER(readMinMaxValues), table);
 }
-static void updateColourWidgets(VisuData *data)
+static void updateColorWidgets(VisuData *data)
 {
   int i, j;
   GString *label;
@@ -838,12 +849,12 @@ static void updateColourWidgets(VisuData *data)
   for (i = 0; i < 3; i++)
     {
       for (j = nbColumns + N_STATIC_COLS - 1; j > N_STATIC_COLS - 1; j--)
-	gtk_combo_box_remove_text(GTK_COMBO_BOX(comboboxDataCh[i]), j);
+	gtk_combo_box_text_remove(GTK_COMBO_BOX_TEXT(comboboxDataCh[i]), j);
       gtk_combo_box_set_active(GTK_COMBO_BOX(comboboxDataCh[i]), 0);
       DBG_fprintf(stderr, "Panel dataFile: reset channel %d.\n", i);
     }
   for (j = nbColumns - 1; j > - 1; j--)
-    gtk_combo_box_remove_text(GTK_COMBO_BOX(comboboxDataCh[3]), j);
+    gtk_combo_box_text_remove(GTK_COMBO_BOX_TEXT(comboboxDataCh[3]), j);
   if (data)
     {
       shade = dataFileGet_shade(data);
@@ -878,7 +889,8 @@ static void updateColourWidgets(VisuData *data)
 	    {
 	      g_string_printf(label, _("Col. %d"), j + 1);
 	      for (i = 0; i < 4; i++)
-		gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxDataCh[i]), label->str);
+		gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboboxDataCh[i]),
+                                          (const gchar*)0, label->str);
 	    }
 	  g_string_free(label, TRUE);
 	}
@@ -1042,12 +1054,26 @@ static void updateStatusBar(gchar* file, int nbColumns)
 			 statusDataFileContextId,
 			 DATA_FILE_NO_FILE_MESSAGE);
 }
-gboolean panelDataFileLoad_file(VisuData *visuData, gchar *file, gboolean *new)
+/**
+ * panelDataFileLoad_file:
+ * @visuData: the #VisuData object to associated the data to ;
+ * @file: the file to read ;
+ * @new: return TRUE if the loaded data are associated for the
+ *       first time to @visuData.
+ *
+ * Read the given data file and associate the values of each column to
+ * the node. It does not update the widgets of the panel. This is done
+ * to allow to change the values of the colouration before drawing the
+ * widgets. See panelDataFileUpdate() to do it.
+ *
+ * Returns: TRUE if visu_data_createAllNodes() should be called after.
+ */
+gboolean panelDataFileLoad_file(VisuData *visuData, const gchar *file, gboolean *new)
 {
-  GString *message;
-  int errors;
+  GError *error;
+  gchar *errStr;
 
-  DBG_fprintf(stderr, "Panel dataFile : loading a new file '%s'.\n", file);
+  DBG_fprintf(stderr, "Panel dataFile: loading a new data file '%s'.\n", file);
   g_return_val_if_fail(visuData && file && new, 0);
 
   /* If panel has still not been loaded, we do it now. */
@@ -1057,13 +1083,17 @@ gboolean panelDataFileLoad_file(VisuData *visuData, gchar *file, gboolean *new)
       createInteriorDataFile();
     }
   
-  message = g_string_new("");
-  flagDataFileIsLoaded = dataFileSet_file(visuData, file, new, message, &errors);
-
+  error = (GError*)0;
+  flagDataFileIsLoaded = dataFileSet_file(visuData, file, new, &error);
   /* Raise the error dialog if necessary. */
-  if (errors)
-    visuGtkRaise_warningLong(_("Loading a data file"), message->str, (GtkWindow*)0);
-  g_string_free(message, TRUE);
+  if (error)
+    {
+      errStr = g_strdup_printf(_("Reading data file '%s' reports:\n\t%s"),
+			       file, error->message);
+      visuGtkRaise_warning(_("Loading a data file"), errStr, (GtkWindow*)0);
+      g_free(errStr);
+      g_error_free(error);
+    }
 
   if (flagDataFileIsLoaded)
     {
@@ -1079,33 +1109,36 @@ gboolean panelDataFileLoad_file(VisuData *visuData, gchar *file, gboolean *new)
   DBG_fprintf(stderr, "Panel dataFile: load OK.\n");
   return flagDataFileIsLoaded;
 }
+/**
+ * panelDataFileUpdate:
+ * @visuData: the #VisuData object to associated the data to.
+ *
+ * Update the widgets depending on the colouration associated to the given
+ * #VisuData object.
+ */
 void panelDataFileUpdate(VisuData *dataObj)
 {
-  gchar *file;
-
   DBG_fprintf(stderr, "Panel dataFile: update the widgets"
 	      " depending on the data %p.\n", (gpointer)dataObj);
 
   if (!dataObj)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbuttonData), FALSE);
 
-  file = (dataObj)?dataFileGet_file(dataObj):(gchar*)0;
-
-  gtk_widget_set_sensitive(vBoxDataFileOption, (dataObj != (VisuData*)0));
-  gtk_widget_set_sensitive(expanderPostProcessing, (file != (gchar*)0));
-
   /* Update flags. */
   if (currentDataFile)
     g_free(currentDataFile);
-  currentDataFile = (dataObj)?g_strdup(file):(gchar*)0;
+  currentDataFile = (dataObj)?dataFileGet_file(dataObj):(gchar*)0;
+
+  gtk_widget_set_sensitive(vBoxDataFileOption, (dataObj != (VisuData*)0));
+  gtk_widget_set_sensitive(expanderPostProcessing, (currentDataFile != (gchar*)0));
 
   /* Update the widgets of this panel if necessary. */
   if (dataObj)
-    updateStatusBar(file, dataFileGet_nbColumns(dataObj));
+    updateStatusBar(currentDataFile, dataFileGet_nbColumns(dataObj));
   else
-    updateStatusBar(file, 0);
+    updateStatusBar(currentDataFile, 0);
   updateNormalisationWidgets(dataObj);
-  updateColourWidgets(dataObj);
+  updateColorWidgets(dataObj);
   updatePostWidgets(dataObj);
 }
 
@@ -1114,13 +1147,11 @@ void panelDataFileUpdate(VisuData *dataObj)
 /*************/
 static void visuFileReset(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 {
-  char* file;
-  gchar* fileCpy, *fileExtPosition;
-  GString *dataFile;
+  gchar *file, *fileCpy, *fileExtPosition, *dataFile;
   int res, nbColumns;
   float minVal, maxVal;
   int dataNormalize;
-  int colUsed[3];
+  int colUsed[3], *oldCols;
   gboolean new;
   Shade *shade, *tmpSh;
   VisuData *dataOld;
@@ -1131,15 +1162,25 @@ static void visuFileReset(GObject *obj _U_, VisuData *dataObj, gpointer data _U_
       /* Store old values, may be useful if data file is autoloaded. */
       DBG_fprintf(stderr, "Panel dataFile: Saving current colour values.\n");
       dataOld = toolPanelGet_visuData(TOOL_PANEL(panelDataFile));
-      tmpSh = (dataOld)?dataFileGet_shade(dataOld):(Shade*)0;
+      tmpSh = (dataOld)?dataFileGet_shade(dataOld):
+	shadeComboBoxGet_selectedShade(SHADE_COMBOX(comboPreSetColorRange));
       shade = (tmpSh)?shadeCopy(tmpSh):(Shade*)0;
-
-      colUsed[0] = gtk_combo_box_get_active(GTK_COMBO_BOX(comboboxDataCh[0])) -
-	N_STATIC_COLS;
-      colUsed[1] = gtk_combo_box_get_active(GTK_COMBO_BOX(comboboxDataCh[1])) -
-	N_STATIC_COLS;
-      colUsed[2] = gtk_combo_box_get_active(GTK_COMBO_BOX(comboboxDataCh[2])) -
-	N_STATIC_COLS;
+      oldCols = (dataOld)?dataFileGet_colUsed(dataOld):(int*)0;
+      
+      if (oldCols)
+	{
+	  colUsed[0] = oldCols[0];
+	  colUsed[1] = oldCols[1];
+	  colUsed[2] = oldCols[2];
+	}
+      else
+	{
+	  colUsed[0] = 0;
+	  colUsed[1] = 0;
+	  colUsed[2] = 0;
+	}
+      DBG_fprintf(stderr, " | column usage %d ; %d ; %d\n",
+		  colUsed[0], colUsed[1], colUsed[2]);
       minVal = numericalEntryGet_value(NUMERICAL_ENTRY(entryDataMin));
       maxVal = numericalEntryGet_value(NUMERICAL_ENTRY(entryDataMax));
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioNormalized)))
@@ -1148,26 +1189,39 @@ static void visuFileReset(GObject *obj _U_, VisuData *dataObj, gpointer data _U_
 	dataNormalize = dataFile_minMax;
 	  
       /* Check the autoload flag. */
+      res = FALSE;
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbuttonAutoLoad)))
 	{
 	  /* Compute the name of the data
 	     file from the rendered filename. */
-	  file = visuDataGet_file(dataObj, 0, (FileFormat**)0);
+	  file = visu_data_getFile(dataObj, 0, (ToolFileFormat**)0);
 	  fileCpy = g_strdup(file);
 	  fileExtPosition = g_strrstr(fileCpy, ".");
 	  if (fileExtPosition)
 	    *fileExtPosition = '\0';
-	  dataFile = g_string_new("");
-	  g_string_printf(dataFile, "%s%s", fileCpy,
-			  gtk_entry_get_text(GTK_ENTRY(entryFileExtension)));
-	  DBG_fprintf(stderr, "Panel DataFile : try to load a new data file"
-		      " ('%s') from the name of the rendered file.\n", dataFile->str);
-	  res = panelDataFileLoad_file(dataObj, dataFile->str, &new);
-	  g_string_free(dataFile, TRUE);
+	  dataFile =
+	    g_strdup_printf("%s%s", fileCpy,
+			    gtk_entry_get_text(GTK_ENTRY(entryFileExtension)));
+	  DBG_fprintf(stderr, "Panel DataFile: try to load a new data file"
+		      " ('%s') from the name of the rendered file.\n", dataFile);
+	  res = panelDataFileLoad_file(dataObj, dataFile, &new);
+	  g_free(dataFile);
 	  g_free(fileCpy);
 	}
-      else
-	res = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbuttonData));
+      else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbuttonData)))
+	{
+	  /* Try to reload the same data file. */
+	  dataFile = (dataOld)?dataFileGet_file(dataOld):(gchar*)0;
+	  if (dataFile)
+            {
+              res = panelDataFileLoad_file(dataObj, dataFile, &new);
+              g_free(dataFile);
+            }
+	  else
+	    res = (colUsed[0] > -N_STATIC_COLS &&
+		   colUsed[1] > -N_STATIC_COLS &&
+		   colUsed[2] > -N_STATIC_COLS);
+	}
 
       if (res)
 	{
@@ -1292,6 +1346,12 @@ static void loadDataFile(GtkButton *button _U_, gpointer data _U_)
       gtk_widget_destroy (file_selector);
     }
 }
+/**
+ * panelDataFileSet_use:
+ * @used: a boolean.
+ *
+ * Set if the panel is used or not.
+ */
 void panelDataFileSet_use(gboolean used)
 {
   VisuData *dataObj;
@@ -1492,6 +1552,14 @@ static void onColorTypeChange(GtkToggleButton *toggle, gpointer data)
   if (res)
     dataFileReDraw(dataObj);
 }
+/**
+ * panelDataFileSet_presetShade:
+ * @shade: a #Shade object.
+ *
+ * Change the preset @shade used to colourise the data.
+ *
+ * Returns: TRUE if a #Shade is set.
+ */
 gboolean panelDataFileSet_presetShade(Shade *shade)
 {
   float *vectA, *vectB;
@@ -1533,7 +1601,7 @@ gboolean panelDataFileSet_presetShade(Shade *shade)
     }
   if (shadeGet_mode(shade) == shade_modeLinear)
     {
-      j = (dataFileGet_file(dataObj))?N_STATIC_COLS:3;
+      j = (dataFileGet_fileSet(dataObj))?N_STATIC_COLS:3;
       shadeGet_linearCoeff(shade, &vectA, &vectB);
       for (i = 0; i < 3; i++)
 	{
@@ -1570,8 +1638,8 @@ static void onColorPreSetChange(ShadeComboBox *combo _U_, Shade *values,
   if (panelDataFileSet_presetShade(values) &&
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbuttonData)))
     {
-      visuData_createAllNodes(toolPanelGet_visuData(TOOL_PANEL(panelDataFile)));
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      visu_data_createAllNodes(toolPanelGet_visuData(TOOL_PANEL(panelDataFile)));
+      VISU_ADD_REDRAW;
     }
 }
 static void applyHideMinValues(VisuData *visuData, gboolean askRedraw)
@@ -1586,7 +1654,7 @@ static void applyHideMinValues(VisuData *visuData, gboolean askRedraw)
      emit the NodeAskForShowHide signal. */
   DBG_fprintf(stderr, "Panel DataFile : emitting 'NodeAskForShowHide' signal.\n");
   g_signal_handler_block(G_OBJECT(visuData), signalAskForHide);
-  visuDataEmit_askForShowHideNodes(visuData, &redraw);
+  visu_data_emitAskForShowHideNodes(visuData, &redraw);
   g_signal_handler_unblock(G_OBJECT(visuData), signalAskForHide);
   DBG_fprintf(stderr, " | returned redraw value %d.\n", redraw);
 
@@ -1602,11 +1670,11 @@ static void applyHideMinValues(VisuData *visuData, gboolean askRedraw)
 
   if (redraw)
     {
-      visuDataEmit_nodeRenderedChange(visuData);
+      visu_data_emitNodeRenderedChange(visuData);
       if (askRedraw)
 	{
-	  visuData_createAllNodes(visuData);
-	  g_idle_add(visuObjectRedraw, (gpointer)0);
+	  visu_data_createAllNodes(visuData);
+	  VISU_ADD_REDRAW;
 	}
     }
 }
@@ -1721,7 +1789,7 @@ static gboolean readFileExt(gchar **lines, int nbLines, int position,
 
   if (!lines[0][0])
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 string value must appear"
 			     " after the %s markup.\n"), position,
 			   FLAG_PARAMETER_FILEEXT);
