@@ -53,6 +53,7 @@
 #include <visu_data.h>
 #include <visu_elements.h>
 #include <extraGtkFunctions/gtk_colorComboBoxWidget.h>
+#include <extraGtkFunctions/gtk_elementComboBox.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 #include <coreTools/toolColor.h>
 #include <openGLFunctions/light.h>
@@ -60,6 +61,12 @@
 #include "gtkAtomic.h"
 #include "gtkSpin.h"
 
+/**
+ * SECTION: panelElements
+ * @short_description: The tab where #VisuElement characteristics can
+ * be tuned.
+ */
+
 /**
  * panelElements:
  *
@@ -75,22 +82,14 @@ static VisuToolsInitFunc listInitRendenringGtkPanelFunc[] = {
   panelElementSpinInit_gtkPanel,
   (VisuToolsInitFunc)0};
 
-static GtkListStore *listStoreVisuElements;
-enum
-  {
-    COLUMN_NAME,  /* The label shown */
-    COLUMN_POINTER_TO_DATA,  /* Pointer to the VisuElement. */
-    N_COLUMNS
-  };
 /* sensitive widgets */
 GtkWidget *vBoxElements;
 GtkWidget *renderingMethodElements;
-GtkWidget *elementsCombo;
+static GtkWidget *elementsComboBox;
 static GtkWidget *checkRendered;
 static GtkWidget *checkMasked;
 GtkWidget *widgetVisuElementColor;
 gint sortVisuElements(gpointer a, gpointer b);
-char *getLabelOfElement(VisuElement *element);
 
 /* Structure to store the hooks that are required for
    the specific zone for elements. */
@@ -102,11 +101,11 @@ struct GtkRenderingInterface_struct
 };
 typedef struct GtkRenderingInterface_struct GtkRenderingInterface;
 GHashTable *listOfRenderingInterfaces;
-panelElements_changeFunc updateRenderingMethodResources;
+static panelElements_changeFunc updateRenderingMethodResources;
 
 /* Local methods. */
-void createInteriorElements(GtkWidget *toolPanel);
-static void sendElementToSpecificArea();
+static void createInteriorElements(GtkWidget *toolPanel);
+static void updateRenderingSpecificPart(VisuRendering *method);
 void createCallBacksElements();
 void setInitialValuesElements();
 char *getDefaultLabelOfElement(VisuElement *element);
@@ -114,20 +113,21 @@ char *getDefaultLabelOfElement(VisuElement *element);
    renderingMethodElements pints then to this widget. If
    renderingMethodElements has already a target, this target is
    freed via gtk_widget_destroy. */
-void changeRenderingMethodInterface(GtkWidget* interface);
+static void changeRenderingMethodInterface(GtkWidget* interface);
 /* It allows the client to set the method use to update
    user defined values. */
-void setElementChangedFunc(panelElements_changeFunc func);
+static void setElementChangedFunc(panelElements_changeFunc func);
 /* It reads the value of the interface methods. */
 static void getRenderingInterface(VisuRendering *method,
 				  panelElements_changeFunc *change,
 				  VisuGtkWidgetFunc *create);
 
 /* Callbacks */
-static guint idRefreshComboElements;
-static void comboVisuElementsChanged(GtkComboBox *combobox, gpointer data);
+static void onElementSelected(ElementComboBox *combo, GList *elements, gpointer data);
+static gboolean onElementChanged(GSignalInvocationHint *ihint, guint n_param_values,
+                                 const GValue *param_values, gpointer data);
 static void resourcesChanged(GObject *object, VisuData *dataObj, gpointer data);
-void colorVisuElementChanged(ColorComboBox *colorWd, Color *color, gpointer userData);
+static void colorVisuElementChanged(ColorComboBox *colorWd, ToolColor *color, gpointer userData);
 static void checkRenderedChanged(GtkToggleButton *button, gpointer data);
 static void checkMaskedChanged(GtkToggleButton *button, gpointer data);
 static void refreshComboElements(GObject *obj, VisuData *dataObj, gpointer userData);
@@ -136,6 +136,16 @@ static void onRenderingMethodChanged(GObject *obj, VisuRendering *method,
 static void onColorChanged(ColorComboBox *colorComboBox, guint colorId, gpointer data);
 static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat, gpointer data);
 
+/**
+ * panelElementsInit: (skip)
+ *
+ * Should be used in the list declared in externalModules.h to be loaded by
+ * V_Sim on start-up. This routine will create the #ToolPanel where the element
+ * stuff can be done, such as choosing a colour, setting the radius of
+ * spheres...
+ *
+ * Returns: a newly created #ToolPanel object.
+ */
 ToolPanel* panelElementsInit()
 {
   gchar *cl = _("Set elements caracteristics");
@@ -144,6 +154,15 @@ ToolPanel* panelElementsInit()
 
   panelElements = toolPanelNew_withIconFromPath("Panel_elements", cl, tl,
 						"stock-elements_20.png");
+
+  /* Create the list of the available rendering method
+     interfaces. */
+  listOfRenderingInterfaces = g_hash_table_new_full(g_direct_hash,
+						    g_direct_equal,
+						    NULL, NULL);
+  for (i = 0; listInitRendenringGtkPanelFunc[i]; i++)
+    listInitRendenringGtkPanelFunc[i]();
+
   createInteriorElements(panelElements);
   toolPanelSet_dockable(TOOL_PANEL(panelElements), TRUE);
 
@@ -153,37 +172,21 @@ ToolPanel* panelElementsInit()
   /* Create the callbacks of all the sensitive widgets. */
   createCallBacksElements();
 
-  /* Create the list of the available rendering method
-     interfaces. */
-  listOfRenderingInterfaces = g_hash_table_new_full(g_direct_hash,
-						    g_direct_equal,
-						    NULL, NULL);
-  g_return_val_if_fail(listOfRenderingInterfaces, (ToolPanel*)0);
-
-  for (i = 0; listInitRendenringGtkPanelFunc[i]; i++)
-    listInitRendenringGtkPanelFunc[i]();
-
   return TOOL_PANEL(panelElements);
 }
 
-void createInteriorElements(GtkWidget *toolPanel)
+static void createInteriorElements(GtkWidget *toolPanel)
 {
   GtkWidget *label, *expand, *image;
   GtkWidget *hbox;
   GtkWidget *align;
   GtkWidget *scrollView;
-  GtkCellRenderer *renderer;
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
 #endif
 
-  /* We create the structure that store the VisuElements */
-  listStoreVisuElements = gtk_list_store_new (N_COLUMNS,
-					      G_TYPE_STRING,
-					      G_TYPE_POINTER);
-  
   scrollView = gtk_scrolled_window_new((GtkAdjustment*)0,
 				       (GtkAdjustment*)0);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollView),
@@ -202,11 +205,8 @@ void createInteriorElements(GtkWidget *toolPanel)
   gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   /* We create the tree widget that show the methods. */
-  elementsCombo = gtk_combo_box_new_with_model(GTK_TREE_MODEL(listStoreVisuElements));
-  renderer = gtk_cell_renderer_text_new();
-  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(elementsCombo), renderer, FALSE);
-  gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(elementsCombo), renderer, "text", 0);
-  gtk_box_pack_start(GTK_BOX(hbox), elementsCombo, TRUE, TRUE, 2);
+  elementsComboBox = elementComboBox_new(TRUE, FALSE, _("Element '%s'"));
+  gtk_box_pack_start(GTK_BOX(hbox), elementsComboBox, TRUE, TRUE, 2);
 
   label = gtk_label_new("");
   gtk_label_set_markup(GTK_LABEL(label), _("<b>Standard resources</b>"));
@@ -242,7 +242,9 @@ void createInteriorElements(GtkWidget *toolPanel)
   gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
   gtk_box_pack_start(GTK_BOX(vBoxElements), label, FALSE, FALSE, 5);
 
+  DBG_fprintf(stderr, "Panel Elements: create the specific widgets.\n");
   renderingMethodElements = (GtkWidget*)0;
+  updateRenderingSpecificPart(visu_object_getRendering(VISU_INSTANCE));
 
   gtk_widget_show_all(scrollView);
 
@@ -251,8 +253,8 @@ void createInteriorElements(GtkWidget *toolPanel)
 
 void createCallBacksElements()
 {
-  idRefreshComboElements = g_signal_connect(G_OBJECT(elementsCombo), "changed",
-					    G_CALLBACK(comboVisuElementsChanged), (gpointer)0);
+  g_signal_connect(G_OBJECT(elementsComboBox), "element-selected",
+                   G_CALLBACK(onElementSelected), (gpointer)0);
   g_signal_connect(G_OBJECT(widgetVisuElementColor), "color-selected",
 		   G_CALLBACK(colorVisuElementChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(widgetVisuElementColor), "material-value-changed",
@@ -274,6 +276,12 @@ void createCallBacksElements()
      a new rendering method is selected. */
   g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(resourcesChanged), (gpointer)0);
+  g_signal_add_emission_hook(g_signal_lookup("ElementRenderedChanged", VISU_ELEMENT_TYPE),
+                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
+  g_signal_add_emission_hook(g_signal_lookup("ElementMaterialChanged", VISU_ELEMENT_TYPE),
+                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
+  g_signal_add_emission_hook(g_signal_lookup("ElementPlaneChanged", VISU_ELEMENT_TYPE),
+                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
 }
 
 /*****************/
@@ -289,55 +297,10 @@ gint sortVisuElements(gpointer a, gpointer b)
 /*************/
 static void refreshComboElements(GObject *obj _U_, VisuData *dataObj, gpointer userData _U_)
 {
-  unsigned int i;
-  GList *tmpLst, *currentListOfElements;
-  char *label;
-  GtkTreeIter iter, selectedIter;
-  Color *color;
-  int posColor;
-  float *rgba;
-  VisuElement *prevSelectedElement;
-  gboolean selected;
-
-  DBG_fprintf(stderr, "Panel Element: catch 'dataReadyForRendering' signal,"
-	      " trying to rebuild element list.\n");
-  if (dataObj)
-    {
-      if (visuDataGet_changeElementFlag(dataObj))
-	{
-	  DBG_fprintf(stderr,"Panel Element: not removing old elements"
-		      " from the liststore of labels.\n");
-	  return;
-	}
-    }
-
-  DBG_fprintf(stderr,"Panel Element: removing old elements"
-	      " from the liststore of labels.\n");
-
-  /* Get the selected iter. */
-  selected = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  if (selected)
-    gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		       COLUMN_POINTER_TO_DATA, &prevSelectedElement, -1);
-  else
-    prevSelectedElement = (VisuElement*)0;
-
-  /* Clear old list, and clean all pointers. */
-  g_signal_handler_block(G_OBJECT(elementsCombo),
-			 idRefreshComboElements);
-  gtk_list_store_clear(listStoreVisuElements);
-  currentListOfElements = (GList*)0;
-  g_signal_handler_unblock(G_OBJECT(elementsCombo),
-			   idRefreshComboElements);
-
   if (dataObj)
     {
       DBG_fprintf(stderr,"Panel Element : creating %d labels for the"
 		  " combobox of VisuElements.\n", dataObj->ntype);
-      for(i = 0; i < dataObj->ntype; i++)
-	currentListOfElements = g_list_prepend(currentListOfElements,
-					       (gpointer)dataObj->fromIntToVisuElement[i]);
-
       gtk_widget_set_sensitive(vBoxElements, TRUE);
     }
   else
@@ -345,174 +308,130 @@ static void refreshComboElements(GObject *obj _U_, VisuData *dataObj, gpointer u
       DBG_fprintf(stderr, "Panel Element : there is no element available.\n");
       gtk_widget_set_sensitive(vBoxElements, FALSE);
     }
-  currentListOfElements = g_list_sort(currentListOfElements,
-				      (GCompareFunc)sortVisuElements);
+}
+static void updateRenderingSpecificPart(VisuRendering *method)
+{
+  panelElements_changeFunc change;
+  VisuGtkWidgetFunc create;
 
-  /* Add a first item that apply changes on all elements. */
-  gtk_list_store_append(listStoreVisuElements, &iter);
-  gtk_list_store_set(listStoreVisuElements, &iter,
-		     COLUMN_NAME, _("All elements"),
-		     COLUMN_POINTER_TO_DATA, (gpointer)0,
-		     -1);
-  tmpLst = currentListOfElements;
-  while(tmpLst)
-    {
-      label = getLabelOfElement((VisuElement*)tmpLst->data);
-      rgba = ((VisuElement*)tmpLst->data)->rgb;
-      color = colorGet_byValues(&posColor, rgba[0], rgba[1], rgba[2], rgba[3]);
-      gtk_list_store_append(listStoreVisuElements, &iter);
-      gtk_list_store_set(listStoreVisuElements, &iter,
-			 COLUMN_NAME, label,
-			 COLUMN_POINTER_TO_DATA, tmpLst->data,
-			 -1);
-      g_free(label);
-      if (tmpLst == currentListOfElements) /* If first. */
-	selectedIter = iter;
-      if (tmpLst->data == (gpointer)prevSelectedElement)
-	selectedIter = iter;
-      currentListOfElements = g_list_prepend(currentListOfElements, tmpLst->data);
-      tmpLst = g_list_next(tmpLst);
-    }
-  if (currentListOfElements)
-    gtk_combo_box_set_active_iter(GTK_COMBO_BOX(elementsCombo), &selectedIter);
+  change = (panelElements_changeFunc)0;
+  create = (VisuGtkWidgetFunc)0;
+  if (method)
+    getRenderingInterface(method, &change, &create);
 
-  DBG_fprintf(stderr,"Panel Element : Refresh OK.\n");
+  DBG_fprintf(stderr,"Panel Element: set the gtk interface for"
+	      " the method '%s'.\n", visu_rendering_getName(method, FALSE));
+  setElementChangedFunc(change);
+  if (create)
+    changeRenderingMethodInterface(create());
+  else
+    changeRenderingMethodInterface((GtkWidget*)0);
 }
 static void onRenderingMethodChanged(GObject *obj _U_, VisuRendering *method,
 				     gpointer userData _U_)
 {
-/*   setSensitiveFunc sensitive; */
-  panelElements_changeFunc change;
-  VisuGtkWidgetFunc create;
-  int sans;
-
-  sans = 1;
-  if (method)
-    {
-      getRenderingInterface(method, &change, &create);
-      if (change && create)
-	{
-	  sans = 0;
-	  DBG_fprintf(stderr,"Panel Element : set the gtk interface for"
-		      " the method '%s'.\n", visuRenderingGet_name(method, FALSE));
-	  setElementChangedFunc(change);
-	  changeRenderingMethodInterface(create());
-	}
-    }
-  if (sans)
-    {
-      DBG_fprintf(stderr,"Panel Element : set the gtk interface to null.\n");
-      setElementChangedFunc((panelElements_changeFunc)0);
-      changeRenderingMethodInterface((GtkWidget*)0);
-    }
+  updateRenderingSpecificPart(method);
 }
-static void comboVisuElementsChanged(GtkComboBox *combobox, gpointer data _U_)
+static gboolean onElementChanged(GSignalInvocationHint *ihint _U_, guint n_param_values _U_,
+                                 const GValue *param_values, gpointer data _U_)
 {
-  GtkTreeModel *tree;
-  gboolean selected;
-  GtkTreeIter iter;
+  GList *elements;
   VisuElement *ele;
 
-  ele = (VisuElement*)0;
-  selected = gtk_combo_box_get_active_iter(combobox, &iter);
-  if (selected)
-    {
-      tree = gtk_combo_box_get_model(combobox);
-      gtk_tree_model_get(tree, &iter,
-			 COLUMN_POINTER_TO_DATA, &ele, -1);
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  if (!elements)
+    return TRUE;
 
-    }
-  else
+  ele = VISU_ELEMENT(g_value_get_object(param_values));
+  DBG_fprintf(stderr, "Panel Elements: element '%s' has been modified.\n", ele->name);
+  if (elements->data != (gpointer)ele)
     {
-      g_warning("Can't find the selected VisuElement in the"
-		" GtkComboBox of the Panel Element.");
-      return;
+      g_list_free(elements);
+      return TRUE;
     }
+  g_list_free(elements);
 
-  if (ele)
-    {
-      DBG_fprintf(stderr, "Panel Element : set the selected VisuElement to '%s'.\n", ele->name);
-      colorComboBoxSet_color(COLOR_COMBOX(widgetVisuElementColor), ele->rgb, FALSE);
-      colorComboBoxSet_material(COLOR_COMBOX(widgetVisuElementColor), ele->material, FALSE);
-      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRendered),
-				   visuElementGet_rendered(ele));
-      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkMasked),
-				   visuElementGet_sensitiveToPlanes(ele));
-    }
-
-  /* Force refresh on the specific area. */
-  sendElementToSpecificArea();
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRendered),
+                               visu_element_getRendered(ele));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkMasked),
+                               visu_element_getSensitiveToPlanes(ele));
+  colorComboBoxSet_color(COLOR_COMBOX(widgetVisuElementColor), ele->rgb, FALSE);
+  colorComboBoxSet_material(COLOR_COMBOX(widgetVisuElementColor),
+                            ele->material, FALSE);
+  return TRUE;
 }
-void colorVisuElementChanged(ColorComboBox *colorWd _U_, Color *color,
+static void onElementSelected(ElementComboBox *combo _U_, GList *elements,
+                              gpointer data _U_)
+{
+  VisuElement *ele;
+
+  DBG_fprintf(stderr, "Panel Elements: set new list of selected elements to %p.\n",
+              (gpointer)elements);
+  if (elements)
+    {
+      ele = (VisuElement*)elements->data;
+      DBG_fprintf(stderr, "Panel Element: set the selected VisuElement to '%s'.\n",
+                  ele->name);
+      colorComboBoxSet_color(COLOR_COMBOX(widgetVisuElementColor), ele->rgb, FALSE);
+      colorComboBoxSet_material(COLOR_COMBOX(widgetVisuElementColor),
+                                ele->material, FALSE);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRendered),
+				   visu_element_getRendered(ele));
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkMasked),
+				   visu_element_getSensitiveToPlanes(ele));
+    }
+  /* Force refresh on the specific area. */
+  DBG_fprintf(stderr, "Panel Element: update the render widgets for %p.\n",
+              (gpointer)elements);
+  if (updateRenderingMethodResources)
+    updateRenderingMethodResources(elements);
+}
+static void colorVisuElementChanged(ColorComboBox *colorWd _U_, ToolColor *color,
 			     gpointer userData _U_)
 {
   int res;
-  int selected, refresh;
-  GtkTreeIter iter;
+  gboolean refresh;
   VisuData *dataObj;
-  VisuElement *currentSelectedElement;
+  GList *elements, *tmp;
 
-  DBG_fprintf(stderr, "Panel Elements : Catch 'color-selected' signal (%p).\n", (gpointer) color);
+  DBG_fprintf(stderr, "Panel Elements: Catch 'color-selected' signal (%p).\n",
+              (gpointer) color);
 
-  /* Get the selected iter. */
-  selected = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  g_return_if_fail(selected);
+  /* Get the selected elements. */
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  g_return_if_fail(elements);
     
   /* If currentSelectedElement is NULL we apply the changes
      on all elements. */
   dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
 
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &currentSelectedElement, -1);
-
   refresh = FALSE;
-  if (!currentSelectedElement)
+  for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
-      /* Change the color for all elements and
-	 unset the stored color for all the GtkListStore */
-      selected = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-      while (selected)
-	{
-	  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-			     COLUMN_POINTER_TO_DATA, &currentSelectedElement, -1);
-	  if (currentSelectedElement)
-	    {
-	      res = visuElementSet_allRGBValues(currentSelectedElement, color->rgba);
-	      if (res > 0)
-		visuData_createNodes(dataObj, currentSelectedElement);
-	      refresh = refresh || (res != 0);
-	    }
-	  selected = gtk_tree_model_iter_next(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-	}
-    }
-  else
-    {
-      /* Change the color for the selected element only. */
-      res = visuElementSet_allRGBValues(currentSelectedElement, color->rgba);
+      res = visu_element_setAllRGBValues((VisuElement*)tmp->data, color->rgba);
       if (res > 0)
-	visuData_createNodes(dataObj, currentSelectedElement);
-      refresh = (res != 0);
+        visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+      refresh = refresh || (res != 0);
     }
+  g_list_free(elements);
   if (refresh)
     {
-      DBG_fprintf(stderr, "Panel Element : color change, refresh.\n");
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      DBG_fprintf(stderr, "Panel Elements: color change, refresh.\n");
+      VISU_ADD_REDRAW;
     }
 }
-static void onColorChanged(ColorComboBox *colorComboBox, guint colorId,
+static void onColorChanged(ColorComboBox *colorComboBox, guint colorId _U_,
 			   gpointer data _U_)
 {
   int res;
-  gboolean selected, refresh;
-  GtkTreeIter iter;
+  gboolean refresh;
   VisuData *dataObj;
-  VisuElement *currentSelectedElement;
   float *rgbVal;
+  GList *elements, *tmp;
 
-  /* Get the selected iter. */
-  selected = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  g_return_if_fail(selected);
+  /* Get the selected elements. */
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  g_return_if_fail(elements);
     
   /* Get the values. */
   rgbVal = colorComboBoxGet_color(colorComboBox);
@@ -521,59 +440,34 @@ static void onColorChanged(ColorComboBox *colorComboBox, guint colorId,
      on all elements. */
   dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
 
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &currentSelectedElement, -1);
-
   refresh = FALSE;
-  if (!currentSelectedElement)
+  for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
-      /* Change the color for all elements and
-	 unset the stored color for all the GtkListStore */
-      selected = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-      while (selected)
-	{
-	  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-			     COLUMN_POINTER_TO_DATA, &currentSelectedElement, -1);
-	  if (currentSelectedElement)
-	    {
-	      res = visuElementSet_allRGBValues(currentSelectedElement, rgbVal);
-	      if (res > 0)
-		visuData_createNodes(dataObj, currentSelectedElement);
-	      refresh = refresh || (res != 0);
-	    }
-	  selected = gtk_tree_model_iter_next(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-	}
-    }
-  else
-    {
-      /* Change the color for the selected element only. */
-      res = visuElementSet_RGBValue(currentSelectedElement, colorId,
-				    rgbVal[colorId]);
+      res = visu_element_setAllRGBValues((VisuElement*)tmp->data, rgbVal);
       if (res > 0)
-	visuData_createNodes(dataObj, currentSelectedElement);
-      refresh = (res != 0);
+        visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+      refresh = refresh || (res != 0);
     }
+  g_list_free(elements);
   if (refresh)
     {
-      DBG_fprintf(stderr, "Panel Element : RGB change, refresh.\n");
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      DBG_fprintf(stderr, "Panel Elements: RGB change, refresh.\n");
+      VISU_ADD_REDRAW;
     }
   g_free(rgbVal);
 }
-static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat,
+static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat _U_,
 			      gpointer data _U_)
 {
   int res;
-  int selected, refresh;
-  GtkTreeIter iter;
+  int refresh;
   VisuData *dataObj;
-  VisuElement *currentSelectedElement;
   float *matVal;
+  GList *elements, *tmp;
 
-  /* Get the selected iter. */
-  selected = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  g_return_if_fail(selected);
+  /* Get the selected elements. */
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  g_return_if_fail(elements);
     
   /* Get the values. */
   matVal = colorComboBoxGet_material(colorComboBox);
@@ -582,236 +476,121 @@ static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat,
      on all elements. */
   dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
 
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &currentSelectedElement, -1);
-
   refresh = FALSE;
-  if (!currentSelectedElement)
+  for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
-      /* Change the material for all elements. */
-      selected = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-      while (selected)
-	{
-	  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-			     COLUMN_POINTER_TO_DATA, &currentSelectedElement, -1);
-	  if (currentSelectedElement)
-	    {
-	      res = visuElementSet_allMaterialValues(currentSelectedElement, matVal);
-	      if (res > 0)
-		visuData_createNodes(dataObj, currentSelectedElement);
-	      refresh = refresh || (res != 0);
-	    }
-	  selected = gtk_tree_model_iter_next(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-	}
-    }
-  else
-    {
-      /* Change the color for the selected element only. */
-      res = visuElementSet_materialValue(currentSelectedElement, mat, matVal[mat]);
+      res = visu_element_setAllMaterialValues((VisuElement*)tmp->data, matVal);
       if (res > 0)
-	visuData_createNodes(dataObj, currentSelectedElement);
-      refresh = (res != 0);
+        visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+      refresh = refresh || (res != 0);
     }
+  g_list_free(elements);
   if (refresh)
     {
-      DBG_fprintf(stderr, "Panel Element : material change, refresh.\n");
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      DBG_fprintf(stderr, "Panel Elements: material change, refresh.\n");
+      VISU_ADD_REDRAW;
     }
   g_free(matVal);
 }
-
-static void resourcesChanged(GObject *object _U_, VisuData *dataObj _U_,
-			     gpointer data _U_)
-{
-  gboolean validIter;
-  GtkTreeIter iter;
-  VisuElement *ele;
-
-  /* The resources loading could have changed Color of the element,
-     so we check all the list. */
-  DBG_fprintf(stderr, "Panel Elements : catch the 'resourcesChanged'"
-	      " signal, checking color pointers.\n");
-
-  /* Get the selected iter. */
-  validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  if (!validIter)
-    return;
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &ele, -1);
-  if (!ele)
-    return;
-
-  colorComboBoxSet_color(COLOR_COMBOX(widgetVisuElementColor), ele->rgb, FALSE);
-  colorComboBoxSet_material(COLOR_COMBOX(widgetVisuElementColor), ele->material, FALSE);
-
-  /* Force refresh on the specific area. */
-  sendElementToSpecificArea();
-}
 static void checkMaskedChanged(GtkToggleButton *button, gpointer data _U_)
 {
-  gboolean validIter, setValue, refresh;
-  GtkTreeIter iter;
+  gboolean refresh;
   VisuData *dataObj;
-  VisuElement *ele;
+  GList *elements, *tmp;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
-
-  /* Get the selected iter. */
-  validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  g_return_if_fail(validIter);
-
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &ele, -1);
-  setValue = gtk_toggle_button_get_active(button);
+  /* Get the selected elements. */
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  g_return_if_fail(elements);
 
   refresh = FALSE;
-  if (ele)
-    /* We change one specific element. */
-    refresh = visuElementSet_sensitiveToPlanes(ele, setValue);
-  else
-    {
-      /* We change for all elements. */
-      validIter = gtk_tree_model_get_iter_first
-	(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-      while (validIter)
-	{
-	  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-			     COLUMN_POINTER_TO_DATA, &ele, -1);
-	  if (ele)
-	    refresh = visuElementSet_sensitiveToPlanes(ele, setValue) || refresh;
-	  validIter = gtk_tree_model_iter_next
-	    (GTK_TREE_MODEL(listStoreVisuElements), &iter);
-	}
-    }
+  for (tmp = elements; tmp; tmp = g_list_next(tmp))
+    refresh =
+      visu_element_setSensitiveToPlanes((VisuElement*)tmp->data,
+                                        gtk_toggle_button_get_active(button)) ||
+      refresh;
+  g_list_free(elements);
   if (refresh)
     {
-      visuDataEmit_askForShowHideNodes(dataObj, &refresh);
-
+      dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+      refresh = FALSE;
+      visu_data_emitAskForShowHideNodes(dataObj, &refresh);
       if (refresh)
 	{
-	  visuDataEmit_nodeRenderedChange(dataObj);
-	  visuData_createAllNodes(dataObj);
-	  g_idle_add(visuObjectRedraw, (gpointer)0);
+	  visu_data_emitNodeRenderedChange(dataObj);
+	  visu_data_createAllNodes(dataObj);
+	  VISU_ADD_REDRAW;
 	}
     }
 }
 static void checkRenderedChanged(GtkToggleButton *button, gpointer data _U_)
 {
   int res;
-  gboolean validIter, setValue, refresh;
-  GtkTreeIter iter;
+  gboolean refresh;
   VisuData *dataObj;
-  VisuElement *ele;
+  GList *elements, *tmp;
+
+  /* Get the selected elements. */
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  g_return_if_fail(elements);
 
   dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
 
-  /* Get the selected iter. */
-  validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  g_return_if_fail(validIter);
-
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &ele, -1);
-
-  setValue = gtk_toggle_button_get_active(button);
   refresh = FALSE;
-  if (ele)
+  for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
-      res = visuElementSet_rendered(ele, setValue);
+      res = visu_element_setRendered((VisuElement*)tmp->data,
+                                     gtk_toggle_button_get_active(button));
       if (res)
 	{
 	  refresh = TRUE;
-	  visuDataEmit_elementRenderedChange(dataObj, ele);
-	  visuData_createNodes(dataObj, ele);
-	}
-    }
-  else
-    {
-      validIter = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-      while (validIter)
-	{
-	  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-			     COLUMN_POINTER_TO_DATA, &ele, -1);
-	  if (ele)
-	    {
-	      res = visuElementSet_rendered(ele, setValue);
-	      if (res)
-		{
-		  refresh = TRUE;
-		  visuDataEmit_elementRenderedChange(dataObj, ele);
-		  visuData_createNodes(dataObj, ele);
-		}
-	    }
-	  validIter = gtk_tree_model_iter_next(GTK_TREE_MODEL(listStoreVisuElements), &iter);
+	  visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
 	}
     }
+  g_list_free(elements);
   if (refresh)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
-
-
-/********************/
-/* Private methods. */
-/********************/
-char *getLabelOfElement(VisuElement *element)
+static void resourcesChanged(GObject *object _U_, VisuData *dataObj _U_,
+			     gpointer data _U_)
 {
-  GString *str;
-  char *res;
+  GList *elements;
 
-  str = g_string_new("");
-  g_string_append_printf(str, _("Element '%s'"), element->name);
-  res = str->str;
-  g_string_free(str, FALSE);
-  return res;
-}
-static void sendElementToSpecificArea()
-{
-  gboolean validIter;
-  GtkTreeIter iter;
-  VisuElement *ele;
-  GList *tmpLst;
-
-  if (!updateRenderingMethodResources)
-    return;
+  /* The resources loading could have changed ToolColor of the element,
+     so we check all the list. */
+  DBG_fprintf(stderr, "Panel Elements: catch the 'resourcesChanged'"
+	      " signal, checking color pointers.\n");
 
   /* Get the selected iter. */
-  validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(elementsCombo), &iter);
-  if (!validIter)
+  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  if (!elements)
     return;
 
-  /* Get a pointer on the current visuElement */
-  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-		     COLUMN_POINTER_TO_DATA, &ele, -1);
-
-  tmpLst = (GList*)0;
-  if (ele)
-    tmpLst = g_list_prepend(tmpLst, (gpointer)ele);
-  else
-    {
-      validIter = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-      while (validIter)
-	{
-	  gtk_tree_model_get(GTK_TREE_MODEL(listStoreVisuElements), &iter,
-			     COLUMN_POINTER_TO_DATA, &ele, -1);
-	  if (ele)
-	    tmpLst = g_list_prepend(tmpLst, (gpointer)ele);
-	  validIter = gtk_tree_model_iter_next(GTK_TREE_MODEL(listStoreVisuElements), &iter);
-	}
-    }
-  updateRenderingMethodResources(tmpLst);
-  g_list_free(tmpLst);
+  /* Force refresh on the specific area. */
+  if (updateRenderingMethodResources)
+    updateRenderingMethodResources(elements);
+  
+  g_list_free(elements);
+}
+/**
+ * panelElementsGet_selected:
+ *
+ * This method is used to get a list of selected #VisuElement from the
+ * element selector of this panel.
+ *
+ * Since: 3.6
+ *
+ * Returns: a list of #VisuElement, the list should be freed after use
+ * by g_list_free().
+ */
+GList* panelElementsGet_selected()
+{
+  return elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
 }
 
 
-/*******************/
-/* Public Methods. */
-/*******************/
 /* It allows the client to set the method use to update
    user defined values. */
-void setElementChangedFunc(panelElements_changeFunc func)
+static void setElementChangedFunc(panelElements_changeFunc func)
 {
   updateRenderingMethodResources = func;
 }
@@ -821,15 +600,17 @@ void setElementChangedFunc(panelElements_changeFunc func)
    freed via gtk_widget_destroy. If interface is a null pointer
    the previous renderingMethodElements is removed, but
    nothing replaces it. */
-void changeRenderingMethodInterface(GtkWidget* interface)
+static void changeRenderingMethodInterface(GtkWidget* interface)
 {
-  DBG_fprintf(stderr, "Panel Element : caught 'resourcesLoaded' signal.\n");
+  GList *elements;
+
+  DBG_fprintf(stderr, "Panel Element: caught 'resourcesLoaded' signal.\n");
   if (renderingMethodElements)
     {
       /* note that gtk_destroy automatically remove
 	 renderingMethodElements for its container, so
 	 a call to gtk_container_remove is not necessary. */
-      DBG_fprintf(stderr, "Panel Element : removing old rendering specific widget.\n");
+      DBG_fprintf(stderr, "Panel Element: removing old rendering specific widget.\n");
       gtk_widget_destroy(renderingMethodElements);
     }
 
@@ -844,14 +625,26 @@ void changeRenderingMethodInterface(GtkWidget* interface)
     }
 
   /* Force refresh on the specific area. */
-  sendElementToSpecificArea();
+  if (updateRenderingMethodResources)
+    {
+      elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+      updateRenderingMethodResources(elements);
+      g_list_free(elements);
+    }
 }
 
 
 /* RenderingMethod gtk interface. */
 
-/* This method allows to initiate the method
-   to deal with the interface. */
+/**
+ * panelElements_setInterfaceMethods:
+ * @method: a pointer on the method this interface is associated to ;
+ * @change: the method to be called whenever the element selection is cahnged ;
+ * @create: the method to be called when the interface must be built.
+ *
+ * This method allows to initiate the methods to deal with the rendering
+ * specific interfaces.
+ */
 void panelElements_setInterfaceMethods(VisuRendering *method,
 				       panelElements_changeFunc change,
 				       VisuGtkWidgetFunc create)
@@ -900,7 +693,13 @@ static void getRenderingInterface(VisuRendering *method,
       *create = interface->createInterface;
     }
 }
-
+/**
+ * panelElementsGet_static:
+ *
+ * Retrives a pointer on this #ToolPanel.
+ *
+ * Returns: a pointer owned by V_Sim.
+ */
 GtkWidget* panelElementsGet_static()
 {
   return panelElements;
