@@ -51,40 +51,29 @@
 #include <visu_rendering.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
-/**
- * panelElementsInit:
- *
- * Should be used in the list declared in externalModules.h to be loaded by
- * V_Sim on start-up. This routine will create the #ToolPanel where the element
- * stuff can be done, such as choosing a colour, setting the radius of
- * spheres...
- *
- * Returns: a newly created #ToolPanel object.
- */
 ToolPanel* panelElementsInit();
 
 /**
  * panelElements_changeFunc:
- * @eleList: a list of all #VisuElements that are selected.
+ * @elements: a list of all #VisuElements that are selected.
  *
  * Methods from this interface are called whenever the currently selected
  * elements are changed.
  */
-typedef void (*panelElements_changeFunc)(GList *eleList);
+typedef void (*panelElements_changeFunc)(GList *elements);
 
-/**
- * panelElements_setInterfaceMethods:
- * @method: a pointer on the method this interface is associated to ;
- * @change: the method to be called whenever the element selection is cahnged ;
- * @create: the method to be called when the interface must be built.
- *
- * This method allows to initiate the methods to deal with the rendering
- * specific interfaces.
- */
 void panelElements_setInterfaceMethods(VisuRendering *method,
 				       panelElements_changeFunc change,
 				       VisuGtkWidgetFunc create);
+GList* panelElementsGet_selected();
 
+/**
+ * PANEL_ELEMENTS:
+ *
+ * Retrieve the widget of the panel of #VisuElement.
+ *
+ * Returns: a #GtkWidget owned by V_Sim.
+ */
 #define PANEL_ELEMENTS panelElementsGet_static()
 GtkWidget* panelElementsGet_static();
 
