@@ -84,12 +84,12 @@ static void changedRGBFogColor(GtkRange *rg, gpointer data);
 static void changedFogStart(GtkRange *rg, gpointer data);
 static void changedFogEnd(GtkRange *rg, gpointer data);
 static void onFogBgEnter(ToolPanel *toolPanel, gpointer data);
-#if GTK_MINOR_VERSION > 11
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
 static void onBgImageSet(GtkFileChooserButton *filechooserbutton, gpointer data);
 #else
 static void onBgImageSet(GtkDialog *dialog, gint response, gpointer data);
 #endif
-#if GTK_MINOR_VERSION < 6
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 6
 static void onBgImageChoose(GtkButton *bt, gpointer data);
 #endif
 static void onBgImageUnset(GtkButton *bt, gpointer data);
@@ -158,7 +158,7 @@ GtkWidget *createInteriorFogBgColor()
   int i;
   GtkWidget *dialog, *bt, *preview;
   GtkFileFilter *filters;
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
@@ -210,9 +210,9 @@ GtkWidget *createInteriorFogBgColor()
   gtk_file_chooser_set_preview_widget_active(GTK_FILE_CHOOSER(dialog), FALSE);
   g_signal_connect(GTK_FILE_CHOOSER(dialog), "update-preview",
 		   G_CALLBACK(update_preview_cb), preview);
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   bgImageWd = gtk_file_chooser_button_new_with_dialog(dialog);
-#if GTK_MINOR_VERSION > 11
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
   g_signal_connect(G_OBJECT(bgImageWd), "file-set",
 		   G_CALLBACK(onBgImageSet), (gpointer)0);
 #else
@@ -248,6 +248,11 @@ GtkWidget *createInteriorFogBgColor()
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
 		   GTK_SHRINK, GTK_SHRINK, 5, 0);
   rangeFogStart = gtk_hscale_new_with_range(0., 100., 0.1);
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
+  gtk_range_set_restrict_to_fill_level(GTK_RANGE(rangeFogStart), TRUE);
+  gtk_range_set_fill_level(GTK_RANGE(rangeFogStart), 50.);
+  gtk_range_set_show_fill_level(GTK_RANGE(rangeFogStart), TRUE);
+#endif
   gtk_scale_set_value_pos(GTK_SCALE(rangeFogStart),
 			  GTK_POS_RIGHT);
   gtk_table_attach(GTK_TABLE(table), rangeFogStart,
@@ -312,9 +317,9 @@ void createCallBacksFogBgColor()
     g_signal_connect((gpointer)rgbFogColor[i], "value-changed",
 		     G_CALLBACK(changedRGBFogColor), GINT_TO_POINTER(i));
   g_signal_connect((gpointer)rangeFogStart, "value-changed",
-		   G_CALLBACK(changedFogStart), (gpointer)0);
+		   G_CALLBACK(changedFogStart), (gpointer)rangeFogEnd);
   g_signal_connect((gpointer)rangeFogEnd, "value-changed",
-		   G_CALLBACK(changedFogEnd), (gpointer)0);
+		   G_CALLBACK(changedFogEnd), (gpointer)rangeFogStart);
 }
 
 /*************/
@@ -327,57 +332,56 @@ static void fogRedraw()
   dataObj = toolPanelGet_visuData(TOOL_PANEL(panelFogBgColor));
   if (!dataObj) 
     return;
-  fogCreate(dataObj);
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  visu_glExt_fog_create(dataObj);
+  VISU_ADD_REDRAW;
 }
 static void fogCheckChanged(GtkToggleButton *button, gpointer data _U_)
 {
   if (disableCallbacksFogBgColor)
     return;
 
-  fogSet_isOn(gtk_toggle_button_get_active(button));
+  visu_glExt_fog_setOn(gtk_toggle_button_get_active(button));
   fogRedraw();
 }
 static void changedFogStart(GtkRange *rg, gpointer data _U_)
 {
-  GtkAdjustment *adj;
   float val[2];
 
   if (disableCallbacksFogBgColor)
     return;
 
-  adj = gtk_range_get_adjustment(rg);
-  val[0] = (float)gtk_adjustment_get_value(adj);
-  if (val[0] / 100. >= fogGet_end() - 0.001)
+  val[0] = (float)gtk_range_get_value(rg);
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 11
+  if (val[0] > gtk_range_get_value(GTK_RANGE(data)))
     {
-      gtk_adjustment_set_value(adj, (gdouble)fogGet_end() * 100. - 0.1);
-      val[0] = fogGet_end() - 0.001;
+      gtk_range_set_value(rg, gtk_range_get_value(GTK_RANGE(data)));
+      val[0] = (float)gtk_range_get_value(rg);
     }
-  else
-    val[0]= val[0] / 100.;
+#endif
+  val[0]= val[0] / 100.;
   
-  if (fogSet_startEndValues(val, MASK_FOG_START))
+  if (visu_glExt_fog_setStartEndValues(val, VISU_GLEXT_FOG_MASK_START))
     fogRedraw();
 }
-static void changedFogEnd(GtkRange *rg, gpointer data _U_)
+static void changedFogEnd(GtkRange *rg, gpointer data)
 {
-  GtkAdjustment *adj;
   float val[2];
 
+  val[1] = (float)gtk_range_get_value(rg);
+  if (val[1] < gtk_range_get_value(GTK_RANGE(data)))
+    {
+      gtk_range_set_value(rg, gtk_range_get_value(GTK_RANGE(data)));
+      val[1] = (float)gtk_range_get_value(rg);
+    }
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
+  gtk_range_set_fill_level(GTK_RANGE(rangeFogStart), val[1]);
+#endif
+  val[1]= val[1] / 100.;
+  
   if (disableCallbacksFogBgColor)
     return;
 
-  adj = gtk_range_get_adjustment(rg);
-  val[1] = (float)gtk_adjustment_get_value(adj);
-  if (val[1] / 100. <= fogGet_start() + 0.001)
-    {
-      gtk_adjustment_set_value(adj, (gdouble)fogGet_start() * 100. + 0.1);
-      val[1] = fogGet_start() + 0.001;
-    }
-  else
-    val[1]= val[1] / 100.;
-  
-  if (fogSet_startEndValues(val, MASK_FOG_END))
+  if (visu_glExt_fog_setStartEndValues(val, VISU_GLEXT_FOG_MASK_END))
     fogRedraw();
 }
 static void radioBgChanged(GtkToggleButton *button, gpointer data _U_)
@@ -389,13 +393,13 @@ static void radioBgChanged(GtkToggleButton *button, gpointer data _U_)
 
   for (i = 0; i < 3; i++)
     gtk_widget_set_sensitive(rgbFogColor[i], !gtk_toggle_button_get_active(button));
-  if (fogSet_useSpecificColor(!gtk_toggle_button_get_active(button)))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+  if (visu_glExt_fog_setUseSpecificColor(!gtk_toggle_button_get_active(button)))
+    VISU_ADD_REDRAW;
 }
 static void changedRGBFogColor(GtkRange *rg, gpointer data)
 {
   GtkAdjustment *adj;
-  int rgbMask[4] = {MASK_RGB_R, MASK_RGB_G, MASK_RGB_B, MASK_RGB_A};
+  int rgbMask[4] = {TOOL_COLOR_MASK_R, TOOL_COLOR_MASK_G, TOOL_COLOR_MASK_B, TOOL_COLOR_MASK_A};
   float rgb[4];
 
   if (disableCallbacksFogBgColor)
@@ -406,8 +410,8 @@ static void changedRGBFogColor(GtkRange *rg, gpointer data)
   adj = gtk_range_get_adjustment(rg);
   rgb[GPOINTER_TO_INT(data)] = (float)gtk_adjustment_get_value(adj);
   
-  if (fogSet_values(rgb, rgbMask[GPOINTER_TO_INT(data)]))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+  if (visu_glExt_fog_setValues(rgb, rgbMask[GPOINTER_TO_INT(data)]))
+    VISU_ADD_REDRAW;
 }
 static void onFogBgEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
 {
@@ -417,17 +421,17 @@ static void onFogBgEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
   disableCallbacksFogBgColor = 1;
   DBG_fprintf(stderr, "Panel Fog & bg : refresh data on enter.\n");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkFogIsOn),
-			       fogGet_isOn());
+			       visu_glExt_fog_getOn());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioOtherFog),
-			       fogGet_useSpecificColor());
-  bgGet_value(rgb);
+			       visu_glExt_fog_getUseSpecificColor());
+  visu_glExt_bg_getValues(rgb);
   for (i = 0; i < 4; i++)
     gtk_range_set_value(GTK_RANGE(rgbBgColor[i]), (gdouble)rgb[i]);
-  fogGet_value(rgb);
+  visu_glExt_fog_getValues(rgb);
   for (i = 0; i < 3; i++)
     gtk_range_set_value(GTK_RANGE(rgbFogColor[i]), (gdouble)rgb[i]);
-  gtk_range_set_value(GTK_RANGE(rangeFogStart), (gdouble)fogGet_start() * 100.);
-  gtk_range_set_value(GTK_RANGE(rangeFogEnd), (gdouble)fogGet_end() * 100.);
+  gtk_range_set_value(GTK_RANGE(rangeFogStart), (gdouble)visu_glExt_fog_getStart() * 100.);
+  gtk_range_set_value(GTK_RANGE(rangeFogEnd), (gdouble)visu_glExt_fog_getEnd() * 100.);
   disableCallbacksFogBgColor = 0;
 }
 
@@ -436,7 +440,7 @@ static void onFogBgEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
 static void changedRGBBgColor(GtkRange *rg, gpointer data)
 {
   GtkAdjustment *adj;
-  int rgbMask[4] = {MASK_RGB_R, MASK_RGB_G, MASK_RGB_B, MASK_RGB_A};
+  int rgbMask[4] = {TOOL_COLOR_MASK_R, TOOL_COLOR_MASK_G, TOOL_COLOR_MASK_B, TOOL_COLOR_MASK_A};
   float rgb[4];
 
   if (disableCallbacksFogBgColor)
@@ -447,10 +451,10 @@ static void changedRGBBgColor(GtkRange *rg, gpointer data)
   adj = gtk_range_get_adjustment(rg);
   rgb[GPOINTER_TO_INT(data)] = (float)gtk_adjustment_get_value(adj);
   
-  if (bgSet_values(rgb, rgbMask[GPOINTER_TO_INT(data)]))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+  if (visu_glExt_bg_setValues(rgb, rgbMask[GPOINTER_TO_INT(data)]))
+    VISU_ADD_REDRAW;
 }
-#if GTK_MINOR_VERSION > 11
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
 static void onBgImageSet(GtkFileChooserButton *filechooserbutton, gpointer data _U_)
 {
   gchar *filename;
@@ -460,7 +464,7 @@ static void onBgImageSet(GtkFileChooserButton *filechooserbutton, gpointer data
   if (!filename)
     return;
   g_idle_add(loadBgFile, (gpointer)filename);
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 #else
 static void onBgImageSet(GtkDialog *dialog, gint response, gpointer data _U_)
@@ -472,10 +476,10 @@ static void onBgImageSet(GtkDialog *dialog, gint response, gpointer data _U_)
 
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
   g_idle_add(loadBgFile, (gpointer)filename);
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 #endif
-#if GTK_MINOR_VERSION < 6
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 6
 static void onBgImageChoose(GtkButton *bt, gpointer data)
 {
   gchar *filename;
@@ -485,7 +489,7 @@ static void onBgImageChoose(GtkButton *bt, gpointer data)
 
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(data));
   g_idle_add(loadBgFile, (gpointer)filename);
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 #endif
 static gboolean loadBgFile(gpointer data)
@@ -518,7 +522,7 @@ static gboolean loadBgFile(gpointer data)
       g_free(title);
       title = (gchar*)0;
     }
-  bgSet_image(gdk_pixbuf_get_pixels(pixbuf),
+  visu_glExt_bg_setImage(gdk_pixbuf_get_pixels(pixbuf),
 	      gdk_pixbuf_get_width(pixbuf),
 	      gdk_pixbuf_get_height(pixbuf),
 	      gdk_pixbuf_get_has_alpha(pixbuf),
@@ -530,11 +534,11 @@ static gboolean loadBgFile(gpointer data)
 }
 static void onBgImageUnset(GtkButton *bt _U_, gpointer data)
 {
-  bgSet_image((guchar*)0, 0, 0, FALSE, (const gchar*)0, TRUE);
-#if GTK_MINOR_VERSION > 5
+  visu_glExt_bg_setImage((guchar*)0, 0, 0, FALSE, (const gchar*)0, TRUE);
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(data));
 #endif
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 void panelFogBgColorSet_bgImage(const gchar *filename)
 {
@@ -549,7 +553,7 @@ void panelFogBgColorSet_bgImage(const gchar *filename)
     }
   else
     path = g_strdup(filename);
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(bgImageWd), path);
 #endif
 
