@@ -50,6 +50,12 @@
 
 #include "gtkSpin.h"
 
+/**
+ * SECTION: panelMethod
+ * @short_description: The tab where drawing method is chosen (atomic
+ * or spin).
+ */
+
 /* Functions used to initialise the
  * specific area in the panel of rendering methods.
  */
@@ -223,6 +229,7 @@ static GtkWidget* createTreeListRenderingMethod(int *iterSelected)
   gpointer str;
   const gchar *iconPath;
 
+  DBG_fprintf(stderr, "Panel Method: create the combobox of methods.\n");
   /* We create the structure that store the methods */
   listStoreRenderingMethods = gtk_list_store_new (N_COLUMNS,
 						  GDK_TYPE_PIXBUF,
@@ -231,12 +238,13 @@ static GtkWidget* createTreeListRenderingMethod(int *iterSelected)
 						  G_TYPE_POINTER);
   *iterSelected = 0;
   i = 0;
-  methodInUse = visuRenderingClassGet_current();
-  for (methodLst = visuRenderingClassGet_Allobjects();
+  methodInUse = visu_object_getRendering(VISU_INSTANCE);
+  for (methodLst = visu_rendering_getAllObjects();
        methodLst; methodLst = g_list_next(methodLst))
     {
       meth = (VisuRendering*)methodLst->data;
-      iconPath = visuRenderingGet_iconPath(meth);
+      DBG_fprintf(stderr, " | add method '%s'.\n", visu_rendering_getName(meth, TRUE));
+      iconPath = visu_rendering_getIconPath(meth);
       if (iconPath)
 	pixbufIconBox = gdk_pixbuf_new_from_file_at_size(iconPath,
 							 16, 16, (GError**)0);
@@ -246,7 +254,7 @@ static GtkWidget* createTreeListRenderingMethod(int *iterSelected)
       gtk_list_store_append(listStoreRenderingMethods, &iter);
       gtk_list_store_set(listStoreRenderingMethods, &iter,
 			 COLUMN_ICON, pixbufIconBox,
-			 COLUMN_NAME, visuRenderingGet_name(meth, TRUE),
+			 COLUMN_NAME, visu_rendering_getName(meth, TRUE),
 			 COLUMN_POINTER_TO_DATA, methodLst->data,
 			 COLUMN_POINTER_TO_WIDGETS, str,
 			 -1);
@@ -282,21 +290,15 @@ static void comboInputMethodsChanged(GtkComboBox *combo, gpointer data _U_)
     {
       gtk_tree_model_get(tree, &iter, COLUMN_POINTER_TO_DATA, &meth,
                          COLUMN_POINTER_TO_WIDGETS, &str, -1);
-      if (meth && visuRenderingGet_description(meth))
-	{
-	  DBG_fprintf(stderr, "Panel Method: set the rendering method to '%s'.\n",
-		      visuRenderingGet_name(meth, FALSE));
-	  markup = g_markup_printf_escaped("<span size=\"smaller\">%s</span>",
-					   visuRenderingGet_description(meth));
-	  gtk_label_set_markup(GTK_LABEL(descrLabel), markup);
-	  g_free(markup);
-	}
-      else
-	{
-	  DBG_fprintf(stderr, "Panel Method: set the rendering method to 'null'.\n");
-	  gtk_label_set_text(GTK_LABEL(descrLabel), _("None"));
-	}
-      visuRenderingClassSet_current(meth);
+      g_return_if_fail(meth);
+
+      DBG_fprintf(stderr, "Panel Method: set the rendering method to '%s'.\n",
+                  visu_rendering_getName(meth, FALSE));
+      markup = g_markup_printf_escaped("<span size=\"smaller\">%s</span>",
+                                       visu_rendering_getDescription(meth));
+      gtk_label_set_markup(GTK_LABEL(descrLabel), markup);
+      g_free(markup);
+      visu_object_setRendering(VISU_INSTANCE, meth);
       setRenderingSpecificWidget(str);
     }
   else
@@ -352,7 +354,7 @@ static void onRenderingChanged(GObject *obj _U_, VisuRendering *meth,
   if (meth)
     {
       DBG_fprintf(stderr, "Panel Method: changing rendering method to '%s'.\n",
-		  visuRenderingGet_name(meth, FALSE));
+		  visu_rendering_getName(meth, FALSE));
       i = 0;
       /* Get the first iter in the list */
       valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoreRenderingMethods), &iter);
@@ -372,7 +374,7 @@ static void onRenderingChanged(GObject *obj _U_, VisuRendering *meth,
 	}
       g_warning("Can't find the current rendering method ('%s')"
 	      " is the combobox of the config panel.",
-		visuRenderingGet_name(meth, FALSE));
+		visu_rendering_getName(meth, FALSE));
     }
   else
     g_warning("Unsupported NULL rendering method.");
