@@ -59,6 +59,11 @@
 #include <openGLFunctions/renderingMode.h>
 #include <openGLFunctions/view.h>
 
+/**
+ * SECTION: panelOpenGL
+ * @short_description: The tab where OpenGL options like lights or quality are setup.
+ */
+
 /* Sensitive widget in this subpanel. */
 static GtkWidget *checkImmediateDrawing;
 static GtkWidget *comboOpenGLRendering;
@@ -73,7 +78,7 @@ static int disableCallbacksOpenGL;
 static GtkListStore *light_list_store;
 static GtkWidget *panelOpenGL;
 
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
 static GtkListStore *renderingListStore;
 #endif
 
@@ -96,7 +101,7 @@ void addPresetFourLightsClicked(GtkButton *button, gpointer data);
 static void selectionChanged(GtkTreeSelection *tree, gpointer data);
 static void addNewLightClicked(GtkButton *button, gpointer data);
 static void removeSelectedLightsClicked(GtkButton *button, gpointer data);
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
 static void renderingModeEdited(GtkCellRendererText *cellrenderertext,
 				gchar *path, gchar *text, gpointer user_data);
 #endif
@@ -188,7 +193,7 @@ void light_tree_show_hide(GtkCellRendererToggle *cell_renderer,
 
   status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 
 void light_update(GtkCellRendererText *cellrenderertext _U_,
@@ -215,7 +220,7 @@ void light_update(GtkCellRendererText *cellrenderertext _U_,
 			 
   status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 
 void light_sync_lists(GtkListStore *list)
@@ -293,7 +298,7 @@ GtkWidget* lights_make_tree_view()
 
 GtkWidget* make_renderingTreeView()
 {
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   GtkTreeViewColumn* column; 
   GtkCellRenderer *renderer;
   GtkWidget *renderingTreeView;
@@ -322,20 +327,20 @@ GtkWidget* make_renderingTreeView()
   renderingListStore =
     gtk_list_store_new(RENDERING_N_PARAMETERS, G_TYPE_POINTER,
 		       G_TYPE_STRING, G_TYPE_STRING);
-  list = OpenGLExtensionGet_list();
+  list = visuExtensions_getList();
   while(list)
     {
-      if (((OpenGLExtension*)list->data)->isSensitiveToRenderingMode)
+      if (((VisuExtension*)list->data)->isSensitiveToRenderingMode)
 	{
-	  if (((OpenGLExtension*)list->data)->preferedRenderingMode ==
+	  if (((VisuExtension*)list->data)->preferedRenderingMode ==
 	      followGeneralSetting)
 	    modeName = OPENGL_FOLLOW_GLOBAL_RENDERING_MODE;
 	  else
-	    modeName = names[((OpenGLExtension*)list->data)->preferedRenderingMode];
+	    modeName = names[((VisuExtension*)list->data)->preferedRenderingMode];
 	  gtk_list_store_append(renderingListStore, &iter);
 	  gtk_list_store_set(renderingListStore, &iter,
 			     RENDERING_POINTER_TO, list->data,
-			     RENDERING_NAME, ((OpenGLExtension*)list->data)->nameI18n,
+			     RENDERING_NAME, ((VisuExtension*)list->data)->nameI18n,
 			     RENDERING_MODE, modeName, -1);
 	}
       list = g_list_next(list);
@@ -401,7 +406,7 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
 
   status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 {
@@ -450,7 +455,7 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 
   status = lightEnvironnementApply(openGLGet_currentLights());
   if (status)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 void selectionChanged(GtkTreeSelection *tree, gpointer data)
 {
@@ -476,9 +481,9 @@ GtkWidget *createInteriorOpenGL()
   GtkWidget *scroll, *viewport;
   GtkWidget *expanderLight, *vbox2, *expand;
   GtkWidget *light_tree_view;
-  const char** names;
+  const char** names, **ids;
   int i;
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   GtkWidget *scrollRendering, *expanderRendering, *renderingTreeView;
 #endif
 
@@ -510,17 +515,18 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 2);
   label = gtk_label_new(_("Precision:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-  spinPrecision = gtk_spin_button_new_with_range(10, 500, 1);
+  spinPrecision = gtk_spin_button_new_with_range(10, 500, 5);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPrecision),
-			    OpenGLViewGet_precision() * 100.);
+			    VisuOpenGLViewGet_precision() * 100.);
   gtk_box_pack_start(GTK_BOX(hbox), spinPrecision, FALSE, FALSE, 2);
   label = gtk_label_new("%");
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-  comboOpenGLRendering = gtk_combo_box_new_text();
+  comboOpenGLRendering = gtk_combo_box_text_new();
   names = openGLGet_allRenderingModesI18n();
-  if (names)
-    for (i = 0; names[i]; i++)
-      gtk_combo_box_append_text(GTK_COMBO_BOX(comboOpenGLRendering), names[i]);
+  ids = openGLGet_allRenderingModes();
+  if (names && ids)
+    for (i = 0; names[i] && ids[i]; i++)
+      gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboOpenGLRendering), ids[i], names[i]);
   else
     g_warning("No OpenGL rendering mode available.");
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboOpenGLRendering), 0);
@@ -536,7 +542,7 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkAntialiasing = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAntialiasing),
-			       (gboolean)getAntialias());
+			       (gboolean)openGLGet_antialias());
   gtk_box_pack_start(GTK_BOX(hbox), checkAntialiasing, FALSE, FALSE, 2);
 
   checkTransparency = gtk_check_button_new();
@@ -566,7 +572,7 @@ GtkWidget *createInteriorOpenGL()
   /******************************/
   /* Rendering mode parameters. */
   /******************************/
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   expanderRendering = gtk_expander_new(_("Per extension rendering mode:"));
   label = gtk_expander_get_label_widget(GTK_EXPANDER(expanderRendering));
   gtk_box_pack_start(GTK_BOX(vbox2), expanderRendering, TRUE, TRUE, 5);
@@ -683,7 +689,7 @@ static void stereoCheckChanged(GtkToggleButton *button, gpointer data _U_)
     return;
 
   openGLSet_stereo(gtk_toggle_button_get_active(button));
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 static void stereoSpinChanged(GtkSpinButton *button, gpointer data _U_)
 {
@@ -691,7 +697,7 @@ static void stereoSpinChanged(GtkSpinButton *button, gpointer data _U_)
     return;
 
   if (openGLSet_stereoAngle((float)gtk_spin_button_get_value(button)))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 void comboOpenGLRenderingChanged(GtkComboBox *combobox, gpointer data _U_)
 {
@@ -703,15 +709,15 @@ void comboOpenGLRenderingChanged(GtkComboBox *combobox, gpointer data _U_)
   mode = (int)gtk_combo_box_get_active(combobox);
 
   if (openGLSet_globalRenderingMode(mode))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 static void antialisingCheckChanged(GtkToggleButton *button, gpointer data _U_)
 {
   if (disableCallbacksOpenGL)
     return;
 
-  if (setAntialias(gtk_toggle_button_get_active(button)))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+  if (openGLSet_antialias(gtk_toggle_button_get_active(button)))
+    VISU_ADD_REDRAW;
 }
 static void onTransparencyChanged(GtkToggleButton *button, gpointer data _U_)
 {
@@ -719,7 +725,7 @@ static void onTransparencyChanged(GtkToggleButton *button, gpointer data _U_)
     return;
 
   if (openGLSet_trueTransparency(gtk_toggle_button_get_active(button)))
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 void precisionChanged(GtkButton *button _U_, gpointer user_data _U_)
 {
@@ -730,22 +736,22 @@ void precisionChanged(GtkButton *button _U_, gpointer user_data _U_)
     return;
 
   prec = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinPrecision));
-  if (OpenGLViewSet_precision(prec / 100.))
+  if (VisuOpenGLViewSet_precision(prec / 100.))
     {
       dataObj = toolPanelGet_visuData(TOOL_PANEL(panelOpenGL));
-      visuDataEmit_facettesChanged(dataObj);
-      visuData_createAllElements(dataObj); 
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      visu_data_emitFacettesChanged(dataObj);
+      visu_data_createAllElements(dataObj); 
+      VISU_ADD_REDRAW;
     }
 }
 static void onOpenGLEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
 {
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   const gchar **names;
   gchar *name;
   GtkTreeIter iter;
   gboolean valid;
-  OpenGLExtension *ext;
+  VisuExtension *ext;
 #endif
 
   if (hboxStereo)
@@ -757,9 +763,9 @@ static void onOpenGLEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboOpenGLRendering),
 			   openGLGet_globalRenderingOption());
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPrecision),
-			    OpenGLViewGet_precision() * 100.);
+			    VisuOpenGLViewGet_precision() * 100.);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAntialiasing),
-			       (gboolean)getAntialias());
+			       (gboolean)openGLGet_antialias());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkTransparency),
 			       openGLGet_trueTransparency());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStereo),
@@ -767,7 +773,7 @@ static void onOpenGLEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinStereoAngle),
 			    openGLGet_stereoAngle());
 
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   names = openGLGet_allRenderingModesI18n();
   valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(renderingListStore), &iter);
   while(valid)
@@ -809,7 +815,7 @@ void addPresetOneLightClicked(GtkButton *button _U_, gpointer data)
 
   status = lightEnvironnementApply(openGLGet_currentLights()) || status;
   if (status)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 {
@@ -844,9 +850,9 @@ void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 
   status = lightEnvironnementApply(openGLGet_currentLights()) || status;
   if (status)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
 static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
 				gchar *path, gchar *text, gpointer user_data)
 {
@@ -855,7 +861,7 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
   GtkTreeIter iter;
   const char** names;
   int mode;
-  OpenGLExtension *ext;
+  VisuExtension *ext;
 
   if (disableCallbacksOpenGL)
     return;
@@ -884,7 +890,7 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
 
   gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 
 		     RENDERING_POINTER_TO, &ext, -1);
-  valid = OpenGLExtensionSet_preferedRenderingMode(ext, mode);
+  valid = visu_extension_setPreferedRenderingMode(ext, mode);
 
   if (mode == followGeneralSetting)
     gtk_list_store_set(list, &iter,
@@ -897,6 +903,6 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
     }
 
   if (valid && ext->used)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 #endif
