@@ -60,6 +60,11 @@
 #include <extraGtkFunctions/gtk_orientationChooser.h>
 #include <extraGtkFunctions/gtk_valueIOWidget.h>
 
+/**
+ * SECTION: panelPlanes
+ * @short_description: The tab where planes are defined.
+ */
+
 #define PANEL_PLANES_NO_PLANE_LIST _("<span font_desc=\"smaller\"><i>none</i></span>")
 
 GtkWidget *panelPlanes;
@@ -105,10 +110,10 @@ void onPlaneAdd(GtkButton *button, gpointer data);
 void onPlaneRemove(GtkButton *button, gpointer data);
 static void onSpinNVectChange(GtkSpinButton *spin, gpointer data);
 static void onSpinDistanceChange(GtkSpinButton *spin, gpointer data);
-static void onPlaneColorChange(ColorComboBox *combo, Color *selectedColor, gpointer data);
+static void onPlaneColorChange(ColorComboBox *combo, ToolColor *selectedColor, gpointer data);
 static void rebuildListPlanes(VisuData *dataObj);
 static void onDataReadyForRendering(GObject *obj, VisuData *dataObj, gpointer data);
-static void onNewFileLoaded(GObject *obj, VisuData *dataObj, gpointer data);
+static void onNewFileLoaded(VisuObject *obj, VisuData *dataObj, gpointer data);
 void onTreeSelectionChanged(GtkTreeSelection *tree, gpointer data);
 static void onNodePositionChanged(VisuData *dataObj, gpointer data);
 static void onNodePopulationIncreased(VisuData *dataObj,
@@ -137,7 +142,7 @@ static void createInteriorPlanes(VisuData *dataObj);
 
 static gboolean isPlanesInitialised;
 
-static OpenGLExtension *extensionPlanes;
+static VisuExtension *extensionPlanes;
 static int identifierAllPlanes;
 
 /* String used to labelled planes, dist. means 'distance' and
@@ -177,13 +182,13 @@ ToolPanel* panelPlanesInit()
 					 G_TYPE_OBJECT);
 
   /* Book some OpenGL list to draw planes. */
-  identifierAllPlanes = openGLObjectList_new(1);
-  extensionPlanes = OpenGLExtension_new("Planes", _("Planes"), _("Draw some planes."),
+  identifierAllPlanes = visu_openGL_objectList_new(1);
+  extensionPlanes = visu_extension_new("Planes", _("Planes"), _("Draw some planes."),
 					identifierAllPlanes, rebuildListPlanes);
   extensionPlanes->used = 0;
-  OpenGLExtensionSet_priority(extensionPlanes, OPENGL_EXTENSION_PRIORITY_LOW + 1);
-  OpenGLExtensionSet_sensitiveToRenderingMode(extensionPlanes, TRUE);
-  OpenGLExtensionRegister(extensionPlanes);
+  visu_extension_setPriority(extensionPlanes, VISU_EXTENSION_PRIORITY_LOW + 1);
+  visu_extension_setSensitiveToRenderingMode(extensionPlanes, TRUE);
+  visuExtensions_add(extensionPlanes);
 
   /* Add the signal for the vBoxPlanes. */
   g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
@@ -246,7 +251,7 @@ static void createAndInitPlanePanel(VisuData *dataObj)
 
 static void onPlanesEnter(ToolPanel *planes, gpointer data _U_)
 {
-  DBG_fprintf(stderr, "Panel Planes : caught the 'page-entered' signal %d.\n",
+  DBG_fprintf(stderr, "Panel Planes: caught the 'page-entered' signal %d.\n",
 	      isPlanesInitialised);
   if (!isPlanesInitialised)
     createAndInitPlanePanel(toolPanelGet_visuData(planes));
@@ -263,9 +268,7 @@ static void createInteriorPlanes(VisuData *dataObj)
   GtkWidget *vbox3, *vboxIO;
   GtkWidget *hbox4;
   GtkWidget *label2;
-  GtkObject *spinbuttonNVect_adj[3];
   GtkWidget *hbox5;
-  GtkObject *spinbuttonDistance_adj;
   GtkWidget *hbox3;
   GtkWidget *label4;
   GtkWidget *alignment2;
@@ -280,10 +283,9 @@ static void createInteriorPlanes(VisuData *dataObj)
   GSList *radiobuttonHideUnion_group;
   GtkWidget *radiobuttonHideInter, *radiobuttonHideUnion;
   GtkWidget *notebook;
-  OpenGLView *view;
   int i;
   float span[2];
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new ();
@@ -403,9 +405,8 @@ static void createInteriorPlanes(VisuData *dataObj)
 
   for (i = 0; i < 3; i++)
     {
-      spinbuttonNVect_adj[i] = gtk_adjustment_new (1, -999, 999, 1, 3, 0);
-      spinbuttonNVect[i] = gtk_spin_button_new(GTK_ADJUSTMENT
-					       (spinbuttonNVect_adj[i]), 1, 0);
+      spinbuttonNVect[i] = gtk_spin_button_new_with_range(-999, 999, 1);
+      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonNVect[i]), 1);
       gtk_widget_show (spinbuttonNVect[i]);
 /*       nVect[i] = 1.; */
       gtk_box_pack_start (GTK_BOX (hbox4), spinbuttonNVect[i], FALSE, FALSE, 0);
@@ -432,18 +433,16 @@ static void createInteriorPlanes(VisuData *dataObj)
   gtk_box_pack_start (GTK_BOX (hbox5), labelDistance, TRUE, TRUE, 0);
   gtk_misc_set_alignment (GTK_MISC (labelDistance), 1, 0.5);
 
-  view = (OpenGLView*)0;
-  if (dataObj) view = visuDataGet_openGLView(dataObj);
-  if (view)
-    {
-      openGLViewGet_boxSpan(view, span);
-      spinbuttonDistance_adj = gtk_adjustment_new((span[0] + span[1]) / 2.f,
-						  -span[1], span[1],
-						  0.25, 2, 0);
-    }
+  if (dataObj)
+    visu_data_getBoxSpan(dataObj, span);
   else
-    spinbuttonDistance_adj = gtk_adjustment_new(1, -1000, 1000, 0.25, 2, 0);
-  spinbuttonDistance = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonDistance_adj), 1, 2);
+    {
+      span[0] = -998.f;
+      span[1] = 1000.f;
+    }
+  spinbuttonDistance = gtk_spin_button_new_with_range(-span[1], span[1], 0.25);
+  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spinbuttonDistance), 2);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDistance), (span[0] + span[1]) / 2.f);
   gtk_widget_show (spinbuttonDistance);
   gtk_box_pack_start (GTK_BOX (hbox5), spinbuttonDistance, FALSE, FALSE, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbuttonDistance), TRUE);
@@ -553,7 +552,7 @@ static void createInteriorPlanes(VisuData *dataObj)
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_widget_show(hbox);
   gtk_container_add(GTK_CONTAINER(buttonDistPlayStop), hbox);
-#if GTK_MINOR_VERSION < 5
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 5
   imageDistPlay = create_pixmap((GtkWidget*)0, "stock_media-play.png");
   imageDistStop = create_pixmap((GtkWidget*)0, "stock_media-stop.png");
 #else
@@ -595,7 +594,7 @@ static void createInteriorPlanes(VisuData *dataObj)
   gtk_widget_show(labelPlaneList);
   gtk_box_pack_start(GTK_BOX(vboxIO), labelPlaneList, TRUE, TRUE, 0);
   gtk_misc_set_alignment(GTK_MISC(labelPlaneList), 0., 0.5);
-#if GTK_MINOR_VERSION > 5
+#if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_label_set_ellipsize(GTK_LABEL(labelPlaneList), PANGO_ELLIPSIZE_START);
 #endif
 
@@ -719,7 +718,7 @@ Plane** panelPlanesGet_listOfAllPlanes(gboolean maskingPlanesOnly)
   int i;
   gboolean skip;
   
-  DBG_fprintf(stderr, "Panel Plane : building plane list...\n");
+  DBG_fprintf(stderr, "Panel Planes: building plane list...\n");
   /* Build the list of all planes. */
   planeList = g_malloc(sizeof(Plane*) *
 		       (gtk_tree_model_iter_n_children
@@ -753,13 +752,13 @@ static void onAskForHideNodes(VisuData *visuData, gboolean *redraw,
 {
   Plane **listOfPlanes;
 
-  DBG_fprintf(stderr, "Panel Planes : caught the 'NodeAskForShowHide' signal for"
+  DBG_fprintf(stderr, "Panel Planes: caught the 'NodeAskForShowHide' signal for"
 	      " VisuData %p.\n", (gpointer)visuData);
 
   if (!checkUsePlanes || !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkUsePlanes)))
     return;
 
-  DBG_fprintf(stderr, "Panel Planes : caught the 'NodeAskForShowHide' signal for"
+  DBG_fprintf(stderr, "Panel Planes: caught the 'NodeAskForShowHide' signal for"
 	      " VisuData %p.\n", (gpointer)visuData);
   listOfPlanes = panelPlanesGet_listOfAllPlanes(FALSE);
   if (listOfPlanes)
@@ -798,9 +797,9 @@ static void onPlaneUsed(GtkToggleButton *button, gpointer data _U_)
 
   res = panelPlanesSet_use(dataObj, gtk_toggle_button_get_active(button));
   if (res)
-    visuData_createAllNodes(dataObj);
+    visu_data_createAllNodes(dataObj);
 
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 void onPlaneAdd(GtkButton *button _U_, gpointer userData _U_)
 {
@@ -808,7 +807,7 @@ void onPlaneAdd(GtkButton *button _U_, gpointer userData _U_)
   float vect[3], vertices[8][3];
   int i;
   GtkTreeIter iter;
-  Color *color;
+  ToolColor *color;
   gchar str[256];
   float dist;
   GdkPixbuf *pixbufColorAlphaBox;
@@ -821,7 +820,7 @@ void onPlaneAdd(GtkButton *button _U_, gpointer userData _U_)
   for (i = 0; i < 3; i++)
     vect[i] = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbuttonNVect[i]));
   dist = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbuttonDistance));
-  visuDataGet_boxVertices(dataObj, vertices, TRUE);
+  visu_data_getBoxVertices(dataObj, vertices, TRUE);
   plane = planeNew(vertices, vect, dist, color);
   
   /* String used to labelled planes, dist. means 'distance' and
@@ -845,7 +844,7 @@ void onPlaneAdd(GtkButton *button _U_, gpointer userData _U_)
   if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(listStoredPlanes), (GtkTreeIter*)0) > 1)
     gtk_widget_set_sensitive(hboxHidingMode, TRUE);
   if (extensionPlanes->used)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 void onPlaneRemove(GtkButton *button _U_, gpointer data _U_)
 {
@@ -855,7 +854,7 @@ void onPlaneRemove(GtkButton *button _U_, gpointer data _U_)
   int val;
   VisuData *dataObj;
 
-  DBG_fprintf(stderr, "Panel Plane : removing plane...\n");
+  DBG_fprintf(stderr, "Panel Planes: removing plane...\n");
   res = gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeviewPlanes)),
 					&tmpList, &iter);
   if (res)
@@ -866,7 +865,7 @@ void onPlaneRemove(GtkButton *button _U_, gpointer data _U_)
       if (!gtk_list_store_remove(GTK_LIST_STORE(listStoredPlanes), &iter))
 	res = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoredPlanes), &iter);
 
-      DBG_fprintf(stderr, "Panel Plane : OK plane found and removed.\n");
+      DBG_fprintf(stderr, "Panel Planes: OK plane found and removed.\n");
 
       if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(listStoredPlanes), (GtkTreeIter*)0) < 2)
 	gtk_widget_set_sensitive(hboxHidingMode, FALSE);
@@ -879,9 +878,9 @@ void onPlaneRemove(GtkButton *button _U_, gpointer data _U_)
       /* Modify nodes visibility accordingly. */
       val = panelPlanesApply_hidingScheme(dataObj);
       if (val)
-	visuData_createAllNodes(dataObj);
+	visu_data_createAllNodes(dataObj);
       if (extensionPlanes->used)
-	g_idle_add(visuObjectRedraw, (gpointer)0);
+	VISU_ADD_REDRAW;
 
       if (res)
 	gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeviewPlanes)),
@@ -957,9 +956,9 @@ static void onSpinNVectChange(GtkSpinButton *spin, gpointer data)
       /* Modify nodes visibility accordingly. */
       res = panelPlanesApply_hidingScheme(dataObj);
       if (res)
-	visuData_createAllNodes(dataObj);
+	visu_data_createAllNodes(dataObj);
     }
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 static void onSpinDistanceChange(GtkSpinButton *spin, gpointer data _U_)
 {
@@ -1022,11 +1021,11 @@ static void onSpinDistanceChange(GtkSpinButton *spin, gpointer data _U_)
       /* Modify nodes visibility accordingly. */
       val = panelPlanesApply_hidingScheme(dataObj);
       if (val)
-	visuData_createAllNodes(dataObj);
+	visu_data_createAllNodes(dataObj);
     }
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
-static void onPlaneColorChange(ColorComboBox *combo, Color *color, gpointer data _U_)
+static void onPlaneColorChange(ColorComboBox *combo, ToolColor *color, gpointer data _U_)
 {
   gboolean res;
   GtkTreeModel *tmpList;
@@ -1042,7 +1041,7 @@ static void onPlaneColorChange(ColorComboBox *combo, Color *color, gpointer data
   /* Get the VisuData to deal with. */
   dataObj = toolPanelGet_visuData(TOOL_PANEL(panelPlanes));
 
-  DBG_fprintf(stderr, "Panel Plane : Catch the 'color-selected' signal.\n");
+  DBG_fprintf(stderr, "Panel Planes: Catch the 'color-selected' signal.\n");
 
   pixbufColorAlphaBox = colorComboBoxGet_selectedPixbuf(combo);
 
@@ -1069,15 +1068,15 @@ static void onPlaneColorChange(ColorComboBox *combo, Color *color, gpointer data
   else if (val == 0)
     return;
 
-  DBG_fprintf(stderr, "Panel Plane : color combobox changed to %p (%f,%f,%f,%f).\n",
+  DBG_fprintf(stderr, "Panel Planes: color combobox changed to %p (%f,%f,%f,%f).\n",
 	      (gpointer)color, color->rgba[0], color->rgba[1], color->rgba[2], color->rgba[3]);
-  DBG_fprintf(stderr, "Panel Plane : Changed color (%p) for plane : %p.\n",
+  DBG_fprintf(stderr, "Panel Planes: Changed color (%p) for plane : %p.\n",
 	      (gpointer)color, (gpointer)plane);
 
   gtk_list_store_set(listStoredPlanes, &iter, COLUMN_PLANE_COLOR_PIXBUF, pixbufColorAlphaBox, -1);
   rebuildListPlanes(dataObj);
   if (extensionPlanes->used)
-    g_idle_add(visuObjectRedraw, (gpointer)0);
+    VISU_ADD_REDRAW;
 }
 
 static void onDataReadyForRendering(GObject *obj _U_, VisuData *dataObj,
@@ -1088,7 +1087,7 @@ static void onDataReadyForRendering(GObject *obj _U_, VisuData *dataObj,
   gboolean needShowHide;
   float span[2], vertices[8][3];
 
-  DBG_fprintf(stderr, "Panel Plane : caught 'dataReadyForRendering' signal\n"
+  DBG_fprintf(stderr, "Panel Planes: caught 'dataReadyForRendering' signal\n"
 	      " | setting sensitivity.\n");
   if (dataObj)
     gtk_widget_set_sensitive(vBoxPlanes, TRUE);
@@ -1101,7 +1100,7 @@ static void onDataReadyForRendering(GObject *obj _U_, VisuData *dataObj,
   if (spinbuttonDistance)
     {
       DBG_fprintf(stderr, " | set the maximum of the distance spin.\n");
-      openGLViewGet_boxSpan(visuDataGet_openGLView(dataObj), span);
+      visu_data_getBoxSpan(dataObj, span);
       gtk_spin_button_set_range(GTK_SPIN_BUTTON(spinbuttonDistance),
 				-span[1], span[1]);
     }
@@ -1112,7 +1111,7 @@ static void onDataReadyForRendering(GObject *obj _U_, VisuData *dataObj,
   DBG_fprintf(stderr, " | recalculating intersections and masking set.\n");
 
   needShowHide = FALSE;
-  visuDataGet_boxVertices(dataObj, vertices, TRUE);
+  visu_data_getBoxVertices(dataObj, vertices, TRUE);
   list = panelPlanesGet_listOfAllPlanes(FALSE);
   for (i = 0; list[i]; i++)
     {
@@ -1129,9 +1128,9 @@ static void onDataReadyForRendering(GObject *obj _U_, VisuData *dataObj,
   rebuildListPlanes((VisuData*)dataObj);
 }
 
-void onNewFileLoaded(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
+void onNewFileLoaded(VisuObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 {
-  DBG_fprintf(stderr, "Panel Plane : caught 'dataNew' signal,"
+  DBG_fprintf(stderr, "Panel Planes: caught 'dataNew' signal,"
 	      " connecting local signals.\n");
   
   onAskForHide_signal_id =
@@ -1149,7 +1148,7 @@ static void onNodePositionChanged(VisuData *dataObj, gpointer data _U_)
 {
   GtkTreeIter iter;
 
-  DBG_fprintf(stderr, "Panel Plane : catch 'NodePositionChanged' signal,"
+  DBG_fprintf(stderr, "Panel Planes: catch 'NodePositionChanged' signal,"
 	      " recalculating masking properties.\n");
 
   if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoredPlanes), &iter))
@@ -1160,7 +1159,7 @@ static void onNodePopulationIncreased(VisuData *dataObj,
 {
   GtkTreeIter iter;
 
-  DBG_fprintf(stderr, "Panel Plane : catch 'NodePopulationIncrease' signal,"
+  DBG_fprintf(stderr, "Panel Planes: catch 'NodePopulationIncrease' signal,"
 	      " recalculating masking properties for all nodes.\n");
 
   if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoredPlanes), &iter))
@@ -1173,10 +1172,10 @@ static void onBoxSizeChanged(VisuData *data, gpointer user_data _U_)
   Plane *plane;
   float span[2], vertices[8][3];
 
-  DBG_fprintf(stderr, "Panel Plane : catch 'BoxSizeChanged' signal,"
+  DBG_fprintf(stderr, "Panel Planes: catch 'BoxSizeChanged' signal,"
 	      " recalculating plane sizes.\n");
 
-  visuDataGet_boxVertices(data, vertices, TRUE);
+  visu_data_getBoxVertices(data, vertices, TRUE);
   valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(listStoredPlanes), &iter);
   while (valid)
     {
@@ -1195,7 +1194,7 @@ static void onBoxSizeChanged(VisuData *data, gpointer user_data _U_)
   if (spinbuttonDistance)
     {
       DBG_fprintf(stderr, " | set the maximum of the distance spin.\n");
-      openGLViewGet_boxSpan(visuDataGet_openGLView(data), span);
+      visu_data_getBoxSpan(data, span);
       gtk_spin_button_set_range(GTK_SPIN_BUTTON(spinbuttonDistance),
 				-span[1], span[1]);
     }
@@ -1209,9 +1208,9 @@ void onTreeSelectionChanged(GtkTreeSelection *tree, gpointer data _U_)
   GtkTreeIter iter;
   Plane *plane;
   float nPlane[3], dist;
-  Color *colorPlane, *colorCombo;
+  ToolColor *colorPlane, *colorCombo;
 
-  DBG_fprintf(stderr, "Panel Plane: catch 'changed' signal from "
+  DBG_fprintf(stderr, "Panel Planes: catch 'changed' signal from "
 	      " the gtkTreeSelection.\n");
 
   res = gtk_tree_selection_get_selected(tree, &tmpList, &iter);
@@ -1224,13 +1223,13 @@ void onTreeSelectionChanged(GtkTreeSelection *tree, gpointer data _U_)
       /* Because the get action increase the counter... */
       g_object_unref(G_OBJECT(plane));
 
-      DBG_fprintf(stderr, "Panel Plane: get the values for plane %p.\n",
+      DBG_fprintf(stderr, "Panel Planes: get the values for plane %p.\n",
 		  (gpointer)plane);
       planeGet_nVectUser(plane, nPlane);
       planeGet_distanceFromOrigin(plane, &dist);
       planeGet_color(plane, &colorPlane);
 
-      DBG_fprintf(stderr, "Panel Plane: update the widgets.\n");
+      DBG_fprintf(stderr, "Panel Planes: update the widgets.\n");
       disableCallbacks = TRUE;
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonNVect[0]), nPlane[0]);
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonNVect[1]), nPlane[1]);
@@ -1273,14 +1272,14 @@ void onSetCameraPosition(GtkButton *button _U_, gpointer data _U_)
       /* Because the get action increase the counter... */
       g_object_unref(G_OBJECT(plane));
 
-      DBG_fprintf(stderr, "Panel Planes : Set the camera position to be"
+      DBG_fprintf(stderr, "Panel Planes: Set the camera position to be"
 		  " normal to the selected plane (%p).\n", (gpointer)plane);
       planeGet_nVectUser(plane, nPlane);
-      matrix_cartesianToSpherical(spherical, nPlane);
-      visuDataSet_angleOfView(toolPanelGet_visuData(TOOL_PANEL(panelPlanes)),
+      tool_matrix_cartesianToSpherical(spherical, nPlane);
+      visu_data_setAngleOfView(toolPanelGet_visuData(TOOL_PANEL(panelPlanes)),
 			      spherical[1], spherical[2], 0.,
-			     MASK_THETA | MASK_PHI);
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+			     VISU_CAMERA_THETA | VISU_CAMERA_PHI);
+      VISU_ADD_REDRAW;
     }
 }
 static void panelSet_rendered(GtkTreeIter *iter, Plane *plane, gboolean status)
@@ -1308,7 +1307,7 @@ static void onGtkPlanesDrawnToggled(GtkCellRendererToggle *cell_renderer,
   g_object_unref(G_OBJECT(plane));
   panelSet_rendered(&iter, plane,
 		    !gtk_cell_renderer_toggle_get_active(cell_renderer));
-  g_idle_add(visuObjectRedraw, (gpointer)0);
+  VISU_ADD_REDRAW;
 }
 gboolean panelPlanesSet_planeRendered(Plane *plane, gboolean status)
 {
@@ -1385,8 +1384,8 @@ void onGtkPlanesHideToggled(GtkCellRendererToggle *cell_renderer _U_,
       val = panelPlanesApply_hidingScheme(dataObj);
       if (val)
 	{
-	  visuData_createAllNodes(dataObj);
-	  g_idle_add(visuObjectRedraw, (gpointer)0);
+	  visu_data_createAllNodes(dataObj);
+	  VISU_ADD_REDRAW;
 	}
     }
 }
@@ -1427,18 +1426,18 @@ void onGtkPlanesHidingModeToggled(GtkToggleButton *toggle, gpointer data)
   g_free(planeList);
   if (res)
     {
-      visuData_createAllNodes(dataObj);
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+      visu_data_createAllNodes(dataObj);
+      VISU_ADD_REDRAW;
     }
 }
 gboolean panelPlanesApply_hidingScheme(VisuData *data)
 {
   gboolean redraw;
 
-  visuDataEmit_askForShowHideNodes(data, &redraw);
+  visu_data_emitAskForShowHideNodes(data, &redraw);
 
   if (redraw)
-    visuDataEmit_nodeRenderedChange(data);
+    visu_data_emitNodeRenderedChange(data);
 
   return redraw;
 }
@@ -1446,7 +1445,7 @@ gboolean panelPlanesApply_hidingScheme(VisuData *data)
 
 static void onPlayStopDist(GtkButton *button _U_, gpointer data _U_)
 {
-  DBG_fprintf(stderr, "Panel Plane : push the play/stop button.\n");
+  DBG_fprintf(stderr, "Panel Planes: push the play/stop button.\n");
 
   if (!isPlayingDistanceId)
     {
@@ -1507,7 +1506,7 @@ static gboolean playDistances(gpointer data _U_)
   if (!changed)
     return FALSE;
 
-  DBG_fprintf(stderr, "Panel Planes : set new distance to %g.\n", val + directionDist * step);
+  DBG_fprintf(stderr, "Panel Planes: set new distance to %g.\n", val + directionDist * step);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbuttonDistance),
 			    val + directionDist * step);
   return TRUE;
@@ -1556,7 +1555,7 @@ gboolean panelPlanesLoad_file(VisuData *dataObj, gchar *filename, GError **error
   gboolean res;
   float vect[3], vertices[8][3];
   float dist;
-  Color *color;
+  ToolColor *color;
   int hide, i;
   gchar str[256];
   GdkPixbuf *pixbufColorAlphaBox;
@@ -1564,7 +1563,8 @@ gboolean panelPlanesLoad_file(VisuData *dataObj, gchar *filename, GError **error
 
   g_return_val_if_fail(dataObj && filename && error && *error == (GError*)0, FALSE);
 
-  g_return_val_if_fail(isPlanesInitialised, FALSE);
+  if (!isPlanesInitialised)
+    createAndInitPlanePanel(dataObj);
 
   /* Try to load the file. */
   list = (Plane**)0;
@@ -1576,7 +1576,7 @@ gboolean panelPlanesLoad_file(VisuData *dataObj, gchar *filename, GError **error
   /* Begin to compute intersections of all planes and then
      add then to the list. */
   gtk_list_store_clear(listStoredPlanes);
-  visuDataGet_boxVertices(dataObj, vertices, TRUE);
+  visu_data_getBoxVertices(dataObj, vertices, TRUE);
   for (i = 0; list[i]; i++)
     {
       DBG_fprintf(stderr, " | %d plane %p.\n", i, (gpointer)list[i]);
@@ -1680,8 +1680,8 @@ static void onPlaneListOpen(GtkButton *button _U_, gpointer data _U_)
     {
       res = panelPlanesApply_hidingScheme(dataObj);
       if (res)
-	visuData_createAllNodes(dataObj);
-      g_idle_add(visuObjectRedraw, (gpointer)0);
+	visu_data_createAllNodes(dataObj);
+      VISU_ADD_REDRAW;
     }
 }
 static gboolean callbackSave(gchar* filename)
@@ -1775,7 +1775,7 @@ static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
 		       G_CALLBACK(onOrientationChanged), (gpointer)0);
     }
   else
-    gdk_window_raise(GDK_WINDOW(orientationChooser->window));
+    gtk_window_present(GTK_WINDOW(orientationChooser));
   
   gtk_widget_show(orientationChooser);
   switch (gtk_dialog_run(GTK_DIALOG(orientationChooser)))
