@@ -56,7 +56,18 @@
 #include <extraFunctions/pot2surf.h>
 #include <extraFunctions/surfaces.h>
 #include <gtk_renderingWindowWidget.h>
-#include <renderingBackend/visu_windowInterface.h>
+
+/**
+ * SECTION:panelSurfacesTools
+ * @short_description: Gtk interface to manage isosurfaces.
+ *
+ * <para>This module contains the panel used to manage your .surf
+ * files. At the moment, only two tools are availiable for you to
+ * use. <link linkend="v-sim-pot2surf">pot2surf</link> will allow you
+ * to create .surf files from .pot files. There is also a .surf file
+ * merger which is so short that we beliedved it didn't need it's own
+ * module.</para>
+ */
 
 static GtkWidget *convert_window;
 static gboolean convert_w_opened = FALSE;
@@ -221,7 +232,7 @@ gboolean surf_simply_parse_file(char *file_name)
 				    _("Keep current values"), GTK_RESPONSE_YES,
 				    _("Change values to new ones"), GTK_RESPONSE_NO, NULL);
       
-      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(choice)->vbox), 
+      gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(choice))), 
 			 gtk_label_new(_("Current dxx, ..., dzz, doesn't match the ones used in the "
 					 "file you are trying to load. Do you want to keep old "
 					 "dxx, ..., dzz ? (if you don't know exactly what you're doing, "
@@ -770,7 +781,7 @@ void surf_gogogo()
 GtkWidget *surf_file_manager()
 {
   enum { DXX, DYX, DYY, DZX, DZY, DZZ };
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips = gtk_tooltips_new ();
 #endif
   GtkWidget* scrolled_window_top = gtk_scrolled_window_new(NULL, NULL);
@@ -1019,8 +1030,8 @@ void pot2surf_popup_help()
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   /* The dialog window is created with a vbox packed into it. */
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG(window)->vbox), scrolled_window,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(window))),
+		     scrolled_window, TRUE, TRUE, 0);
     
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (scrolled_window),
 					text_view);
@@ -1674,10 +1685,6 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
   int n=0, i;
   const gchar *pot_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_source_pot_file));
   const gchar *surf_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_target_surf_file));
-  RenderingWindow *window;
-
-  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
-  g_return_val_if_fail(window, FALSE);
 
   gtk_tree_model_foreach(GTK_TREE_MODEL(pot2surf_list_store), pot2surf_count_surf, &n);
   if(n == 0)
@@ -1733,8 +1740,9 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data)))
     {
       if(panelIsosurfacesLoad_file(surf_file, 0,
-				   renderingWindowGet_visuData(window),
-				   (OptionTable*)0, (double**)0) == 0)
+				   visu_rendering_window_getVisuData
+				   (visu_uiMainClass_getDefaultRendering()),
+				   (GHashTable*)0, (double**)0) == 0)
 	{
 	  for(i=0; i<n; i++)
 	    g_free(names[i]);
@@ -1944,7 +1952,7 @@ void pot2surf_select_instruc_file_to_load()
 /* See header file for more info */
 GtkWidget* pot2surf_widget()
 {
-#if GTK_MINOR_VERSION < 12
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips = gtk_tooltips_new ();
 #endif
 
