@@ -43,12 +43,13 @@
 */
 #include "atomic_xyz.h"
 #include "renderingAtomic_ascii.h"
+#include "renderingAtomic.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <visu_rendering.h>
 #include <visu_data.h>
-
+#include <coreTools/toolPhysic.h>
 #include <extraFunctions/vibration.h>
 
 /*#define TESTNEW*/
@@ -67,7 +68,7 @@
  * repeated as much time as required to store animation for instance.</para>
  */
 
-static gboolean loadXyz(VisuData *data, const gchar* filename, FileFormat *format, int nSet, GError **error);
+static gboolean loadXyz(VisuData *data, const gchar* filename, ToolFileFormat *format, int nSet, GError **error);
 static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **error);
 
 #ifdef TESTNEW
@@ -75,27 +76,26 @@ static gboolean test_Routine(float* coords, float* dcoord, VisuElement **nodeTyp
 #endif
 
 /******************************************************************************/
-RenderingFormatLoad* atomicXyzInit()
+/**
+ * initAtomicXyz: (skip)
+ * @method: the #VisuRendering method to be associated to.
+ *
+ * Create the structure that gives access to a load method and
+ * some description of it (file formats associated, name...). Internal
+ * use only
+ */
+void initAtomicXyz(VisuRendering *method)
 {
   char *typeXYZ[] = {"*.xyz", (char*)0};
-  char *descrXYZ = _("'Element x y z' format");
-  RenderingFormatLoad *meth;
-  
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = "XYZ format (very loose).";
-  meth->fmt = fileFormatNew(descrXYZ, typeXYZ);
-  if (!meth->fmt)
-    {
-      g_error("Can't initialize the rendering atomic method, aborting...\n");
-    }
-  meth->priority = 100;
-  meth->load = loadXyz;
 
-  return meth;
+  visu_rendering_addFileFormat(method, 0,
+                               tool_file_format_new(_("'Element x y z' format"),
+                                                    typeXYZ),
+                               100, loadXyz, (GDestroyNotify)0);
 }
 
 static gboolean loadXyz(VisuData *data, const gchar* filename,
-			FileFormat *format _U_, int nSet, GError **error)
+			ToolFileFormat *format _U_, int nSet, GError **error)
 {
   int res;
   GIOChannel *readFrom;
@@ -150,16 +150,16 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   gchar *infoUTF8;
   GList *lst, *tmpLst;
   GHashTable *elements;
-  struct dataAscii *infos;
+  struct VisuMethAscii *infos;
   float qpt[3], omega;
   double box[3], boxGeometry[6];
   int ntype;
-  VisuUnits unit;
+  ToolUnits unit;
   VisuElement *type;
   VisuElement **types, **nodeTypes;
   unsigned int *nattyp, natom;
   gchar *pt;
-  OpenGLBoxBoundaries bc;
+  VisuDataBoxBoundaries bc;
   gboolean reduced;
 
   int nbcolumn;
@@ -379,50 +379,29 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	      /* Store the elements. */
 	      nomloc[8] = '\0';
 
-	      type = visuElementGet_fromName(nomloc);
+	      type = visu_element_retrieveFromName(nomloc, (gboolean*)0);
 	      if (!type)
 		{
-		  type = visuElementNew_withName(nomloc);
-		  if (!type)
-		    {
-		      g_warning("Cannot create a new type for '%s'.", nomloc);
-		      g_string_free(line, TRUE);
-		      g_hash_table_destroy(elements);
-		      if (nSets == nSet)
-			{
-			  g_free(nodeTypes);
-			  g_free(coords);
-			  g_free(dcoord);
-			  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-			    g_free(tmpLst->data);
-			  g_list_free(lst);
-			}
-		      return 1;
-		    }
-		  res = visuElementAdd(type);
-		  if (res)
-		    {
-		      g_warning("Cannot add new element, maximum has been reached.");
-		      g_string_free(line, TRUE);
-		      g_hash_table_destroy(elements);
-		      if (nSets == nSet)
-			{
-			  g_free(nodeTypes);
-			  g_free(coords);
-			  g_free(dcoord);
-			  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-			    g_free(tmpLst->data);
-			  g_list_free(lst);
-			}
-		      return 1;
-		    }
+                  g_warning("Cannot create a new type for '%s'.", nomloc);
+                  g_string_free(line, TRUE);
+                  g_hash_table_destroy(elements);
+                  if (nSets == nSet)
+                    {
+                      g_free(nodeTypes);
+                      g_free(coords);
+                      g_free(dcoord);
+                      for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
+                        g_free(tmpLst->data);
+                      g_list_free(lst);
+                    }
+                  return 1;
 		}
 	      nodeTypes[iNodes] = type;
-	      infos = (struct dataAscii*)g_hash_table_lookup(elements,
+	      infos = (struct VisuMethAscii*)g_hash_table_lookup(elements,
 							     (gconstpointer)type);
 	      if (!infos)
 		{
-		  infos = g_malloc(sizeof(struct dataAscii));
+		  infos = g_malloc(sizeof(struct VisuMethAscii));
 		  infos->ele = type;
 		  infos->pos = ntype;
 		  infos->nbNodes = 1;
@@ -506,15 +485,15 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
     }
   types  = g_malloc(sizeof(VisuElement*) * ntype);
   nattyp = g_malloc(sizeof(int) * ntype);
-  g_hash_table_foreach(elements, (GHFunc)putValTypeInAsciiType, (gpointer)&types);
-  g_hash_table_foreach(elements, (GHFunc)putValNbInAsciiType, (gpointer)&nattyp);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
   g_hash_table_destroy(elements);
 
   DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
   /* Begin the storage into VisuData. */
-  visuDataSet_nSet(data, nSets);
+  visu_data_setNSubset(data, nSets);
 
-  res = visuDataSet_population(data, ntype, nattyp, types);
+  res = visu_data_setPopulation(data, ntype, nattyp, types);
   if (!res)
     {
       g_error("Can't store the nodes in the VisuData object.");
@@ -531,7 +510,7 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   g_free(types);
 
   /* Set the commentary. */
-  bc = BOX_FREE;
+  bc = VISU_DATA_BOX_FREE;
   tmpLst = lst;
   for (i = 0; i < nSets; i++)
     {
@@ -541,41 +520,20 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	  kwd = strstr((char*)tmpLst->data, "periodic");
 	  if (kwd && sscanf(kwd + 8, "%lf %lf %lf",
 				    box, box + 1, box + 2) == 3)
-	    bc = BOX_PERIODIC;
+	    bc = VISU_DATA_BOX_PERIODIC;
 	  kwd = strstr((char*)tmpLst->data, "surface");
 	  if (kwd && sscanf(kwd + 8, "%lf %lf %lf",
 				    box, box + 1, box + 2) == 3)
-	    bc = BOX_SURFACE_ZX;
+	    bc = VISU_DATA_BOX_SURFACE_ZX;
 	}
 
-      visuDataSet_fileCommentary(data, (gchar*)tmpLst->data, i);
+      visu_data_setFileCommentary(data, (gchar*)tmpLst->data, i);
       g_free(tmpLst->data);
       tmpLst = g_list_next(tmpLst);
     }
   g_list_free(lst);
          
-  /* Store the coordinates */
-  for(iNodes = 0; iNodes < nNodesSet; iNodes++)
-    {
-      if (reduced)
-	{
-	  coords[3 * iNodes + 0] *= box[0];
-	  coords[3 * iNodes + 1] *= box[1];
-	  coords[3 * iNodes + 2] *= box[2];
-	}
-      visuDataAdd_nodeFromElement(data, nodeTypes[iNodes],
-				  coords + 3 * iNodes, FALSE);
-    }
-
-#ifdef TESTNEW
-  if ( test_Routine(coords, dcoord, nodeTypes) == FALSE )
-    return -1;
-#endif
-
-  g_free(nodeTypes);
-  g_free(coords);
-
-  if (bc != BOX_FREE)
+  if (bc != VISU_DATA_BOX_FREE)
     {
       DBG_fprintf(stderr, "Atomic xyz: the elements are in %fx%fx%f.\n",
 		  box[0], box[1], box[2]);
@@ -585,29 +543,43 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
       boxGeometry[3] = 0.;
       boxGeometry[4] = 0.;
       boxGeometry[5] = box[2];
-      visuDataSet_boxGeometry(data, boxGeometry, bc);
+      visu_data_setBoxGeometry(data, boxGeometry, bc);
     }
-  else
-    visuDataSet_tightBox(data);
 
-  visuDataApply_boxGeometry(data, 0.f);
-  visuDataSet_unit(data, unit);
+  /* Store the coordinates */
+  for(iNodes = 0; iNodes < nNodesSet; iNodes++)
+    visu_data_addNodeFromElement(data, nodeTypes[iNodes],
+                                 coords + 3 * iNodes, reduced, FALSE);
+
+#ifdef TESTNEW
+  if ( test_Routine(coords, dcoord, nodeTypes) == FALSE )
+    return -1;
+#endif
+
+  g_free(nodeTypes);
+  g_free(coords);
+
+  if (bc != VISU_DATA_BOX_PERIODIC)
+    visu_data_setTightBox(data);
+
+  visu_data_applyBoxGeometry(data);
+  visu_data_setUnit(data, unit);
 
   /* create the structure for phonons */
   if (nbcolumn == 7)
     {
-      vibrationInit(data, nSets, natom);
+      visu_vibration_init(data, nSets, natom);
       for (i = 0; i < nSets; i++)
 	{
 	  omega = 1.f;
-	  pt = strstr(visuDataGet_fileCommentary(data, i), "freq=");
+	  pt = strstr(visu_data_getFileCommentary(data, i), "freq=");
 	  if (pt)
 	    sscanf(pt + 5, "%f", &omega);
 	  if (omega < 0.)
 	    g_warning("Negative phonon frequency (%f).", omega);
-	  vibrationSet_characteristic(data, i, qpt, 0.f, omega);
+	  visu_vibration_setCharacteristic(data, i, qpt, 0.f, omega);
 	}
-      vibrationSet_displacements(data, nSet, dcoord, FALSE);
+      visu_vibration_setDisplacements(data, nSet, dcoord, FALSE);
       g_free(dcoord);
     }
 
