@@ -42,7 +42,6 @@
 	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
 */
 #include <glib.h>
-#include <glib/gstdio.h>
 
 #include "renderingAtomic.h"
 #include "renderingAtomic_ascii.h"
@@ -51,18 +50,27 @@
 #include <visu_basic.h>
 #include <visu_elements.h>
 #include <visu_configFile.h>
-#include <renderingBackend/visu_windowInterface.h>
 #include <openGLFunctions/view.h>
 #include <openGLFunctions/objectList.h>
 #include <opengl.h>
 #include <coreTools/toolConfigFile.h>
-#include <coreTools/toolElements.h>
+#include <coreTools/toolPhysic.h>
 
 #include <GL/gl.h>
 #include <GL/glu.h> 
 
 #include <math.h>
 
+/**
+ * SECTION:renderingAtomic
+ * @short_description: A rendering method to draw atoms positioned in
+ * a box.
+ *
+ * <para> This the main part of a rendering method made to represent
+ * atomic positions. It draws either spheres or cubes depending of the
+ * elements properties. The radius (for the sphere) or the length of
+ * the sides of the cubes can be tuned.</para>
+ */
 
 /* The OpenGL identifier to store the glObjectLists that
    describe the spheres. */
@@ -83,7 +91,7 @@ static GLuint tindices[20][3] = {
    {6,1,10}, {9,0,11}, {9,11,2}, {9,2,5}, {7,2,11} };
 
 #define RADIUS_DEFAULT 1.
-#define SHAPE_DEFAULT shapeSphere
+#define SHAPE_DEFAULT VISU_RENDERING_ATOMIC_SPHERE
 #define RATIO_DEFAULT 2.
 #define PHI_DEFAULT  0.
 #define THETA_DEFAULT 90.
@@ -105,12 +113,13 @@ enum
     sphere_icosahedron,
     sphere_nb
   };
-static guint sphereMethod = sphere_icosahedron;
+static guint sphereMethod = sphere_glu;
 const char* sphereName[sphere_nb + 1] = {"GluSphere", "Icosahedron", (const char*)0};
 
 const char* shapeName[nbAtomicShapes + 1] = {"Sphere", "Cube", "Elipsoid", "Point", "Torus", (const char*)0};
 const char* shapeNameI18n[nbAtomicShapes + 1];
-struct atomicResources_struct
+
+struct atomicResources
 {
   /* One of this structure is associated to each element. */
 
@@ -123,86 +132,72 @@ struct atomicResources_struct
   float phi, theta;
 
   /* The shape used. */
-  int shape;
+  VisuAtomicShapeId shape;
 
   /* An id of the list associated with the form. */
   int openGLIdentifier;
 };
 
+/* Local callbacks. */
+static void visu_rendering_atomic_dispose(GObject* obj);
+static void visu_rendering_atomic_finalize(GObject* obj);
+static int createShape(VisuElement* ele, VisuOpenGLCamera *camera, guint winSize);
+static void positionShape(VisuData *visuData, VisuNode *node, VisuElement* ele);
 
-static VisuRendering *atom;
-/* To build a list of rendering loading methods. */
-/* This list contains all the method than can load an atomic file. */
-static GList *allAtomicLoadingMethods;
-static VisuRendering* atomic = (VisuRendering*)0;
+/**
+ * VisuRenderingAtomic:
+ *
+ * An opaque structure.
+ */
+struct _VisuRenderingAtomic
+{
+  VisuRendering method;
 
-static struct atomicResources_struct *getRadiusAndShape(VisuElement *ele);
+  gboolean dispose_has_run;
+};
 
-void renderingAtomicInit()
+/**
+ * VisuRenderingAtomicClass:
+ *
+ * An opaque structure.
+ */
+struct _VisuRenderingAtomicClass
+{
+  VisuRenderingClass parent_class;
+};
+
+static VisuRenderingAtomic *atomic = (VisuRenderingAtomic*)0;
+
+G_DEFINE_TYPE(VisuRenderingAtomic, visu_rendering_atomic, VISU_RENDERING_TYPE)
+
+static void visu_rendering_atomic_class_init(VisuRenderingAtomicClass *klass)
 {
-  char *name = _("Atom visualisation");
-  char *descr = _("It draws spheres at specified positions to represent atoms."
-		  " The radius of the sphere can vary.");
-  gchar *iconPath;
-  GList *formatList;
   VisuConfigFileEntry *resourceEntry;
-  GList *tmpLst;
-  RenderingFormatLoad *meth;
 
-  DBG_fprintf(stderr,"Initialising the atomic rendering method...\n");
-  formatList = (GList*)0;
-  allAtomicLoadingMethods = (GList*)0;
+  DBG_fprintf(stderr, "Visu RenderingAtomic: creating the class of the object.\n");
 
-  meth = atomicD3Init();
-  if (meth)
-    allAtomicLoadingMethods = g_list_prepend(allAtomicLoadingMethods, meth);
-  meth = atomicAsciiInit();
-  if (meth)
-    allAtomicLoadingMethods = g_list_prepend(allAtomicLoadingMethods, meth);
-  meth = atomicXyzInit();
-  if (meth)
-    allAtomicLoadingMethods = g_list_prepend(allAtomicLoadingMethods, meth);
-  allAtomicLoadingMethods = g_list_sort(allAtomicLoadingMethods,
-					visuRenderingFormatCompare_priority);
-  tmpLst = allAtomicLoadingMethods;
-  while (tmpLst)
-    {
-      formatList = g_list_append(formatList, ((RenderingFormatLoad*)tmpLst->data)->fmt);
-      tmpLst = g_list_next(tmpLst);
-    }
-
-  atom = visuRendering_new(VISU_RENDERING_ATOMIC, name, descr,
-			   1, renderingAtomicLoad,
-			   renderingAtomic_createShape,
-			   renderingAtomic_positionShape,
-			   renderingAtomicGet_radius);
-  visuRenderingSet_fileType(atom, formatList, 0, _("Position files"));
-  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "stock-atomic.png", NULL);
-  visuRenderingSet_icon(atom, iconPath);
-  g_free(iconPath);
+  /* Connect freeing methods. */
+  G_OBJECT_CLASS(klass)->dispose = visu_rendering_atomic_dispose;
+  G_OBJECT_CLASS(klass)->finalize = visu_rendering_atomic_finalize;
+  VISU_RENDERING_CLASS(klass)->createElement = createShape;
+  VISU_RENDERING_CLASS(klass)->createNode    = positionShape;
+  VISU_RENDERING_CLASS(klass)->getNodeExtend = visu_renderingAtomic_getRadius;
 
   /* Dealing with config files. */
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
 					  FLAG_RESOURCE_RADIUS_SHAPE,
 					  DESC_RESOURCE_RADIUS_SHAPE,
 					  1, readAtomicRadiusShape);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
 				   exportAtomicRadiusShape);
-  resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 					  FLAG_PARAMETER_SHAPE,
 					  DESC_PARAMETER_SHAPE,
 					  1, readAtomicShape);
-  visuConfigFileSet_version(resourceEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportAtomicShape);
 					  
-
-  /* Initialise the OpenGl part. */
-/*   identifierSpheres = openGLObjectList_new(NMAX_TP); */
-
-  /* Set the general pointer to retrieve easily this method. */
-  atomic = atom;
-
   shapeNameI18n[0] = _("Sphere");
   shapeNameI18n[1] = _("Cube");
   shapeNameI18n[2] = _("Elipsoid");
@@ -210,131 +205,152 @@ void renderingAtomicInit()
   shapeNameI18n[4] = _("Torus");
   shapeNameI18n[5] = (const char*)0;
 }
-
-gboolean renderingAtomicLoad(VisuData *data, FileFormat *format _U_,
-			     int nSet, GError **error)
+static void visu_rendering_atomic_dispose(GObject* obj)
 {
-  gchar *file;
-  gboolean loadOk;
-  GList *tmpLst;
-  FileFormat *fmt;
-  RenderingFormatLoad *load;
-#if GLIB_MINOR_VERSION > 5
-  struct stat buf;
-#endif
+  DBG_fprintf(stderr, "Visu RenderingAtomic: dispose object %p.\n", (gpointer)obj);
 
-  g_return_val_if_fail(error && *error == (GError*)0, FALSE);
+  if (VISU_RENDERING_ATOMIC(obj)->dispose_has_run)
+    return;
 
-  if (!data)
-    return 0;
+  VISU_RENDERING_ATOMIC(obj)->dispose_has_run = TRUE;
 
-  file = visuDataGet_file(data, 0, &fmt);
-  if (!file)
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			   _("No file name available."));
-      return FALSE;
-    }
-  
-  if (!g_file_test(file, G_FILE_TEST_IS_REGULAR))
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			   _("The specified file is"
-			     " not a regular file."));
-      return FALSE;
-    }
-#if GLIB_MINOR_VERSION > 5
-  if (!g_stat(file, &buf) && buf.st_size == 0)
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			   _("The specified file is"
-			     " an empty file."));
-      return FALSE;
-    }
-#endif
-  
-  loadOk = FALSE;
-  tmpLst = allAtomicLoadingMethods;
-  while (tmpLst && !loadOk)
-    {
-      /* Each load may set error even if the format is not recognise
-	 and loadOK is FALSE, then we need to free the error. */
-      if (*error)
-	g_error_free(*error);
-      *error = (GError*)0;
-      load = (RenderingFormatLoad*)tmpLst->data;
-      if (!fmt || load->fmt == fmt)
-	{
-	  DBG_fprintf(stderr,"Rendering Atomic: testing '%s' with format: %s.\n",
-		      file, load->name);
-	  loadOk = load->load(data, file, load->fmt, nSet, error);
-	  DBG_fprintf(stderr,"Rendering Atomic: with format '%s' returns %d.\n",
-		      load->name, loadOk);
-	}
-      if (*error && (*error)->domain == G_FILE_ERROR)
-	return FALSE;
-      
-      if (fmt && load->fmt == fmt)
-	tmpLst = (GList*)0;
-      else
-	tmpLst = g_list_next(tmpLst);
-    }
+  /* Chain up to the parent class */
+  G_OBJECT_CLASS(visu_rendering_atomic_parent_class)->dispose(obj);
+}
+static void visu_rendering_atomic_finalize(GObject* obj)
+{
+  VisuRenderingAtomicClass *klass;
+  VisuRenderingAtomic *meth;
 
-  if (!loadOk)
-    {
-      if (*error)
-	g_error_free(*error);
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
-			   _("Impossible to load this file, unrecognised format.\n"));
-      return FALSE;
-    }
-  else if (*error)
-    return FALSE;
+  DBG_fprintf(stderr, "Visu RenderingAtomic: finalize object %p.\n", (gpointer)obj);
 
-  return TRUE;
+  meth = VISU_RENDERING_ATOMIC(obj);
+  klass = VISU_RENDERING_ATOMIC_GET_CLASS(meth);
+
+  /* Chain up to the parent class */
+  G_OBJECT_CLASS(visu_rendering_atomic_parent_class)->finalize(obj);
 }
 
-static struct atomicResources_struct *getRadiusAndShape(VisuElement *ele)
+static void visu_rendering_atomic_init(VisuRenderingAtomic *obj)
 {
-  struct atomicResources_struct *str;
+  DBG_fprintf(stderr, "Visu renderingAtomic: initializing a new object (%p).\n",
+	      (gpointer)obj);
 
-  g_return_val_if_fail(ele, (struct atomicResources_struct*)0);
+  obj->dispose_has_run = FALSE;
 
-  str = (struct atomicResources_struct*)visuElementGet_property
-    (ele, "radiusAndShape");
+  g_return_if_fail((atomic == (VisuRenderingAtomic*)0));
+  atomic = obj;
+}
+
+static struct atomicResources *getRadiusAndShape(VisuElement *ele);
+
+/**
+ * visu_rendering_atomic_new:
+ *
+ * Create the structure and initialise its values.
+ *
+ * Since: 3.6
+ *
+ * Returns: a newly allocate #VisuRenderingAtomic object.
+ */
+VisuRenderingAtomic* visu_rendering_atomic_new()
+{
+  char *descr = _("It draws spheres at specified positions to represent atoms."
+		  " The radius of the sphere can vary.");
+  gchar *iconPath;
+  VisuRenderingAtomic* atom;
+
+  DBG_fprintf(stderr,"Initialising the atomic rendering method...\n");
+  atom = VISU_RENDERING_ATOMIC(g_object_new(VISU_RENDERING_ATOMIC_TYPE,
+                                            "name", VISU_RENDERING_ATOMIC_NAME,
+                                            "label", _(VISU_RENDERING_ATOMIC_NAME),
+                                            "description", descr, 
+                                            "nFiles", 1, NULL));
+  visu_rendering_setFileTypeLabel(VISU_RENDERING(atom), 0, _("Position files"));
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "stock-atomic.png", NULL);
+  visu_rendering_setIcon(VISU_RENDERING(atom), iconPath);
+  g_free(iconPath);
+
+  initAtomicD3(VISU_RENDERING(atom));
+  initAtomicAscii(VISU_RENDERING(atom));
+  initAtomicXyz(VISU_RENDERING(atom));
+
+  return atom;
+}
+
+static struct atomicResources *getRadiusAndShape(VisuElement *ele)
+{
+  struct atomicResources *str;
+
+  g_return_val_if_fail(ele, (struct atomicResources*)0);
+
+  DBG_fprintf(stderr, "Rendering Atomic: get resource structure (%s - %p)...\n",
+              ele->name, (gpointer)ele);
+  str = (struct atomicResources*)g_object_get_data(G_OBJECT(ele), "radiusAndShape");
   if (!str)
     {
-      str = g_malloc(sizeof(struct atomicResources_struct));
-      if (!toolElementsGet_elementFromSymbol((int*)0, &str->radius, ele->name))
+      DBG_fprintf(stderr, "Rendering Atomic: create a new resource structure for '%s'.\n",
+                  ele->name);
+      str = g_malloc(sizeof(struct atomicResources));
+      if (!tool_physic_getElementFromSymbol((int*)0, &str->radius, ele->name))
 	str->radius = RADIUS_DEFAULT;
       str->shape  = SHAPE_DEFAULT;
       str->ratio  = RATIO_DEFAULT;
       str->phi    = PHI_DEFAULT;
       str->theta  = THETA_DEFAULT;
-      str->openGLIdentifier = openGLObjectList_new(1);
+      str->openGLIdentifier = visu_openGL_objectList_new(1);
 
-      visuElementSet_property(ele, "radiusAndShape", (gpointer)str);
+      g_object_set_data(G_OBJECT(ele), "radiusAndShape", (gpointer)str);
     }
   return str;
 }
 
-float renderingAtomicGet_radius(VisuElement *ele)
+/**
+ * visu_renderingAtomic_getRadius:
+ * @ele: a #VisuElement object.
+ *
+ * In the rendering atomic method, shapes are characterized by
+ * a radius. This method gets it for the specified element. If this
+ * element has no radius defined yet, the default value is
+ * associated and returned.
+ *
+ * Returns: the radius of the specified element. A negative value if something
+ *          goies wrong.
+ */
+float visu_renderingAtomic_getRadius(VisuElement *ele)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele, RADIUS_DEFAULT);
 
+  DBG_fprintf(stderr, "Rendering Atomic: get radius.\n");
   str = getRadiusAndShape(ele);
   g_return_val_if_fail(str, -1.f);
   return str->radius;
 }
-float renderingAtomicGet_radiusDefault()
+/**
+ * visu_renderingAtomic_getRadiusDefault:
+ *
+ * This method gets the default radius of the rendering atomic method.
+ *
+ * Returns: the default value for radius resource.
+ */
+float visu_renderingAtomic_getRadiusDefault()
 {
   return RADIUS_DEFAULT;
 }
-gboolean renderingAtomicSet_radius(VisuElement* ele, float value)
+/**
+ * visu_renderingAtomic_setRadius:
+ * @ele: a #VisuElement object ;
+ * @value: a positive floating point value.
+ *
+ * This change the radius value of element @ele to @value.
+ *
+ * Returns: 1 if a call to visu_rendering_createElement() is required, 0 if not.
+ */
+gboolean visu_renderingAtomic_setRadius(VisuElement* ele, float value)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele && value > 0.f, FALSE);
   
@@ -346,41 +362,88 @@ gboolean renderingAtomicSet_radius(VisuElement* ele, float value)
   else
     str->radius = value;
 
-  visuRenderingEmit_elementSize(atom, value);
+  DBG_fprintf(stderr, "Rendering Atomic: emit 'elementSizeChanged'.\n");
+  if (atomic)
+    g_signal_emit_by_name(G_OBJECT(atomic), "elementSizeChanged", value, NULL);
+  DBG_fprintf(stderr, "Rendering Atomic: emission done.\n");
 
   /* Ask for reDraw if needed. */
   return TRUE;
 }
 
-int renderingAtomicGet_shape(VisuElement *ele)
+/**
+ * visu_renderingAtomic_getShape:
+ * @ele: a #VisuElement object.
+ *
+ * In the rendering atomic method, shapes are multiple.
+ * This method gets it for the specified element. Shapes are
+ * characterized by their id, corresponding to an integer value.
+ * Use the enum #VisuAtomicShapeId to associate an integer value
+ * to a specific shape.
+ *
+ * Returns: the shape id of the element @ele.
+ */
+VisuAtomicShapeId visu_renderingAtomic_getShape(VisuElement *ele)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   str = getRadiusAndShape(ele);
   g_return_val_if_fail(str, FALSE);
 
   return str->shape;
 }
-const char* renderingAtomicGet_shapeName(int shape)
+/**
+ * visu_renderingAtomic_getShapeName:
+ * @shape: an integer.
+ *
+ * This method does the corresponding between a shape id and
+ * its name (a string value).
+ *
+ * Returns: the name associated to a shape.
+ */
+const char* visu_renderingAtomic_getShapeName(VisuAtomicShapeId shape)
 {
-  if (shape < 0 || shape >= nbAtomicShapes)
-    return (char*)0;
+  if (shape >= nbAtomicShapes)
+    return (const char*)0;
   else
     return shapeName[shape];
 }
-const char* renderingAtomicGet_shapeNameDefault()
+/**
+ * visu_renderingAtomic_getShapeNameDefault:
+ *
+ * This method is used to retrieve the default name for shapes.
+ *
+ * Returns: the name associated to the default shape.
+ */
+const char* visu_renderingAtomic_getShapeNameDefault()
 {
   return shapeName[SHAPE_DEFAULT];
 }
-int renderingAtomicGet_shapeDefault()
+/**
+ * visu_renderingAtomic_getShapeDefault:
+ *
+ * This method gets the default shape.
+ *
+ * Returns: the default shape id.
+ */
+VisuAtomicShapeId visu_renderingAtomic_getShapeDefault()
 {
   return SHAPE_DEFAULT;
 }
-int renderingAtomicSet_shape(VisuElement *ele, int shape)
+/**
+ * visu_renderingAtomic_setShape:
+ * @ele: a #VisuElement object ;
+ * @shape: an integer.
+ *
+ * This changes the shape of the element @ele to the shape defined by its id.
+ *
+ * Returns: 1 if a call to visu_rendering_createElement() is required, 0 if not.
+ */
+int visu_renderingAtomic_setShape(VisuElement *ele, VisuAtomicShapeId shape)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
-  g_return_val_if_fail(ele && shape >= 0 && shape < nbAtomicShapes, 0);
+  g_return_val_if_fail(ele && shape < nbAtomicShapes, 0);
   
   str = getRadiusAndShape(ele);
   g_return_val_if_fail(str, FALSE);
@@ -393,7 +456,17 @@ int renderingAtomicSet_shape(VisuElement *ele, int shape)
   return 1;
 }
 
-int renderingAtomicSet_shapeFromName(VisuElement *ele, char* shape)
+/**
+ * visu_renderingAtomic_setShapeFromName:
+ * @ele: a #VisuElement object ;
+ * @shape: a string.
+ *
+ * This method is equivalent to visu_renderingAtomic_setShape() but the shape is
+ * defined by its name.
+ *
+ * Returns: 1 if a call to visu_rendering_createElement() is required, 0 if not.
+ */
+int visu_renderingAtomic_setShapeFromName(VisuElement *ele, const char* shape)
 {
   int res, i;
 
@@ -405,24 +478,54 @@ int renderingAtomicSet_shapeFromName(VisuElement *ele, char* shape)
     }
   if (res < 0)
     {
-      g_warning("Unknown shape name in the call of renderingAtomicSet_shapeFromName.");
+      g_warning("Unknown shape name in the call of visu_renderingAtomic_setShapeFromName.");
       return 0;
     }
   else
-    return renderingAtomicSet_shape(ele, res);
+    return visu_renderingAtomic_setShape(ele, res);
 }
-const char** renderingAtomicGet_allShapes()
+/**
+ * visu_renderingAtomic_getAllShapes:
+ *
+ * This methods retrieve the whole list of shape names used by V_Sim for example
+ * in the resources file. These names are not translated. If internationalized
+ * names are required, use visu_renderingAtomic_getAllShapesI18n() instead.
+ *
+ * Returns: (transfer none) (array zero-terminated=1) (element-type filename): a pointer to a list of shape names (should not be modified or freed).
+ */
+const char** visu_renderingAtomic_getAllShapes()
 {
   return shapeName;
 }
-const char** renderingAtomicGet_allShapesI18n()
+/**
+ * visu_renderingAtomic_getAllShapesI18n:
+ *
+ * This methods retrieve the whole list of shape names, translated strings.
+ *
+ * Returns: (transfer none) (array zero-terminated=1) (element-type utf8): a pointer to a list of shape names (should not be modified or freed).
+ */
+const char** visu_renderingAtomic_getAllShapesI18n()
 {
   return shapeNameI18n;
 }
-gboolean renderingAtomicSet_elipsoidParameters(VisuElement *ele, float ratio,
+/**
+ * visu_renderingAtomic_setElipsoidParameters:
+ * @ele: a #VisuElement object ;
+ * @ratio: a float ;
+ * @phi: a float ;
+ * @theta: a float.
+ *
+ * Change the parameters for the elipsoid shape for the given @ele.
+ * These parameters include a @ratio which is the ratio of the
+ * long axis on the short one. Thus @ratio is always equal or greater than 1.
+ * Arguments @theta and @phi are the direction of the long axis.
+ *
+ * Returns: TRUE if visu_rendering_createElement() should be called.
+ */
+gboolean visu_renderingAtomic_setElipsoidParameters(VisuElement *ele, float ratio,
 					       float phi, float theta)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
   gboolean refresh;
 
   g_return_val_if_fail(ele && (ratio >= 1.), 0);
@@ -447,11 +550,20 @@ gboolean renderingAtomicSet_elipsoidParameters(VisuElement *ele, float ratio,
       refresh = TRUE;
     }
 
-  return refresh && (str->shape == shapeElipsoid || str->shape == shapeTorus);
+  return refresh && (str->shape == VISU_RENDERING_ATOMIC_ELLIPSOID || str->shape == VISU_RENDERING_ATOMIC_TORUS);
 }
-gboolean renderingAtomicSet_elipsoidRatio(VisuElement *ele, float ratio)
+/**
+ * visu_renderingAtomic_setElipsoidRatio:
+ * @ele: a #VisuElement object.
+ * @ratio: a float ;
+ *
+ * Set the ratio parameter of the elipsoid shape for the element @ele.
+ *
+ * Returns: TRUE if visu_rendering_createElement() should be called.
+ */
+gboolean visu_renderingAtomic_setElipsoidRatio(VisuElement *ele, float ratio)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele && (ratio >= 1.), FALSE);
   
@@ -461,13 +573,22 @@ gboolean renderingAtomicSet_elipsoidRatio(VisuElement *ele, float ratio)
   if (ratio != str->ratio)
     {
       str->ratio = ratio;
-      return (str->shape == shapeElipsoid || str->shape == shapeTorus);
+      return (str->shape == VISU_RENDERING_ATOMIC_ELLIPSOID || str->shape == VISU_RENDERING_ATOMIC_TORUS);
     }
   return FALSE;
 }
-gboolean renderingAtomicSet_elipsoidPhi(VisuElement *ele, float phi)
+/**
+ * visu_renderingAtomic_setElipsoidPhi:
+ * @ele: a #VisuElement object.
+ * @phi: a float ;
+ *
+ * Set the phi angle parameter of the elipsoid shape for the element @ele.
+ *
+ * Returns: TRUE if visu_rendering_createElement() should be called.
+ */
+gboolean visu_renderingAtomic_setElipsoidPhi(VisuElement *ele, float phi)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele, FALSE);
   
@@ -477,13 +598,22 @@ gboolean renderingAtomicSet_elipsoidPhi(VisuElement *ele, float phi)
   if (phi != str->phi)
     {
       str->phi = phi;
-      return (str->shape == shapeElipsoid || str->shape == shapeTorus);
+      return (str->shape == VISU_RENDERING_ATOMIC_ELLIPSOID || str->shape == VISU_RENDERING_ATOMIC_TORUS);
     }
   return FALSE;
 }
-gboolean renderingAtomicSet_elipsoidTheta(VisuElement *ele, float theta)
+/**
+ * visu_renderingAtomic_setElipsoidTheta:
+ * @ele: a #VisuElement object.
+ * @theta: a float.
+ *
+ * Set the theta angle parameter of the elipsoid shape for the element @ele.
+ *
+ * Returns: TRUE if visu_rendering_createElement() should be called.
+ */
+gboolean visu_renderingAtomic_setElipsoidTheta(VisuElement *ele, float theta)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele, FALSE);
   
@@ -493,41 +623,65 @@ gboolean renderingAtomicSet_elipsoidTheta(VisuElement *ele, float theta)
   if (theta != str->theta)
     {
       str->theta = theta;
-      return (str->shape == shapeElipsoid || str->shape == shapeTorus);
+      return (str->shape == VISU_RENDERING_ATOMIC_ELLIPSOID || str->shape == VISU_RENDERING_ATOMIC_TORUS);
     }
   return FALSE;
 }
-float renderingAtomicGet_elipsoidRatio(VisuElement *ele)
+/**
+ * visu_renderingAtomic_getElipsoidRatio:
+ * @ele: a #VisuElement object.
+ *
+ * Retrieve the ratio parameter of the elipsoid shape for the element @ele.
+ *
+ * Returns: the ratio of the elipsoid.
+ */
+float visu_renderingAtomic_getElipsoidRatio(VisuElement *ele)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele, RATIO_DEFAULT);
 
-  str = (struct atomicResources_struct*)visuElementGet_property(ele, "radiusAndShape");
+  str = (struct atomicResources*)g_object_get_data(G_OBJECT(ele), "radiusAndShape");
   if (str)
     return str->ratio;
   else
     return RATIO_DEFAULT;
 }
-float renderingAtomicGet_elipsoidPhi(VisuElement *ele)
+/**
+ * visu_renderingAtomic_getElipsoidPhi:
+ * @ele: a #VisuElement object.
+ *
+ * Retrieve the phi angle parameter of the elipsoid shape for the element @ele.
+ *
+ * Returns: the phi angle of the elipsoid.
+ */
+float visu_renderingAtomic_getElipsoidPhi(VisuElement *ele)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele, PHI_DEFAULT);
 
-  str = (struct atomicResources_struct*)visuElementGet_property(ele, "radiusAndShape");
+  str = (struct atomicResources*)g_object_get_data(G_OBJECT(ele), "radiusAndShape");
   if (str)
     return str->phi;
   else
     return PHI_DEFAULT;
 }
-float renderingAtomicGet_elipsoidTheta(VisuElement *ele)
+/**
+ * visu_renderingAtomic_getElipsoidTheta:
+ * @ele: a #VisuElement object.
+ *
+ * Retrieve the theta angle parameter of the elipsoid shape for the element @ele.
+ *
+ * Returns: the theta angle of the elipsoid.
+ */
+float visu_renderingAtomic_getElipsoidTheta(VisuElement *ele)
 {
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_return_val_if_fail(ele, THETA_DEFAULT);
 
-  str = (struct atomicResources_struct*)visuElementGet_property(ele, "radiusAndShape");
+  str = (struct atomicResources*)g_object_get_data(G_OBJECT(ele), "radiusAndShape");
   if (str)
     return str->theta;
   else
@@ -551,14 +705,14 @@ static gboolean readAtomicRadiusShape(gchar **lines, int nbLines, int position,
   token = 0;
 
   /* Get the two elements. */
-  if (!configFileRead_elementFromTokens(tokens, &token, &ele, 1, position, error))
+  if (!tool_configFile_readElementFromTokens(tokens, &token, &ele, 1, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
     }
 
   /* Read 1 int. */
-  if (!configFileRead_floatFromTokens(tokens, &token, &radius, 1, position, error))
+  if (!tool_configFile_readFloatFromTokens(tokens, &token, &radius, 1, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
@@ -566,7 +720,7 @@ static gboolean readAtomicRadiusShape(gchar **lines, int nbLines, int position,
   radius = CLAMP(radius, 0., G_MAXFLOAT);
 
   /* Read 1 string. */
-  if (!configFileRead_stringFromTokens(tokens, &token, &shape, 1, position, error))
+  if (!tool_configFile_readStringFromTokens(tokens, &token, &shape, 1, position, error))
     {
       g_strfreev(tokens);
       return FALSE;
@@ -579,16 +733,16 @@ static gboolean readAtomicRadiusShape(gchar **lines, int nbLines, int position,
       if (!strcmp(shapeName[i], shape[0]))
 	shapeNum = i;
     }
-  g_free(shape);
   if (shapeNum < 0)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: the shape '%s' is unknown.\n"),
 			   position, shape[0]);
       return FALSE;
     }
-  renderingAtomicSet_radius(ele, radius);
-  renderingAtomicSet_shape(ele, shapeNum);
+  g_strfreev(shape);
+  visu_renderingAtomic_setRadius(ele, radius);
+  visu_renderingAtomic_setShape(ele, shapeNum);
 
   return TRUE;
 }
@@ -598,7 +752,7 @@ static void exportAtomicRadiusShape(GString *data, VisuData *dataObj)
 {
   GList *pos, *eleList;
   unsigned int i;
-  struct atomicResources_struct *str;
+  struct atomicResources *str;
 
   g_string_append_printf(data, "# %s\n", DESC_RESOURCE_RADIUS_SHAPE);
   /* We create a list of elements, or get the whole list. */
@@ -610,11 +764,10 @@ static void exportAtomicRadiusShape(GString *data, VisuData *dataObj)
       pos = eleList;
     }
   else
-    pos = visuElementGet_allElements();
+    pos = (GList*)visu_element_getAllElements();
   while(pos)
     {
-      str = (struct atomicResources_struct*)
-	visuElementGet_property((VisuElement*)pos->data, "radiusAndShape");
+      str = (struct atomicResources*)g_object_get_data(G_OBJECT(pos->data), "radiusAndShape");
       if (str)
 	{
 	  g_string_append_printf(data, "%s:\n", FLAG_RESOURCE_RADIUS_SHAPE);
@@ -637,7 +790,7 @@ static gboolean readAtomicShape(gchar **lines, int nbLines, int position,
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_string(lines[0], position, &vals, 1, FALSE, error))
+  if (!tool_configFile_readString(lines[0], position, &vals, 1, FALSE, error))
     return FALSE;
 
   for (i = 0; i < sphere_nb; i++)
@@ -648,7 +801,7 @@ static gboolean readAtomicShape(gchar **lines, int nbLines, int position,
       }
   if (i == sphere_nb)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: the sphere method '%s' is unknown.\n"),
 			   position, vals[0]);
       g_strfreev(vals);
@@ -669,22 +822,19 @@ static void exportAtomicShape(GString *data, VisuData* dataObj _U_)
 /* OpenGL part */
 /***************/
 
-void renderingAtomic_positionShape(VisuData *visuData, VisuNode *node, VisuElement* ele)
+static void positionShape(VisuData *visuData, VisuNode *node, VisuElement* ele)
 {
   float rgba[4];
   float xyz[3];
   float scale;
 
-  visuDataGet_nodePosition(visuData, node, xyz);
-  scale = visuDataGet_nodeScalingFactor(visuData, node);
+  visu_data_getNodePosition(visuData, node, xyz);
+  scale = visu_data_getNodeScalingFactor(visuData, node);
 
   glPushMatrix();
   glTranslated(xyz[0], xyz[1], xyz[2]);
-  if (visuData->setColor)
-    {
-      visuData->setColor(visuData, rgba, ele, node);
-      openGLSet_color(ele->material, rgba);
-    }
+  if (visu_data_getUserColor(visuData, ele, node, rgba))
+    openGLSet_color(ele->material, rgba);
   glScalef(scale, scale, scale);
   glCallList(ele->openGLIdentifier);
   glPopMatrix();
@@ -698,10 +848,10 @@ static void drawtriangle(float *v1, float *v2, float *v3)
    glEnd(); 
 }
 static void normalize(float v[3]) {    
-   GLfloat d = sqrt(v[0]*v[0]+v[1]*v[1]+v[2]*v[2]); 
+   GLfloat d = 1.f / sqrt(v[0]*v[0]+v[1]*v[1]+v[2]*v[2]); 
 
    g_return_if_fail(d > 0.);
-   v[0] /= d; v[1] /= d; v[2] /= d; 
+   v[0] *= d; v[1] *= d; v[2] *= d; 
 }
 static void subdivide(float *v1, float *v2, float *v3, int depth) 
 { 
@@ -727,22 +877,18 @@ static void subdivide(float *v1, float *v2, float *v3, int depth)
   subdivide(v3, v31, v23, depth - 1);    
   subdivide(v12, v23, v31, depth - 1); 
 }
-int renderingAtomic_createShape(VisuData *visuData, VisuElement* ele)
+static int createShape(VisuElement* ele, VisuOpenGLCamera *camera, guint winSize)
 {
-  struct atomicResources_struct *str;
-  OpenGLView *view;
+  struct atomicResources *str;
   int nlat, i, nfac;
   GLUquadricObj *obj;
 
-  obj = gluNewQuadric();
-
-  g_return_val_if_fail(visuData && ele, -1);
+  g_return_val_if_fail(ele, -1);
 
   str = getRadiusAndShape(ele);
   g_return_val_if_fail(str, -1);
 
-  view = visuDataGet_openGLView(visuData);
-  nlat = OpenGLViewGet_numberOfFacettes(view, str->radius);
+  nlat = VisuOpenGLCameraGet_numberOfFacettes(camera, winSize, str->radius);
 
   DBG_fprintf(stderr, "Rendering Atomic: creating '%s' for %s (%d - OpenGL id"
 	      " %d - fac %d)\n", shapeName[str->shape],
@@ -751,17 +897,18 @@ int renderingAtomic_createShape(VisuData *visuData, VisuElement* ele)
   if (nlat < 0)
     return -1;
    
+  obj = gluNewQuadric();
   glNewList(str->openGLIdentifier, GL_COMPILE);
   switch (str->shape)
     {
-    case shapeSphere:
+    case VISU_RENDERING_ATOMIC_SPHERE:
       DBG_fprintf(stderr, " | use sphere method %d\n", sphereMethod);
       if (sphereMethod == sphere_glu)
 	gluSphere(obj, (double)str->radius, nlat, nlat);
       else if (sphereMethod == sphere_icosahedron)
 	{
 	  nfac = (int)(log((float)(nlat + 2) / 4.f) / log(2.f));
-	  DBG_fprintf(stderr, " | glusphere vs. dodecahedron %dx%d\n",
+	  DBG_fprintf(stderr, " | glusphere vs. icosahedron %dx%d\n",
 		      nlat * nlat, 20 * (int)pow(4, nfac));
 	  glPushMatrix();
 	  glScalef(str->radius, str->radius, str->radius);
@@ -776,7 +923,7 @@ int renderingAtomic_createShape(VisuData *visuData, VisuElement* ele)
       else
 	g_warning("Wrong sphere method.");
       break;
-    case shapeElipsoid:
+    case VISU_RENDERING_ATOMIC_ELLIPSOID:
       glPushMatrix();
       glRotatef(str->phi, 0., 0., 1.);
       glRotatef(str->theta, 0., 1., 0.);
@@ -784,15 +931,15 @@ int renderingAtomic_createShape(VisuData *visuData, VisuElement* ele)
       gluSphere(obj, (double)str->radius, nlat, nlat);
       glPopMatrix();
       break;
-    case shapePoint:
+    case VISU_RENDERING_ATOMIC_POINT:
       glPushMatrix();
-      glPointSize(MAX(1, (int)(str->radius * view->camera->gross * 5.)));
+      glPointSize(MAX(1, (int)(str->radius * camera->gross * 5.)));
       glBegin(GL_POINTS);
       glVertex3f(0., 0., 0.);
       glEnd();
       glPopMatrix();
       break;
-    case shapeCube:
+    case VISU_RENDERING_ATOMIC_CUBE:
       glBegin(GL_QUADS);
 
       glNormal3f(0., 0., 1.);
@@ -833,36 +980,24 @@ int renderingAtomic_createShape(VisuData *visuData, VisuElement* ele)
 
       glEnd();
       break;
-    case shapeTorus:
+    case VISU_RENDERING_ATOMIC_TORUS:
       
       glPushMatrix();
       glRotatef(str->phi, 0., 0., 1.);
       glRotatef(str->theta, 0., 1., 0.);
-      openGLObjectListDraw_torus(obj, 0, str->radius, str->ratio, nlat, nlat, FALSE);
+      visu_openGL_drawTorus(obj, 0, str->radius, str->ratio, nlat, nlat, FALSE);
       glPopMatrix();
       
       break;
-	
+    default:
+      g_warning("Unsupported shape id.");
     }
   glEndList();
-
   gluDeleteQuadric(obj);
    
 /*   ele->openGLIdentifier = identifierSpheres + ele->typeNumber; */
   DBG_fprintf(stderr, " | shape created %d\n", str->openGLIdentifier);
-  return str->openGLIdentifier;
-}
+  ele->openGLIdentifier = str->openGLIdentifier;
 
-void renderingAtomicAdd_loadMethod(RenderingFormatLoad* meth)
-{
-  g_return_if_fail(meth && meth->load);
-  g_return_if_fail(atomic);
-
-  DBG_fprintf(stderr, "Rendering Atomic: adding a new loading method '%s'.\n",
-	      meth->name);
-  allAtomicLoadingMethods = g_list_prepend(allAtomicLoadingMethods, meth);
-  allAtomicLoadingMethods = g_list_sort(allAtomicLoadingMethods,
-					visuRenderingFormatCompare_priority);
-  if (meth->fmt)
-    visuRenderingAdd_fileFormat(atomic, meth->fmt, 0);
+  return (str->openGLIdentifier);
 }
