@@ -50,6 +50,7 @@
 #include "renderingAtomic.h"
 #include <visu_rendering.h>
 #include <visu_data.h>
+#include <coreTools/toolPhysic.h>
 #include <extraFunctions/extraNode.h>
 #include <extraFunctions/vibration.h>
 
@@ -71,99 +72,157 @@
  * with a '#' character or containing three numbers and a label name
  * for the element.</para>
  *
- * <para>The read_ascii_file() method is used to try to load an ascii
- * file in memory. Other methods are quite private and just put here
- * for other loader which wants to share the code of this loader (see
- * read_xyz_file() for instance).</para>
+ * <para>Some public methods here have been put for other loader which
+ * wants to share the code of this loader (see the XYZ loader for
+ * instance).</para>
  */
 
+typedef struct AsciiKeywordData_
+{
+  gboolean reduced;
+  gboolean angdeg;
+  ToolUnits unit;
+  VisuDataBoxBoundaries bc;
+} AsciiKeywordData;
+typedef struct AsciiMetaData_
+{
+  guint nqpt;
+  gdouble totalEnergy;
+} AsciiMetaData;
+
+static double readTotalEnergy(const gchar *str);
 static gboolean loadAscii(VisuData *data, const gchar* filename,
-			  FileFormat *format, int nSet, GError **error);
+			  ToolFileFormat *format, int nSet, GError **error);
 static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error);
-static gboolean readFile_is_comment(char *str, gboolean *reduced, gboolean *angdeg,
-				    VisuUnits *unit, OpenGLBoxBoundaries *bc,
-				    guint *qpt);
+static gboolean readFile_is_comment(char *str, AsciiKeywordData *kw,
+				    AsciiMetaData *md);
 
-
-
-RenderingFormatLoad* atomicAsciiInit()
+/**
+ * initAtomicAscii: (skip)
+ * @method: the #VisuRendering method to be associated to.
+ *
+ * Create the structure that gives access to a load method and
+ * some description of it (file formats associated, name...). Internal
+ * use only
+ */
+void initAtomicAscii(VisuRendering *method)
 {
   char *typeASCII[] = {"*.ascii", (char*)0};
-  char *descrASCII = _("'x y z Element' format");
-  RenderingFormatLoad *meth;
-  
-  meth = g_malloc(sizeof(RenderingFormatLoad));
-  meth->name = "Plain text native format of V_Sim.";
-  meth->fmt = fileFormatNew(descrASCII, typeASCII);
-  if (!meth->fmt)
-    {
-      g_error("Can't initialize the rendering atomic method, aborting...");
-    }
-  meth->priority = 50;
-  meth->load = loadAscii;
 
-  return meth;
+  visu_rendering_addFileFormat(method, 0,
+                               tool_file_format_new(_("'x y z Element' format"),
+                                                    typeASCII),
+                               50, loadAscii, (GDestroyNotify)0);
 }
 
 /******************************************************************************/
 
-static gboolean readFile_is_comment(char *str, gboolean *reduced, gboolean *angdeg,
-				    VisuUnits *unit, OpenGLBoxBoundaries *bc,
-				    guint *qpt)
+static gboolean readFile_is_comment(char *str, AsciiKeywordData *kw,
+				    AsciiMetaData *md)
 {
   gchar **tokens;
   int i;
 
-  if ((reduced || angdeg || unit || bc || qpt) &&
-      !strncmp(str + 1, "keyword:", 8))
+  if (kw && !strncmp(str + 1, "keyword", 7))
     {
       tokens = g_strsplit_set(str + 9, " ,\n\t\r", -1);
       for (i = 0; tokens[i]; i++)
-	{
-	  DBG_fprintf(stderr, "Atomic ASCII: get keyword '%s'.\n", tokens[i]);
-	  if (reduced && !g_ascii_strcasecmp(tokens[i], "reduced"))
-	    *reduced = TRUE;
-	  else if (angdeg && !g_ascii_strcasecmp(tokens[i], "angdeg"))
-	    *angdeg = TRUE;
-	  else if (unit && (!g_ascii_strcasecmp(tokens[i], "atomic") ||
-			    !g_ascii_strcasecmp(tokens[i], "atomicd0") ||
-			    !g_ascii_strcasecmp(tokens[i], "bohr") ||
-			    !g_ascii_strcasecmp(tokens[i], "bohrd0")))
-	    *unit = unit_bohr;
-	  else if (unit && (!g_ascii_strcasecmp(tokens[i], "angstroem") ||
-			    !g_ascii_strcasecmp(tokens[i], "angstroemd0")))
-	    *unit = unit_angstroem;
-	  else if (bc && !g_ascii_strcasecmp(tokens[i], "periodic"))
-	    *bc = BOX_PERIODIC;
-	  else if (bc && !g_ascii_strcasecmp(tokens[i], "surface"))
-	    *bc = BOX_SURFACE_ZX;
-	  else if (bc && !g_ascii_strcasecmp(tokens[i], "freeBC"))
-	    *bc = BOX_FREE;
-	  else if (qpt && !g_ascii_strncasecmp(tokens[i], "qpt", 3))
-	    *qpt += 1;
-	}
+	if (tokens[i][0] != '\0')
+	  {
+/* 	    tokens[i] = g_strstrip(tokens[i]); */
+	    DBG_fprintf(stderr, "Atomic ASCII: get keyword '%s'.\n", tokens[i]);
+	    if (!g_ascii_strcasecmp(tokens[i], "reduced"))
+	      kw->reduced = TRUE;
+	    else if (!g_ascii_strcasecmp(tokens[i], "angdeg"))
+	      kw->angdeg = TRUE;
+	    else if (!g_ascii_strcasecmp(tokens[i], "atomic") ||
+		     !g_ascii_strcasecmp(tokens[i], "atomicd0") ||
+		     !g_ascii_strcasecmp(tokens[i], "bohr") ||
+		     !g_ascii_strcasecmp(tokens[i], "bohrd0"))
+	      kw->unit = unit_bohr;
+	    else if (!g_ascii_strcasecmp(tokens[i], "angstroem") ||
+		     !g_ascii_strcasecmp(tokens[i], "angstroemd0"))
+	      kw->unit = unit_angstroem;
+	    else if (!g_ascii_strcasecmp(tokens[i], "periodic"))
+	      kw->bc = VISU_DATA_BOX_PERIODIC;
+	    else if (!g_ascii_strcasecmp(tokens[i], "surface"))
+	      kw->bc = VISU_DATA_BOX_SURFACE_ZX;
+	    else if (!g_ascii_strcasecmp(tokens[i], "surfaceXY"))
+	      kw->bc = VISU_DATA_BOX_SURFACE_XY;
+	    else if (!g_ascii_strcasecmp(tokens[i], "freeBC"))
+	      kw->bc = VISU_DATA_BOX_FREE;
+	  }
       g_strfreev(tokens);
     }
-  if(str[0] == '#')
-    return TRUE;
-  if(str[0] == '!')
+  if (md && !g_ascii_strncasecmp(str + 1, "metaData", 8))
+    {
+      tokens = g_strsplit_set(str + 10, " ,\n\t\r", -1);
+      for (i = 0; tokens[i]; i++)
+	if (tokens[i][0] != '\0')
+	  {
+/* 	    tokens[i] = g_strstrip(tokens[i]); */
+	    DBG_fprintf(stderr, "Atomic ASCII: get meta data '%s'.\n", tokens[i]);
+	    if (!g_ascii_strncasecmp(tokens[i], "qpt", 3))
+	      md->nqpt += 1;
+	    else if (!g_ascii_strncasecmp(tokens[i], "totalEnergy", 11))
+	      md->totalEnergy = readTotalEnergy(str + 10);
+	  }
+      g_strfreev(tokens);
+    }
+  if(str[0] == '#' || str[0] == '!')
     return TRUE;
   str = g_strstrip(str);
   return (str[0] == '\0');
 }
 
-gboolean readQpt(gchar *str, float qpt[4], float *disp, guint natom)
+static double readTotalEnergy(const gchar *str)
+{
+  gchar *chr, *tmpStr;
+  int res, pos;
+  double val;
+
+  chr = strstr(str, "totalEnergy");
+  chr = strchr(chr, '=');
+  chr += 1;
+
+  val = 999.;
+  res = (chr)?sscanf(chr, "%lf%n", &val, &pos):0;
+  if (res != 1)
+    g_warning("syntax error for meta data 'totalEnergy' in '%s'.",
+	      chr);
+  else if (chr[pos] != '\0')
+    {
+      tmpStr = g_strdup(chr + pos);
+      tmpStr = g_strstrip(tmpStr);
+      if (!g_ascii_strncasecmp(tmpStr, "Ht", 2))
+	val *= 27.21138386;
+      else if (!g_ascii_strncasecmp(tmpStr, "Ry", 2))
+	val *= .5 * 27.21138386;
+      g_free(tmpStr);
+    }
+  DBG_fprintf(stderr, "Atomic ASCII: found 'totalEnergy' at %geV.\n", val);
+  return val;
+}
+
+static gboolean readQpt(gchar *str, float qpt[4], float *disp, guint natom)
 {
   gchar **values;
   gchar *ptr;
   guint j, k;
 
-  ptr = strstr(str, "qpt=");
+  ptr = strstr(str, "qpt");
   if (!ptr)
     return FALSE;
+  ptr = strstr(ptr, "=");
+  if (!ptr)
+    {
+      g_warning("syntax error for meta data 'qpt' in '%s'.", str);
+      return FALSE;
+    }
 
   DBG_fprintf(stderr, "Atomic ASCII: read qpt from '%s'\n", ptr);
-  values = g_strsplit_set(ptr + 4, "[];\n\\\t", -1);
+  memset(disp, 0, sizeof(float) * 6 * natom);
+  values = g_strsplit_set(ptr + 1, " [];\n\r\\\t", -1);
   k = 0;
   for (j = 0; values[j] && k < 4; j++)
     if (values[j][0] != '\0')
@@ -203,7 +262,8 @@ gboolean continuousLine(GString *line)
   gsize len;
 
   len = line->len - 1;
-  while (line->str[len] == '\n' || line->str[len] == '\t' || line->str[len] == ' ')
+  while (line->str[len] == '\n' || line->str[len] == '\r' ||
+	 line->str[len] == '\t' || line->str[len] == ' ')
     len -= 1;
 
   return (line->str[len] == '\\');
@@ -211,32 +271,61 @@ gboolean continuousLine(GString *line)
 
 /******************************************************************************/
 
-void freeDataAscii(gpointer data)
+/**
+ * visu_meth_asciiFree:
+ * @data: a pointer to #stuct VisuMethAscii instances.
+ *
+ * This method is used to free an allocated #stuct VisuMethAscii, and can
+ * be used as a destructor when creating an hashtable with such datas.
+ */
+void visu_meth_asciiFree(gpointer data)
 {
-  g_free((struct dataAscii*)data);
+  g_free((struct VisuMethAscii*)data);
 }
-void putValTypeInAsciiType(gpointer key _U_, gpointer value, gpointer data)
+/**
+ * visu_meth_asciiValToType:
+ * @key: a #VisuElement pointer ;
+ * @value: a #struct VisuMethAscii pointer ;
+ * @data: a pointer on array of pointers of #VisuElement.
+ *
+ * This method is used in a g_hash_table_foreach() method that work on @data.
+ * @data is an array of pointers to #VisuElement and this method puts its
+ * nth value to point to @key. The value nth is read from the @pos attribute of
+ * the structure object pointed by @value.
+ */
+void visu_meth_asciiValToType(gpointer key _U_, gpointer value, gpointer data)
 {
   VisuElement **tab;
-  struct dataAscii *infos;
+  struct VisuMethAscii *infos;
   
   tab = *(VisuElement***)data;
-  infos = (struct dataAscii *)value;
+  infos = (struct VisuMethAscii *)value;
   tab[infos->pos] = infos->ele;
 }
-void putValNbInAsciiType(gpointer key _U_, gpointer value, gpointer data)
+/**
+ * visu_meth_asciiValToNb:
+ * @key: a #VisuElement pointer ;
+ * @value: a #struct VisuMethAscii pointer ;
+ * @data: a pointer on array of int.
+ *
+ * This method is used in a g_hash_table_foreach() method that work on @data.
+ * @data is an array of int and this method puts its
+ * nth value to the value read from the @nbNodes attribute of
+ * the structure object pointed by @value.
+ */
+void visu_meth_asciiValToNb(gpointer key _U_, gpointer value, gpointer data)
 {
   int *tab;
-  struct dataAscii *infos;
+  struct VisuMethAscii *infos;
   
   tab = *(int**)data;
-  infos = (struct dataAscii *)value;
+  infos = (struct VisuMethAscii *)value;
   tab[infos->pos] = infos->nbNodes;
 }
 /******************************************************************************/
 
 static gboolean loadAscii(VisuData *data, const gchar* filename,
-			  FileFormat *format _U_, int nSet _U_, GError **error)
+			  ToolFileFormat *format _U_, int nSet _U_, GError **error)
 {
   int res;
   GIOChannel *readFrom;
@@ -282,7 +371,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   GString *line, *bufLine;
   gsize term;
   double xu, yu, zu;
-  unsigned int i, iph, nph;
+  unsigned int i, iph;
   int res, pos;
   char nomloc[MAX_LINE_LENGTH];
   VisuElement *type;
@@ -290,15 +379,15 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   unsigned int *nattyp;
   unsigned int ntype, nbLine, natom;
   GHashTable *elements;
-  struct dataAscii *infos;
+  struct VisuMethAscii *infos;
   double boxGeometry[6], abc[3], ang[3];
   float  xyz[3], uvw[3];
   gchar *infoUTF8, **nodeComments;
-  gboolean reduced, angdeg, hasNodeComments;
+  gboolean hasNodeComments;
   GIOStatus status;
-  VisuUnits unit;
-  OpenGLBoxBoundaries bc;
   float qpt[4], *dcoord;
+  AsciiKeywordData kw;
+  AsciiMetaData md;
     
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
 
@@ -354,6 +443,10 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   /* Ok, from this point we assert that the file is in ascii format.
      All following errors are treated as syntax errors and the corresponding
      flag is return. */
+  DBG_fprintf(stderr, "Atomic ASCII: read box is %f x %f x %f\n"
+	      "                          %f x %f x %f\n",
+	      boxGeometry[0], boxGeometry[1], boxGeometry[2],
+	      boxGeometry[3], boxGeometry[4], boxGeometry[5]);
 
   /* Set the commentary. */
   g_strstrip(info);
@@ -363,23 +456,24 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
     infoUTF8 = g_locale_to_utf8(info, -1, NULL, NULL, NULL);
   if (infoUTF8)
     {
-      visuDataSet_fileCommentary(data, infoUTF8, 0);
+      visu_data_setFileCommentary(data, infoUTF8, 0);
       g_free(infoUTF8);
     }
   else
     g_warning("Can't convert '%s' to UTF8.\n", info);
 
   /* 1st pass to count ntype */
-  reduced = FALSE;
-  angdeg  = FALSE;
-  unit    = unit_undefined;
-  bc      = BOX_PERIODIC;
-  nph     = 0;
+  kw.reduced     = FALSE;
+  kw.angdeg      = FALSE;
+  kw.unit        = unit_undefined;
+  kw.bc          = VISU_DATA_BOX_PERIODIC;
+  md.nqpt        = 0;
+  md.totalEnergy = 999.;
   dcoord  = (float*)0;
   nbLine  = 4;
   ntype   = 0;
   elements = g_hash_table_new_full(g_direct_hash, g_direct_equal,
-				   NULL, freeDataAscii);
+				   NULL, visu_meth_asciiFree);
   g_return_val_if_fail(elements, -1);
 
   for(status = g_io_channel_read_line_string(flux, line, &term, error);
@@ -387,8 +481,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       status = g_io_channel_read_line_string(flux, line, &term, error))
     {
       nbLine += 1;
-      if(readFile_is_comment(line->str, &reduced, &angdeg,
-			     &unit, &bc, &nph)) continue;
+      if(readFile_is_comment(line->str, &kw, &md)) continue;
       if(sscanf(line->str, "%lf %lf %lf %s", 
 		&xu, &yu, &zu, nomloc) != 4)
 	{
@@ -401,28 +494,11 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
 	}
       nomloc[8] = '\0';
       /* adding nomloc to the hashtable */
-      type = visuElementGet_fromName(nomloc);
-      if (!type)
-	{
-	  type = visuElementNew_withName(nomloc);
-	  if (!type)
-	    {
-	      g_warning("Cannot create a new type for '%s'.", nomloc);
-	      g_string_free(line, TRUE);
-	      return 1;
-	    }
-	  res = visuElementAdd(type);
-	  if (res)
-	    {
-	      g_warning("Cannot add new element, maximum has been reached.");
-	      g_string_free(line, TRUE);
-	      return 1;
-	    }
-	}
-      infos = (struct dataAscii*)g_hash_table_lookup(elements, (gconstpointer)type);
+      type = visu_element_retrieveFromName(nomloc, (gboolean*)0);
+      infos = (struct VisuMethAscii*)g_hash_table_lookup(elements, (gconstpointer)type);
       if (!infos)
 	{
-	  infos = g_malloc(sizeof(struct dataAscii));
+	  infos = g_malloc(sizeof(struct VisuMethAscii));
 	  infos->ele = type;
 	  infos->pos = ntype;
 	  infos->nbNodes = 1;
@@ -448,13 +524,13 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   /* Allocate the space for the nodes. */
   types  = g_malloc(sizeof(VisuElement*) * ntype);
   nattyp = g_malloc(sizeof(int) * ntype);
-  g_hash_table_foreach(elements, (GHFunc)putValTypeInAsciiType, (gpointer)&types);
-  g_hash_table_foreach(elements, (GHFunc)putValNbInAsciiType, (gpointer)&nattyp);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
   g_hash_table_destroy(elements);
   natom = 0;
   for (i = 0; i < ntype; i++) natom += nattyp[i];
 
-  res = visuDataSet_population(data, ntype, nattyp, types);
+  res = visu_data_setPopulation(data, ntype, nattyp, types);
   if (!res)
     {
       g_error("Can't store the nodes in the VisuData object.");
@@ -463,7 +539,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   g_free(types);
          
   /* We build boxGeometry according to angdeg flag. */
-  if (angdeg)
+  if (kw.angdeg)
     {
       abc[0] = boxGeometry[0];
       abc[1] = boxGeometry[1];
@@ -494,12 +570,14 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
 			    boxGeometry[4] * boxGeometry[4]);
       boxGeometry[5] *= (ang[1] < 0.)?-1.:+1.;
     }
-  if (bc != BOX_FREE)
-    visuDataSet_boxGeometry(data, boxGeometry, bc);
+  /* Always set the given box, in case coordinates are reduced. */
+  visu_data_setBoxGeometry(data, boxGeometry, kw.bc);
   /* Test phonons. */
-  if (nph > 0)
+  if (md.nqpt > 0)
     {
-      vibrationInit(data, nph, natom);
+      DBG_fprintf(stderr, "Atomic ASCII: initialise phonon storage for %d data.\n",
+		  natom * 6);
+      visu_vibration_init(data, md.nqpt, natom);
       dcoord = g_malloc(sizeof(float) * (natom * 6));
     }
 
@@ -519,9 +597,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       status == G_IO_STATUS_NORMAL;
       status = g_io_channel_read_line_string(flux, line, &term, error))
     {
-      if(readFile_is_comment(line->str, (gboolean*)0,
-			     (gboolean*)0, (VisuUnits*)0,
-			     (OpenGLBoxBoundaries*)0, &iph))
+      if(readFile_is_comment(line->str, (AsciiKeywordData*)0, (AsciiMetaData*)0))
 	{
 	  while (continuousLine(line) && status == G_IO_STATUS_NORMAL)
 	    {
@@ -529,10 +605,11 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
 	      g_string_append(line, bufLine->str);
 	    }
 	  
-	  if (readQpt(line->str, qpt, dcoord, natom))
+	  if (md.nqpt > 0 && readQpt(line->str, qpt, dcoord, natom))
 	    {
-	      vibrationSet_characteristic(data, iph - 1, qpt, qpt[3], 1.f);
-	      vibrationSet_displacements(data, iph - 1, dcoord, TRUE);
+	      visu_vibration_setCharacteristic(data, iph, qpt, qpt[3], 1.f);
+	      visu_vibration_setDisplacements(data, iph, dcoord, TRUE);
+	      iph += 1;
 	    }
 	  
 	  continue;
@@ -541,7 +618,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       pos = 0;
       res = sscanf(line->str, "%lf %lf %lf %s %n", &xu, &yu, &zu, nomloc, &pos);
       nomloc[8] = '\0';
-      type = visuElementGet_fromName(nomloc);
+      type = visu_element_lookup(nomloc);
       if (!type)
 	{
 	  g_warning("INTERNAL ERROR! The input file must"
@@ -555,9 +632,10 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       xyz[0] = uvw[0] = (float)xu;
       xyz[1] = uvw[1] = (float)yu;
       xyz[2] = uvw[2] = (float)zu;
-      if (reduced)
-	visuDataConvert_boxCoordinatestoXYZ(data, xyz, uvw);
-      visuDataAdd_nodeFromElement(data, type, xyz, FALSE);
+      if (kw.reduced)
+	visu_data_convertBoxCoordinatestoXYZ(data, xyz, uvw);
+      visu_data_addNodeFromElement(data, type, xyz, FALSE, FALSE);
+
       /* Store a possible comment. */
       if (line->str[pos] != '\0')
 	{
@@ -580,13 +658,13 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   g_string_free(bufLine, TRUE);
 
   /* In free boundary conditions, find the bounding box. */
-  if (bc == BOX_FREE)
-    visuDataSet_tightBox(data);
+  if (kw.bc != VISU_DATA_BOX_PERIODIC)
+    visu_data_setTightBox(data);
 
   /* We finish with the box description. */
   DBG_fprintf(stderr, "Atomic ASCII: apply the box geometry and set the unit.\n");
-  visuDataApply_boxGeometry(data, 0.f);
-  visuDataSet_unit(data, unit);
+  visu_data_applyBoxGeometry(data);
+  visu_data_setUnit(data, kw.unit);
 
   /* We apply the comments, if any. */
   if (hasNodeComments)
@@ -600,8 +678,12 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
 	  }
     }
   g_free(nodeComments);
+
+  /* Add some other meta data. */
+  if (md.totalEnergy != 999.)
+    g_object_set(G_OBJECT(data), "totalEnergy", md.totalEnergy, NULL);
   
-  if (nph > 0)
+  if (md.nqpt > 0)
     g_free(dcoord);
 
   DBG_fprintf(stderr, "Atomic ASCII: parse done.\n");
