@@ -86,126 +86,145 @@ typedef enum
     policyNbModulusModes
   } SpinModulusPolicy;
 
-/* An identifier for the different shapes to draw elements. */
+/**
+ * VisuSpinShapeId:
+ * @VISU_RENDERING_SPIN_ARROW_SMOOTH: the shape is smooth and rounded ;
+ * @VISU_RENDERING_SPIN_ARROW_SHARP: the shape is built on squares ;
+ * @VISU_RENDERING_SPIN_ELLIPSOID: the shape is an ellipsoid ;
+ * @VISU_RENDERING_SPIN_TORUS: the shape is a torus (direction of the arrow is
+ * normal to the torus plane).
+ * @nbSpinShapes: private.
+ *
+ * An identifier for the different shapes to draw elements.
+ */
 typedef enum
   {
-    arrow_smooth,
-    arrow_sharp,
-    arrow_ellipsoid,
-    arrow_torus,
-    arrow_shape_nb
-  } SpinArrowShape;
+    VISU_RENDERING_SPIN_ARROW_SMOOTH,
+    VISU_RENDERING_SPIN_ARROW_SHARP,
+    VISU_RENDERING_SPIN_ELLIPSOID,
+    VISU_RENDERING_SPIN_TORUS,
+    /*< private >*/
+    nbSpinShapes
+  } VisuSpinShapeId;
 
 /**
- * initSpin:
+ * SpinFileType:
+ * @FILE_KIND_POSITION: define a position file ;
+ * @FILE_KIND_SPIN: define a spin description file.
  *
- * Create the whole method and initialise its values. 
- */
-void rspinInit();
-
-/**
  * These are keys for the storing of spin files in a VisuData object. 
  */
-enum
+typedef enum
   {
     FILE_KIND_POSITION,
     FILE_KIND_SPIN
-  };
+  } SpinFileType;
 
 /**
  * SPINVALUES_ID:
  *
  * This flag should be used when creating a new spin rendering method
  * as the flag for the spin values as node properties (see
- * visuNodeNew_pointerProperty()).
+ * visu_node_property_newPointer()).
  */
 #define SPINVALUES_ID     "spinRendering_values"
 /**
  * SPINMAXMODULUS_ID:
  *
  * This flag should be used when creating a new spin rendering method
- * as the flag for the max modulus values as a #VisuData property (see
- * visuDataSet_property()).
+ * as the flag for the max modulus values as a #VisuNode property (see
+ * visu_node_property_newPointer()).
  */
 #define SPINMAXMODULUS_ID "spinRendering_maxModulus"
-/**
- * SPIN_THETA:
- *
- * The offset to read theta in a float[3] array.
- */
-#define SPIN_THETA   0
-/**
- * SPIN_PHI:
- *
- * The offset to read phi in a float[3] array.
- */
-#define SPIN_PHI     1
-/**
- * SPIN_MODULUS:
- *
- * The offset to read the modulus in a float[3] array.
- */
-#define SPIN_MODULUS 2
 
 /**
- * rspin_load:
- * @data: a #VisuData object ;
- * @format: a pointer on a format (can be NULL if format is to be guessed) ;
- * @nSet: an integer ;
- * @error: a pointer to store a possible error.
+ * VISU_RENDERING_SPIN_NAME:
  *
- * Try to load the spin file declared in the @data. It tries all formats added with
- * rspin_addLoadMethod().
- *
- * Returns: FALSE if the file can't be loaded.
+ * Public name of the spin rendering mode.
  */
-gboolean rspin_load(VisuData *data, FileFormat *format, int nSet, GError **error);
+#define VISU_RENDERING_SPIN_NAME "Spin visualisation"
 
 /**
- * rspin_shape_number_to_translated_name:
- * @n: an id for spin shape.
+ * VISU_RENDERING_SPIN_TYPE:
  *
- * This routine returnes the translated name in UTF-8 corresponding to
- * the given shape id.
- *
- * Returns: a string owned by V_Sim.
+ * return the type of #VisuRenderingSpin.
  */
-const char* rspin_shape_number_to_translated_name(SpinArrowShape n);
+#define VISU_RENDERING_SPIN_TYPE	     (visu_rendering_spin_get_type ())
 /**
- * rspin_hiding_name_to_number:
- * @name: a string.
+ * VISU_RENDERING_SPIN:
+ * @obj: a #GObject to cast.
  *
- * In the config file, the hiding policy resource is stored with its name (untranslated).
- * This method is used to retrieve the id from the name.
- *
- * Returns: -1 if the name is invalid.
+ * Cast the given @obj into #VisuRenderingSpin type.
  */
-int rspin_hiding_name_to_number(const char *name);
+#define VISU_RENDERING_SPIN(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_RENDERING_SPIN_TYPE, VisuRenderingSpin))
 /**
- * rspin_hiding_number_to_name:
- * @n: an id for hiding policy.
+ * VISU_RENDERING_SPIN_CLASS:
+ * @klass: a #GObjectClass to cast.
  *
- * Transform ids to untranslated names.
- *
- * Returns: the name associated to the id.
+ * Cast the given @klass into #VisuRenderingSpinClass.
  */
-const char* rspin_hiding_number_to_name(int n);
+#define VISU_RENDERING_SPIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_RENDERING_SPIN_TYPE, VisuRenderingSpinClass))
 /**
- * rspin_hiding_number_to_translated_name:
- * @n: an id for hiding policy.
+ * IS_VISU_RENDERING_SPIN_TYPE:
+ * @obj: a #GObject to test.
  *
- * Transform ids to translated names.
- *
- * Returns: the name associated to the id in UTF-8.
+ * Test if the given @ogj is of the type of #VisuRenderingSpin object.
  */
-const char* rspin_hiding_number_to_translated_name(int n);
+#define IS_VISU_RENDERING_SPIN_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_RENDERING_SPIN_TYPE))
+/**
+ * IS_VISU_RENDERING_SPIN_CLASS:
+ * @klass: a #GObjectClass to test.
+ *
+ * Test if the given @klass is of the type of #VisuRenderingSpinClass class.
+ */
+#define IS_VISU_RENDERING_SPIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_RENDERING_SPIN_TYPE))
+/**
+ * VISU_RENDERING_SPIN_GET_CLASS:
+ * @obj: a #GObject to get the class of.
+ *
+ * It returns the class of the given @obj.
+ */
+#define VISU_RENDERING_SPIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_RENDERING_SPIN_TYPE, VisuRenderingSpinClass))
 
 /**
- * returnOneF:
+ * visu_rendering_spin_get_type:
  *
- * Return value: the incredible value of 1.0f
+ * This method returns the type of #VisuRenderingSpin, use
+ * VISU_RENDERING_SPIN_TYPE instead.
+ *
+ * Returns: the type of #VisuRenderingSpin.
  */
-float returnOneF();
+GType visu_rendering_spin_get_type(void);
+
+/**
+ * VisuRenderingSpinPriv:
+ *
+ * An opaque structure.
+ */
+typedef struct _VisuRenderingSpinPriv VisuRenderingSpinPriv;
+typedef struct _VisuRenderingSpinClass VisuRenderingSpinClass;
+/**
+ * VisuRenderingSpin:
+ *
+ * An opaque structure.
+ */
+struct _VisuRenderingSpin
+{
+  VisuRendering method;
+
+  VisuRenderingSpinPriv *priv;
+};
+typedef struct _VisuRenderingSpin VisuRenderingSpin;
+
+VisuRenderingSpin* visu_rendering_spin_new();
+
+/***********************/
+/* Different resources */
+/***********************/
+const char* visu_renderingSpin_getShapeNameI18n(VisuSpinShapeId n);
+SpinDrawingPolicy visu_renderingSpin_getHidingPolicyFromName(const char *name);
+const char* visu_renderingSpin_getHidingPolicyName(SpinDrawingPolicy n);
+const char* visu_renderingSpin_getHidingPolicyNameI18n(SpinDrawingPolicy n);
 
 /**
  * SpinElementResources:
@@ -240,111 +259,6 @@ typedef enum
     spin_nbElementResources
   } SpinElementResources;
 
-/**
- * SpinGlobalResources:
- * @spin_globalConeTheta: the theta angle to set the color cone ;
- * @spin_globalConePhi: the phi angle to set the color cone ;
- * @spin_globalColorWheel: an angle to set the color origin around the z axis of the cone ;
- * @spin_globalHidingMode: an id used to define the policy used to draw spin
- *                         with null modulus (see #SpinDrawingPolicy) ;
- * @spin_globalAtomic: if TRUE, atoms are drawn with spins ;
- * @spin_globalModulus: an id used to define the policy used to draw spin
- *                      depending on modulus (see #SpinModulusPolicy) ;
- * @spin_nbGlobalResources: number of global resources.
- *
- * These are resources that impact the entire rendering spin method. They can be accessed
- * through rspin_getGlobalResource() or rspin_setGlobalResource_boolean() and other
- * similar methods.
- */
-typedef enum
-  {
-    spin_globalConeTheta,
-    spin_globalConePhi,
-    spin_globalColorWheel,
-    spin_globalHidingMode,
-    spin_globalAtomic,
-    spin_globalModulus,
-    spin_nbGlobalResources
-  } SpinGlobalResources;
-
-
-/** 
- * rspin_getGlobalResource:
- * @property: the name of the resource ;
- * @type: a location to store the type.
- *
- * This is a generic method to access global resources. Use rspin_setGlobalResource_boolean()
- * is favored if the type of the value is known. If the returned value is not NULL
- * the argument @type contains the type of the returned value.
- *
- * Return value: a pointer to the location where the value for the given global 
- * resource is stored.
- */
-gpointer rspin_getGlobalResource(SpinGlobalResources property, GType *type);
-/**
- * rspin_setGlobalResource_boolean:
- * @property: the id of the property to set ;
- * @value: its value.
- *
- * This method is used to change global resources that are boolean.
- *
- * Returns: TRUE if the value was changed.
- */
-gboolean rspin_setGlobalResource_boolean(SpinGlobalResources property,
-					 gboolean value);
-/**
- * rspin_setGlobalResource_uint:
- * @property: the id of the property to set ;
- * @value: its value.
- *
- * This method is used to change global resources that are unsigned int.
- *
- * Returns: TRUE if the value was changed.
- */
-gboolean rspin_setGlobalResource_uint(SpinGlobalResources property,
-				      guint value);
-/**
- * rspin_setGlobalResource_float:
- * @property: the id of the property to set ;
- * @value: its value.
- *
- * This method is used to change global resources that are floating point.
- *
- * Returns: TRUE if the value was changed.
- */
-gboolean rspin_setGlobalResource_float(SpinGlobalResources property,
-				       gfloat value);
-/**
- * rspin_getGlobalResource_boolean:
- * @property: the id of the property to get.
- *
- * This is the specific method to retrieve value of boolean global resources.
- *
- * Returns: the boolean value.
- */
-gboolean rspin_getGlobalResource_boolean(SpinGlobalResources property);
-/**
- * rspin_getGlobalResource_uint:
- * @property: the id of the property to get.
- *
- * This is the specific method to retrieve value of unsigned int global resources.
- *
- * Returns: the unsigned int value.
- */
-guint rspin_getGlobalResource_uint(SpinGlobalResources property);
-/**
- * rspin_getGlobalResource_float:
- * @property: the id of the property to get.
- *
- * This is the specific method to retrieve value of floating point global resources.
- *
- * Returns: the floating point value.
- */
-gfloat rspin_getGlobalResource_float(SpinGlobalResources property);
-
-
-
-
 /**
  * rspin_getElementResource:
  * @ele: a pointer to a #VisuElement object ;
@@ -426,42 +340,4 @@ guint rspin_getElementResource_uint(VisuElement *ele, SpinElementResources prope
  */
 gfloat rspin_getElementResource_float(VisuElement *ele, SpinElementResources property);
 
-
-/**
- * rspin_createShapeSpin:
- * @visuData: a #VisuData object ;
- * @ele: a visu element.
- *
- * Creates the shape to be drawed by opengl for the @ele VisuElement.
- * Keep in mind that it does NOT redraw the scene. You must explicitly
- * send a redraw signal for that task to be done.
- *
- * Returns: an id representing an OpenGL list where the shape has been
- *          created.
- */
-int rspin_createShapeSpin(VisuData *visuData, VisuElement* ele);
-
-/**
- * rspin_placeNodeSpin
- * @visuData: a #VisuData object ;
- * @node: a visu node ;
- * @ele: the element matching the @node.
- *
- * Apply a particular drawing treatment (coloration) on the given @node 
- * according to its orientation and current set module parameters.
- */
-void rspin_placeNodeSpin(VisuData *visuData, VisuNode *node, VisuElement* ele);
-
-/**
- * rspin_addLoadMethod:
- * @meth: a new load method.
- *
- * This routine is used to register a new load method with its description
- * (file formats, name...). The list of all known load methods is automatically
- * resorted after a call to this method to reflect the priorities.
- */
-void rspin_addLoadMethod(RenderingFormatLoad* meth);
-
-#define VISU_RENDERING_SPIN "Spin visualisation"
-
 #endif
