@@ -52,7 +52,7 @@
 #include <coreTools/toolMatrix.h>
 
 /**
- * parseCommandLine:
+ * commandLineParse:
  * @argc: the number of arguments.
  * @argv: the values of all arguments.
  *
@@ -62,7 +62,7 @@
  *
  * Returns: 0 if everything goes well.
  */
-int parseCommandLine(int argc, char **argv);
+int commandLineParse(int argc, char **argv);
 
 /**
  * commandLineExport:
@@ -84,7 +84,7 @@ gboolean commandLineExport(const gchar *filename, GError **error);
  *
  * Returns: the value of the first argument.
  */
-char* commandLineGet_ArgFilename();
+char* commandLineGet_ArgFilename(void);
 /**
  * commandLineGet_ArgSpinFileName:
  *
@@ -92,7 +92,7 @@ char* commandLineGet_ArgFilename();
  *
  * Returns: the value of the second argument.
  */
-char* commandLineGet_ArgSpinFileName();
+char* commandLineGet_ArgSpinFileName(void);
 /**
  * commandLineGet_ExportFileName:
  *
@@ -101,7 +101,7 @@ char* commandLineGet_ArgSpinFileName();
  *
  * Returns: the value of the option --export.
  */
-char* commandLineGet_ExportFileName();
+char* commandLineGet_ExportFileName(void);
 /**
  * commandLineGet_WithGtk:
  *
@@ -109,14 +109,14 @@ char* commandLineGet_ExportFileName();
  *
  * Returns: 1 if the interface is needed.
  */
-int   commandLineGet_WithGtk();
+int   commandLineGet_WithGtk(void);
 /**
  * commandLineGet_XWindowGeometry:
  * @width: an integer to stores the desired width.
  * @height: an integer to stores the desired height.
  *
  * This method retrieves the values of the option --geometry or -g.
- * These values must be formatted with the following format : %dx%d and they give
+ * These values must be formatted with the following format : &amp;dx&amp;d and they give
  * the size of the rendering window.
  *
  */
@@ -130,7 +130,7 @@ void  commandLineGet_XWindowGeometry(int *width, int *height);
  *
  * Returns: the value of the option --colorize.
  */
-gchar* commandLineGet_colorizeFileName();
+gchar* commandLineGet_colorizeFileName(void);
 /**
  * commandLineGet_colorizeColUsed:
  *
@@ -140,7 +140,7 @@ gchar* commandLineGet_colorizeFileName();
  * Returns: the three values of the option --use-column, or NULL if this option
  *          is not present.
  */
-int* commandLineGet_colorizeColUsed();
+int* commandLineGet_colorizeColUsed(void);
 /**
  * commandLineGet_colorizePresetColor:
  *
@@ -156,7 +156,7 @@ int* commandLineGet_colorizeColUsed();
  *
  * Returns: the value of option --color-preset if set, -1 if not.
  */
-int commandLineGet_presetColor();
+int commandLineGet_presetColor(void);
 /**
  * commandLineGet_translation:
  *
@@ -165,7 +165,7 @@ int commandLineGet_presetColor();
  *
  * Returns: the three values of the option --translate.
  */
-float* commandLineGet_translation();
+float* commandLineGet_translation(void);
 /**
  * commandLineGet_extension:
  *
@@ -174,7 +174,7 @@ float* commandLineGet_translation();
  *
  * Returns: the three values of the option --expand.
  */
-float* commandLineGet_extension();
+float* commandLineGet_extension(void);
 /**
  * commandLineGet_planesFileName:
  *
@@ -183,7 +183,7 @@ float* commandLineGet_extension();
  *
  * Returns: the value of the option --planes.
  */
-gchar* commandLineGet_planesFileName();
+gchar* commandLineGet_planesFileName(void);
 /**
  * commandLineGet_spinHidingMode:
  *
@@ -191,7 +191,7 @@ gchar* commandLineGet_planesFileName();
  *
  * Returns: the value of the option.
  */
-int commandLineGet_spinHidingMode();
+int commandLineGet_spinHidingMode(void);
 /**
  * commandLineGet_spinAndAtomic:
  *
@@ -199,7 +199,7 @@ int commandLineGet_spinHidingMode();
  *
  * Returns: the TRUE if the option exists.
  */
-gboolean commandLineGet_spinAndAtomic();
+gboolean commandLineGet_spinAndAtomic(void);
 /**
  * commandLineGet_isoValues:
  * @nb: a location to store an integer.
@@ -216,7 +216,7 @@ float* commandLineGet_isoValues(int *nb);
  * This method retrieves the names associated to the values of the option --ios-values or -v.
  * It returns an array of size @nb, but not all element are set since names are not
  * mandatory. The @nb value is guarantied to by equal to the one returned by
- * commandLineGet_isoValues();
+ * commandLineGet_isoValues(void);
  *
  * Returns: an array with the values of a size stored in @nb.
  */
@@ -228,7 +228,7 @@ gchar** commandLineGet_isoNames(int *nb);
  *
  * Returns: a filename, the string is owned by V_Sim.
  */
-gchar* commandLineGet_scalarFieldFileName();
+gchar* commandLineGet_scalarFieldFileName(void);
 /**
  * commandLineGet_isoSurfacesFileName:
  *
@@ -236,7 +236,7 @@ gchar* commandLineGet_scalarFieldFileName();
  *
  * Returns: a filename, the string is owned by V_Sim.
  */
-gchar* commandLineGet_isoSurfacesFileName();
+gchar* commandLineGet_isoSurfacesFileName(void);
 /**
  * commandLineGet_fitToBox:
  *
@@ -244,7 +244,7 @@ gchar* commandLineGet_isoSurfacesFileName();
  *
  * Returns: TRUE if the surface should be fitted.
  */
-gboolean commandLineGet_fitToBox();
+gboolean commandLineGet_fitToBox(void);
 /**
  * commandLineGet_resourcesFile:
  *
@@ -253,7 +253,7 @@ gboolean commandLineGet_fitToBox();
  * Returns: the name (owned by V_Sim) of the given resources file or NULL if none
  *          was present.
  */
-gchar* commandLineGet_resourcesFile();
+gchar* commandLineGet_resourcesFile(void);
 /**
  * commandLineGet_options:
  *
@@ -261,9 +261,9 @@ gchar* commandLineGet_resourcesFile();
  * letters to check for a boolean value (F/T), then, a float is used and finally
  * an integer. If nothing parsed, the option is dismissed.
  *
- * Returns: a #OptionTable pointer owned by V_Sim.
+ * Returns: a #GHashTable pointer owned by V_Sim.
  */
-OptionTable* commandLineGet_options();
+GHashTable* commandLineGet_options(void);
 /**
  * commandLineGet_coloredMap:
  * @planeId: a location to store the plane to be used.
@@ -276,7 +276,7 @@ OptionTable* commandLineGet_options();
  *
  * Returns: TRUE if a coloured map is requested.
  */
-int* commandLineGet_coloredMap();
+int* commandLineGet_coloredMap(void);
 /**
  * commandLineGet_logScale:
  *
@@ -284,7 +284,7 @@ int* commandLineGet_coloredMap();
  *
  * Returns: the logscale method.
  */
-matrix_scaleflag commandLineGet_logScale();
+ToolMatrixScalingFlag commandLineGet_logScale(void);
 /**
  * commandLineGet_nIsoLines:
  *
@@ -293,7 +293,7 @@ matrix_scaleflag commandLineGet_logScale();
  *
  * Returns: a positive number if some isolines are required, 0 if not.
  */
-guint commandLineGet_nIsoLines();
+guint commandLineGet_nIsoLines(void);
 /**
  * commandLineGet_bgImage:
  *
@@ -301,7 +301,7 @@ guint commandLineGet_nIsoLines();
  *
  * Returns: a string or NULL if option is not used.
  */
-gchar* commandLineGet_bgImage();
+gchar* commandLineGet_bgImage(void);
 /**
  * commandLineGet_isoLinesColor:
  *
@@ -311,7 +311,7 @@ gchar* commandLineGet_bgImage();
  *
  * Since: 3.5
  */
-float* commandLineGet_isoLinesColor();
+float* commandLineGet_isoLinesColor(void);
 /**
  * commandLineGet_windowMode:
  *
@@ -323,7 +323,7 @@ float* commandLineGet_isoLinesColor();
  *
  * Since: 3.5
  */
-gchar* commandLineGet_windowMode();
+gchar* commandLineGet_windowMode(void);
 /**
  * commandLineGet_iSet:
  *
@@ -333,7 +333,7 @@ gchar* commandLineGet_windowMode();
  *
  * Since: 3.5
  */
-guint commandLineGet_iSet();
+guint commandLineGet_iSet(void);
 /**
  * commandLineGet_valueFile:
  *
@@ -344,8 +344,10 @@ guint commandLineGet_iSet();
  *
  * Since: 3.5
  */
-gchar* commandLineGet_valueFile();
-void commandLineFree_all();
-guint commandLineGet_mapPrecision();
+gchar* commandLineGet_valueFile(void);
+void commandLineFree_all(void);
+guint commandLineGet_mapPrecision(void);
+float* commandLineGet_mapMinMax(void);
+gchar* commandLineGet_introspect(void);
 
 #endif
