@@ -44,7 +44,7 @@
 #include "visu_extension.h"
 #include "visu_configFile.h"
 #include "coreTools/toolConfigFile.h"
-#include "extensions/externalOpenGLExtensions.h"
+#include "extensions/externalVisuExtensions.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -56,28 +56,28 @@
 /**
  * SECTION:visu_extension
  * @short_description: All objects drawn by V_Sim are defined in by a
- * #OpenGLExtension object
+ * #VisuExtension object
  *
  * <para>All objects that are drawn by V_Sim are handled by a
- * #OpenGLExtension object. Such an object has an OpenGL list. This
+ * #VisuExtension object. Such an object has an OpenGL list. This
  * list is only COMPILED. When V_Sim receives the 'OpenGLAskForReDraw'
  * or the 'OpenGLForceReDraw' signals, each list of all known
- * #OpenGLExtension are excecuted. This excecution can be canceled if
- * the used flag of the #OpenGLExtension object is set to FALSE. The
+ * #VisuExtension are excecuted. This excecution can be canceled if
+ * the used flag of the #VisuExtension object is set to FALSE. The
  * order in which the lists are called depends on the priority of the
- * #OpenGLExtension object. This priority is set to
- * #OPENGL_EXTENSION_PRIORITY_NORMAL as default value, but it can be
- * tune by a call to OpenGLExtensionSet_priority(). This priority is
+ * #VisuExtension object. This priority is set to
+ * #VISU_EXTENSION_PRIORITY_NORMAL as default value, but it can be
+ * tune by a call to visu_extension_setPriority(). This priority is
  * an integer, the lower it is, the sooner the list is
  * excecuted.</para>
  *
- * <para>The method registerOpenGLExtension() is used to declare to
- * V_Sim that there is a new #OpenGLExtension object available. This
+ * <para>The method registerVisuExtension() is used to declare to
+ * V_Sim that there is a new #VisuExtension object available. This
  * allows to create extension when V_Sim is already
  * running. Nevertheless, an extension must be initialized in the
  * initialisation process, it is better to add an
- * #initOpenGLExtensionFunc method in the #listInitExtensionFunc array
- * declared in extensions/externalOpenGLExtensions.h.</para>
+ * #initVisuExtensionFunc method in the listInitExtensionFunc array
+ * declared in extensions/externalVisuExtensions.h.</para>
  *
  * <para>Once again, the OpenGL list corresponding to an OpenGL
  * extension is COMPILE only. Then, OpenGL methods like glIsenabled()
@@ -86,7 +86,7 @@
  * alter some OpenGL state, such as desable GL_LIGHTING, it needs to
  * set a flag for the extension. With this flag, V_Sim will save the
  * OpenGL states and restore it when the list is called. Use
- * OpenGLExtensionSet_saveOpenGLState() to set this flag.</para>
+ * visu_extension_setSaveOpenGLState() to set this flag.</para>
  */
 
 #define FLAG_PARAMETER_MODE "extension_render"
@@ -97,31 +97,47 @@ static void exportParametersRendering(GString *data, VisuData *dataObj);
 
 /* A GHashTable to store all the available OpenGL extensions
    in the system. The keys are the name of each extension. */
-static GList *availableOpenGLExtensions;
+static GList *allExtensions;
 
 /* This flag is TRUE when some priorities are new or have changed, and 
    the list should be reordered. */
-static gboolean OpenGLExtension_reorderingNeeded;
+static gboolean VisuExtension_reorderingNeeded;
 /* Method used to compare the priority of two extensions. */
 static gint compareExtensionPriority(gconstpointer a, gconstpointer b);
 
-static void callList(OpenGLExtension *ext, RenderingModeId *renderingMode,
-		     RenderingModeId globalRenderingMode);
-static void drawExtension(OpenGLExtension *extension, RenderingModeId renderingMode);
+static void callList(GList *lst, VisuRenderingModeId *renderingMode,
+		     VisuRenderingModeId globalRenderingMode);
 
 /***************/
 /* Public part */
 /***************/
 
 
-/* Method used to create such structures. */
-OpenGLExtension* OpenGLExtension_new(const gchar* name, const gchar *nameI18n,
-				     const gchar* description,
-				     int objectListId, rebuildObjectListFunc rebuild)
+/**
+ * visu_extension_new:
+ * @name: (type filename): name of the extension, in ASCII, used as id in the config files,
+ * @nameI18n: (type utf8): name in UTF8 that can be translated and shown to user,
+ * @description: (allow-none): a brief description of the extension (can be null),
+ * @objectListId: an int to identify an list of OpenGL objects (null
+ * if this extension as no OpenGL object,
+ * @rebuild: (allow-none) (scope call): handler to a method that is called every time V_Sim needs
+ * to create again the OpenGL object list. If NULL, nothing is called.
+ *
+ * Create a new VisuExtension with the specified name, description
+ * and OpenGL object list. The priority is set by default to
+ * #VISU_EXTENSION_PRIORITY_NORMAL. The flag used to store
+ * the OpenGL state is put to FALSE by default (see
+ * visu_extension_setSaveOpenGLState() to chance it).
+ *
+ * Returns: (transfer none): the new VisuExtension or null if something wrong happens.
+ */
+VisuExtension* visu_extension_new(const gchar* name, const gchar *nameI18n,
+				  const gchar* description,
+				  int objectListId, VisuExtensionRebuildFunc rebuild)
 {
-  OpenGLExtension *extension;
+  VisuExtension *extension;
 
-  extension = g_malloc(sizeof(OpenGLExtension));
+  extension = g_malloc(sizeof(VisuExtension));
   extension->name = g_strdup(name);
   extension->nameI18n = g_strdup(nameI18n);
   if (description)
@@ -131,7 +147,7 @@ OpenGLExtension* OpenGLExtension_new(const gchar* name, const gchar *nameI18n,
 
   extension->objectListId = objectListId;
   extension->rebuild = rebuild;
-  extension->priority = OPENGL_EXTENSION_PRIORITY_NORMAL;
+  extension->priority = VISU_EXTENSION_PRIORITY_NORMAL;
   extension->saveState = FALSE;
   extension->isSensitiveToRenderingMode = FALSE;
   extension->preferedRenderingMode = followGeneralSetting;
@@ -142,7 +158,7 @@ OpenGLExtension* OpenGLExtension_new(const gchar* name, const gchar *nameI18n,
 }
 
 /* Free all the allocated attributes of the specified extension. */
-void OpenGLExtension_free(OpenGLExtension* extension)
+void visu_extension_free(VisuExtension* extension)
 {
   if (!extension)
     return;
@@ -155,7 +171,7 @@ void OpenGLExtension_free(OpenGLExtension* extension)
   g_free(extension);
 }
 /* Get if the extension is used or not. */
-int OpenGLExtensionGet_active(OpenGLExtension* extension)
+int visu_extension_getActive(VisuExtension* extension)
 {
   if (extension)
     return extension->used;
@@ -163,62 +179,62 @@ int OpenGLExtensionGet_active(OpenGLExtension* extension)
     return 0;
 }
 /* Set if an extension is actually used or not. */
-void OpenGLExtensionSet_active(OpenGLExtension* extension, int value)
+void visu_extension_setActive(VisuExtension* extension, int value)
 {
   if (!extension || extension->used == value)
     return;
 
   extension->used = value;
 }
-GList* OpenGLExtensionGet_list()
+GList* visuExtensions_getList(void)
 {
-  if (OpenGLExtension_reorderingNeeded)
+  if (VisuExtension_reorderingNeeded)
     {
       DBG_fprintf(stderr, "Visu Extension : sorting known extension depending on their priority.\n");
-      availableOpenGLExtensions = g_list_sort(availableOpenGLExtensions, compareExtensionPriority);
-      OpenGLExtension_reorderingNeeded = FALSE;
+      allExtensions = g_list_sort(allExtensions, compareExtensionPriority);
+      VisuExtension_reorderingNeeded = FALSE;
     }
-  return availableOpenGLExtensions;
+  return allExtensions;
 }
-OpenGLExtension* OpenGLExtensionGet_fromName(const gchar* name)
+VisuExtension* VisuExtensionGet_fromName(const gchar* name)
 {
   GList *pnt;
-  OpenGLExtension *ext;
+  VisuExtension *ext;
 
   DBG_fprintf(stderr, "Visu Extension: get '%s' from list.\n", name);
 
-  pnt = availableOpenGLExtensions;
+  pnt = allExtensions;
   while (pnt)
     {
-      ext = (OpenGLExtension*)pnt->data;
+      ext = (VisuExtension*)pnt->data;
       if (!strcmp(ext->name, name))
 	return ext;
       pnt = g_list_next(pnt);
     }
-  return (OpenGLExtension*)0;
+  return (VisuExtension*)0;
 }
 
-void OpenGLExtensionSet_priority(OpenGLExtension* extension, int priority)
+void visu_extension_setPriority(VisuExtension* extension, guint priority)
 {
   g_return_if_fail(extension);
   extension->priority = priority;
-  OpenGLExtension_reorderingNeeded = TRUE;
+  VisuExtension_reorderingNeeded = TRUE;
 }
 
-void OpenGLExtensionSet_saveOpenGLState(OpenGLExtension *extension, gboolean saveState)
+void visu_extension_setSaveOpenGLState(VisuExtension *extension, gboolean saveState)
 {
   g_return_if_fail(extension);
   extension->saveState = saveState;
 }
 
-void OpenGLExtensionSet_sensitiveToRenderingMode(OpenGLExtension* extension,
+void visu_extension_setSensitiveToRenderingMode(VisuExtension* extension,
 						 gboolean status)
 {
   g_return_if_fail(extension);
   extension->isSensitiveToRenderingMode = status;
 }
-gboolean OpenGLExtensionSet_preferedRenderingMode(OpenGLExtension* extension,
-						  RenderingModeId value)
+gboolean visu_extension_setPreferedRenderingMode(VisuExtension* extension,
+						  VisuRenderingModeId value)
 {
   g_return_val_if_fail(extension, FALSE);
   g_return_val_if_fail(value < nb_renderingModes ||
@@ -235,125 +251,139 @@ gboolean OpenGLExtensionSet_preferedRenderingMode(OpenGLExtension* extension,
 
 
 /* A method used by user to registered a new extension. */
-void OpenGLExtensionRegister(OpenGLExtension *extension)
+void visuExtensions_add(VisuExtension *extension)
 {
   DBG_fprintf(stderr, "Visu Extension : registering a new OpenGL extension ... ");
   g_return_if_fail(extension && extension->name && extension->name[0]);
 
-  availableOpenGLExtensions = g_list_append(availableOpenGLExtensions,
-					    (gpointer)extension);
+  allExtensions = g_list_append(allExtensions, (gpointer)extension);
 
-  OpenGLExtension_reorderingNeeded = TRUE;
+  VisuExtension_reorderingNeeded = TRUE;
   DBG_fprintf(stderr, "'%s' (%p).\n", extension->name, (gpointer)extension);
 }
 
 /* A method used by user to remove a previously registered extension. */
-void OpenGLExtensionRemove(OpenGLExtension *extension)
+void visuExtensions_remove(VisuExtension *extension)
 {
   DBG_fprintf(stderr, "Visu Extension : removing a registered OpenGL"
 	      " extension (%p).\n", (gpointer)extension);
   g_return_if_fail(extension);
 
-  availableOpenGLExtensions = g_list_remove(availableOpenGLExtensions,
-					    (gpointer)extension);
+  allExtensions = g_list_remove(allExtensions, (gpointer)extension);
 }
 
-void OpenGLExtensionCall_list(const char *name, gboolean lastOnly)
+void visuExtensions_callList(const char *name, gboolean lastOnly)
 {
-  OpenGLExtension *ext;
-  RenderingModeId renderingMode, globalRenderingMode;
+  VisuExtension *ext;
+  VisuRenderingModeId renderingMode, globalRenderingMode;
+  GList lst;
 
   DBG_fprintf(stderr, "Visu Extension: call '%s' list.\n", name);
 
   globalRenderingMode = openGLGet_globalRenderingOption();
   renderingMode = globalRenderingMode;
-  ext = OpenGLExtensionGet_fromName(name);
+  ext = VisuExtensionGet_fromName(name);
   g_return_if_fail(ext);
 
-  if (ext->used && ((lastOnly && ext->priority == OPENGL_EXTENSION_PRIORITY_LAST) ||
-		    (!lastOnly && ext->priority < OPENGL_EXTENSION_PRIORITY_LAST)))
+  if (ext->used && ((lastOnly && ext->priority == VISU_EXTENSION_PRIORITY_LAST) ||
+		    (!lastOnly && ext->priority < VISU_EXTENSION_PRIORITY_LAST)) &&
+      ext->objectListId > 1000)
     {
-      callList(ext, &renderingMode, globalRenderingMode);
+      lst.data = (gpointer)ext;
+      lst.next = lst.prev = (GList*)0;
+      callList(&lst, &renderingMode, globalRenderingMode);
       if (renderingMode != globalRenderingMode)
 	/* Return the rendering mode to normal. */
 	openGLApply_renderingMode(globalRenderingMode);
     }
 }
 /* For each extension that has a valid list (id > 1000) a glCallList is raised. */
-void OpenGLExtensionCall_allLists()
+void visuExtensions_callAllLists(void)
 {
-  GList *pnt;
-  RenderingModeId renderingMode, globalRenderingMode;
-  OpenGLExtension *ext;
+  GList *pnt, *lst;
+  VisuRenderingModeId renderingMode, globalRenderingMode;
 
-  if (OpenGLExtension_reorderingNeeded)
+  if (VisuExtension_reorderingNeeded)
     {
       DBG_fprintf(stderr, "Visu Extension: sorting known extension depending on their priority.\n");
-      availableOpenGLExtensions = g_list_sort(availableOpenGLExtensions, compareExtensionPriority);
-      OpenGLExtension_reorderingNeeded = FALSE;
+      allExtensions = g_list_sort(allExtensions, compareExtensionPriority);
+      VisuExtension_reorderingNeeded = FALSE;
     }
   globalRenderingMode = openGLGet_globalRenderingOption();
   renderingMode = globalRenderingMode;
-  for (pnt = availableOpenGLExtensions; pnt; pnt = g_list_next(pnt))
-    {
-      ext = (OpenGLExtension*)pnt->data;
-      if (ext->priority < OPENGL_EXTENSION_PRIORITY_LAST)
-	callList((OpenGLExtension*)pnt->data, &renderingMode, globalRenderingMode);
-    }
+  lst = (GList*)0;
+  for (pnt = allExtensions; pnt && ((VisuExtension*)pnt->data)->priority <
+         VISU_EXTENSION_PRIORITY_LAST; pnt = g_list_next(pnt))
+    if (((VisuExtension*)pnt->data)->used && ((VisuExtension*)pnt->data)->objectListId > 1000)
+      lst = g_list_append(lst, pnt->data);
+  callList(lst, &renderingMode, globalRenderingMode);
+  g_list_free(lst);
   if (renderingMode != globalRenderingMode)
     /* Return the rendering mode to normal. */
     openGLApply_renderingMode(globalRenderingMode);
 }
-void OpenGLExtensionCall_lastLists()
+/**
+ * visuExtensions_callAllLastLists:
+ *
+ * Call all lists whose priority is exactly
+ * #VISU_EXTENSION_PRIORITY_LAST. To draw other priority, see
+ * visuExtensions_callList().
+ *
+ * Since: 3.6
+ */
+void visuExtensions_callAllLastLists(void)
 {
-  GList *pnt;
-  RenderingModeId renderingMode, globalRenderingMode;
-  OpenGLExtension *ext;
+  GList *pnt, *lst;
+  VisuRenderingModeId renderingMode, globalRenderingMode;
 
+  if (VisuExtension_reorderingNeeded)
+    {
+      DBG_fprintf(stderr, "Visu Extension: sorting known extension depending on their priority.\n");
+      allExtensions = g_list_sort(allExtensions, compareExtensionPriority);
+      VisuExtension_reorderingNeeded = FALSE;
+    }
   DBG_fprintf(stderr, "Visu Extension: draw PRIORITY_LAST only.\n");
   globalRenderingMode = openGLGet_globalRenderingOption();
   renderingMode = globalRenderingMode;
-  for (pnt = availableOpenGLExtensions; pnt; pnt = g_list_next(pnt))
-    {
-      ext = (OpenGLExtension*)pnt->data;
-      if (ext->priority == OPENGL_EXTENSION_PRIORITY_LAST)
-	callList(ext, &renderingMode, globalRenderingMode);
-    }
+  for (pnt = allExtensions; pnt && ((VisuExtension*)pnt->data)->priority <
+         VISU_EXTENSION_PRIORITY_LAST; pnt = g_list_next(pnt));
+  lst = (GList*)0;
+  for (; pnt; pnt = g_list_next(pnt))
+    if (((VisuExtension*)pnt->data)->used && ((VisuExtension*)pnt->data)->objectListId > 1000)
+      lst = g_list_append(lst, pnt->data);
+  callList(lst, &renderingMode, globalRenderingMode);
+  g_list_free(lst);
   if (renderingMode != globalRenderingMode)
     /* Return the rendering mode to normal. */
     openGLApply_renderingMode(globalRenderingMode);
 }
-void rebuildAllExtensionsLists(VisuData *dataObj)
+void visuExtensions_rebuildAllLists(VisuData *dataObj)
 {
   GList *pnt;
 
-  DBG_fprintf(stderr, "Visu Extension: Rebuilding lists...\n");
-  if (OpenGLExtension_reorderingNeeded)
+  DBG_fprintf(stderr, "Visu Extension: Rebuilding all lists...\n");
+  if (VisuExtension_reorderingNeeded)
     {
       DBG_fprintf(stderr, "Visu Extension: sorting known extension depending on their priority.\n");
-      availableOpenGLExtensions = g_list_sort(availableOpenGLExtensions, compareExtensionPriority);
-      OpenGLExtension_reorderingNeeded = FALSE;
-    }
-  pnt = availableOpenGLExtensions;
-  while (pnt)
-    {
-      if (((OpenGLExtension*)pnt->data)->used &&
-	  ((OpenGLExtension*)pnt->data)->rebuild)
-	{
-	  DBG_fprintf(stderr, "Visu Extension: rebuild extension %s (list %d).\n",
-		      ((OpenGLExtension*)pnt->data)->name,
-		      ((OpenGLExtension*)pnt->data)->objectListId);
-	  ((OpenGLExtension*)pnt->data)->rebuild(dataObj);
-	}
-      pnt = g_list_next(pnt);
+      allExtensions = g_list_sort(allExtensions, compareExtensionPriority);
+      VisuExtension_reorderingNeeded = FALSE;
     }
+  for (pnt = allExtensions; pnt; pnt = g_list_next(pnt))
+    if (((VisuExtension*)pnt->data)->used &&
+        ((VisuExtension*)pnt->data)->rebuild)
+      {
+        DBG_fprintf(stderr, "Visu Extension: rebuild extension %s (list %d).\n",
+                    ((VisuExtension*)pnt->data)->name,
+                    ((VisuExtension*)pnt->data)->objectListId);
+        ((VisuExtension*)pnt->data)->rebuild(dataObj);
+      }
 }
-void OpenGLExtensionRebuild_list(VisuData *dataObj, const char *name)
+void visuExtensions_rebuildList(VisuData *dataObj, const char *name)
 {
-  OpenGLExtension *ext;
+  VisuExtension *ext;
 
   DBG_fprintf(stderr, "Visu Extension: rebuilding '%s' list.\n", name);
-  ext = OpenGLExtensionGet_fromName(name);
+  ext = VisuExtensionGet_fromName(name);
   g_return_if_fail(ext);
 
   if (ext->used && ext->rebuild)
@@ -366,25 +396,25 @@ void OpenGLExtensionRebuild_list(VisuData *dataObj, const char *name)
 /****************/
 
 /* Initialise all the variable of this part. */
-int initOpenGLExtensions()
+int initVisuExtensions(void)
 {
   VisuConfigFileEntry *confEntry;
 
-  availableOpenGLExtensions = (GList*)0;
-  OpenGLExtension_reorderingNeeded = FALSE;
+  allExtensions = (GList*)0;
+  VisuExtension_reorderingNeeded = FALSE;
 
-  confEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_PARAMETER,
+  confEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
 				      FLAG_PARAMETER_MODE,
 				      DESC_PARAMETER_MODE,
 				      1, readExtensionRendering);
-  visuConfigFileSet_version(confEntry, 3.4f);
-  visuConfigFileAdd_exportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_configFile_entry_setVersion(confEntry, 3.4f);
+  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
 				   exportParametersRendering);
   return 1;
 }
-void loadExtensions()
+void loadExtensions(void)
 {
-  OpenGLExtension *extension;
+  VisuExtension *extension;
   int i, res;
 
   res = 1;
@@ -393,19 +423,28 @@ void loadExtensions()
       extension = listInitExtensionFunc[i]();
       if (!extension)
 	res = 0;
-      OpenGLExtensionRegister(extension);
+      visuExtensions_add(extension);
     }
   
   if (!res)
     g_warning("Some OpenGL extensions can't initialse.\n");
 }
 
-static void callList(OpenGLExtension *ext, RenderingModeId *renderingMode,
-		     RenderingModeId globalRenderingMode)
+static void callList(GList *lst, VisuRenderingModeId *renderingMode,
+		     VisuRenderingModeId globalRenderingMode)
 {
-  if (ext->used &&
-      ext->objectListId > 1000)
+  VisuExtension *ext;
+  GTimer *timer;
+  gulong fractionTimer;
+
+#if DEBUG == 1
+  timer = g_timer_new();
+  g_timer_start(timer);
+#endif
+
+  for (; lst; lst = g_list_next(lst))
     {
+      ext = (VisuExtension*)lst->data;
       /* The extension needs its own rendering mode. */
       if (ext->isSensitiveToRenderingMode &&
 	  ext->preferedRenderingMode < nb_renderingModes)
@@ -431,7 +470,33 @@ static void callList(OpenGLExtension *ext, RenderingModeId *renderingMode,
 	  glPushAttrib(GL_ENABLE_BIT);
 	}
 
-      drawExtension(ext, *renderingMode);
+      if (ext->isSensitiveToRenderingMode && *renderingMode == SmoothAndEdge)
+        {
+          glPushAttrib(GL_ENABLE_BIT);
+          glEnable(GL_POLYGON_OFFSET_FILL);
+          glPolygonOffset(1.0, 1.0);
+        }
+
+      /* Call the compiled list. */
+      DBG_fprintf(stderr, "Visu Extension: call list %d (%s)",
+                  ext->objectListId, ext->name);
+      glCallList(ext->objectListId);
+      DBG_fprintf(stderr, " at %g micro-s",
+                  g_timer_elapsed(timer, &fractionTimer)*1e6);
+      DBG_fprintf(stderr, ".\n");
+
+      /* Add a wireframe draw if renderingMode is SmoothAndEdge. */
+      if (ext->isSensitiveToRenderingMode && *renderingMode == SmoothAndEdge)
+        {
+          glDisable(GL_POLYGON_OFFSET_FILL);
+          glDisable(GL_LIGHTING);
+          glColor3f (0.0, 0.0, 0.0);
+          glLineWidth(1);
+          glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
+          glCallList(ext->objectListId);
+          glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
+          glPopAttrib();
+        }
 
       if (ext->saveState)
 	{
@@ -439,44 +504,18 @@ static void callList(OpenGLExtension *ext, RenderingModeId *renderingMode,
 	  glPopAttrib();
 	}
     }
-}
-static void drawExtension(OpenGLExtension *extension, RenderingModeId renderingMode)
-{
-/*   float mat[5] = {0., 0., 0., 0., 0.}; */
-/*   float rgba[4] = {0., 0., 0., 0.}; */
 
-  /* Add a wireframe draw if renderingMode is SmoothAndEdge. */
-  if (extension->isSensitiveToRenderingMode && renderingMode == SmoothAndEdge)
-    {
-      glPushAttrib(GL_ENABLE_BIT);
-      glEnable(GL_POLYGON_OFFSET_FILL);
-      glPolygonOffset(1.0, 1.0);
-    }
-
-  /* Call the compiled list. */
-  DBG_fprintf(stderr, "Visu Extension: call list %d (%s).\n",
-	      extension->objectListId, extension->name);
-  glCallList(extension->objectListId);
-
-  /* Add a wireframe draw if renderingMode is SmoothAndEdge. */
-  if (extension->isSensitiveToRenderingMode && renderingMode == SmoothAndEdge)
-    {
-      glDisable(GL_POLYGON_OFFSET_FILL);
-      glDisable(GL_LIGHTING);
-      glColor3f (0.0, 0.0, 0.0);
-      glLineWidth(1);
-      glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
-      glCallList(extension->objectListId);
-      glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
-      glPopAttrib();
-    }
+#if DEBUG == 1
+  g_timer_stop(timer);
+  g_timer_destroy(timer);
+#endif
 }
 
 static gint compareExtensionPriority(gconstpointer a, gconstpointer b)
 {
-  if (((OpenGLExtension*)a)->priority < ((OpenGLExtension*)b)->priority)
+  if (((VisuExtension*)a)->priority < ((VisuExtension*)b)->priority)
     return (gint)-1;
-  else if (((OpenGLExtension*)a)->priority > ((OpenGLExtension*)b)->priority)
+  else if (((VisuExtension*)a)->priority > ((VisuExtension*)b)->priority)
     return (gint)+1;
   else
     return (gint)0;
@@ -486,17 +525,17 @@ static gboolean readExtensionRendering(gchar **lines, int nbLines, int position,
 				       VisuData *dataObj _U_, GError **error)
 {
   gchar **val;
-  OpenGLExtension *ext;
-  RenderingModeId id;
+  VisuExtension *ext;
+  VisuRenderingModeId id;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!configFileRead_string(lines[0], position, &val, 2, FALSE, error))
+  if (!tool_configFile_readString(lines[0], position, &val, 2, FALSE, error))
     return FALSE;
-  ext = OpenGLExtensionGet_fromName(val[0]);
+  ext = VisuExtensionGet_fromName(val[0]);
   if (!ext)
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: the extension"
 			     " '%s' is unknown.\n"), position, val[0]);
       g_strfreev(val);
@@ -504,30 +543,30 @@ static gboolean readExtensionRendering(gchar **lines, int nbLines, int position,
     }
   if (!openGLGet_renderingFromName(val[1], &id))
     {
-      *error = g_error_new(CONFIG_FILE_ERROR, CONFIG_FILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
 			   _("Parse error at line %d: the rendering mode"
 			     " '%s' is unknown.\n"), position, val[1]);
       g_strfreev(val);
       return FALSE;
     }
   g_strfreev(val);
-  OpenGLExtensionSet_preferedRenderingMode(ext, id);
+  visu_extension_setPreferedRenderingMode(ext, id);
 
   return TRUE;
 }
 static void exportParametersRendering(GString *data, VisuData *dataObj _U_)
 {
   GList *tmp;
-  OpenGLExtension *ext;
+  VisuExtension *ext;
   const char **names;
 
   g_string_append_printf(data, "# %s\n", DESC_PARAMETER_MODE);
 
   names = openGLGet_allRenderingModes();
-  tmp = availableOpenGLExtensions;
+  tmp = allExtensions;
   while (tmp)
     {
-      ext = (OpenGLExtension*)tmp->data;
+      ext = (VisuExtension*)tmp->data;
       if (ext->isSensitiveToRenderingMode &&
 	  ext->preferedRenderingMode < nb_renderingModes)
 	g_string_append_printf(data, "%s: %s %s\n", FLAG_PARAMETER_MODE,
