@@ -47,6 +47,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include "openGLFunctions/objectList.h"
 #include "openGLFunctions/renderingMode.h"
 #include "visu_data.h"
 
@@ -55,111 +56,98 @@
 /***************/
 
 /**
- * OPENGL_EXTENSION_PRIORITY_FIRST
+ * VISU_EXTENSION_PRIORITY_BACKGROUND
  *
  * An extension with this priority is drawn first.
  */
-#define OPENGL_EXTENSION_PRIORITY_FIRST 0
+#define VISU_EXTENSION_PRIORITY_BACKGROUND 0
 /**
- * OPENGL_EXTENSION_PRIORITY_HIGH
+ * VISU_EXTENSION_PRIORITY_NODES
  *
- * An extension with this priority is quickly drawn.
+ * An extension with this priority is drawn alsmost first with the nodes.
  */
-#define OPENGL_EXTENSION_PRIORITY_HIGH 20
+#define VISU_EXTENSION_PRIORITY_NODES 2
 /**
- * OPENGL_EXTENSION_PRIORITY_NORMAL
+ * VISU_EXTENSION_PRIORITY_NODE_DECORATIONS
+ *
+ * An extension with this priority is drawn just after the nodes.
+ */
+#define VISU_EXTENSION_PRIORITY_NODE_DECORATIONS 5
+/**
+ * VISU_EXTENSION_PRIORITY_HIGH
  *
  * An extension with this priority is drawn after the higher priorities.
  */
-#define OPENGL_EXTENSION_PRIORITY_NORMAL 50
+#define VISU_EXTENSION_PRIORITY_HIGH 20
 /**
- * OPENGL_EXTENSION_PRIORITY_LOW
+ * VISU_EXTENSION_PRIORITY_NORMAL
+ *
+ * An extension with this priority is drawn after the higher priorities.
+ */
+#define VISU_EXTENSION_PRIORITY_NORMAL 50
+/**
+ * VISU_EXTENSION_PRIORITY_LOW
  *
  * An extension with this priority is drawn among last extensions.
  */
-#define OPENGL_EXTENSION_PRIORITY_LOW 80
+#define VISU_EXTENSION_PRIORITY_LOW 80
 /**
- * OPENGL_EXTENSION_PRIORITY_LAST
+ * VISU_EXTENSION_PRIORITY_LAST
  *
  * An extension with this priority is drawn last.
  */
-#define OPENGL_EXTENSION_PRIORITY_LAST 100
+#define VISU_EXTENSION_PRIORITY_LAST 100
 
 /**
- * OpenGLExtension_struct:
+ * VisuExtension:
  * 
- * This structure allows the user to store data
- * about an OpenGL extension.
+ * Common name to refer to a #VisuExtension_struct.
  */
-struct OpenGLExtension_struct;
-/**
- * OpenGLExtension:
- * 
- * Common name to refer to a #OpenGLExtension_struct.
- */
-typedef struct OpenGLExtension_struct OpenGLExtension;
+typedef struct _VisuExtension VisuExtension;
 
 /**
- * rebuildObjectListFunc:
+ * VisuExtensionRebuildFunc:
  * @dataObj: the #VisuData object to be rebuilt.
  *
  * Prototypes used to recreate OpenGL list of objects for each extension.
  */
-typedef void (*rebuildObjectListFunc)(VisuData *dataObj);
+typedef void (*VisuExtensionRebuildFunc)(VisuData *dataObj);
 
+VisuExtension* visu_extension_new(const gchar* name, const gchar *nameI18n,
+				  const gchar* description,
+				  int objectListId, VisuExtensionRebuildFunc rebuild);
 /**
- * OpenGLExtension_new:
- * @name: name of the extension, in ASCII, used as id in the config files,
- * @nameI18n: name in UTF8 that can be translated and shown to user,
- * @description: a brief description of the extension (can be null),
- * @objectListId: an int to identify an list of OpenGL objects (null
- * if this extension as no OpenGL object,
- * @rebuild: handler to a method that is called every time V_Sim needs
- * to create again the OpenGL object list. If NULL, nothing is called.
- *
- * Create a new OpenGLExtension with the specified name, description
- * and OpenGL object list. The priority is set by default to
- * #OPENGL_EXTENSION_PRIORITY_NORMAL. The flag used to store
- * the OpenGL state is put to FALSE by default (see
- * OpenGLExtensionSet_saveOpenGLState() to chance it).
- *
- * Returns: the new OpenGLExtension or null if something wrong happens.
- */
-OpenGLExtension* OpenGLExtension_new(const gchar* name, const gchar *nameI18n,
-				     const gchar* description,
-				     int objectListId, rebuildObjectListFunc rebuild);
-/**
- * OpenGLExtension_free:
+ * visu_extension_free:
  * @extension: the extension to delete.
  *
  * Free all the allocated attributes of the specified method.
  */
-void OpenGLExtension_free(OpenGLExtension* extension);
+void visu_extension_free(VisuExtension* extension);
 /**
- * OpenGLExtensionGet_list:
+ * visuExtensions_getList:
  *
- * This method is used to get the list of all registered OpenGLExtension.
+ * This method is used to get the list of all registered VisuExtension.
  * This list is own by V_Sim and should not be freed.
  *
- * Returns: the list of all OpenGLExtension.
+ * Returns: the list of all VisuExtension.
  */
-GList* OpenGLExtensionGet_list();
+GList* visuExtensions_getList(void);
 
 /**
- * OpenGLExtensionSet_priority:
- * @extension: a #OpenGLExtension object ;
+ * visu_extension_setPriority:
+ * @extension: a #VisuExtension object ;
  * @priority: an integer value.
  *
  * Extentions are drawn in an order that depends on their priority.
  * The lower is the number, the sooner the extension is drawn. Flags,
- * such as #OPENGL_EXTENSION_PRIORITY_NORMAL or #OPENGL_EXTENSION_PRIORITY_LOW,
+ * such as #VISU_EXTENSION_PRIORITY_NORMAL or #VISU_EXTENSION_PRIORITY_LOW,
  * can be used or user defined values are also possible.
  */
-void OpenGLExtensionSet_priority(OpenGLExtension* extension, int priority);
+void visu_extension_setPriority(VisuExtension* extension, guint priority);
 
 /**
- * OpenGLExtensionSet_saveOpenGLState:
- * @extension: a #OpenGLExtension object ;
+ * visu_extension_setSaveOpenGLState:
+ * @extension: a #VisuExtension object ;
  * @saveState: an boolean value.
  *
  * If the extension needs to change some OpenGL state (to disable the fog for example,
@@ -168,37 +156,37 @@ void OpenGLExtensionSet_priority(OpenGLExtension* extension, int priority);
  * the extension can't just save and restore state itself because when the list is called,
  * the state can have been changed.
  */
-void OpenGLExtensionSet_saveOpenGLState(OpenGLExtension *extension, gboolean saveState);
+void visu_extension_setSaveOpenGLState(VisuExtension *extension, gboolean saveState);
 
 /**
- * OpenGLExtensionSet_sensitiveToRenderingMode:
- * @extension: a #OpenGLExtension object ;
+ * visu_extension_setSensitiveToRenderingMode:
+ * @extension: a #VisuExtension object ;
  * @status: an boolean value.
  *
  * If @status is TRUE, when the extension is rendered, OpenGL context is
  * switched to the rendering mode preferd for the extension. Use
- * OpenGLExtensionSet_preferedRenderingMode() to choose one.
+ * visu_extension_setPreferedRenderingMode() to choose one.
  */
-void OpenGLExtensionSet_sensitiveToRenderingMode(OpenGLExtension* extension, gboolean status);
+void visu_extension_setSensitiveToRenderingMode(VisuExtension* extension, gboolean status);
 /**
- * OpenGLExtensionSet_preferedRenderingMode:
- * @extension: a #OpenGLExtension object ;
- * @value: see #RenderingModeId to choose one.
+ * visu_extension_setPreferedRenderingMode:
+ * @extension: a #VisuExtension object ;
+ * @value: see #VisuRenderingModeId to choose one.
  *
  * This method is used to specify the rendering mode that the extension should use
  * to be drawn (if the sensitive flag has been set, see
- * OpenGLExtensionSet_sensitiveToRenderingMode()). If the @value is set
+ * visu_extension_setSensitiveToRenderingMode()). If the @value is set
  * to followGeneralSetting, the extension follows the global setting
  * for rendering mode.
  *
  * Returns: TRUE if the "OpenGLAskForReDraw" should be emitted.
  */
-gboolean OpenGLExtensionSet_preferedRenderingMode(OpenGLExtension* extension,
-						  RenderingModeId value);
+gboolean visu_extension_setPreferedRenderingMode(VisuExtension* extension,
+						  VisuRenderingModeId value);
 
 
 /**
- * OpenGLExtensionGet_active:
+ * visu_extension_getActive:
  * @extension: the extension.
  *
  * Get if the extension is used or not. If not its ObjectList
@@ -206,78 +194,84 @@ gboolean OpenGLExtensionSet_preferedRenderingMode(OpenGLExtension* extension,
  *
  * Returns: 1 if used, 0 otherwise.
  */
-int OpenGLExtensionGet_active(OpenGLExtension* extension);
+int visu_extension_getActive(VisuExtension* extension);
 /**
- * OpenGLExtensionSet_active:
+ * visu_extension_setActive:
  * @extension: the extension,
  * @value: the new value.
  *
  * Set if an extension is actually used or not.
  */
-void OpenGLExtensionSet_active(OpenGLExtension* extension, int value);
+void visu_extension_setActive(VisuExtension* extension, int value);
 
 /**
- * OpenGLExtensionRegister:
+ * visuExtensions_add:
  * @extension: an extension.
  *
  * A method used by user to registered a new extension.
  */
-void OpenGLExtensionRegister(OpenGLExtension *extension);
+void visuExtensions_add(VisuExtension *extension);
 
 /**
- * OpenGLExtensionGet_fromName:
+ * VisuExtensionGet_fromName:
  * @name: a string.
  *
  * Look for the extension with this name.
  *
  * Returns: the extension or NULL if none.
  */
-OpenGLExtension* OpenGLExtensionGet_fromName(const gchar* name);
+VisuExtension* VisuExtensionGet_fromName(const gchar* name);
 
 /**
- * OpenGLExtensionRemove:
+ * visuExtensions_remove:
  * @extension: an extension.
  *
- * This method is used to removed fom the list of registered #OpenGLExtension
+ * This method is used to removed fom the list of registered #VisuExtension
  * the given one. Removing @extension does not free it.
  */
-void OpenGLExtensionRemove(OpenGLExtension *extension);
+void visuExtensions_remove(VisuExtension *extension);
 
 /**
- * OpenGLExtensionCall_allLists:
+ * visuExtensions_callAllLists:
  *
  * For each registered extension that has a valid list (id > 1000),
  * it calls it with glCallList.
  */
-void OpenGLExtensionCall_allLists();
+void visuExtensions_callAllLists(void);
 /**
- * OpenGLExtensionCall_list:
+ * visuExtensions_callList:
  * @name: the name of the list to be called.
+ * @lastOnly: a boolean.
  *
- * Select the #OpenGLExtension matching the given @name and call
- * it. To draw all of them, use callAllExtensionsLists() instead.
+ * Select the #VisuExtension matching the given @name and call
+ * it. The call is indeed done only if the extension is used. If
+ * @lastOnly is TRUE, the list is called only if it has a
+ * #VISU_EXTENSION_PRIORITY_LAST priority. On the contrary the list
+ * is called only if its priority is lower than
+ * #VISU_EXTENSION_PRIORITY_LAST. To draw all of them, use
+ * visuExtensions_callAllLists() instead.
  */
-void OpenGLExtensionCall_list(const char *name, gboolean lastOnly);
-void OpenGLExtensionCall_lastLists();
+void visuExtensions_callList(const char *name, gboolean lastOnly);
+void visuExtensions_callAllLastLists(void);
 /**
- * rebuildAllExtensionsLists:
+ * visuExtensions_rebuildAllLists:
  * @dataObj: the #VisuData object to be rebuilt.
  *
  * For each registered extension that has a valid rebuild method,
  * it calls it.
  */
-void rebuildAllExtensionsLists(VisuData *dataObj);
+void visuExtensions_rebuildAllLists(VisuData *dataObj);
 /**
- * OpenGLExtensionRebuild_list:
+ * visuExtensions_rebuildList:
  * @dataObj: the #VisuData object to be rebuilt ;
  * @name: the name of the list to be rebuilt.
  *
- * Select the #OpenGLExtension matching the given @name and rebuild
+ * Select the #VisuExtension matching the given @name and rebuild
  * it. This routine does not sort the extension on their priority and
  * should be used only to draw some selected extensions. To draw all
  * of them, use rebuildAllExtensionsLists() instead.
  */
-void OpenGLExtensionRebuild_list(VisuData *dataObj, const char *name);
+void visuExtensions_rebuildList(VisuData *dataObj, const char *name);
 
 
 
@@ -286,7 +280,7 @@ void OpenGLExtensionRebuild_list(VisuData *dataObj, const char *name);
 /****************/
 
 /**
- * OpenGLExtension_struct:
+ * VisuExtension:
  * @name: name of the extension, in ASCII, used as id in the config
  * files ;
  * @nameI18n: name in UTF8 that can be translated and shown to user ;
@@ -308,7 +302,7 @@ void OpenGLExtensionRebuild_list(VisuData *dataObj, const char *name);
  * This structure allows the user to store data
  * about an OpenGL extension.
  */
-struct OpenGLExtension_struct
+struct _VisuExtension
 {
   /* Some variable to describe this OpenGL extension.
      The attribute name is mandatory since it is
@@ -321,10 +315,10 @@ struct OpenGLExtension_struct
   int objectListId;
 
   /* Function called to rebuild the object list of the extension. */
-  rebuildObjectListFunc rebuild;
+  VisuExtensionRebuildFunc rebuild;
 
   /* A priority for the extension. */
-  int priority;
+  guint priority;
 
   /* If set, V_Sim save the OpenGL state before the list
      id is called and restore all states after. */
@@ -337,7 +331,7 @@ struct OpenGLExtension_struct
      mode is used. Otherwise the value is stored in
      preferedRenderingMode. */
   gboolean isSensitiveToRenderingMode;
-  RenderingModeId preferedRenderingMode;
+  VisuRenderingModeId preferedRenderingMode;
 
   /* A boolean to know if this extension is actually used
      or not. */
@@ -345,25 +339,25 @@ struct OpenGLExtension_struct
 };
 
 /**
- * initOpenGLExtensions:
+ * initVisuExtensions:
  *
  * Initialise all the variable of this part. It calls all
- * the elements in %listInitExtensionFunc (that stores the
+ * the elements in listInitExtensionFunc (that stores the
  * init function of the extensions). If these elements return
- * valid OpenGLExtension, they are registered through a call
- * to registerOpenGLExtension().
+ * valid VisuExtension, they are registered through a call
+ * to registerVisuExtension().
  *
  * Returns: 1 if everything goes allright during the initialisation.
  */
-int initOpenGLExtensions();
+int initVisuExtensions(void);
 /**
  * loadExtensions:
  *
  * This method is used when V_Sim is initialized and should
  * not be called elsewhere. For each valid init method found
- * in #listInitExtensionFunc, it is called.
+ * in listInitExtensionFunc, it is called.
  */
-void loadExtensions();
+void loadExtensions(void);
 
 
 #endif
