@@ -56,18 +56,24 @@
  *
  * This prototype is used whenever a method is required to create a GtkWidget.
  *
- * Returns: a newly created GtkWidget.
+ * Returns: (transfer full): a newly created GtkWidget.
  */
-typedef GtkWidget* (*VisuGtkWidgetFunc)();
+typedef GtkWidget* (*VisuGtkWidgetFunc)(void);
 
 /**
  * VisuGtkInitWidgetFunc:
+ * @panel: a location for a #GtkWindow ;
+ * @renderWindow: a location for a #GtkWindow ;
+ * @renderArea: a location for a #GtkWidget.
  *
- * This prototype is used whenever a method is required to create a GtkWidget.
- *
- * Returns: a newly created GtkWidget.
+ * This prototype is used whenever a method is required to initialise
+ * the GTK interface of V_Sim. @panel must be set to point on the
+ * window of the command panel, @renderWindow must point to the window
+ * containing the rendering area (can be the same than @panel) and
+ * @renderArea contains the widget that does the OpenGL rendering.
  */
-typedef void (*VisuGtkInitWidgetFunc)(GtkWindow **panel, GtkWindow **render);
+typedef void (*VisuGtkInitWidgetFunc)(GtkWindow **panel, GtkWindow **renderWindow,
+				      GtkWidget **renderArea);
 
 /**
  * visuGtkRaise_warning:
@@ -107,7 +113,7 @@ typedef gboolean (*VisuGtkSetFilesFunc)(VisuData *data, GtkWindow *parent);
 /**
  * visuGtkSet_renderingSpecificMethods:
  * @method: a #RenderingMethod object;
- * @methodLoad: a #GtkMainSetFilesFunc method (can be NULL).
+ * @methodLoad: a #VisuUiMainSetFilesFunc method (can be NULL).
  *
  * This function is used by a client to add gtk methods to a rendering method.
  * The @methodLoad argument is called to when the 'load' button is pushed.
@@ -118,7 +124,7 @@ void visuGtkSet_renderingSpecificMethods(VisuRendering *method,
  * visuGtkGet_renderingSpecificOpen:
  * @method: a #RenderingMethod object.
  *
- * This method is used to retrieve the #GtkMainSetFilesFunc associate with
+ * This method is used to retrieve the #VisuUiMainSetFilesFunc associate with
  * the specified @method.
  *
  * Returns: a load method if one has been specified for @method
@@ -135,7 +141,7 @@ VisuGtkSetFilesFunc visuGtkGet_renderingSpecificOpen(VisuRendering *method);
  *
  * A container for the relevant widgets of the preview area.
  */
-typedef struct VisuGtkPreview_struct
+typedef struct _VisuGtkPreview
 {
   GtkWidget *check;
   GtkWidget *image;
@@ -222,12 +228,12 @@ gboolean visuGtkGet_fileFromDefaultFileChooser(VisuData *data, GtkWindow *parent
 void visuGtkMain(VisuGtkInitWidgetFunc panelFunc);
 /**
  * visuGtkRun_commandLine:
- * @data: a pointer to the command panel (see #GtkMain).
+ * @data: a pointer to the command panel (see #VisuUiMain).
  *
  * Call the get routines from the command line module and deal with
  * them. This method is not aware of the panels and is intended to be
  * called only when the command panel is not used. In the opposite
- * case, use gtkMainRun_commandLine() instead.
+ * case, use visu_ui_main_runCommandLine() instead.
  *
  * Returns: FALSE always.
  */
@@ -238,23 +244,12 @@ gboolean visuGtkRun_commandLine(gpointer data);
  *
  * It runs the Gtk event loop, flushing it before returning.
  */
-void visuGtkWait();
-
-/**
- * visuGtkLoad_file:
- * @data: the #VisuData to be loaded.
- * @iSet: the id of @data to load.
- *
- * This method calls the general function to load data from file
- * and deals with errors with gtkDialogs. The filenames must have
- * already been set into @data using visuDataAdd_file().
- */
-void visuGtkLoad_file(VisuData *data, guint iSet);
+void visuGtkWait(void);
 
 /**
  * FileFilterCustom:
  * @gtkFilter: the #GtkFileFilter associate to @visuFilter.
- * @visuFilter: a #FileFormat object.
+ * @visuFilter: a #ToolFileFormat object.
  *
  * Structure used to associate the V_Sim way to store file filters
  * with the Gtk way.
@@ -262,12 +257,12 @@ void visuGtkLoad_file(VisuData *data, guint iSet);
 typedef struct FileFilterCustom_struct
 {
   GtkFileFilter *gtkFilter;
-  FileFormat* visuFilter;
+  ToolFileFormat* visuFilter;
 } FileFilterCustom;
 
 /**
  * visuGtkCreate_fileChooserFilter:
- * @list: a GList of #FileFormat ;
+ * @list: a GList of #ToolFileFormat ;
  * @fileChooser: a file chooser to associate filters with.
  *
  * Create a list of GtkFileFilter created from the given list of file formats
@@ -277,12 +272,29 @@ typedef struct FileFilterCustom_struct
  */
 GList* visuGtkCreate_fileChooserFilter(GList *list, GtkWidget *fileChooser);
 
+/**
+ * VisuGtkDirType:
+ * @VISU_DIR_FILE: default kind of directory ;
+ * @VISU_DIR_SURFACE: directory for surfaces ;
+ * @VISU_DIR_DATAFILE: directory for data files ;
+ * @VISU_DIR_CONF: directory for configuration files ;
+ * @VISU_DIR_BROWSER: directory used in the browser.
+ * @N_VISU_DIR: private.
+ *
+ * V_Sim remembers the last open directory when presenting a new file
+ * selector. This enum is used to specify different kind of
+ * directories. Like that saving a configuration file in a given
+ * directory will not affect the prefered directory for browsing a
+ * list of files.
+ */
 typedef enum
   {
     VISU_DIR_FILE,
     VISU_DIR_SURFACE,
     VISU_DIR_DATAFILE,
     VISU_DIR_CONF,
+    VISU_DIR_BROWSER,
+    /*< private >*/
     N_VISU_DIR
   } VisuGtkDirType;
 /**
@@ -296,17 +308,18 @@ typedef enum
  *
  * Returns: a string owned by V_Sim.
  */
-gchar* visuGtkGet_lastOpenDirectory();
+gchar* visuGtkGet_lastOpenDirectory(void);
 /**
  * visuGtkSet_lastOpenDirectory:
- * @directory: a full path to a directory.
+ * @directory: a full path to a directory ;
+ * @type: the kind of directory to set the remember flag on.
  *
  * V_Sim stores the last open directory to set the file chooser to
  * this one the next time it will come. Use this routine each time a
  * file chooser returns GTK_RESPONSE_OK. The given string will be
  * copied and can be freed after use.
  */
-void visuGtkSet_lastOpenDirectory(char* directory, VisuGtkDirType type);
+void visuGtkSet_lastOpenDirectory(const char* directory, VisuGtkDirType type);
 
 /**
  * visuGtkCreate_pixbuf:
@@ -320,24 +333,39 @@ void visuGtkSet_lastOpenDirectory(char* directory, VisuGtkDirType type);
 GdkPixbuf* visuGtkCreate_pixbuf(const gchar *filename);
 /**
  * visuGtkCreate_main:
+ * @panel: a location for a #GtkWindow, will be NULL at return time ;
+ * @renderWindow: a location for a #GtkWindow ;
+ * @renderArea: a location for a #GtkWidget.
  *
- * A convenient routine that creates a #RenderingWindow alone. To
- * create also a command panel, gtkMainClassCreate_main() should be
+ * A convenient routine that creates a #VisuRenderingWindow alone. To
+ * create also a command panel, visu_uiMainClass_createMain() should be
  * used instead.
- *
- * Returns: the window containing the rendering area.
  */
-void visuGtkCreate_main(GtkWindow **panel, GtkWindow **render);
+void visuGtkCreate_main(GtkWindow **panel, GtkWindow **renderWindow,
+			GtkWidget **renderArea);
 /**
- * visuGtkGet_parent:
+ * visuGtkGet_panel:
  *
- * A convenient function to get the main GtkWindow (either the command
- * panel or the rendering area itself).
+ * A convenient function to get the command panel window.
  *
- * Returns: a #GtkWindow or NULL if the rendering area is a simple
- * #GtkWidget.
+ * Returns: a #GtkWindow.
  */
-GtkWindow* visuGtkGet_panel();
-GtkWindow* visuGtkGet_render();
+GtkWindow* visuGtkGet_panel(void);
+/**
+ * visuGtkGet_render:
+ *
+ * A convenient function to get the rendering area window.
+ *
+ * Returns: a #GtkWindow.
+ */
+GtkWindow* visuGtkGet_render(void);
+/**
+ * visuGtkGet_renderArea:
+ *
+ * A convenient function to get the rendering area widget.
+ *
+ * Returns: a #GtkWidget.
+ */
+GtkWidget* visuGtkGet_renderArea(void);
 
 #endif
