@@ -46,19 +46,25 @@
 #include "visu_commandLine.h"
 #include "visu_tools.h"
 #include "visu_basic.h"
+#include "opengl.h"
+#include "visu_plugins.h"
 #include "visu_gtk.h"
 #include "gtk_main.h"
 #include "visu_data.h"
+#include "extensions/scale.h"
 #include "renderingMethods/renderingSpin.h"
-#include "renderingBackend/visu_windowInterface.h"
 #include "gtk_renderingWindowWidget.h"
 
+#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <locale.h>
 #include <glib.h>
 
+#ifdef WITH_GOBJECT_INTROSPECTION
+#include <girepository.h>
+#endif
 #ifdef HAVE_GTKGLEXT
 #include <gdk/gdkgl.h>
 #endif
@@ -71,13 +77,18 @@ int main (int argc, char *argv[])
   char *arg;
   VisuData *newData;
   gchar *dirname, *normDir;
+#ifdef WITH_GOBJECT_INTROSPECTION
+  GError *error;
+#endif
+  VisuRenderingWindow *window;
 
 #if DEBUG == 1 && VISU_MEM_CHECK == 1
   g_mem_set_vtable(glib_mem_profiler_table);
 #endif
+  g_type_init();
 
   DBG_fprintf(stderr, "--- Get the default path ---\n");
-  visuBasicSet_paths(argv[0]);
+  visu_basic_setExePath(argv[0]);
 
 #ifdef G_THREADS_ENABLED
   DBG_fprintf(stderr, "--- Initialise threads ---\n");
@@ -92,7 +103,7 @@ int main (int argc, char *argv[])
 #endif
 
   DBG_fprintf(stderr, "--- Parse the command line ---\n");
-  res = parseCommandLine(argc, argv);
+  res = commandLineParse(argc, argv);
   if (res)
     exit(1);
   /* 5444o still allocated by GLIB. */
@@ -102,68 +113,113 @@ int main (int argc, char *argv[])
   if (arg)
     {
 #ifdef HAVE_GTKGLEXT
-      DBG_fprintf(stderr, "Visu Gtk: initialise Gtk.\n");
+      DBG_fprintf(stderr, "Visu Main: initialise Gtk.\n");
       gtk_init(&argc, &argv);
 
-      DBG_fprintf(stderr, "Visu Gtk: initialise GtkGlExt.\n");
+      DBG_fprintf(stderr, "Visu Main: initialise GtkGlExt.\n");
       gdk_gl_init(&argc, &argv);
 #endif
 
-      DBG_fprintf(stderr, "Visu Basic : V_Sim has been called in an export session,"
+      DBG_fprintf(stderr,"--- Initialising plugins ---\n");
+      visu_plugins_init();
+
+      DBG_fprintf(stderr, "Visu Main: test for help message.\n");
+      if (visu_basic_showOptionHelp(FALSE))
+        exit(0);
+
+      DBG_fprintf(stderr, "Visu Main: V_Sim has been called in an export session,"
 		  " with parameter '%s'.\n", arg);
-      res = visuBasicExport_main();
+      res = visu_basic_mainExport();
 
       return res;
     }
 
+  /* Introspection case, must be called after g_object initialisation. */
+  if (commandLineGet_introspect())
+    {
+#ifdef WITH_GOBJECT_INTROSPECTION
+      /* Additional classes. */
+      g_type_class_ref(VISU_RENDERING_TYPE);
+      g_type_class_ref(VISU_DATA_TYPE);
+      g_type_class_ref(VISU_GLEXT_SCALE_TYPE);
+      g_type_class_ref(VISU_MARKS_TYPE);
+      g_type_class_ref(RENDERING_WINDOW_TYPE);
+      g_type_class_ref(VISU_UIMAIN_TYPE);
+
+      DBG_fprintf(stderr, "Visu Main: call introspection for file '%s'.\n",
+		  commandLineGet_introspect());
+      error = (GError*)0;
+      g_irepository_dump(commandLineGet_introspect(), &error);
+      if (error)
+	{
+	  g_error("%s", error->message);
+	  g_error_free(error);
+	}
+      return 0;
+#else
+      g_warning("Introspection required but not compiled.");
+#endif
+    }
+
   DBG_fprintf(stderr, "Visu Main: initialise Gtk.\n");
   gtk_init(&argc, &argv);
 
+  gtk_window_set_default_icon_name("v_sim");
+  gtk_icon_theme_append_search_path(gtk_icon_theme_get_default(),
+                                    V_SIM_ICONS_DIR);
+  g_set_application_name(_("Visualise atomic simulations"));
+
 #ifdef HAVE_GTKGLEXT
   DBG_fprintf(stderr, "Visu Main: initialise GtkGlExt.\n");
   gdk_gl_init(&argc, &argv);
 #endif
   /* 38713o still allocated by GLIB and GTK. */
 
-  visuBasicInit();
+  initVisuBasic();
+  initOpenglGraphics();
 
   /* the default is V_Sim with gtk interface. */
   if (!strcmp(commandLineGet_windowMode(), "renderOnly"))
     visuGtkMain(visuGtkCreate_main);
   else
-    visuGtkMain(gtkMainClassCreate_main);
+    visuGtkMain(visu_uiMainClass_createMain);
+  window = RENDERING_WINDOW(visuGtkGet_renderArea());
 
-  newData = visuBasicSet_dataFromCommandLine();
+  DBG_fprintf(stderr,"--- Initialising plugins ---\n");
+  visu_plugins_init();
+
+  DBG_fprintf(stderr, "Visu Main: test for help message.\n");
+  if (visu_basic_showOptionHelp(FALSE))
+    exit(0);
+
+  newData = visu_basic_setDataFromCommandLine();
   if (newData)
     {
-      dirname = g_path_get_dirname(visuDataGet_file(newData, FILE_KIND_POSITION,
-						    (FileFormat**)0));
+      dirname = g_path_get_dirname(visu_data_getFile(newData, FILE_KIND_POSITION,
+						    (ToolFileFormat**)0));
       normDir = normalize_path(dirname);
       visuGtkSet_lastOpenDirectory((char*)normDir, VISU_DIR_FILE);
       g_free(dirname);
       g_free(normDir);
 
-      visuGtkLoad_file(newData, commandLineGet_iSet());
+      visu_rendering_window_loadFile(window, newData, commandLineGet_iSet());
 
       /* Run the command line. */
       if (!strcmp(commandLineGet_windowMode(), "renderOnly"))
 	g_idle_add(visuGtkRun_commandLine, (gpointer)0);
       else
 	{
-	  g_idle_add(gtkMainInit_panels, (gpointer)0);
-	  g_idle_add(gtkMainRun_commandLine, (gpointer)visuGtkGet_panel());
+	  g_idle_add(visu_ui_main_initPanels, (gpointer)0);
+	  g_idle_add(visu_ui_main_runCommandLine, (gpointer)visuGtkGet_panel());
 	}
-
-      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
   else
     {
-      renderingWindowSet_visuData(RENDERING_WINDOW(visuRenderingWindowGet_current()),
-				(VisuData*)0);
+      visu_rendering_window_setData(window, (VisuData*)0);
 
       /* Run the command line. */
       if (strcmp(commandLineGet_windowMode(), "renderOnly"))
-	g_idle_add(gtkMainInit_panels, (gpointer)0);
+	g_idle_add(visu_ui_main_initPanels, (gpointer)0);
     }
 
   DBG_fprintf(stderr, "Visu Main: starting main GTK loop.\n");
