@@ -1,7 +1,7 @@
 /*   EXTRAITS DE LA LICENCE
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
-  
+
 	Adresse ml :
 	BILLARD, non joignable par ml ;
 	CALISTE, damien P caliste AT cea P fr.
@@ -67,8 +67,26 @@
  *
  * <para>The only basic informations own by the #VisuNode structure is
  * basicaly its position. To add further informations (such as
- * orientation for the spin), the node must be attached to a #VisuData
- * and then visuDataAdd_nodeProperty() can be used.</para>
+ * orientation for the spin), define a node property using
+ * visu_node_property_newPointer().</para>
+ */
+
+/**
+ * VisuNode:
+ * @xyz: (in) (array fixed-size=3): an array of three floating point values that positions the node in (x, y, z) ;
+ * @translation: (in) (array fixed-size=3): an array of three floating point values that translates the
+ *               node to its drawn position from (x, y, z) ;
+ * @number: an integer that corresponds to its position in the entry file, it references
+ *          also the node itself in the array 'fromNumberToVisuNode' of the #VisuData
+ *          that contains the node ;
+ * @posElement: an integer that is the position of the #VisuElement of the node
+ *              in the array 'fromIntToVisuElement' of the #VisuData object that
+ *              contains the node ;
+ * @posNode: an integer that is the position of the node itself in the array
+ *           'nodes' of the #VisuData object that contains the node ;
+ * @rendered: a boolean to store if the node is drwn or not.
+ *
+ * Structure to store primary data of a node.
  */
 
 /* Local routines. */
@@ -78,7 +96,7 @@ static void reallocNodeProperty(gpointer key, gpointer value, gpointer data);
 static void createNodeproperty(gpointer key, gpointer value, gpointer data);
 static VisuNode* newOrCopyNode(VisuNodeArray *nodeArray, int iEle, int oldNodeId);
 
-/* The number of nodes to be reallocated each time the visuNodeGet_newNode()
+/* The number of nodes to be reallocated each time the visu_node_array_getNewNode()
    is called. */
 #define REALLOCATION_STEP 100
 
@@ -91,7 +109,7 @@ struct twoNodes
   VisuNode *newNode;
 };
 
-struct VisuNodeProperty_struct
+struct _VisuNodeProperty
 {
   /* A label to define the property. */
   gchar *name;
@@ -120,8 +138,17 @@ struct VisuNodeProperty_struct
   gpointer user_data;
 };
 
-
-int visuNodeSet_visibility(VisuNode* node, gboolean visibility)
+/**
+ * visu_node_setVisibility:
+ * @node: a #VisuNode object ;
+ * @visibility: a boolean.
+ *
+ * This method is used to turn on or off the drawing of the specified node.
+ *
+ * Returns: true if the calling method should recreate the node list with
+ * a call to the visu_data_createAllNodes() method.
+ */
+int visu_node_setVisibility(VisuNode* node, gboolean visibility)
 {
   g_return_val_if_fail(node, 0);
 
@@ -130,18 +157,35 @@ int visuNodeSet_visibility(VisuNode* node, gboolean visibility)
   node->rendered = visibility;
   return 1;
 }
-gboolean visuNodeGet_visibility(VisuNode* node)
+
+/**
+ * visu_node_getVisibility:
+ * @node: a #VisuNode object.
+ *
+ * This method is used get the status of the drawing state of a node.
+ *
+ * Returns: true if the node is rendered, false otherwise.
+ */
+gboolean visu_node_getVisibility(VisuNode* node)
 {
   g_return_val_if_fail(node, FALSE);
 
   return node->rendered;
 }
-void visuNodeNew_values(VisuNode *node, float xyz[3])
+
+/**
+ * visu_node_newValues:
+ * @node: an allocated #VisuNode object ;
+ * @xyz: (in) (array fixed-size=3): the coordinates to set.
+ * 
+ * Set the coordinates and set all other values to default.
+ */
+void visu_node_newValues(VisuNode *node, float xyz[3])
 {
   g_return_if_fail(node);
 
-/*   DBG_fprintf(stderr, "Visu Node: set new position for node %d (%g;%g;%g).\n", */
-/* 	      node->number, xyz[0], xyz[1], xyz[2]); */
+  DBG_fprintf(stderr, "Visu Node: set new position for node %d (%g;%g;%g).\n",
+              node->number, xyz[0], xyz[1], xyz[2]);
   node->xyz[0]         = xyz[0];
   node->xyz[1]         = xyz[1];
   node->xyz[2]         = xyz[2];
@@ -150,7 +194,15 @@ void visuNodeNew_values(VisuNode *node, float xyz[3])
   node->translation[2] = 0.;
   node->rendered       = TRUE;
 }
-void visuNodeCopy(VisuNode *nodeTo, VisuNode *nodeFrom)
+
+/**
+ * visu_node_copy:
+ * @nodeTo: an allocated #VisuNode object ;
+ * @nodeFrom: an allocated #VisuNode object.
+ * 
+ * Copy all attributes of the object @nodeFrom to @nodeTo.
+ */
+void visu_node_copy(VisuNode *nodeTo, VisuNode *nodeFrom)
 {
   g_return_if_fail(nodeTo && nodeFrom);
 
@@ -168,7 +220,17 @@ void visuNodeCopy(VisuNode *nodeTo, VisuNode *nodeFrom)
 /***************/
 /* Node Arrays */
 /***************/
-VisuNodeArray* visuNodeNew_nodes(unsigned int nTypes, unsigned int *nNodes)
+
+/**
+ * visu_node_array_newNodes:
+ * @nTypes: the size of nNodes.
+ * @nNodes: (in) (array length=nTypes): an array giving the number of nodes per element.
+ *
+ * Create a new #VisuNodeArray structure, allocate all necessary values.
+ *
+ * Returns: (transfer none): a newly created #VisuNodeArray object.
+ */
+VisuNodeArray* visu_node_array_newNodes(unsigned int nTypes, unsigned int *nNodes)
 {
   VisuNodeArray *array;
   unsigned int i, j;
@@ -221,12 +283,21 @@ VisuNodeArray* visuNodeNew_nodes(unsigned int nTypes, unsigned int *nNodes)
      node and negative if not. The value is the node id that the
      duplicate refers to. */
   DBG_fprintf(stderr, " | create the original node property.\n");
-  array->origProp   = visuNodeNew_intProperty(array, ORIGINAL_ID);
+  array->origProp   = visu_node_property_newInteger(array, ORIGINAL_ID);
   array->nOrigNodes = 0;
 
   return array;
 }
-void visuNodeRemove_nodes(VisuNodeArray *nodeArray, int *nodeNumbers)
+
+/**
+ * visu_node_array_removeNodes:
+ * @nodeArray: a #VisuNodeArray object.
+ * @nodeNumbers: (in) (array): an array of integers (negative terminated).
+ *
+ * Remove the given #VisuNode from the @nodeArray. The properties
+ * are also updated.
+ */
+void visu_node_array_removeNodes(VisuNodeArray *nodeArray, int *nodeNumbers)
 {
   VisuNode *node;
   unsigned int i, iEle, iNode;
@@ -240,8 +311,9 @@ void visuNodeRemove_nodes(VisuNodeArray *nodeArray, int *nodeNumbers)
   for (i = 0; nodeNumbers[i] >= 0; i++)
     {
       node = nodeArray->nodeTable[nodeNumbers[i]];
+DBG_fprintf(stderr, "node : %p\n",(gpointer)node);
       g_return_if_fail(node);
-
+DBG_fprintf(stderr, "OK\n");
       iEle  = node->posElement;
       iNode = node->posNode;
       g_return_if_fail(node->number == (unsigned int)nodeNumbers[i]);
@@ -257,7 +329,7 @@ void visuNodeRemove_nodes(VisuNodeArray *nodeArray, int *nodeNumbers)
 			       nodeArray->nodes[iEle] + iNode);
 
 	  /* Then, we copy the node values themselves. */
-	  visuNodeCopy(nodeArray->nodes[iEle] + iNode,
+	  visu_node_copy(nodeArray->nodes[iEle] + iNode,
 		       nodeArray->nodes[iEle] + nodeArray->numberOfStoredNodes[iEle]);
 	  /* We update the index values. */
 	  nodeArray->nodes[iEle][iNode].posNode = iNode;
@@ -288,7 +360,20 @@ void visuNodeRemove_nodes(VisuNodeArray *nodeArray, int *nodeNumbers)
 		    sizeof(VisuNode*) * nodeArray->ntype +
 		    sizeof(VisuNode*) * nodeArray->nNodes + sizeof(VisuNodeArray)));
 }
-gboolean visuNodeRemove_allDuplicateNodes(VisuNodeArray *nodeArray,
+
+/**
+ * visu_node_array_removeAllDuplicateNodes:
+ * @nodeArray: a #VisuNodeArray object.
+ * @nodeNumbers: a location to create an arry of int.
+ *
+ * Remove all nodes that are not original in the box. The list of
+ * removed nodes ids are stored in @nodeNumbers. This array is
+ * allocated and should be freed with g_free(). If no nodes are
+ * removed, this array is not allocated.
+ *
+ * Returns: TRUE if some nodes have been removed (and @nodeNumbers allocated).
+ */
+gboolean visu_node_array_removeAllDuplicateNodes(VisuNodeArray *nodeArray,
 					  int **nodeNumbers)
 {
   int nb;
@@ -312,13 +397,24 @@ gboolean visuNodeRemove_allDuplicateNodes(VisuNodeArray *nodeArray,
 	  if (nodeArray->origProp->data_int[i][j] >= 0)
 	    (*nodeNumbers)[nb++] = nodeArray->nodes[i][j].number;
       (*nodeNumbers)[nb] = -1;
-      visuNodeRemove_nodes(nodeArray, *nodeNumbers);
+      visu_node_array_removeNodes(nodeArray, *nodeNumbers);
       return TRUE;
     }
   else
     return FALSE;
 }
-gint visuNodeGet_original(VisuNodeArray *nodeArray, guint nodeId)
+
+/**
+ * visu_node_array_getOriginal:
+ * @nodeArray: a #VisuNodeArray object.
+ * @nodeId: a node id.
+ *
+ * Test if the given @nodeId is an original or a replica for the
+ * periodisation.
+ *
+ * Returns: TRUE for an original node.
+ */
+gint visu_node_array_getOriginal(VisuNodeArray *nodeArray, guint nodeId)
 {
   VisuNode *node;
   gint orig;
@@ -333,11 +429,23 @@ gint visuNodeGet_original(VisuNodeArray *nodeArray, guint nodeId)
       orig = nodeArray->origProp->data_int[node->posElement][node->posNode];
     }
   while (orig >= 0);
-  DBG_fprintf(stderr, "Visu Node: get original from %d: %d.\n",
-	      nodeId, nodeArray->origProp->data_int[node->posElement][node->posNode]);
+/*   DBG_fprintf(stderr, "Visu Node: get original from %d: %d (%d).\n", */
+/* 	      nodeId, node->number, */
+/* 	      nodeArray->origProp->data_int[node->posElement][node->posNode]); */
   return (node->number == nodeId)?-1:(gint)node->number;
 }
-gboolean visuNodeSet_original(VisuNodeArray *nodeArray, guint nodeId)
+
+/**
+ * visu_node_array_setOriginal:
+ * @nodeArray: a #VisuNodeArray object.
+ * @nodeId: a node id.
+ *
+ * Test if the given @nodeId is an original or a replica for the
+ * periodisation.
+ *
+ * Returns: TRUE for an original node.
+ */
+gboolean visu_node_array_setOriginal(VisuNodeArray *nodeArray, guint nodeId)
 {
   VisuNode *node;
   gint orig;
@@ -353,7 +461,14 @@ gboolean visuNodeSet_original(VisuNodeArray *nodeArray, guint nodeId)
 	      nodeId, orig);
   return (orig != -1);
 }
-void visuNodeFree_nodes(VisuNodeArray *nodeArray)
+
+/**
+ * visu_node_array_freeNodes:
+ * @nodeArray: a #VisuNodeArray object.
+ *
+ * Free the given object and all associated memory.
+ */
+void visu_node_array_freeNodes(VisuNodeArray *nodeArray)
 {
   unsigned int i;
 
@@ -385,7 +500,47 @@ void visuNodeFree_nodes(VisuNodeArray *nodeArray)
   g_free(nodeArray);
   DBG_fprintf(stderr, "Visu Node: freeing node array ... OK.\n");
 }
-void visuNodeAllocate_newNodes(VisuNodeArray *nodeArray, unsigned int iEle,
+/**
+ * visu_node_array_switchNumber:
+ * @nodeArray: a #VisuNodeArray object.
+ * @from: a node id.
+ * @to: another node id.
+ *
+ * Two nodes of @nodeArray switches their number.
+ *
+ * Since: 3.6
+ *
+ * Returns: TRUE if number is switched.
+ */
+gboolean visu_node_array_switchNumber(VisuNodeArray *nodeArray, guint from, guint to)
+{
+  VisuNode *nodeFrom, *nodeTo;
+
+  if (from == to)
+    return FALSE;
+
+  nodeFrom = nodeArray->nodeTable[from];
+  nodeTo   = nodeArray->nodeTable[to];
+  nodeArray->nodeTable[from] = nodeTo;
+  nodeArray->nodeTable[to]   = nodeFrom;
+  nodeFrom->number = to;
+  nodeTo->number   = from;
+  return TRUE;
+}
+
+
+/**
+ * visu_node_array_allocateNewNodes:
+ * @nodeArray: a #VisuNodeArray object ;
+ * @iEle: the id of a #VisuElement to expand the number of allocated nodes ;
+ * @step: the number of newly allocated nodes.
+ *
+ * When a new node is required, using visu_node_array_getNewNode() or visu_node_array_getCopyNode()
+ * the storing arrays are expand automatically with a fixed increment. If the user
+ * wants to control this increment, he should call this routine before the get() ones
+ * with the appropriated @step value.
+ */
+void visu_node_array_allocateNewNodes(VisuNodeArray *nodeArray, unsigned int iEle,
 			       unsigned int step)
 {
   unsigned int j;
@@ -439,20 +594,44 @@ void visuNodeAllocate_newNodes(VisuNodeArray *nodeArray, unsigned int iEle,
 		    sizeof(VisuNode*) * nodeArray->ntype +
 		    sizeof(VisuNode*) * nodeArray->nNodes + sizeof(VisuNodeArray)));
 }
-VisuNode* visuNodeGet_newNode(VisuNodeArray *nodeArray, unsigned int iEle)
+
+/**
+ * visu_node_array_getNewNode:
+ * @nodeArray: a #VisuNodeArray object ;
+ * @iEle: an integer between 0 and @nodeArray->ntypes - 1.
+ *
+ * Return the location of an unstored node for the given #VisuElement.
+ * The returned node is then added in the list of used nodes.
+ *
+ * Returns: (transfer none): the location of a newly used node.
+ */
+VisuNode* visu_node_array_getNewNode(VisuNodeArray *nodeArray, unsigned int iEle)
 {
   DBG_fprintf(stderr, "Visu Node: create a new node of element %d.\n", iEle);
   return newOrCopyNode(nodeArray, iEle, -1);
 }
-VisuNode* visuNodeGet_copyNode(VisuNodeArray *nodeArray, VisuNode *node)
+
+/**
+ * visu_node_array_getCopyNode:
+ * @nodeArray: a #VisuNodeArray object ;
+ * @node: a node of the given #VisuNodeArray.
+ *
+ * Return the location of an unstored node that is the deep copy of the given node.
+ * The returned node is then added in the list of used nodes.
+ *
+ * Returns: (transfer none): the location of a newly used node.
+ */
+VisuNode* visu_node_array_getCopyNode(VisuNodeArray *nodeArray, VisuNode *node)
 {
   VisuNode* out;
 
+  DBG_fprintf(stderr, "Visu Node: copy a new node from node %d (%d-%d).\n",
+	      node->number, node->posElement, node->posNode);
   out = newOrCopyNode(nodeArray, node->posElement, node->number);
-  DBG_fprintf(stderr, "Visu Node: copy a new node from node %d (%d-%d) -> %d.\n",
-	      node->number, node->posElement, node->posNode, out->number);
+  DBG_fprintf(stderr, "Visu Node: copy a new node from node -> %d.\n", out->number);
   return out;
 }
+
 static VisuNode* newOrCopyNode(VisuNodeArray *nodeArray, int iEle,
 			       int oldNodeId)
 {
@@ -468,7 +647,7 @@ static VisuNode* newOrCopyNode(VisuNodeArray *nodeArray, int iEle,
 
   if (nodeArray->numberOfStoredNodes[iEle] == nodeArray->numberOfNodes[iEle])
     /* We need to realloc... */
-    visuNodeAllocate_newNodes(nodeArray, iEle, REALLOCATION_STEP);
+    visu_node_array_allocateNewNodes(nodeArray, iEle, REALLOCATION_STEP);
 
   /* Update the node internal values. */
   node         = nodeArray->nodes[iEle] + nodeArray->numberOfStoredNodes[iEle];
@@ -507,7 +686,7 @@ static VisuNode* newOrCopyNode(VisuNodeArray *nodeArray, int iEle,
      -1 if not. */
   g_value_init(&idValue, G_TYPE_INT);
   g_value_set_int(&idValue, oldNodeId);
-  visuNodePropertySet_value(nodeArray->origProp, node, &idValue);
+  visu_node_property_setValue(nodeArray->origProp, node, &idValue);
   nodeArray->nOrigNodes += (oldNodeId < 0)?1:0;
 
   return node;
@@ -554,6 +733,7 @@ static void freePropertiesStruct(gpointer data)
   g_free(prop);
   DBG_fprintf(stderr, "Visu Node: freeing property ... OK.\n");
 }
+
 /* Remove the property of the node given in data and move the
    last property of this element at the place of the removed node. */
 static void removeNodeProperty(gpointer key, gpointer value, gpointer data)
@@ -599,6 +779,7 @@ static void removeNodeProperty(gpointer key, gpointer value, gpointer data)
 	[prop->array->numberOfStoredNodes[node->posElement]] = 0;
     }
 }
+
 static void reallocNodeProperty(gpointer key, gpointer value, gpointer data)
 {
   VisuNodeProperty *prop;
@@ -632,6 +813,7 @@ static void reallocNodeProperty(gpointer key, gpointer value, gpointer data)
 	prop->data_int[iEle][j] = 0;
     }
 }
+
 static void createNodeproperty(gpointer key, gpointer value, gpointer data)
 {
   VisuNodeProperty *prop;
@@ -663,7 +845,22 @@ static void createNodeproperty(gpointer key, gpointer value, gpointer data)
 /*****************************/
 /* Public property routines. */
 /*****************************/
-void visuNodePropertySet_value(VisuNodeProperty* nodeProp, VisuNode* node,
+
+/**
+ * visu_node_property_setValue:
+ * @nodeProp: a #VisuNodeProperty object ;
+ * @node: a #VisuNode object ;
+ * @value: A GValue pointer this the value to be stored.
+ *
+ * This method is used to store some values associated with
+ * the given @node of the given @nodeArray. These values can be pointers to
+ * anything allocated (will be free automatically when the property is deleted) or
+ * they can be static values. This depends on the construction of the node property.
+ * These values can be retrieved with the visu_node_property_getValue() method.
+ *
+ * See visu_node_array_getProperty() to get a property by its name.
+ */
+void visu_node_property_setValue(VisuNodeProperty* nodeProp, VisuNode* node,
 			       GValue *value)
 {
   g_return_if_fail(nodeProp && value && nodeProp->gtype == G_VALUE_TYPE(value));
@@ -692,7 +889,21 @@ void visuNodePropertySet_value(VisuNodeProperty* nodeProp, VisuNode* node,
     }
 }
 
-GValue* visuNodePropertyGet_value(VisuNodeProperty* nodeProp, VisuNode* node,
+/**
+ * visu_node_property_getValue:
+ * @nodeProp: a #VisuNodeArray object ;
+ * @node: a #VisuNode object ;
+ * @value: an initialise GValue location.
+ *
+ * This method is used to retrieve some data associated to
+ * the specified @node, stored in the given @data. These return data
+ * should not be freed after used. The read value is stored in the given
+ * GValue pointer. This GValue must be of the right type, depending on the
+ * creation of the #VisuNodeProperty.
+ *
+ * Returns: some data associated to the key, stored the given GValue location.
+ */
+GValue* visu_node_property_getValue(VisuNodeProperty* nodeProp, VisuNode* node,
 				  GValue *value)
 {
   g_return_val_if_fail(nodeProp && value && nodeProp->gtype == G_VALUE_TYPE(value),
@@ -721,8 +932,16 @@ GValue* visuNodePropertyGet_value(VisuNodeProperty* nodeProp, VisuNode* node,
   return value;
 }
 
-
-VisuNodeProperty* visuNodeGet_property(VisuNodeArray* nodeArray, const char* key)
+/**
+ * visu_node_array_getProperty:
+ * @nodeArray: a #VisuNodeArray object ;
+ * @key: a string.
+ *
+ * This method is used to retrieve the node property associated to the given @key.
+ *
+ * Returns: (transfer none): a #VisuNodeProperty.
+ */
+VisuNodeProperty* visu_node_array_getProperty(VisuNodeArray* nodeArray, const char* key)
 {
   VisuNodeProperty *prop;
 
@@ -731,14 +950,44 @@ VisuNodeProperty* visuNodeGet_property(VisuNodeArray* nodeArray, const char* key
   prop = (VisuNodeProperty*)g_hash_table_lookup(nodeArray->properties, (gpointer)key);
   return prop;
 }
-void visuNodeFree_property(VisuNodeArray* nodeArray, const char* key)
+
+/**
+ * visu_node_array_freeProperty:
+ * @nodeArray: a #VisuNodeArray object.
+ * @key: the name of the property to be removed.
+ * 
+ * This method free the given property and all associated data.
+ */
+void visu_node_array_freeProperty(VisuNodeArray* nodeArray, const char* key)
 {
   g_return_if_fail(nodeArray && key);
 
   g_hash_table_remove(nodeArray->properties, key);
   DBG_fprintf(stderr, "Visu Node: removing the property called '%s'.\n", key);
 }
-VisuNodeProperty* visuNodeNew_pointerProperty(VisuNodeArray* nodeArray,
+
+/**
+ * visu_node_property_newPointer:
+ * @nodeArray: a #VisuNodeArray object ;
+ * @key: a string ;
+ * @freeFunc: (allow-none) (scope call): a method to free each token (can be NULL).
+ * @newAndCopyFunc: (scope call): a method to create or copy each token.
+ * @user_data: (closure): a user defined pointer that will be given to
+ * the free and copy routine.
+ * 
+ * This method creates and allocates a new area to store nodes associated data that
+ * can be retrieve with the @key. These data are pointers on allocated memory
+ * locations. When the property is removed with the #visu_node_freePropertry (or the
+ * associated #VisuNodeArray is free) the area is free and @freeFunc is called for
+ * each token (or g_free() if @freeFunc is NULL).
+ *
+ * The method @newAndCopyFunc is used when the number of nodes is increased,
+ * if the const gpointer of the GCopyFunc is not NULL, then we require a copy,
+ * if it is NULL, then the routine must create a new token with default values.
+ *
+ * Returns: (transfer none): the newly created #VisuNodeProperty object.
+ */
+VisuNodeProperty* visu_node_property_newPointer(VisuNodeArray* nodeArray,
 					      const char* key, 
 					      GFunc freeFunc,
 					      GCopyFunc newAndCopyFunc,
@@ -776,7 +1025,19 @@ VisuNodeProperty* visuNodeNew_pointerProperty(VisuNodeArray* nodeArray,
   
   return prop;
 }
-VisuNodeProperty* visuNodeNew_intProperty(VisuNodeArray* nodeArray,
+
+/**
+ * visu_node_property_newInteger:
+ * @nodeArray: a #VisuNodeArray object ;
+ * @key: a string.
+ * 
+ * This method creates and allocates a new area to store nodes associated integer
+ * values. This is the same than visu_node_property_newPointer() but for static
+ * integers instead of pointers as data.
+ *
+ * Returns: (transfer none): the newly created #VisuNodeProperty object.
+ */
+VisuNodeProperty* visu_node_property_newInteger(VisuNodeArray* nodeArray,
 					  const char* key)
 {
   VisuNodeProperty *prop;
@@ -809,12 +1070,21 @@ VisuNodeProperty* visuNodeNew_intProperty(VisuNodeArray* nodeArray,
   
   return prop;
 }
-void visuNodeTrace_property(VisuNodeArray *array, const gchar *id)
+
+/**
+ * visu_node_array_traceProperty:
+ * @array: a #VisuNodeArray object ;
+ * @id: a property name.
+ *
+ * This is a debug method. It outputs on stderr the values for all
+ * nodes of the property @id.
+ */
+void visu_node_array_traceProperty(VisuNodeArray *array, const gchar *id)
 {
   VisuNodeProperty* prop;
   unsigned int i, j;
   
-  prop = visuNodeGet_property(array, id);
+  prop = visu_node_array_getProperty(array, id);
   
   fprintf(stderr, "Visu Node: output node property '%s'.\n", id);
   fprintf(stderr, " | type= %d\n", (int)prop->gtype);
