@@ -52,6 +52,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "visu_tools.h"
+#include "visu_rendering.h"
 
 G_BEGIN_DECLS
 
@@ -70,7 +71,7 @@ G_BEGIN_DECLS
 #define VISU(obj)		  (G_TYPE_CHECK_INSTANCE_CAST ((obj), VISU_TYPE, VisuObject))
 /**
  * VISU_CLASS:
- * @klass: a #GClassObject to cast.
+ * @klass: a #GObjectClass to cast.
  *
  * Cast the given @klass into #VisuObjectClass.
  */
@@ -84,7 +85,7 @@ G_BEGIN_DECLS
 #define IS_VISU_TYPE(obj)	  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VISU_TYPE))
 /**
  * IS_VISU_CLASS:
- * @klass: a #GClassObject to test.
+ * @klass: a #GObjectClass to test.
  *
  * Test if the given @klass is of the type of #VisuObjectClass class.
  */
@@ -114,7 +115,6 @@ enum
     RESOURCESLOADED_SIGNAL,
     OPENGLASKFORREDRAW_SIGNAL,
     OPENGLFORCEREDRAW_SIGNAL,
-    SPINAXES_SIGNAL,
     DIR_SIGNAL,
     VISU_NB_SIGNAL
   };
@@ -122,21 +122,7 @@ enum
 /**
  * VisuObjectClass:
  * @parent: an object to inherit from (NULL here).
- * @colorNewAvailable_signal_id: this signal is emitted when a new
- *   #Color has been added ;
- * @dataNew_signal_id: this signal is emitted each time a new #VisuData object
- *   is created. It should be used to attached signals to this object.
- * @dataLoaded_signal_id: this signal is emitted as soon as a new #VisuData is available,
- *                        it should be used to modify some values in it before rendering ;
- * @dataReadyForRendering_signal_id: this signal is emitted when a new #VisuData is available
- *                                   and when every modifications (following dataLoaded_signal_id
- *                                   signal) have been done ;
- * @renderingChanged_signal_id: emitted when the rendering method has been changed ;
- * @resourcesLoaded_signal_id: emitted when resources have been (re-)loaded ;
- * @OpenGLAskForReDraw_signal_id: emitted when a part of V_Sim needs to redraw ;
- * @OpenGLForceReDraw_signal_id: emitted when redraw is needed even if opegl part
- *                               does not allow redrawing operations ;
- * @SpinAxes_signal_id: ??
+ * @signals: the array with the signals.
  *
  * This structure describes the class #VisuObjectClass.
  */
@@ -146,27 +132,28 @@ struct _VisuObjectClass
 
   guint signals[VISU_NB_SIGNAL];
 };
-
-/**
- * VisuObjectClass:
- *
- * A short way to identify #_VisuObjectClass structure.
- */
 typedef struct _VisuObjectClass VisuObjectClass;
 
-/**
- * visuObjectRedraw:
- * @data: some data (unused).
- *
- * Call the signal OpenGLAskForReDraw. The API is adapted to the routine to be added
- * in the gloop.
- *
- * Returns: FALSE to stop the emission as soon as done.
- */
-gboolean visuObjectRedraw(gpointer data);
+gboolean visu_object_redraw(gpointer data);
+gboolean visu_object_redrawForce(gpointer data);
 
 /**
- * visu_get_type:
+ * VISU_ADD_REDRAW:
+ *
+ * A macro to ask V_Sim to redraw the rendering area at next idle
+ * time, except if the deferred redraw option is set.
+ */
+#define VISU_ADD_REDRAW   g_idle_add(visu_object_redraw, (gpointer)__func__)
+/**
+ * VISU_FORCE_REDRAW:
+ *
+ * Force V_Sim to redraw at the next idle time, whatever value for the
+ * deferred redraw option.
+ */
+#define VISU_FORCE_REDRAW g_idle_add(visu_object_redrawForce, (gpointer)__func__)
+
+/**
+ * visuObject_get_type:
  *
  * This method returns the type of #VisuObject, use VISU_TYPE instead.
  *
@@ -174,11 +161,25 @@ gboolean visuObjectRedraw(gpointer data);
  */
 GType visuObject_get_type (void);
 
+/**
+ * VISU_INSTANCE:
+ * 
+ * This routine is used to get the global #VisuObject object to listen
+ * to its signals.
+ */
 #define VISU_INSTANCE visuObjectGet_static()
-GObject* visuObjectGet_static();
+VisuObject* visuObjectGet_static();
 
+/**
+ * VISU_SIGNALS:
+ *
+ * Get the list of signals of a #VisuObject.
+ */
 #define VISU_SIGNALS VISU_GET_CLASS(VISU_INSTANCE)->signals
 
+gboolean visu_object_setRendering(VisuObject *obj, VisuRendering* method);
+VisuRendering* visu_object_getRendering(VisuObject *obj);
+
 G_END_DECLS
 
 #endif
