@@ -56,7 +56,7 @@
  * Plug-ins are made of shared library presenting some common routines. These routines are of kind:
  * <itemizedlist>
  * <listitem><para>
- * pluginsInitFunc(), such a routine is called at V_Sim startup. It should initialise all things required by the module. For instance, if the module is used to add a load method for atomic rendering, it should call renderingAtomicAdd_loadMethod() to declare itself to V_Sim.
+ * pluginsInitFunc(), such a routine is called at V_Sim startup. It should initialise all things required by the module. For instance, if the module is used to add a load method for atomic rendering, it should call visu_rendering_addFileFormat() to declare itself to V_Sim.
  * </para></listitem>
  * <listitem><para>
  * pluginsDescriptionFunc(), is used to get a short description of the plug-in.
@@ -75,19 +75,54 @@
  * </para>
  */
 
+/**
+ * VisuPlugin_struct:
+ * @hook: a pointer to the opened shared library ;
+ * @name: the name of the module (on UNIX it is lib{name}.so) ;
+ * @init: a pointer on the init method ;
+ * @getDescription: a pointer to the description method ;
+ * @getAuthors: a pointer to the author method.
+ * @getIcon: a pointer to the icon method.
+ *
+ * This structure is used to deals with a plugin. It gives handles
+ * to the public method of the plugin.
+ */
+struct _VisuPlugin
+{
+  GModule *hook;
+
+  gchar *name;
+
+  VisuPluginInitFunc init;
+  VisuPluginInitFunc initGtk;
+  VisuPluginInfoFunc getDescription;
+  VisuPluginInfoFunc getAuthors;
+  VisuPluginInfoFunc getIcon;
+};
+
 /* Local variables. */
-GList *presentPlugins;
+GList *presentPlugins = NULL;
 
 /* Local methods. */
-static gboolean visuPluginLoad_byPath(gchar* path);
+static gboolean visuPluginLoad_byPath(const gchar* path);
 
-
-GList* visuPluginsGet_listLoaded()
+/**
+ * visu_plugins_getListLoaded:
+ *
+ * On startup, plugins are loaded according to a list present in the configuration
+ * file. It is possible to access the list of all loaded plugins with this method.
+ *
+ * Returns: (element-type VisuPlugin) (transfer none): a #GList owned by V_Sim of #VisuPlugin objects.
+ */
+GList* visu_plugins_getListLoaded()
 {
+  if (!presentPlugins)
+    visu_plugins_init();
+
   return presentPlugins;
 }
 
-static gboolean visuPluginLoad_byPath(gchar* path)
+static gboolean visuPluginLoad_byPath(const gchar* path)
 {
   gchar *func, *name, *ptChar, *libname;
   VisuPlugin *plugin;
@@ -144,13 +179,13 @@ static gboolean visuPluginLoad_byPath(gchar* path)
       func = g_strdup_printf("%sGet_icon", name);
       res = g_module_symbol(plugin->hook, func, (void*)&(plugin->getIcon));
       if (!res)
-	plugin->getIcon = (pluginsIconFunc)0;
+	plugin->getIcon = (VisuPluginInfoFunc)0;
       g_free(func);
       func = g_strdup_printf("%sInitGtk", name);
       res = g_module_symbol(plugin->hook, func, (void*)&(plugin->initGtk));
       g_free(func);
       if (!res)
-	plugin->initGtk = (pluginsInitGtkFunc)0;
+	plugin->initGtk = (VisuPluginInitFunc)0;
       plugin->name = g_strdup(name);
       g_free(name);
       presentPlugins = g_list_prepend(presentPlugins, (gpointer)plugin);
@@ -166,7 +201,7 @@ static gboolean visuPluginLoad_byPath(gchar* path)
   return TRUE;
 }
 
-GList* visuPluginsParseDir(const gchar* path)
+static GList* visuPluginsParseDir(const gchar* path)
 {
   GDir *gdir;
   const gchar *fileFromDir;
@@ -187,13 +222,14 @@ GList* visuPluginsParseDir(const gchar* path)
       fileFromDir = g_dir_read_name(gdir);
     }
   g_dir_close(gdir);
+  g_pattern_spec_free(pattern);
   
   return lst;
 }
 
 /* Parse install directory and $XDG_CONFIG_HOME/v_sim/plugins to find
    files and create a gchar** array of names (as full path). */
-gchar** visuPluginsGet_installedPlugins()
+static gchar** visuPluginsGet_installedPlugins()
 {
   gchar **data, *path;
   GList* lst1, *lst2, *tmpLst;
@@ -231,14 +267,20 @@ gchar** visuPluginsGet_installedPlugins()
   return data;
 }
 
-void visuPluginsInit()
+/**
+ * visu_plugins_init:
+ *
+ * Initialise this part of code. Should not be called (called once
+ * by V_Sim on startup only). It try to load
+ * all plugins found in the installation directory and in the user directory.
+ */
+void visu_plugins_init()
 {
   gchar **plugins;
   gboolean res;
   int i;
 
-  presentPlugins = (GList*)0;
-  if (g_module_supported())
+  if (g_module_supported() && !presentPlugins)
     {
       plugins = visuPluginsGet_installedPlugins();
       for (i = 0; plugins[i]; i++)
@@ -248,9 +290,96 @@ void visuPluginsInit()
 	  res = visuPluginLoad_byPath(plugins[i]);
 	  if (res)
 	    ((VisuPlugin*)presentPlugins->data)->init();
-	  else
-	    g_warning("failure loading plugin '%s'!\n", plugins[i]);
 	}
       g_strfreev(plugins);
     }
 }
+
+/**
+ * visu_plugin_getName:
+ * @plug: a #VisuPlugin object.
+ *
+ * Return a string with the name.
+ *
+ * Returns: a private string.
+ *
+ * Since: 3.6
+ */
+const gchar* visu_plugin_getName(VisuPlugin *plug)
+{
+  g_return_val_if_fail(plug, (const gchar*)0);
+  
+  return plug->name;
+}
+/**
+ * visu_plugin_getDescription:
+ * @plug: a #VisuPlugin object.
+ *
+ * Return a string with the description of the plugin.
+ *
+ * Returns: a private string.
+ *
+ * Since: 3.6
+ */
+const gchar* visu_plugin_getDescription(VisuPlugin *plug)
+{
+  g_return_val_if_fail(plug, (const gchar*)0);
+
+  if (plug->getDescription)
+    return plug->getDescription();
+  else
+    return (const gchar*)0;
+}
+/**
+ * visu_plugin_getIconPath:
+ * @plug: a #VisuPlugin object.
+ *
+ * Return a string with the path to find an icon representing the plugin.
+ *
+ * Returns: a private string.
+ *
+ * Since: 3.6
+ */
+const gchar* visu_plugin_getIconPath(VisuPlugin *plug)
+{
+  g_return_val_if_fail(plug, (const gchar*)0);
+
+  if (plug->getIcon)
+    return plug->getIcon();
+  else
+    return (const gchar*)0;
+}
+/**
+ * visu_plugin_getAuthors:
+ * @plug: a #VisuPlugin object.
+ *
+ * Return a string with the list of authors.
+ *
+ * Returns: a private string.
+ *
+ * Since: 3.6
+ */
+const gchar* visu_plugin_getAuthors(VisuPlugin *plug)
+{
+  g_return_val_if_fail(plug, (const gchar*)0);
+
+  if (plug->getAuthors)
+    return plug->getAuthors();
+  else
+    return (const gchar*)0;
+}
+/**
+ * visu_plugin_initGtk:
+ * @plug: a #VisuPlugin object.
+ *
+ * Run the initGtk() method of the plugin, if it exists.
+ *
+ * Since: 3.6
+ */
+void visu_plugin_initGtk(VisuPlugin *plug)
+{
+  g_return_if_fail(plug);
+
+  if (plug->initGtk)
+    plug->initGtk();
+}
