@@ -46,89 +46,37 @@
 #include <gmodule.h>
 
 /**
- * pluginsInitFunc:
+ * VisuPluginInitFunc:
  *
  * This kind of method should exist in all plugins with the
  * name '{module_name}Init'. It is called by V_Sim when the module is loaded.
  *
  * Returns: TRUE if it loads correctly.
  */
-typedef gboolean (*pluginsInitFunc)();
-typedef gboolean (*pluginsInitGtkFunc)();
+typedef gboolean (*VisuPluginInitFunc)(void);
 /**
- * pluginsDescriptionFunc:
+ * VisuPluginInfoFunc:
  *
  * This kind of method should exist in all plugins it give a description of
  * what the plugin does. It must be named '{module_name}Get_description'.
  *
  * Returns: a string in UTF-8 owned by the plugin.
  */
-typedef const gchar* (*pluginsDescriptionFunc)();
-/**
- * pluginsAuthorsFunc:
- *
- * This kind of method should exist in all plugins it give the list of
- * the authors. It must be named '{module_name}Get_authors'.
- *
- * Returns: a string in UTF-8 owned by the plugin.
- */
-typedef const gchar* (*pluginsAuthorsFunc)();
-/**
- * pluginsIconFunc:
- *
- * This kind of method is not mandatory and it returns the path to
- * a loadable icon of 32x32 to illustrate the plug-in.
- *
- * Returns: a path owned by the plug-in.
- */
-typedef const gchar* (*pluginsIconFunc)();
+typedef const gchar* (*VisuPluginInfoFunc)(void);
 
-/**
- * VisuPlugin_struct:
- * @hook: a pointer to the opened shared library ;
- * @name: the name of the module (on UNIX it is lib{name}.so) ;
- * @init: a pointer on the init method ;
- * @getDescription: a pointer to the description method ;
- * @getAuthors: a pointer to the author method.
- * @getIcon: a pointer to the icon method.
- *
- * This structure is used to deals with a plugin. It gives handles
- * to the public method of the plugin.
- */
-struct VisuPlugin_struct
-{
-  GModule *hook;
-
-  gchar *name;
-
-  pluginsInitFunc init;
-  pluginsInitGtkFunc initGtk;
-  pluginsDescriptionFunc getDescription;
-  pluginsAuthorsFunc getAuthors;
-  pluginsIconFunc getIcon;
-};
+struct _VisuPlugin;
 /**
  * VisuPlugin:
  *
- * Short way to address #VisuPlugin_struct objects.
+ * Short way to address #_VisuPlugin objects.
  */
-typedef struct VisuPlugin_struct VisuPlugin;
+typedef struct _VisuPlugin VisuPlugin;
 
-/**
- * visuPluginsInit:
- *
- * Initialise this part of code. Should not be called (called once
- * by V_Sim on startup only). It try to load
- * all plugins found in the installation directory and in the user directory.
- */
-void visuPluginsInit();
+void visu_plugins_init();
+GList* visu_plugins_getListLoaded();
 
-/**
- * visuPluginsGet_listLoaded:
- *
- * On startup, plugins are loaded according to a list present in the configuration
- * file. It is possible to access the list of all loaded plugins with this method.
- *
- * Returns: a #GList owned by V_Sim of #VisuPlugin objects.
- */
-GList* visuPluginsGet_listLoaded();
+const gchar* visu_plugin_getName(VisuPlugin *plug);
+const gchar* visu_plugin_getDescription(VisuPlugin *plug);
+const gchar* visu_plugin_getIconPath(VisuPlugin *plug);
+const gchar* visu_plugin_getAuthors(VisuPlugin *plug);
+void visu_plugin_initGtk(VisuPlugin *plug);
