@@ -55,18 +55,8 @@
 G_BEGIN_DECLS
 
 #ifndef DEBUG
-/**
- * DEBUG:
- *
- * For developpers: use this macro to test if debug mode is on.
- */
   #define DEBUG 0
 #endif
-/**
- * DBG_fprintf:
- *
- * For developpers: use this macro instead of fprintf.
- */
 #define DBG_fprintf if(DEBUG) (void)fprintf
 
 #ifdef ENABLE_NLS
@@ -88,11 +78,6 @@ G_BEGIN_DECLS
 #  define N_(String) (String)
 #endif
 
-
-#define V_SIM_NAME          PACKAGE
-#define V_SIM_VERSION       VERSION
-#define V_SIM_WEB_SITE      "http://inac.cea.fr/L_Sim/V_Sim"
-
 /**
  * MAX_LINE_LENGTH
  *
@@ -102,13 +87,13 @@ G_BEGIN_DECLS
 #define MAX_LINE_LENGTH 256
 
 /**
- * voidDataFunc:
+ * ToolVoidDataFunc:
  * @data: a pointer to some user defined object.
  *
  * These methods are used when no specific argument is required except
  * a user-defined object and when void is the return type.
  */
-typedef void (*voidDataFunc)(gpointer data);
+typedef void (*ToolVoidDataFunc)(gpointer data);
 
 /**
  * VisuToolsInitFunc:
@@ -116,42 +101,7 @@ typedef void (*voidDataFunc)(gpointer data);
  * These methods are used by V_Sim to initialise some part of the
  * program. They are called once on start-up.
  */
-typedef void (*VisuToolsInitFunc)();
-
-/**
- * Property_struct:
- * @name: a pointer to a string, only used when DEBUG is on ;
- * @data: a pointer to an allocated memory area ;
- * @freeFunc: a destroy functon (can be NULL).
- *
- * This container can be used in hashtable to store whatever kind of
- * data that requires specific free functions.
- */
-struct Property_struct
-{
-  /* A convenient debug pointer on the name. */
-  const gchar *name;
-
-  /* This is a pointer to the data stored. */
-  gpointer data;
-  
-  /* This method is called when the table is freed. */
-  GDestroyNotify freeFunc;
-};
-/**
- * Property:
- *
- * A convenient name for #Property_struct.
- */
-typedef struct Property_struct Property;
-/**
- * freeProperty:
- * @prop: a #Property.
- *
- * It calls @freeFunc of @prop on its @data field (see #Property), if
- * @freeFunc is not NULL. Then the #Property itself is g_free().
- */
-void freeProperty(gpointer prop);
+typedef void (*VisuToolsInitFunc)(void);
 
 /**
  * getValidPath:
@@ -170,14 +120,6 @@ void freeProperty(gpointer prop);
  */
 gchar* getValidPath(GList **pathList, char *fileName, int accessMode);
 
-/**
- * visuWaitFunction:
- *
- * This function must be called in a blocking loop to update
- * different things like the gtk for example.
- */
-void visuWaitFunction();
-
 /**
  * fModulo:
  * @a: a float ;
@@ -233,18 +175,6 @@ gboolean g_file_set_contents(const gchar *fileName, const gchar *str,
 gboolean visuToolsSubstitute_XML(GString *output, const gchar *filename,
 				 const gchar *tag, GError **error);
 
-typedef enum
-  {
-    unit_undefined,
-    unit_bohr,
-    unit_angstroem,
-    unit_nanometer,
-    nb_units
-  } VisuUnits;
-const gchar** visuToolsGet_unitNames();
-float visuToolsGet_unitValueInMeter(VisuUnits unit);
-VisuUnits visuToolsGet_unitFromName(const gchar *name);
-
 G_END_DECLS
 
 #endif
